import * as i0 from '@angular/core';

/**
 * This component holds the right-aligned action buttons for the action bar.
 *
 * ```html
 * <div fd-action-bar>
 *     <div fd-action-bar-actions>
 *         <button fd-button [fdType]="'primary'">Cancel</button>
 *         <button fd-button [fdType]="'main'">Save</button>
 *     </div>
 * </div>
 * ```
 */
declare class ActionBarActionsDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionBarActionsDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ActionBarActionsDirective, "[fd-action-bar-actions]", never, {}, {}, never, never, true, never>;
}

/**
 * The left-aligned back button for the action bar.
 *
 * ```html
 * <div fd-action-bar>
 *     <div fd-action-bar-back>
 *         <button aria-label="back" fd-button [fdType]="'transparent'" [compact]="true" [glyph]="'nav-back'"></button>
 *     </div>
 * </div>
 * ```
 */
declare class ActionBarBackDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionBarBackDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ActionBarBackDirective, "[fd-action-bar-back]", never, {}, {}, never, never, true, never>;
}

/**
 * The action bar description.
 *
 * ```html
 * <div fd-action-bar>
 *     <div fd-action-bar-header>
 *         <div fd-action-bar-description>Page Description</div>
 *     </div>
 * <div>
 * ```
 */
declare class ActionBarDescriptionDirective {
    /** Whether the action bar also has a back button. */
    withBackBtn: boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionBarDescriptionDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ActionBarDescriptionDirective, "[fd-action-bar-description]", never, { "withBackBtn": { "alias": "withBackBtn"; "required": false; }; }, {}, never, never, true, never>;
}

/**
 * The action bar header, which contains the action bar's title and description components.
 *
 * ```html
 * <div fd-action-bar>
 *     <div fd-action-bar-header>
 *     </div>
 * </div>
 * ```
 */
declare class ActionBarHeaderDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionBarHeaderDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ActionBarHeaderDirective, "[fd-action-bar-header]", never, {}, {}, never, never, true, never>;
}

/**
 * The action bar mobile component. This component should wrap all other action bar components, including the `[fd-action-bar]`.
 *
 * ```html
 * <div fd-action-bar-mobile>
 *     <div fd-action-bar>
 *     </div>
 * </div>
 * ```
 */
declare class ActionBarMobileDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionBarMobileDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ActionBarMobileDirective, "[fd-action-bar-mobile]", never, {}, {}, never, never, true, never>;
}

/**
 * The action bar title component.
 *
 * ```html
 * <fd-action-bar>
 *     <div fd-action-bar-header>
 *         <div fd-action-bar-title>Page Title</div>
 *     </div>
 * <fd-action-bar>
 * ```
 */
declare class ActionBarTitleComponent {
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionBarTitleComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ActionBarTitleComponent, "[fd-action-bar-title]", never, {}, {}, never, ["*"], true, never>;
}

/**
 * @deprecated
 * Action Bar component is deprecated since version 0.40.0
 *
 * Children usage:
 * ```html
 * <div fd-action-bar-actions>
 * <div fd-action-bar-back>
 * <div fd-action-bar-description>
 * <div fd-action-bar-header>
 * <div fd-action-bar-mobile>
 * <div fd-action-bar-title>
 * ```
 */
declare class ActionBarComponent {
    /** @hidden */
    constructor();
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionBarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ActionBarComponent, "[fd-action-bar]", never, {}, {}, never, ["*"], true, never>;
}

/**
 * @deprecated
 * Use direct imports of components and directives.
 */
declare class ActionBarModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionBarModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<ActionBarModule, never, [typeof ActionBarComponent, typeof ActionBarTitleComponent, typeof ActionBarDescriptionDirective, typeof ActionBarHeaderDirective, typeof ActionBarActionsDirective, typeof ActionBarBackDirective, typeof ActionBarMobileDirective], [typeof ActionBarComponent, typeof ActionBarTitleComponent, typeof ActionBarDescriptionDirective, typeof ActionBarHeaderDirective, typeof ActionBarActionsDirective, typeof ActionBarBackDirective, typeof ActionBarMobileDirective]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<ActionBarModule>;
}

export { ActionBarActionsDirective, ActionBarBackDirective, ActionBarComponent, ActionBarDescriptionDirective, ActionBarHeaderDirective, ActionBarMobileDirective, ActionBarModule, ActionBarTitleComponent };
