import * as i0 from '@angular/core';
import { TemplateRef, OnInit, QueryList, OnChanges, InjectionToken } from '@angular/core';
import { Direction } from '@angular/cdk/bidi';
import { FocusableItem, Nullable, Size, FocusableItemDirective, CssClassBuilder, ColorAccent } from '@fundamental-ngx/cdk/utils';
import { Observable } from 'rxjs';
import * as i7 from '@angular/cdk/portal';

/**
 * Avatar group item directive, used to provide a template for the avatar group item.
 */
declare class AvatarGroupItemDirective {
    /**
     * Text, which will be displayed when in overflow popover and activated
     * */
    title: string;
    /**
     * If set to true, item will never be hidden in overflow popover
     * */
    forceVisibility: boolean;
    /** @hidden */
    _templateRef: TemplateRef<void>;
    /**
     * Template for the details of the avatar group item.
     * This template it used to render additional information in the overflow popover.
     * */
    set details(detailsTemplate: TemplateRef<void> | string);
    get details(): TemplateRef<void>;
    /** @hidden */
    private _details;
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarGroupItemDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AvatarGroupItemDirective, "[fdAvatarGroupItem]", never, { "title": { "alias": "fdAvatarGroupItemTitle"; "required": false; }; "forceVisibility": { "alias": "fdAvatarGroupItemForceVisibility"; "required": false; }; "details": { "alias": "fdAvatarGroupItem"; "required": false; }; }, {}, never, never, true, never>;
}

declare class AvatarGroupItemRendererDirective implements OnInit, FocusableItem {
    /**
     * Avatar group item to be rendered.
     **/
    avatarGroupItem: AvatarGroupItemDirective;
    /**
     * Whether the item should be forced to be visible.
     **/
    forceVisibility: boolean;
    /**
     * HTML element of the item.
     **/
    element$: Observable<Nullable<HTMLElement>>;
    /** @hidden */
    keydown: Observable<KeyboardEvent>;
    /**
     * Whether the item is visible.
     **/
    get visible(): boolean;
    /**
     * Currently rendered element's HTMLElement.
     **/
    get element(): HTMLElement;
    /**
     * Rendered element's width or it's last saved width.
     **/
    get width(): number;
    /**
     * Rendered element's height or it's last saved height.
     **/
    get height(): number;
    /** @hidden */
    private _portalOutlet;
    /** @hidden */
    private _viewContainerRef;
    /**
     * @hidden
     **/
    private _element$;
    /** @hidden */
    private _templatePortal?;
    /** @hidden */
    private _isFocusable;
    /** @hidden */
    private _embeddedViewRef;
    /** @hidden */
    private _lastSavedWidth;
    /** @hidden */
    private _lastSavedHeight;
    /** @hidden */
    private _hostConfig;
    /** @hidden */
    constructor();
    /** @hidden */
    ngOnInit(): void;
    /**
     * Hides the item.
     **/
    hide(): void;
    /**
     * Shows the item.
     **/
    show(): void;
    /**
     * Whether the item is focusable.
     **/
    isFocusable: () => boolean;
    /**
     * Sets the tabbable state of the item.
     **/
    setTabbable(tabbable: boolean): void;
    /** @hidden */
    focus(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarGroupItemRendererDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AvatarGroupItemRendererDirective, "[fdAvatarGroupItemPortal]", ["fdAvatarGroupItemPortal"], { "avatarGroupItem": { "alias": "avatarGroupItem"; "required": false; }; "forceVisibility": { "alias": "forceVisibility"; "required": false; }; }, {}, never, never, true, never>;
}

/**
 * Avatar group overflow body directive, used to provide a template for the avatar group overflow body.
 * If nothing is provided, default overflow body will be used.
 */
declare class AvatarGroupOverflowBodyDirective {
    /** @hidden */
    readonly _templateRef: TemplateRef<{
        hiddenItems: AvatarGroupItemRendererDirective[];
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarGroupOverflowBodyDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AvatarGroupOverflowBodyDirective, "[fdAvatarGroupOverflowBody]", never, {}, {}, never, never, true, never>;
}

/**
 * Avatar group overflow button directive, used to provide a template for the avatar group overflow button.
 * If nothing is provided, default overflow button will be used.
 */
declare class AvatarGroupOverflowButtonDirective {
    /** @hidden */
    readonly _templateRef: TemplateRef<{
        hiddenItems: AvatarGroupItemRendererDirective[];
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarGroupOverflowButtonDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AvatarGroupOverflowButtonDirective, "[fdAvatarGroupOverflowButton]", never, {}, {}, never, never, true, never>;
}

type AvatarGroupType = 'individual' | 'group';
type AvatarGroupOrientation = 'horizontal' | 'vertical';
type AvatarGroupSize = Size;
interface AvatarGroupHostConfig {
    type: AvatarGroupType;
    orientation: AvatarGroupOrientation;
    size: AvatarGroupSize;
}

declare class AvatarGroupComponent implements AvatarGroupHostConfig {
    /**
     * The AvatarGroup control has two group types:
     *
     * `group`: The avatars are displayed as partially overlapped on top of each other and the entire group has one click/tap area.
     * `individual`: The avatars are displayed side-by-side and each avatar has its own click/tap area.
     * */
    type: AvatarGroupHostConfig['type'];
    /**
     * Orientation of the AvatarGroup control.
     *
     * `horizontal`: The avatars are displayed horizontally.
     * `vertical`: The avatars are displayed vertically.
     */
    orientation: AvatarGroupHostConfig['orientation'];
    /**
     * The spacing between the items depends on the size of the avatars in the group.
     * The size is also used for the default overflow button.
     * `xs`, `s`, `m`, `l`, `xl`
     */
    size: AvatarGroupHostConfig['size'];
    /**
     * The title which is displayed when user opens the overflow popover.
     * This takes effect only when default overflow popover body is used,
     * otherwise the title should be set on the custom overflow popover body component.
     */
    overflowPopoverTitle: string;
    /** @hidden */
    _avatarRenderers: QueryList<AvatarGroupItemRendererDirective>;
    /** @hidden */
    _avatars: QueryList<AvatarGroupItemDirective>;
    /** @hidden */
    _overflowButton: AvatarGroupOverflowButtonDirective;
    /** @hidden */
    _avatarGroupPopoverBody: AvatarGroupOverflowBodyDirective;
    /** @hidden */
    _contentDirection$: i0.Signal<Direction>;
    /** @hidden */
    private readonly _cdr;
    /** @hidden */
    private readonly _rtlService;
    /** @hidden */
    _detectChanges(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarGroupComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AvatarGroupComponent, "fd-avatar-group", never, { "type": { "alias": "type"; "required": false; }; "orientation": { "alias": "orientation"; "required": false; }; "size": { "alias": "size"; "required": false; }; "overflowPopoverTitle": { "alias": "overflowPopoverTitle"; "required": false; }; }, {}, ["_overflowButton", "_avatarGroupPopoverBody", "_avatars"], ["*"], true, never>;
}

/**
 * Avatar group overflow button component.
 * This is used for the overflow button template.
 * Although any content can be projected as the overflow button, this component provides some styling and accessibility features.
 */
declare class AvatarGroupOverflowButtonComponent extends FocusableItemDirective implements OnChanges, OnInit, CssClassBuilder {
    /**
     * Size of the overflow button.
     */
    size: Size;
    /**
     * Whether the overflow button should be displayed as a circle.
     */
    circle: boolean;
    /**
     * A number from 1 to 10 representing the background color of the Avatar.
     */
    colorAccent: Nullable<ColorAccent>;
    /**
     * The class to apply to the host element.
     **/
    class: Nullable<string>;
    /** @hidden */
    constructor();
    /** @hidden */
    buildComponentCssClass(): string[];
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    ngOnChanges(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarGroupOverflowButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AvatarGroupOverflowButtonComponent, "fd-avatar-group-overflow-button", never, { "size": { "alias": "size"; "required": false; }; "circle": { "alias": "circle"; "required": false; }; "colorAccent": { "alias": "colorAccent"; "required": false; }; "class": { "alias": "class"; "required": false; }; }, {}, never, ["*"], true, never>;
}

/**
 * Avatar group overflow body component, used to provide a template for the avatar group overflow body.
 */
declare class AvatarGroupOverflowBodyComponent {
    /** Remove the padding from the overflow body. */
    noPadding: boolean;
    /** Hide horizontal scrollbar from the overflow body. */
    noHorizontalScroll: boolean;
    /** Hide vertical scrollbar from the overflow body. */
    noVerticalScroll: boolean;
    /** Additional popover body class */
    additionalPopoverBodyClass: string;
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarGroupOverflowBodyComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AvatarGroupOverflowBodyComponent, "fd-avatar-group-overflow-body", never, { "noPadding": { "alias": "noPadding"; "required": false; }; "noHorizontalScroll": { "alias": "noHorizontalScroll"; "required": false; }; "noVerticalScroll": { "alias": "noVerticalScroll"; "required": false; }; "additionalPopoverBodyClass": { "alias": "additionalPopoverBodyClass"; "required": false; }; }, {}, never, ["[fd-popover-body-header]", "[fd-avatar-group-overflow-body-content]"], true, never>;
}

declare class AvatarGroupModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<AvatarGroupModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<AvatarGroupModule, never, [typeof AvatarGroupComponent, typeof AvatarGroupItemDirective, typeof AvatarGroupOverflowButtonComponent, typeof AvatarGroupOverflowButtonDirective, typeof AvatarGroupOverflowBodyComponent, typeof AvatarGroupOverflowBodyDirective, typeof i7.PortalModule], [typeof AvatarGroupComponent, typeof AvatarGroupItemDirective, typeof AvatarGroupOverflowButtonComponent, typeof AvatarGroupOverflowButtonDirective, typeof AvatarGroupOverflowBodyComponent, typeof AvatarGroupOverflowBodyDirective]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<AvatarGroupModule>;
}

declare const AVATAR_GROUP_HOST_CONFIG: InjectionToken<AvatarGroupHostConfig>;

export { AVATAR_GROUP_HOST_CONFIG, AvatarGroupComponent, AvatarGroupItemDirective, AvatarGroupModule, AvatarGroupOverflowBodyComponent, AvatarGroupOverflowBodyDirective, AvatarGroupOverflowButtonComponent, AvatarGroupOverflowButtonDirective };
export type { AvatarGroupHostConfig, AvatarGroupOrientation, AvatarGroupSize, AvatarGroupType };
