import * as i0 from '@angular/core';
import { Directive, Input, HostBinding, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import { warnOnce } from '@fundamental-ngx/core/utils';

/**
 * This component holds the right-aligned action buttons for the action bar.
 *
 * ```html
 * <div fd-action-bar>
 *     <div fd-action-bar-actions>
 *         <button fd-button [fdType]="'primary'">Cancel</button>
 *         <button fd-button [fdType]="'main'">Save</button>
 *     </div>
 * </div>
 * ```
 */
class ActionBarActionsDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarActionsDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: ActionBarActionsDirective, isStandalone: true, selector: "[fd-action-bar-actions]", host: { classAttribute: "fd-action-bar__actions" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarActionsDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-action-bar-actions]',
                    host: {
                        class: 'fd-action-bar__actions'
                    },
                    standalone: true
                }]
        }] });

/**
 * The left-aligned back button for the action bar.
 *
 * ```html
 * <div fd-action-bar>
 *     <div fd-action-bar-back>
 *         <button aria-label="back" fd-button [fdType]="'transparent'" [compact]="true" [glyph]="'nav-back'"></button>
 *     </div>
 * </div>
 * ```
 */
class ActionBarBackDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarBackDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: ActionBarBackDirective, isStandalone: true, selector: "[fd-action-bar-back]", host: { classAttribute: "fd-action-bar__back" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarBackDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-action-bar-back]',
                    host: {
                        class: 'fd-action-bar__back'
                    },
                    standalone: true
                }]
        }] });

/**
 * The action bar description.
 *
 * ```html
 * <div fd-action-bar>
 *     <div fd-action-bar-header>
 *         <div fd-action-bar-description>Page Description</div>
 *     </div>
 * <div>
 * ```
 */
class ActionBarDescriptionDirective {
    constructor() {
        /** Whether the action bar also has a back button. */
        this.withBackBtn = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarDescriptionDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: ActionBarDescriptionDirective, isStandalone: true, selector: "[fd-action-bar-description]", inputs: { withBackBtn: "withBackBtn" }, host: { properties: { "class.fd-action-bar__description--back": "this.withBackBtn" }, classAttribute: "fd-action-bar__description" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarDescriptionDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-action-bar-description]',
                    host: {
                        class: 'fd-action-bar__description'
                    },
                    standalone: true
                }]
        }], propDecorators: { withBackBtn: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.fd-action-bar__description--back']
            }] } });

/**
 * The action bar header, which contains the action bar's title and description components.
 *
 * ```html
 * <div fd-action-bar>
 *     <div fd-action-bar-header>
 *     </div>
 * </div>
 * ```
 */
class ActionBarHeaderDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarHeaderDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: ActionBarHeaderDirective, isStandalone: true, selector: "[fd-action-bar-header]", host: { classAttribute: "fd-action-bar__header" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarHeaderDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-action-bar-header]',
                    host: {
                        class: 'fd-action-bar__header'
                    },
                    standalone: true
                }]
        }] });

/**
 * The action bar mobile component. This component should wrap all other action bar components, including the `[fd-action-bar]`.
 *
 * ```html
 * <div fd-action-bar-mobile>
 *     <div fd-action-bar>
 *     </div>
 * </div>
 * ```
 */
class ActionBarMobileDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarMobileDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: ActionBarMobileDirective, isStandalone: true, selector: "[fd-action-bar-mobile]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarMobileDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-action-bar-mobile]',
                    standalone: true
                }]
        }] });

/**
 * The action bar title component.
 *
 * ```html
 * <fd-action-bar>
 *     <div fd-action-bar-header>
 *         <div fd-action-bar-title>Page Title</div>
 *     </div>
 * <fd-action-bar>
 * ```
 */
class ActionBarTitleComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarTitleComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: ActionBarTitleComponent, isStandalone: true, selector: "[fd-action-bar-title]", host: { classAttribute: "fd-action-bar__title" }, ngImport: i0, template: `
        <h2 class="fd-title fd-title--h3">
            <ng-content></ng-content>
        </h2>
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarTitleComponent, decorators: [{
            type: Component,
            args: [{
                    // eslint-disable-next-line @angular-eslint/component-selector
                    selector: '[fd-action-bar-title]',
                    template: `
        <h2 class="fd-title fd-title--h3">
            <ng-content></ng-content>
        </h2>
    `,
                    host: {
                        class: 'fd-action-bar__title'
                    },
                    encapsulation: ViewEncapsulation.None,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true
                }]
        }] });

/**
 * @deprecated
 * Action Bar component is deprecated since version 0.40.0
 *
 * Children usage:
 * ```html
 * <div fd-action-bar-actions>
 * <div fd-action-bar-back>
 * <div fd-action-bar-description>
 * <div fd-action-bar-header>
 * <div fd-action-bar-mobile>
 * <div fd-action-bar-title>
 * ```
 */
class ActionBarComponent {
    /** @hidden */
    constructor() {
        warnOnce('ActionBarComponent is deprecated since version 0.40.0 and will be removed in future release.');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: ActionBarComponent, isStandalone: true, selector: "[fd-action-bar]", host: { classAttribute: "fd-action-bar" }, ngImport: i0, template: ` <ng-content></ng-content>`, isInline: true, styles: [".fd-action-bar{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-height:4.25rem;min-height:3rem;padding-block:0;padding-inline:0;word-wrap:break-word;padding-block:.5rem;-webkit-box-pack:justify;-ms-flex-pack:justify;background-color:var(--sapPageHeader_Background);-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow);justify-content:space-between;padding-inline:var(--fdActionBarInlinePadding,2rem)}.fd-action-bar:after,.fd-action-bar:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-action-bar__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;height:2rem}.fd-action-bar__header:after,.fd-action-bar__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-action-bar__back{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative;-webkit-margin-end:.5rem;margin-inline-end:.5rem}.fd-action-bar__back:after,.fd-action-bar__back:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}@media (min-width:320px){.fd-action-bar__back{display:none!important}}@media (min-width:600px){.fd-action-bar__back{display:inline-block!important}}.fd-action-bar__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;-ms-flex-preferred-size:0;flex-basis:0;line-height:1.375rem;margin-block:0;margin-inline:0;vertical-align:middle;-webkit-padding-end:.5rem;color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontHeaderFamily);padding-inline-end:.5rem;text-rendering:optimizeLegibility}.fd-action-bar__title:after,.fd-action-bar__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-action-bar__description{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:1.25rem;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;vertical-align:middle;white-space:nowrap;width:100%}.fd-action-bar__description:after,.fd-action-bar__description:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}@media (min-width:320px){.fd-action-bar__description{display:none!important}}@media (min-width:600px){.fd-action-bar__description{display:inline-block!important}}.fd-action-bar__description--back{-webkit-padding-start:2.5rem;padding-inline-start:2.5rem}.fd-action-bar__actions{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.5rem;height:2rem;-webkit-transition:opacity .25s ease-in;transition:opacity .25s ease-in;visibility:visible}.fd-action-bar__actions:after,.fd-action-bar__actions:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-action-bar__actions.is-hidden,.fd-action-bar__actions[aria-hidden=true]{opacity:0;visibility:hidden}.fd-action-bar--s,.fd-action-bar--sm{--fdActionBarInlinePadding:1rem}.fd-action-bar--lg,.fd-action-bar--m_l,.fd-action-bar--md{--fdActionBarInlinePadding:2rem}.fd-action-bar--xl{--fdActionBarInlinePadding:3rem}.fd-title{font-size:1rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;--fdTitle_Font_Size:1rem;--fdTitle_Color:var(--sapTextColor);--fdTitle_Font_Family:var(--sapFontHeaderFamily);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdTitle_Color);font-family:var(--sapFontFamily);font-family:var(--fdTitle_Font_Family);font-size:var(--sapFontSize);font-size:var(--fdTitle_Font_Size);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-title:after,.fd-title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-title--h1{--fdTitle_Font_Size:var(--sapFontHeader1Size)}.fd-title--h2{--fdTitle_Font_Size:var(--sapFontHeader2Size)}.fd-title--h3{--fdTitle_Font_Size:var(--sapFontHeader3Size)}.fd-title--h4{--fdTitle_Font_Size:var(--sapFontHeader4Size)}.fd-title--h5{--fdTitle_Font_Size:var(--sapFontHeader5Size)}.fd-title--h6{--fdTitle_Font_Size:var(--sapFontHeader6Size)}.fd-title--wrap{overflow:auto;text-overflow:clip;white-space:normal}\n/*! Bundled license information:\n\nfundamental-styles/dist/title.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarComponent, decorators: [{
            type: Component,
            args: [{ selector: '[fd-action-bar]', template: ` <ng-content></ng-content>`, host: {
                        class: 'fd-action-bar'
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, styles: [".fd-action-bar{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-height:4.25rem;min-height:3rem;padding-block:0;padding-inline:0;word-wrap:break-word;padding-block:.5rem;-webkit-box-pack:justify;-ms-flex-pack:justify;background-color:var(--sapPageHeader_Background);-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow);justify-content:space-between;padding-inline:var(--fdActionBarInlinePadding,2rem)}.fd-action-bar:after,.fd-action-bar:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-action-bar__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;height:2rem}.fd-action-bar__header:after,.fd-action-bar__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-action-bar__back{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative;-webkit-margin-end:.5rem;margin-inline-end:.5rem}.fd-action-bar__back:after,.fd-action-bar__back:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}@media (min-width:320px){.fd-action-bar__back{display:none!important}}@media (min-width:600px){.fd-action-bar__back{display:inline-block!important}}.fd-action-bar__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;-ms-flex-preferred-size:0;flex-basis:0;line-height:1.375rem;margin-block:0;margin-inline:0;vertical-align:middle;-webkit-padding-end:.5rem;color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontHeaderFamily);padding-inline-end:.5rem;text-rendering:optimizeLegibility}.fd-action-bar__title:after,.fd-action-bar__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-action-bar__description{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:1.25rem;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;vertical-align:middle;white-space:nowrap;width:100%}.fd-action-bar__description:after,.fd-action-bar__description:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}@media (min-width:320px){.fd-action-bar__description{display:none!important}}@media (min-width:600px){.fd-action-bar__description{display:inline-block!important}}.fd-action-bar__description--back{-webkit-padding-start:2.5rem;padding-inline-start:2.5rem}.fd-action-bar__actions{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.5rem;height:2rem;-webkit-transition:opacity .25s ease-in;transition:opacity .25s ease-in;visibility:visible}.fd-action-bar__actions:after,.fd-action-bar__actions:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-action-bar__actions.is-hidden,.fd-action-bar__actions[aria-hidden=true]{opacity:0;visibility:hidden}.fd-action-bar--s,.fd-action-bar--sm{--fdActionBarInlinePadding:1rem}.fd-action-bar--lg,.fd-action-bar--m_l,.fd-action-bar--md{--fdActionBarInlinePadding:2rem}.fd-action-bar--xl{--fdActionBarInlinePadding:3rem}.fd-title{font-size:1rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;--fdTitle_Font_Size:1rem;--fdTitle_Color:var(--sapTextColor);--fdTitle_Font_Family:var(--sapFontHeaderFamily);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdTitle_Color);font-family:var(--sapFontFamily);font-family:var(--fdTitle_Font_Family);font-size:var(--sapFontSize);font-size:var(--fdTitle_Font_Size);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-title:after,.fd-title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-title--h1{--fdTitle_Font_Size:var(--sapFontHeader1Size)}.fd-title--h2{--fdTitle_Font_Size:var(--sapFontHeader2Size)}.fd-title--h3{--fdTitle_Font_Size:var(--sapFontHeader3Size)}.fd-title--h4{--fdTitle_Font_Size:var(--sapFontHeader4Size)}.fd-title--h5{--fdTitle_Font_Size:var(--sapFontHeader5Size)}.fd-title--h6{--fdTitle_Font_Size:var(--sapFontHeader6Size)}.fd-title--wrap{overflow:auto;text-overflow:clip;white-space:normal}\n/*! Bundled license information:\n\nfundamental-styles/dist/title.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [] });

const components = [
    ActionBarComponent,
    ActionBarTitleComponent,
    ActionBarDescriptionDirective,
    ActionBarHeaderDirective,
    ActionBarActionsDirective,
    ActionBarBackDirective,
    ActionBarMobileDirective
];
/**
 * @deprecated
 * Use direct imports of components and directives.
 */
class ActionBarModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: ActionBarModule, imports: [ActionBarComponent,
            ActionBarTitleComponent,
            ActionBarDescriptionDirective,
            ActionBarHeaderDirective,
            ActionBarActionsDirective,
            ActionBarBackDirective,
            ActionBarMobileDirective], exports: [ActionBarComponent,
            ActionBarTitleComponent,
            ActionBarDescriptionDirective,
            ActionBarHeaderDirective,
            ActionBarActionsDirective,
            ActionBarBackDirective,
            ActionBarMobileDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ActionBarModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...components],
                    exports: [...components]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ActionBarActionsDirective, ActionBarBackDirective, ActionBarComponent, ActionBarDescriptionDirective, ActionBarHeaderDirective, ActionBarMobileDirective, ActionBarModule, ActionBarTitleComponent };
//# sourceMappingURL=fundamental-ngx-core-action-bar.mjs.map
