import { NgTemplateOutlet } from '@angular/common';
import * as i0 from '@angular/core';
import { InjectionToken, inject, TemplateRef, Input, Directive, ViewContainerRef, ElementRef, signal, DestroyRef, ChangeDetectorRef, ContentChildren, ViewEncapsulation, ChangeDetectionStrategy, Component, forwardRef, HostBinding, Renderer2, ViewChildren, computed, ContentChild, NgModule } from '@angular/core';
import { FDK_FOCUSABLE_ITEM_DIRECTIVE, ResizeObserverDirective, applyCssClass, FocusableItemDirective, RtlService, elementClick$, FocusableListDirective } from '@fundamental-ngx/cdk/utils';
import { PopoverBodyHeaderDirective, PopoverComponent, PopoverControlComponent, PopoverBodyDirective } from '@fundamental-ngx/core/popover';
import { __decorate, __metadata } from 'tslib';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { BehaviorSubject, fromEvent, Subject, combineLatest, map, startWith, delayWhen, animationFrames, merge } from 'rxjs';
import * as i1 from '@angular/cdk/portal';
import { CdkPortalOutlet, TemplatePortal, PortalModule } from '@angular/cdk/portal';
import { filter, switchMap } from 'rxjs/operators';
import { BarComponent, ButtonBarComponent, BarElementDirective, BarLeftDirective } from '@fundamental-ngx/core/bar';

const AVATAR_GROUP_HOST_CONFIG = new InjectionToken('AvatarGroup host configuration. Is provided by AvatarGroupComponent.');

/**
 * Avatar group item directive, used to provide a template for the avatar group item.
 */
class AvatarGroupItemDirective {
    constructor() {
        /**
         * If set to true, item will never be hidden in overflow popover
         * */
        this.forceVisibility = false;
        /** @hidden */
        this._templateRef = inject(TemplateRef);
    }
    /**
     * Template for the details of the avatar group item.
     * This template it used to render additional information in the overflow popover.
     * */
    set details(detailsTemplate) {
        if (typeof detailsTemplate === 'string') {
            return;
        }
        this._details = detailsTemplate;
    }
    get details() {
        return this._details;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupItemDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: AvatarGroupItemDirective, isStandalone: true, selector: "[fdAvatarGroupItem]", inputs: { title: ["fdAvatarGroupItemTitle", "title"], forceVisibility: ["fdAvatarGroupItemForceVisibility", "forceVisibility"], details: ["fdAvatarGroupItem", "details"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdAvatarGroupItem]',
                    standalone: true
                }]
        }], propDecorators: { title: [{
                type: Input,
                args: ['fdAvatarGroupItemTitle']
            }], forceVisibility: [{
                type: Input,
                args: ['fdAvatarGroupItemForceVisibility']
            }], details: [{
                type: Input,
                args: ['fdAvatarGroupItem']
            }] } });

class AvatarGroupItemRendererDirective {
    /**
     * Whether the item is visible.
     **/
    get visible() {
        return this._portalOutlet.hasAttached();
    }
    /**
     * Currently rendered element's HTMLElement.
     **/
    get element() {
        return this._embeddedViewRef?.rootNodes[0];
    }
    /**
     * Rendered element's width or it's last saved width.
     **/
    get width() {
        if (this.visible) {
            const rect = this.element.getBoundingClientRect();
            const style = getComputedStyle(this.element);
            const width = rect.width;
            const marginLeft = parseFloat(style.marginLeft);
            const marginRight = parseFloat(style.marginRight);
            if (!isNaN(width) && !isNaN(marginLeft) && !isNaN(marginRight)) {
                this._lastSavedWidth = width + marginLeft + marginRight;
            }
        }
        return this._lastSavedWidth;
    }
    /**
     * Rendered element's height or it's last saved height.
     **/
    get height() {
        if (this.visible) {
            this._lastSavedHeight =
                this.element.getBoundingClientRect().height +
                    parseFloat(getComputedStyle(this.element).marginTop) +
                    parseFloat(getComputedStyle(this.element).marginBottom);
        }
        return this._lastSavedHeight;
    }
    /** @hidden */
    constructor() {
        /**
         * Whether the item should be forced to be visible.
         **/
        this.forceVisibility = false;
        /** @hidden */
        this._portalOutlet = inject(CdkPortalOutlet, { host: true });
        /** @hidden */
        this._viewContainerRef = inject(ViewContainerRef);
        /**
         * @hidden
         **/
        this._element$ = new BehaviorSubject(null);
        /** @hidden */
        this._isFocusable = true;
        /** @hidden */
        this._lastSavedWidth = 0;
        /** @hidden */
        this._lastSavedHeight = 0;
        /** @hidden */
        this._hostConfig = inject(AVATAR_GROUP_HOST_CONFIG);
        /**
         * Whether the item is focusable.
         **/
        this.isFocusable = () => this._isFocusable && this.visible;
        this.element$ = this._element$.asObservable();
        this.keydown = this._element$.pipe(filter((element) => !!element), switchMap((element) => fromEvent(element, 'keydown')));
    }
    /** @hidden */
    ngOnInit() {
        this.show();
    }
    /**
     * Hides the item.
     **/
    hide() {
        this._portalOutlet.detach();
        this.setTabbable(false);
        this._isFocusable = false;
    }
    /**
     * Shows the item.
     **/
    show() {
        if (this.visible) {
            return;
        }
        if (!this._templatePortal) {
            this._templatePortal = new TemplatePortal(this.avatarGroupItem._templateRef, this._viewContainerRef);
        }
        this._embeddedViewRef = this._portalOutlet.attach(this._templatePortal);
        this._embeddedViewRef.detectChanges();
        this._element$.next(this.element);
        this.setTabbable(this._hostConfig.type === 'individual');
        this._isFocusable = this._hostConfig.type === 'individual';
    }
    /**
     * Sets the tabbable state of the item.
     **/
    setTabbable(tabbable) {
        this.element.tabIndex = tabbable ? 0 : -1;
    }
    /** @hidden */
    focus() {
        this.element?.focus();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupItemRendererDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: AvatarGroupItemRendererDirective, isStandalone: true, selector: "[fdAvatarGroupItemPortal]", inputs: { avatarGroupItem: "avatarGroupItem", forceVisibility: "forceVisibility" }, providers: [
            {
                provide: FDK_FOCUSABLE_ITEM_DIRECTIVE,
                useExisting: AvatarGroupItemRendererDirective
            },
            CdkPortalOutlet
        ], exportAs: ["fdAvatarGroupItemPortal"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupItemRendererDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdAvatarGroupItemPortal]',
                    exportAs: 'fdAvatarGroupItemPortal',
                    standalone: true,
                    providers: [
                        {
                            provide: FDK_FOCUSABLE_ITEM_DIRECTIVE,
                            useExisting: AvatarGroupItemRendererDirective
                        },
                        CdkPortalOutlet
                    ]
                }]
        }], ctorParameters: () => [], propDecorators: { avatarGroupItem: [{
                type: Input
            }], forceVisibility: [{
                type: Input
            }] } });

class AvatarGroupHostComponent {
    constructor() {
        /** @hidden */
        this._resizeEmitter = inject(ResizeObserverDirective).resized;
        /** The reference to the host element */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this._hiddenItems = signal([]);
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._cdr = inject(ChangeDetectorRef);
        /** @hidden */
        this._onChanges$ = new Subject();
    }
    /** @hidden */
    buildComponentCssClass() {
        return [
            this.class || '',
            'fd-avatar-group',
            this.type === 'individual' ? 'fd-avatar-group--individual-type' : '',
            this.type === 'group' ? 'fd-avatar-group--group-type' : '',
            this.orientation ? 'fd-avatar-group--' + this.orientation : '',
            this.size ? 'fd-avatar-group--' + this.size : ''
        ];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnChanges(changes) {
        this.buildComponentCssClass();
        this._onChanges$.next(changes);
    }
    /** @hidden */
    ngAfterViewInit() {
        combineLatest([
            this._resizeEmitter.pipe(map((entries) => entries[0].contentRect.width)),
            this._portals.changes.pipe(startWith(this._portals), map((r) => r.toArray())),
            this._onChanges$.pipe(startWith({}))
        ])
            .pipe(map(([containerWidth, items]) => this._calculateVisibility(containerWidth, items)), delayWhen(() => animationFrames()), takeUntilDestroyed(this._destroyRef))
            .subscribe(({ hiddenItems, visibleItems }) => {
            visibleItems.forEach((item) => item.show());
            hiddenItems.forEach((item) => item.hide());
            this._cdr.detectChanges();
            this._hiddenItems.set(hiddenItems);
        });
    }
    /** @hidden */
    _calculateVisibility(containerWidth, items) {
        if (this.orientation === 'vertical') {
            return {
                visibleItems: items,
                hiddenItems: []
            };
        }
        const visibleItems = items.filter((i) => i.forceVisibility);
        const hiddenItems = [];
        let accWidth = items.reduce((acc, item) => (item.forceVisibility ? acc + item.width : acc), 0);
        for (const item of items) {
            if (item.forceVisibility) {
                continue;
            }
            accWidth += item.width;
            if (accWidth <= containerWidth) {
                visibleItems.push(item);
            }
            else if (!item.forceVisibility) {
                hiddenItems.push(item);
            }
        }
        /* take last item from the visibleItems which is not forced to be visible and push it to the hiddenItems
         * This is done to free up the space for the overflow button
         */
        if (hiddenItems.length > 0) {
            const lastAllowedToBeHidden = visibleItems.reverse().findIndex((item) => !item.forceVisibility);
            hiddenItems.push(...visibleItems.splice(lastAllowedToBeHidden * -1, 1));
        }
        return {
            visibleItems,
            hiddenItems
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupHostComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: AvatarGroupHostComponent, isStandalone: true, selector: "fd-avatar-group-host", inputs: { class: "class", type: "type", orientation: "orientation", size: "size", items: "items" }, queries: [{ propertyName: "_portals", predicate: AvatarGroupItemRendererDirective, descendants: true }], usesOnChanges: true, ngImport: i0, template: '<ng-content></ng-content>', isInline: true, styles: ["fd-avatar-group-host{position:relative}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], AvatarGroupHostComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupHostComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-avatar-group-host', template: '<ng-content></ng-content>', imports: [], changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, styles: ["fd-avatar-group-host{position:relative}\n"] }]
        }], propDecorators: { class: [{
                type: Input
            }], type: [{
                type: Input
            }], orientation: [{
                type: Input
            }], size: [{
                type: Input
            }], items: [{
                type: Input
            }], _portals: [{
                type: ContentChildren,
                args: [AvatarGroupItemRendererDirective, { descendants: true }]
            }], buildComponentCssClass: [] } });

/**
 * Avatar group overflow button component.
 * This is used for the overflow button template.
 * Although any content can be projected as the overflow button, this component provides some styling and accessibility features.
 */
class AvatarGroupOverflowButtonComponent extends FocusableItemDirective {
    /** @hidden */
    constructor() {
        super();
        /**
         * Size of the overflow button.
         */
        this.size = 'l';
        /**
         * Whether the overflow button should be displayed as a circle.
         */
        this.circle = false;
        /**
         * A number from 1 to 10 representing the background color of the Avatar.
         */
        this.colorAccent = null;
        this.fdkFocusableItem = inject(AVATAR_GROUP_HOST_CONFIG).type === 'individual';
    }
    /** @hidden */
    buildComponentCssClass() {
        return [
            this.class || '',
            'fd-avatar fd-avatar--overflow',
            'fd-avatar--' + this.size,
            this.colorAccent ? 'fd-avatar--' + this.colorAccent : ''
        ];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupOverflowButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: AvatarGroupOverflowButtonComponent, isStandalone: true, selector: "fd-avatar-group-overflow-button", inputs: { size: "size", circle: "circle", colorAccent: "colorAccent", class: "class" }, host: { attributes: { "role": "button" }, properties: { "class.fd-avatar--circle": "this.circle" } }, providers: [
            {
                provide: FDK_FOCUSABLE_ITEM_DIRECTIVE,
                useExisting: forwardRef(() => AvatarGroupOverflowButtonComponent)
            }
        ], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: ` <ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], AvatarGroupOverflowButtonComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupOverflowButtonComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-avatar-group-overflow-button',
                    template: ` <ng-content></ng-content>`,
                    host: {
                        role: 'button'
                    },
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    standalone: true,
                    providers: [
                        {
                            provide: FDK_FOCUSABLE_ITEM_DIRECTIVE,
                            useExisting: forwardRef(() => AvatarGroupOverflowButtonComponent)
                        }
                    ]
                }]
        }], ctorParameters: () => [], propDecorators: { size: [{
                type: Input
            }], circle: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.fd-avatar--circle']
            }], colorAccent: [{
                type: Input
            }], class: [{
                type: Input
            }], buildComponentCssClass: [] } });

class DefaultAvatarGroupOverflowBodyComponent {
    constructor() {
        /**
         * List of avatars to be rendered in the overflow popover.
         **/
        this.avatars = [];
        /** @hidden */
        this._overflowPopoverStage = 'main';
        /** @hidden */
        this._changeDetectorRef = inject(ChangeDetectorRef);
        /** @hidden */
        this._renderer = inject(Renderer2);
        /** @hidden */
        this._rtlService = inject(RtlService, { optional: true });
    }
    /** @hidden */
    get _isDetailStage() {
        return this._overflowPopoverStage === 'details';
    }
    /** @hidden */
    get isRtl() {
        return !!this._rtlService?.rtl.value;
    }
    /** @hidden */
    ngAfterViewInit() {
        this._avatarGroupItemPortals.changes
            .pipe(startWith(this._avatarGroupItemPortals), map((avatarGroupItemPortals) => avatarGroupItemPortals.toArray()))
            .subscribe((items) => {
            if (this._itemClickSubscription) {
                this._itemClickSubscription.unsubscribe();
            }
            this._itemClickSubscription = merge(...items.map((item) => item.element$.pipe(filter(Boolean), switchMap((el) => elementClick$(el, this._renderer).pipe(map(() => item)))))).subscribe((item) => {
                this._overflowPopoverStage = 'details';
                this._selectedItem = item.avatarGroupItem;
                this._changeDetectorRef.detectChanges();
            });
        });
    }
    /** @hidden */
    ngOnDestroy() {
        if (this._itemClickSubscription) {
            this._itemClickSubscription.unsubscribe();
        }
    }
    /** @hidden */
    _openOverflowMain() {
        this._overflowPopoverStage = 'main';
        this._changeDetectorRef.detectChanges();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DefaultAvatarGroupOverflowBodyComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: DefaultAvatarGroupOverflowBodyComponent, isStandalone: true, selector: "fd-default-avatar-group-overflow-body", inputs: { avatars: "avatars", overflowPopoverTitle: "overflowPopoverTitle" }, host: { properties: { "style.max-width.rem": "20" }, classAttribute: "fd-popover__wrapper" }, viewQueries: [{ propertyName: "_avatarGroupItemPortals", predicate: AvatarGroupItemRendererDirective, descendants: true }], ngImport: i0, template: "<div fd-popover-body-header>\n    <div fd-bar barDesign=\"header\">\n        <div fd-bar-left>\n            @if (_isDetailStage) {\n                <fd-button-bar\n                    (click)=\"_openOverflowMain()\"\n                    [glyph]=\"isRtl ? 'navigation-right-arrow' : 'navigation-left-arrow'\"\n                    fdType=\"transparent\"\n                    aria-label=\"Back\"\n                    title=\"Back\"\n                ></fd-button-bar>\n            }\n            <fd-bar-element>\n                {{ _isDetailStage ? _selectedItem.title : overflowPopoverTitle }}\n            </fd-bar-element>\n            @if (_isDetailStage) {\n                <fd-bar-element>&nbsp;</fd-bar-element>\n            }\n        </div>\n    </div>\n</div>\n<div\n    class=\"fd-avatar-group__overflow-body\"\n    [class.fd-avatar-group__overflow-body--no-padding]=\"_isDetailStage\"\n    [class.fd-avatar-group__overflow-body--no-horizontal-scroll]=\"_isDetailStage\"\n    fdkFocusableList\n    navigationDirection=\"horizontal\"\n>\n    @if (_overflowPopoverStage === 'main') {\n        @for (item of avatars; track item) {\n            <ng-template\n                cdkPortalOutlet\n                fdAvatarGroupItemPortal\n                [avatarGroupItem]=\"item.avatarGroupItem\"\n                [forceVisibility]=\"true\"\n            >\n            </ng-template>\n        }\n    } @else {\n        <ng-template [ngTemplateOutlet]=\"_selectedItem.details\"></ng-template>\n    }\n</div>\n", styles: ["fd-default-avatar-group-overflow-body{display:flex;flex-direction:column}\n"], dependencies: [{ kind: "ngmodule", type: PortalModule }, { kind: "directive", type: i1.CdkPortalOutlet, selector: "[cdkPortalOutlet]", inputs: ["cdkPortalOutlet"], outputs: ["attached"], exportAs: ["cdkPortalOutlet"] }, { kind: "directive", type: AvatarGroupItemRendererDirective, selector: "[fdAvatarGroupItemPortal]", inputs: ["avatarGroupItem", "forceVisibility"], exportAs: ["fdAvatarGroupItemPortal"] }, { kind: "directive", type: FocusableListDirective, selector: "[fdkFocusableList]", inputs: ["focusable", "navigationDirection", "contentDirection", "wrap", "listFocusedEventAnnouncer"], outputs: ["itemFocused"], exportAs: ["fdkFocusableList"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: PopoverBodyHeaderDirective, selector: "[fdPopoverBodyHeader], [fd-popover-body-header]" }, { kind: "component", type: BarComponent, selector: "[fd-bar]", inputs: ["class", "barDesign", "inPage", "inHomePage", "size", "role"] }, { kind: "component", type: ButtonBarComponent, selector: "fd-button-bar", inputs: ["fullWidth", "fdType", "title", "ariaLabelledby", "id"] }, { kind: "directive", type: BarElementDirective, selector: "fd-bar-element", inputs: ["fullWidth"] }, { kind: "directive", type: BarLeftDirective, selector: "[fd-bar-left]" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DefaultAvatarGroupOverflowBodyComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-default-avatar-group-overflow-body', imports: [
                        PortalModule,
                        AvatarGroupItemRendererDirective,
                        FocusableListDirective,
                        NgTemplateOutlet,
                        PopoverBodyHeaderDirective,
                        BarComponent,
                        ButtonBarComponent,
                        BarElementDirective,
                        BarLeftDirective
                    ], host: {
                        class: 'fd-popover__wrapper',
                        '[style.max-width.rem]': '20'
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, template: "<div fd-popover-body-header>\n    <div fd-bar barDesign=\"header\">\n        <div fd-bar-left>\n            @if (_isDetailStage) {\n                <fd-button-bar\n                    (click)=\"_openOverflowMain()\"\n                    [glyph]=\"isRtl ? 'navigation-right-arrow' : 'navigation-left-arrow'\"\n                    fdType=\"transparent\"\n                    aria-label=\"Back\"\n                    title=\"Back\"\n                ></fd-button-bar>\n            }\n            <fd-bar-element>\n                {{ _isDetailStage ? _selectedItem.title : overflowPopoverTitle }}\n            </fd-bar-element>\n            @if (_isDetailStage) {\n                <fd-bar-element>&nbsp;</fd-bar-element>\n            }\n        </div>\n    </div>\n</div>\n<div\n    class=\"fd-avatar-group__overflow-body\"\n    [class.fd-avatar-group__overflow-body--no-padding]=\"_isDetailStage\"\n    [class.fd-avatar-group__overflow-body--no-horizontal-scroll]=\"_isDetailStage\"\n    fdkFocusableList\n    navigationDirection=\"horizontal\"\n>\n    @if (_overflowPopoverStage === 'main') {\n        @for (item of avatars; track item) {\n            <ng-template\n                cdkPortalOutlet\n                fdAvatarGroupItemPortal\n                [avatarGroupItem]=\"item.avatarGroupItem\"\n                [forceVisibility]=\"true\"\n            >\n            </ng-template>\n        }\n    } @else {\n        <ng-template [ngTemplateOutlet]=\"_selectedItem.details\"></ng-template>\n    }\n</div>\n", styles: ["fd-default-avatar-group-overflow-body{display:flex;flex-direction:column}\n"] }]
        }], propDecorators: { avatars: [{
                type: Input
            }], overflowPopoverTitle: [{
                type: Input
            }], _avatarGroupItemPortals: [{
                type: ViewChildren,
                args: [AvatarGroupItemRendererDirective]
            }] } });

class AvatarGroupInternalOverflowButtonDirective {
    constructor() {
        /** @hidden */
        this._templateContext = { $implicit: [] };
        /** @hidden */
        this._templateRef = inject(TemplateRef);
        /** @hidden */
        this._viewContainerRef = inject(ViewContainerRef);
    }
    /**
     * List of hidden items to be rendered in the overflow popover.
     **/
    set hiddenItems(value) {
        const hiddenItems = value || [];
        if (hiddenItems.length > 0) {
            this._show(hiddenItems);
        }
        else {
            this._hide();
        }
    }
    /** @hidden */
    static ngTemplateContextGuard(_directive, context) {
        return true;
    }
    /** @hidden */
    ngOnDestroy() {
        this._hide();
    }
    /** @hidden */
    _show(hiddenItems) {
        this._templateContext.$implicit = hiddenItems;
        if (this._embeddedView) {
            this._embeddedView.detectChanges();
            return;
        }
        this._viewContainerRef.clear();
        this._embeddedView = this._viewContainerRef.createEmbeddedView(this._templateRef, this._templateContext);
        this._embeddedView.detectChanges();
    }
    /** @hidden */
    _hide() {
        this._viewContainerRef.clear();
        this._embeddedView = undefined;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupInternalOverflowButtonDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: AvatarGroupInternalOverflowButtonDirective, isStandalone: true, selector: "[fdAvatarGroupInternalOverflowButton]", inputs: { hiddenItems: ["fdAvatarGroupInternalOverflowButton", "hiddenItems"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupInternalOverflowButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdAvatarGroupInternalOverflowButton]',
                    standalone: true
                }]
        }], propDecorators: { hiddenItems: [{
                type: Input,
                args: ['fdAvatarGroupInternalOverflowButton']
            }] } });

/**
 * Avatar group overflow body directive, used to provide a template for the avatar group overflow body.
 * If nothing is provided, default overflow body will be used.
 */
class AvatarGroupOverflowBodyDirective {
    constructor() {
        /** @hidden */
        this._templateRef = inject(TemplateRef);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupOverflowBodyDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: AvatarGroupOverflowBodyDirective, isStandalone: true, selector: "[fdAvatarGroupOverflowBody]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupOverflowBodyDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdAvatarGroupOverflowBody]',
                    standalone: true
                }]
        }] });

/**
 * Avatar group overflow button directive, used to provide a template for the avatar group overflow button.
 * If nothing is provided, default overflow button will be used.
 */
class AvatarGroupOverflowButtonDirective {
    constructor() {
        /** @hidden */
        this._templateRef = inject(TemplateRef);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupOverflowButtonDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: AvatarGroupOverflowButtonDirective, isStandalone: true, selector: "[fdAvatarGroupOverflowButton]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupOverflowButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdAvatarGroupOverflowButton]',
                    standalone: true
                }]
        }] });

class AvatarGroupComponent {
    constructor() {
        /**
         * The AvatarGroup control has two group types:
         *
         * `group`: The avatars are displayed as partially overlapped on top of each other and the entire group has one click/tap area.
         * `individual`: The avatars are displayed side-by-side and each avatar has its own click/tap area.
         * */
        this.type = 'individual';
        /**
         * Orientation of the AvatarGroup control.
         *
         * `horizontal`: The avatars are displayed horizontally.
         * `vertical`: The avatars are displayed vertically.
         */
        this.orientation = 'horizontal';
        /**
         * The spacing between the items depends on the size of the avatars in the group.
         * The size is also used for the default overflow button.
         * `xs`, `s`, `m`, `l`, `xl`
         */
        this.size = 'l';
        /** @hidden */
        this._contentDirection$ = computed(() => (this._rtlService?.rtlSignal() ? 'rtl' : 'ltr'));
        /** @hidden */
        this._cdr = inject(ChangeDetectorRef);
        /** @hidden */
        this._rtlService = inject(RtlService, { optional: true });
    }
    /** @hidden */
    _detectChanges() {
        this._cdr.detectChanges();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: AvatarGroupComponent, isStandalone: true, selector: "fd-avatar-group", inputs: { type: "type", orientation: "orientation", size: "size", overflowPopoverTitle: "overflowPopoverTitle" }, providers: [
            {
                provide: AVATAR_GROUP_HOST_CONFIG,
                useExisting: AvatarGroupComponent
            }
        ], queries: [{ propertyName: "_overflowButton", first: true, predicate: AvatarGroupOverflowButtonDirective, descendants: true }, { propertyName: "_avatarGroupPopoverBody", first: true, predicate: AvatarGroupOverflowBodyDirective, descendants: true }, { propertyName: "_avatars", predicate: AvatarGroupItemDirective }], viewQueries: [{ propertyName: "_avatarRenderers", predicate: AvatarGroupItemRendererDirective, descendants: true }], ngImport: i0, template: "<ng-content></ng-content>\n@if (type === 'individual') {\n    <fd-avatar-group-host\n        #avatarGroupHostComponent\n        [type]=\"type\"\n        [size]=\"size\"\n        [orientation]=\"orientation\"\n        fdkResizeObserver\n        fdkFocusableList\n        [contentDirection]=\"_contentDirection$()\"\n        [wrap]=\"true\"\n        [navigationDirection]=\"orientation\"\n        [items]=\"_avatars\"\n        (resized)=\"_detectChanges()\"\n    >\n        @for (item of _avatars; track item) {\n            <fd-popover [noArrow]=\"false\" [focusAutoCapture]=\"true\">\n                <fd-popover-control tabindex=\"-1\" (click)=\"outletItem.element.focus()\">\n                    <ng-template\n                        #outletItem=\"fdAvatarGroupItemPortal\"\n                        cdkPortalOutlet\n                        fdAvatarGroupItemPortal\n                        [forceVisibility]=\"item.forceVisibility\"\n                        [avatarGroupItem]=\"item\"\n                    >\n                    </ng-template>\n                </fd-popover-control>\n                @if (item.details) {\n                    <ng-template fdPopoverBody>\n                        <ng-template [ngTemplateOutlet]=\"item.details\"></ng-template>\n                    </ng-template>\n                }\n            </fd-popover>\n        }\n        <fd-popover\n            [noArrow]=\"false\"\n            [focusAutoCapture]=\"true\"\n            *fdAvatarGroupInternalOverflowButton=\"avatarGroupHostComponent._hiddenItems(); let hiddenItems\"\n        >\n            <fd-popover-control tabindex=\"-1\">\n                <ng-template\n                    [ngTemplateOutlet]=\"overflowButtonTemplate\"\n                    [ngTemplateOutletContext]=\"{ $implicit: hiddenItems }\"\n                ></ng-template>\n            </fd-popover-control>\n            <ng-template fdPopoverBody>\n                <ng-template\n                    [ngTemplateOutlet]=\"avatarGroupOverflowBodyTemplate\"\n                    [ngTemplateOutletContext]=\"{ $implicit: hiddenItems }\"\n                ></ng-template>\n            </ng-template>\n        </fd-popover>\n    </fd-avatar-group-host>\n} @else {\n    <fd-popover [noArrow]=\"false\" [focusAutoCapture]=\"true\" fdkResizeObserver (resized)=\"_detectChanges()\">\n        <fd-popover-control>\n            <fd-avatar-group-host\n                #avatarGroupHostComponent\n                [type]=\"type\"\n                [size]=\"size\"\n                [orientation]=\"orientation\"\n                [fdkFocusableItem]=\"true\"\n            >\n                @for (item of _avatars; track item) {\n                    <ng-template\n                        cdkPortalOutlet\n                        fdAvatarGroupItemPortal\n                        [forceVisibility]=\"item.forceVisibility\"\n                        [avatarGroupItem]=\"item\"\n                    >\n                    </ng-template>\n                }\n                <ng-template\n                    [fdAvatarGroupInternalOverflowButton]=\"avatarGroupHostComponent._hiddenItems()\"\n                    let-hiddenItems\n                >\n                    <ng-template\n                        [ngTemplateOutlet]=\"overflowButtonTemplate\"\n                        [ngTemplateOutletContext]=\"{ $implicit: hiddenItems }\"\n                    ></ng-template>\n                </ng-template>\n            </fd-avatar-group-host>\n        </fd-popover-control>\n        <ng-template fdPopoverBody>\n            <ng-template\n                [ngTemplateOutlet]=\"avatarGroupOverflowBodyTemplate\"\n                [ngTemplateOutletContext]=\"{ $implicit: _avatarRenderers }\"\n            ></ng-template>\n        </ng-template>\n    </fd-popover>\n}\n<ng-template #overflowButtonTemplate let-hiddenItems>\n    @if (_overflowButton) {\n        <ng-template\n            [ngTemplateOutlet]=\"_overflowButton._templateRef\"\n            [ngTemplateOutletContext]=\"{ hiddenItems: hiddenItems }\"\n        />\n    } @else {\n        <fd-avatar-group-overflow-button [size]=\"size\" [colorAccent]=\"1\">\n            +{{ hiddenItems.length }}\n        </fd-avatar-group-overflow-button>\n    }\n</ng-template>\n<ng-template #avatarGroupOverflowBodyTemplate let-hiddenItems>\n    @if (_avatarGroupPopoverBody) {\n        <ng-template\n            [ngTemplateOutlet]=\"_avatarGroupPopoverBody._templateRef\"\n            [ngTemplateOutletContext]=\"{ hiddenItems: hiddenItems }\"\n        />\n    } @else {\n        <fd-default-avatar-group-overflow-body [avatars]=\"hiddenItems\" [overflowPopoverTitle]=\"overflowPopoverTitle\" />\n    }\n</ng-template>\n", styles: [".fd-avatar{--fdAvatarZoomIconPosition:0;background-color:var(--fdAvatarBackgroundColor);background-position:50%;background-repeat:no-repeat;background-size:var(--fdAvatarBackgroundSize);border:0;border:var(--fdAvatarBorderWidth, .0625rem) solid var(--fdAvatarBorderColor);border-radius:var(--fdAvatarBorderRadius);-webkit-box-shadow:var(--fdAvatarBoxShadow);box-shadow:var(--fdAvatarBoxShadow);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdAvatarColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdAvatarFontSize);font-stretch:var(--fdAvatarFontStretch);font-weight:400;forced-color-adjust:none;height:var(--fdAvatarRatio);line-height:normal;margin-block:0;margin-inline:0;max-height:var(--fdAvatarRatio);max-width:var(--fdAvatarRatio);min-height:var(--fdAvatarRatio);min-width:var(--fdAvatarRatio);padding-block:0;padding-inline:0;position:relative;text-shadow:var(--fdAvatarTextShadow);vertical-align:middle;width:var(--fdAvatarRatio)}.fd-avatar:after,.fd-avatar:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-avatar.is-focus,.fd-avatar:focus{outline:none}.fd-avatar.is-focus:after,.fd-avatar:focus:after{border-color:var(--sapContent_FocusColor);border-radius:var(--fdAvatar_Focus_Outline_Radius);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset);pointer-events:none;position:absolute}.fd-avatar--interactive,.fd-avatar[role=button],.fd-avatar[tabindex=\"0\"]{cursor:pointer}.fd-avatar--interactive.is-hover,.fd-avatar--interactive:hover,.fd-avatar[role=button].is-hover,.fd-avatar[role=button]:hover,.fd-avatar[tabindex=\"0\"].is-hover,.fd-avatar[tabindex=\"0\"]:hover{--fdAvatarBorderColor:var(--fdAvatarBorderHoverColor,var(--sapAvatar_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarHoverBackgroundColor,var(--sapAvatar_6_Hover_Background))}.fd-avatar--interactive.is-disabled,.fd-avatar--interactive:disabled,.fd-avatar--interactive[aria-disabled=true],.fd-avatar[role=button].is-disabled,.fd-avatar[role=button]:disabled,.fd-avatar[role=button][aria-disabled=true],.fd-avatar[tabindex=\"0\"].is-disabled,.fd-avatar[tabindex=\"0\"]:disabled,.fd-avatar[tabindex=\"0\"][aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity)}.fd-avatar--interactive.is-active,.fd-avatar--interactive:active,.fd-avatar[role=button].is-active,.fd-avatar[role=button]:active,.fd-avatar[tabindex=\"0\"].is-active,.fd-avatar[tabindex=\"0\"]:active{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar--interactive.is-active.is-hover,.fd-avatar--interactive.is-active:hover,.fd-avatar--interactive:active.is-hover,.fd-avatar--interactive:active:hover,.fd-avatar[role=button].is-active.is-hover,.fd-avatar[role=button].is-active:hover,.fd-avatar[role=button]:active.is-hover,.fd-avatar[role=button]:active:hover,.fd-avatar[tabindex=\"0\"].is-active.is-hover,.fd-avatar[tabindex=\"0\"].is-active:hover,.fd-avatar[tabindex=\"0\"]:active.is-hover,.fd-avatar[tabindex=\"0\"]:active:hover{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar--interactive.is-toggled,.fd-avatar[role=button].is-toggled,.fd-avatar[tabindex=\"0\"].is-toggled{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar--interactive.is-toggled.is-hover,.fd-avatar--interactive.is-toggled:hover,.fd-avatar[role=button].is-toggled.is-hover,.fd-avatar[role=button].is-toggled:hover,.fd-avatar[tabindex=\"0\"].is-toggled.is-hover,.fd-avatar[tabindex=\"0\"].is-toggled:hover{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar--interactive.is-focus,.fd-avatar--interactive:focus,.fd-avatar[role=button].is-focus,.fd-avatar[role=button]:focus,.fd-avatar[tabindex=\"0\"].is-focus,.fd-avatar[tabindex=\"0\"]:focus{padding-block:.125rem;padding-inline:.125rem;z-index:5}.fd-avatar__zoom-icon{--fdAvatarZoomIconColor:var(--sapButton_Emphasized_TextColor);--fdAvatarZoomIconBorderColor:var(--sapButton_Emphasized_BorderColor);--fdAvatarZoomIconBackground:var(--sapButton_Emphasized_Background)}.fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdAvatarZoomIconBackground);border:.0625rem solid var(--fdAvatarZoomIconBorderColor);border-radius:100%;color:var(--fdAvatarZoomIconColor);font-size:var(--fdAvatarZoomIconFontSize);height:var(--fdAvatarZoomIconDimensions);min-width:var(--fdAvatarZoomIconDimensions);position:absolute;width:var(--fdAvatarZoomIconDimensions);z-index:5}.fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon],.fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon]{bottom:var(--fdAvatarZoomIconPosition);right:var(--fdAvatarZoomIconPosition)}.fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon][dir=rtl],[dir=rtl] .fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon]{left:var(--fdAvatarZoomIconPosition);right:auto}.fd-avatar__zoom-icon--positive{--fdAvatarZoomIconColor:var(--sapPositiveTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapSuccessBackground)}.fd-avatar__zoom-icon--caution{--fdAvatarZoomIconColor:var(--sapCriticalTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapWarningBackground)}.fd-avatar__zoom-icon--negative{--fdAvatarZoomIconColor:var(--sapNegativeTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapErrorBackground)}.fd-avatar__zoom-icon--information{--fdAvatarZoomIconColor:var(--sapInformativeTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapInformationBackground)}.fd-avatar__zoom-icon--indication-1{--fdAvatarZoomIconColor:var(--sapIndicationColor_1_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_1_Background)}.fd-avatar__zoom-icon--indication-2{--fdAvatarZoomIconColor:var(--sapIndicationColor_2_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_2_Background)}.fd-avatar__zoom-icon--indication-3{--fdAvatarZoomIconColor:var(--sapIndicationColor_3_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_3_Background)}.fd-avatar__zoom-icon--indication-4{--fdAvatarZoomIconColor:var(--sapIndicationColor_4_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_4_Background)}.fd-avatar__zoom-icon--indication-5{--fdAvatarZoomIconColor:var(--sapIndicationColor_5_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_5_Background)}.fd-avatar__zoom-icon--indication-6{--fdAvatarZoomIconColor:var(--sapIndicationColor_6_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_6_Background)}.fd-avatar__zoom-icon--indication-7{--fdAvatarZoomIconColor:var(--sapIndicationColor_7_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_7_Background)}.fd-avatar__zoom-icon--indication-8{--fdAvatarZoomIconColor:var(--sapIndicationColor_8_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_8_Background)}.fd-avatar__zoom-icon--indication-9{--fdAvatarZoomIconColor:var(--sapIndicationColor_9_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_9_Background)}.fd-avatar__zoom-icon--indication-10{--fdAvatarZoomIconColor:var(--sapIndicationColor_10_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_10_Background)}.fd-avatar__icon [class*=sap-icon],.fd-avatar__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-line-pack:center;align-content:center}.fd-avatar--circle{--fdAvatarBorderRadius:100%}.fd-avatar--circle.is-focus,.fd-avatar--circle:focus{outline:none}.fd-avatar--circle.is-focus:after,.fd-avatar--circle:focus:after{border-color:var(--sapContent_FocusColor);border-radius:var(--fdAvatar_Focus_Outline_Radius_Circle);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset);pointer-events:none;position:absolute}.fd-avatar--background-contain{--fdAvatarBackgroundSize:contain}.fd-avatar--transparent{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapAvatar_Lite_Background);--fdAvatarColor:var(--sapContent_IconColor);--fdAvatarBorderHoverColor:var(--sapContent_IconColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_Lite_Background)}.fd-avatar--tile{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapTile_Background);--fdAvatarColor:var(--sapTile_IconColor);--fdAvatarBorderHoverColor:var(--sapTile_IconColor);--fdAvatarHoverBackgroundColor:var(--sapTile_Background)}.fd-avatar--placeholder{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapContent_ImagePlaceholderBackground);--fdAvatarColor:var(--sapContent_ImagePlaceholderForegroundColor);--fdAvatarBorderHoverColor:var(--sapContent_ImagePlaceholderForegroundColor);--fdAvatarHoverBackgroundColor:var(--sapContent_ImagePlaceholderBackground)}.fd-avatar--thumbnail{--fdAvatarBorderColor:var(--fdAvatar_Thumbnail_BorderColor);--fdAvatarHoverBorderColor:var(--sapContent_IconColor);--fdAvatarBackgroundColor:var(--sapAvatar_Lite_Background);--fdAvatarHoverBackgroundColor:var(--sapAvatar_Lite_Background)}.fd-avatar--border{--fdAvatarBorderColor:var(--sapGroup_ContentBorderColor);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor)}.fd-avatar--overflow{cursor:pointer;--fdAvatarBorderWidth:var(--fdAvatar_Overflow_Border_Width);--fdAvatarBorderColor:var(--sapButton_BorderColor);--fdAvatarBackgroundColor:var(--sapButton_Background);--fdAvatarColor:var(--sapButton_TextColor);--fdAvatarHoverBackgroundColor:var(--sapButton_Hover_Background);--fdAvatarHoverBorderColor:var(--sapButton_Hover_BorderColor);--fdAvatarBorderActiveColor:var(--sapButton_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapButton_Active_Background);--fdAvatarActiveColor:var(--sapButton_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapButton_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapButton_Active_Background);--fdAvatarActiveHoverColor:var(--sapButton_Active_TextColor)}.fd-avatar--overflow.is-disabled,.fd-avatar--overflow:disabled,.fd-avatar--overflow[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity)}.fd-avatar--accent-color-1,.fd-avatar--accent-color-1.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_1_BorderColor);--fdAvatarColor:var(--sapAvatar_1_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_1_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_1_Hover_Background)}.fd-avatar--accent-color-2,.fd-avatar--accent-color-2.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_2_BorderColor);--fdAvatarColor:var(--sapAvatar_2_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_2_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_2_Hover_Background)}.fd-avatar--accent-color-3,.fd-avatar--accent-color-3.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_3_BorderColor);--fdAvatarColor:var(--sapAvatar_3_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_3_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_3_Hover_Background)}.fd-avatar--accent-color-4,.fd-avatar--accent-color-4.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_4_BorderColor);--fdAvatarColor:var(--sapAvatar_4_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_4_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_4_Hover_Background)}.fd-avatar--accent-color-5,.fd-avatar--accent-color-5.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_5_BorderColor);--fdAvatarColor:var(--sapAvatar_5_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_5_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_5_Hover_Background)}.fd-avatar--accent-color-6,.fd-avatar--accent-color-6.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_6_BorderColor);--fdAvatarColor:var(--sapAvatar_6_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_6_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_6_Hover_Background)}.fd-avatar--accent-color-7,.fd-avatar--accent-color-7.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_7_BorderColor);--fdAvatarColor:var(--sapAvatar_7_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_7_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_7_Hover_Background)}.fd-avatar--accent-color-8,.fd-avatar--accent-color-8.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_8_BorderColor);--fdAvatarColor:var(--sapAvatar_8_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_8_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_8_Hover_Background)}.fd-avatar--accent-color-9,.fd-avatar--accent-color-9.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_9_BorderColor);--fdAvatarColor:var(--sapAvatar_9_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_9_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_9_Hover_Background)}.fd-avatar--accent-color-10,.fd-avatar--accent-color-10.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_10_BorderColor);--fdAvatarColor:var(--sapAvatar_10_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_10_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_10_Hover_Background)}.fd-avatar--indication-color-1,.fd-avatar--indication-color-1.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_1_BorderColor);--fdAvatarColor:var(--sapIndicationColor_1_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_1_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_1_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_1_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_1_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_1_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_1_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_1_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_1_Active_TextColor)}.fd-avatar--indication-color-2,.fd-avatar--indication-color-2.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_2_BorderColor);--fdAvatarColor:var(--sapIndicationColor_2_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_2_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_2_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_2_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_2_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_2_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_2_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_2_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_2_Active_TextColor)}.fd-avatar--indication-color-3,.fd-avatar--indication-color-3.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_3_BorderColor);--fdAvatarColor:var(--sapIndicationColor_3_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_3_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_3_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_3_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_3_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_3_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_3_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_3_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_3_Active_TextColor)}.fd-avatar--indication-color-4,.fd-avatar--indication-color-4.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_4_BorderColor);--fdAvatarColor:var(--sapIndicationColor_4_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_4_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_4_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_4_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_4_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_4_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_4_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_4_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_4_Active_TextColor)}.fd-avatar--indication-color-5,.fd-avatar--indication-color-5.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_5_BorderColor);--fdAvatarColor:var(--sapIndicationColor_5_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_5_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_5_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_5_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_5_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_5_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_5_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_5_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_5_Active_TextColor)}.fd-avatar--indication-color-6,.fd-avatar--indication-color-6.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_6_BorderColor);--fdAvatarColor:var(--sapIndicationColor_6_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_6_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_6_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_6_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_6_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_6_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_6_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_6_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_6_Active_TextColor)}.fd-avatar--indication-color-7,.fd-avatar--indication-color-7.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_7_BorderColor);--fdAvatarColor:var(--sapIndicationColor_7_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_7_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_7_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_7_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_7_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_7_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_7_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_7_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_7_Active_TextColor)}.fd-avatar--indication-color-8,.fd-avatar--indication-color-8.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_8_BorderColor);--fdAvatarColor:var(--sapIndicationColor_8_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_8_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_8_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_8_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_8_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_8_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_8_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_8_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_8_Active_TextColor)}.fd-avatar--indication-color-9,.fd-avatar--indication-color-9.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_9_BorderColor);--fdAvatarColor:var(--sapIndicationColor_9_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_9_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_9_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_9_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_9_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_9_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_9_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_9_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_9_Active_TextColor)}.fd-avatar--indication-color-10,.fd-avatar--indication-color-10.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_10_BorderColor);--fdAvatarColor:var(--sapIndicationColor_10_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_10_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_10_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_10_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_10_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_10_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_10_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_10_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_10_Active_TextColor)}.fd-avatar--xs{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:2rem;--fdAvatarFontSize:1rem;--fdAvatarFontStretch:condensed}.fd-avatar--xs .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--xs .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--s{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:3rem;--fdAvatarFontSize:1.125rem;--fdAvatarFontStretch:condensed}.fd-avatar--s .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--s .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--sm{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:3rem;--fdAvatarFontSize:1.125rem;--fdAvatarFontStretch:condensed}.fd-avatar--sm .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--sm .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--m{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:4rem;--fdAvatarFontSize:1.5rem;--fdAvatarFontStretch:normal}.fd-avatar--m .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--m .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--md{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:4rem;--fdAvatarFontSize:1.5rem;--fdAvatarFontStretch:normal}.fd-avatar--md .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--md .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--l{--fdAvatarZoomIconOffset:-.1875rem;--fdAvatarRatio:5rem;--fdAvatarFontSize:2.25rem;--fdAvatarFontStretch:normal}.fd-avatar--l .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--l .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.25rem;--fdAvatarZoomIconFontSize:.875rem}.fd-avatar--lg{--fdAvatarZoomIconOffset:-.1875rem;--fdAvatarRatio:5rem;--fdAvatarFontSize:2.25rem;--fdAvatarFontStretch:normal}.fd-avatar--lg .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--lg .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.25rem;--fdAvatarZoomIconFontSize:.875rem}.fd-avatar--xl{--fdAvatarZoomIconOffset:-.25rem;--fdAvatarRatio:7rem;--fdAvatarFontSize:3rem;--fdAvatarFontStretch:normal}.fd-avatar--xl .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--xl .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.75rem;--fdAvatarZoomIconFontSize:1rem}.fd-avatar--accent-color-1.fd-avatar--shell,.fd-avatar--accent-color-10.fd-avatar--shell,.fd-avatar--accent-color-2.fd-avatar--shell,.fd-avatar--accent-color-3.fd-avatar--shell,.fd-avatar--accent-color-4.fd-avatar--shell,.fd-avatar--accent-color-5.fd-avatar--shell,.fd-avatar--accent-color-6.fd-avatar--shell,.fd-avatar--accent-color-7.fd-avatar--shell,.fd-avatar--accent-color-8.fd-avatar--shell,.fd-avatar--accent-color-9.fd-avatar--shell,.fd-avatar--indication-color-1.fd-avatar--shell,.fd-avatar--indication-color-10.fd-avatar--shell,.fd-avatar--indication-color-2.fd-avatar--shell,.fd-avatar--indication-color-3.fd-avatar--shell,.fd-avatar--indication-color-4.fd-avatar--shell,.fd-avatar--indication-color-5.fd-avatar--shell,.fd-avatar--indication-color-6.fd-avatar--shell,.fd-avatar--indication-color-7.fd-avatar--shell,.fd-avatar--indication-color-8.fd-avatar--shell,.fd-avatar--indication-color-9.fd-avatar--shell{border:.0625rem solid var(--sapShell_InteractiveBorderColor)}.fd-avatar--l,.fd-avatar--lg,.fd-avatar--m,.fd-avatar--md,.fd-avatar--s,.fd-avatar--sm,.fd-avatar--xl,.fd-avatar--xs{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-avatar--l:not(.fd-avatar--circle),.fd-avatar--lg:not(.fd-avatar--circle),.fd-avatar--m:not(.fd-avatar--circle),.fd-avatar--md:not(.fd-avatar--circle),.fd-avatar--s:not(.fd-avatar--circle),.fd-avatar--sm:not(.fd-avatar--circle),.fd-avatar--xl:not(.fd-avatar--circle),.fd-avatar--xs:not(.fd-avatar--circle){--fdAvatarZoomIconPosition:var(--fdAvatarZoomIconOffset)}.fd-avatar-group{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row}.fd-avatar-group:after,.fd-avatar-group:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-avatar-group .fd-avatar:not(:first-child){margin-block:var(--fdAvatarGroupItemsSpacingY) 0;margin-inline:var(--fdAvatarGroupItemsSpacingX) 0}.fd-avatar-group__overflow-body{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:1rem;padding-inline:0;padding-inline:1rem;white-space:normal}.fd-avatar-group__overflow-body:after,.fd-avatar-group__overflow-body:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-avatar-group__overflow-body--no-padding{padding-block:0;padding-inline:0}.fd-avatar-group__overflow-body--no-horizontal-scroll{overflow-x:hidden}.fd-avatar-group__overflow-body--no-vertical-scroll{overflow-y:hidden}.fd-avatar-group__overflow-body>.fd-avatar{margin-block:.25rem;margin-inline:.25rem}.fd-avatar-group--vertical{-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.fd-avatar-group--individual-type{gap:var(--fdAvatarGroupItemsGap)}.fd-avatar-group--individual-type.fd-avatar-group--xs{--fdAvatarGroupItemsGap:.0625rem}.fd-avatar-group--individual-type.fd-avatar-group--l,.fd-avatar-group--individual-type.fd-avatar-group--lg,.fd-avatar-group--individual-type.fd-avatar-group--m,.fd-avatar-group--individual-type.fd-avatar-group--md,.fd-avatar-group--individual-type.fd-avatar-group--s,.fd-avatar-group--individual-type.fd-avatar-group--sm{--fdAvatarGroupItemsGap:.125rem}.fd-avatar-group--individual-type.fd-avatar-group--xl{--fdAvatarGroupItemsGap:.25rem}.fd-avatar-group--group-type .fd-avatar{pointer-events:none}.fd-avatar-group--group-type.fd-avatar-group--xs{--fdAvatarGroupItemsSpacingX:-.5rem}.fd-avatar-group--group-type.fd-avatar-group--xs.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-.5rem}.fd-avatar-group--group-type.fd-avatar-group--s{--fdAvatarGroupItemsSpacingX:-1.25rem}.fd-avatar-group--group-type.fd-avatar-group--s.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-1.25rem}.fd-avatar-group--group-type.fd-avatar-group--sm{--fdAvatarGroupItemsSpacingX:-1.25rem}.fd-avatar-group--group-type.fd-avatar-group--sm.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-1.25rem}.fd-avatar-group--group-type.fd-avatar-group--m{--fdAvatarGroupItemsSpacingX:-1.625rem}.fd-avatar-group--group-type.fd-avatar-group--m.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-1.625rem}.fd-avatar-group--group-type.fd-avatar-group--md{--fdAvatarGroupItemsSpacingX:-1.625rem}.fd-avatar-group--group-type.fd-avatar-group--md.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-1.625rem}.fd-avatar-group--group-type.fd-avatar-group--l{--fdAvatarGroupItemsSpacingX:-2rem}.fd-avatar-group--group-type.fd-avatar-group--l.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-2rem}.fd-avatar-group--group-type.fd-avatar-group--lg{--fdAvatarGroupItemsSpacingX:-2rem}.fd-avatar-group--group-type.fd-avatar-group--lg.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-2rem}.fd-avatar-group--group-type.fd-avatar-group--xl{--fdAvatarGroupItemsSpacingX:-2.75rem}.fd-avatar-group--group-type.fd-avatar-group--xl.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-2.75rem}.fd-avatar-group--group-type.is-hover .fd-avatar,.fd-avatar-group--group-type:hover .fd-avatar{--fdAvatarBorderColor:var(--fdAvatarBorderHoverColor,var(--sapAvatar_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarHoverBackgroundColor,var(--sapAvatar_6_Hover_Background))}.fd-avatar-group--group-type.is-active .fd-avatar,.fd-avatar-group--group-type:active .fd-avatar{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar-group--group-type.is-active.is-hover .fd-avatar,.fd-avatar-group--group-type.is-active:hover .fd-avatar,.fd-avatar-group--group-type:active.is-hover .fd-avatar,.fd-avatar-group--group-type:active:hover .fd-avatar{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar-group--group-type.is-toggled .fd-avatar{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar-group--group-type.is-toggled.is-hover .fd-avatar,.fd-avatar-group--group-type.is-toggled:hover .fd-avatar{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar-group--group-type.is-disabled,.fd-avatar-group--group-type:disabled,.fd-avatar-group--group-type[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-avatar-group--group-type.is-focus,.fd-avatar-group--group-type:focus{z-index:5}.fd-avatar-group--group-type.is-focus.is-focus,.fd-avatar-group--group-type.is-focus:focus,.fd-avatar-group--group-type:focus.is-focus,.fd-avatar-group--group-type:focus:focus{outline:none}.fd-avatar-group--group-type.is-focus.is-focus:after,.fd-avatar-group--group-type.is-focus:focus:after,.fd-avatar-group--group-type:focus.is-focus:after,.fd-avatar-group--group-type:focus:focus:after{border-color:var(--sapContent_FocusColor);border-radius:var(--fdAvatarGroup_Focus_Outline_Radius);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:var(--fdAvatarGroup_Focus_Outline_Offset) var(--fdAvatarGroup_Focus_Outline_Offset) var(--fdAvatarGroup_Focus_Outline_Offset) var(--fdAvatarGroup_Focus_Outline_Offset);pointer-events:none;position:absolute}fd-popover{display:inline-block}fd-avatar-group{display:block}fd-avatar-group .fd-avatar-group.fd-avatar-group--individual-type{gap:initial}fd-avatar-group .fd-avatar-group.fd-avatar-group--individual-type>fd-popover>.fd-popover__control>fd-popover-control{display:block;height:100%}fd-avatar-group .fd-avatar-group.fd-avatar-group--individual-type>fd-popover>.fd-popover__control>fd-popover-control>.fd-avatar{margin-inline-start:var(--fdAvatarGroupItemsGap)}fd-avatar-group .fd-avatar-group.fd-avatar-group--individual-type>fd-popover:first-child>.fd-popover__control>fd-popover-control>.fd-avatar{margin-inline:0}fd-avatar-group>.fd-popover-custom{width:100%}fd-avatar-group>.fd-popover-custom .fd-popover__control{display:inline-block}fd-avatar-group>.fd-popover-custom .fd-avatar-group{display:inline-block}\n/*!\n * Fundamental Library Styles v0.40.1\n * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n */\n"], dependencies: [{ kind: "component", type: AvatarGroupHostComponent, selector: "fd-avatar-group-host", inputs: ["class", "type", "orientation", "size", "items"] }, { kind: "component", type: PopoverComponent, selector: "fd-popover", inputs: ["title", "trigger", "fixedPosition", "id", "mobile", "mobileConfig", "preventSpaceKeyScroll"] }, { kind: "component", type: PopoverControlComponent, selector: "fd-popover-control, [fdPopoverControl]" }, { kind: "directive", type: PopoverBodyDirective, selector: "[fdPopoverBody]" }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: FocusableItemDirective, selector: "[fdkFocusableItem]", inputs: ["fdkFocusableItem", "cellFocusedEventAnnouncer"], outputs: ["cellFocused"] }, { kind: "directive", type: FocusableListDirective, selector: "[fdkFocusableList]", inputs: ["focusable", "navigationDirection", "contentDirection", "wrap", "listFocusedEventAnnouncer"], outputs: ["itemFocused"], exportAs: ["fdkFocusableList"] }, { kind: "directive", type: AvatarGroupItemRendererDirective, selector: "[fdAvatarGroupItemPortal]", inputs: ["avatarGroupItem", "forceVisibility"], exportAs: ["fdAvatarGroupItemPortal"] }, { kind: "component", type: AvatarGroupOverflowButtonComponent, selector: "fd-avatar-group-overflow-button", inputs: ["size", "circle", "colorAccent", "class"] }, { kind: "component", type: DefaultAvatarGroupOverflowBodyComponent, selector: "fd-default-avatar-group-overflow-body", inputs: ["avatars", "overflowPopoverTitle"] }, { kind: "directive", type: AvatarGroupInternalOverflowButtonDirective, selector: "[fdAvatarGroupInternalOverflowButton]", inputs: ["fdAvatarGroupInternalOverflowButton"] }, { kind: "directive", type: ResizeObserverDirective, selector: "[fdkResizeObserver]", outputs: ["resized"], exportAs: ["fdkResizeObserver"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-avatar-group', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: AVATAR_GROUP_HOST_CONFIG,
                            useExisting: AvatarGroupComponent
                        }
                    ], imports: [
                        AvatarGroupHostComponent,
                        PopoverComponent,
                        PopoverControlComponent,
                        PopoverBodyDirective,
                        NgTemplateOutlet,
                        FocusableItemDirective,
                        FocusableListDirective,
                        AvatarGroupItemRendererDirective,
                        AvatarGroupOverflowButtonComponent,
                        DefaultAvatarGroupOverflowBodyComponent,
                        AvatarGroupInternalOverflowButtonDirective,
                        ResizeObserverDirective
                    ], standalone: true, template: "<ng-content></ng-content>\n@if (type === 'individual') {\n    <fd-avatar-group-host\n        #avatarGroupHostComponent\n        [type]=\"type\"\n        [size]=\"size\"\n        [orientation]=\"orientation\"\n        fdkResizeObserver\n        fdkFocusableList\n        [contentDirection]=\"_contentDirection$()\"\n        [wrap]=\"true\"\n        [navigationDirection]=\"orientation\"\n        [items]=\"_avatars\"\n        (resized)=\"_detectChanges()\"\n    >\n        @for (item of _avatars; track item) {\n            <fd-popover [noArrow]=\"false\" [focusAutoCapture]=\"true\">\n                <fd-popover-control tabindex=\"-1\" (click)=\"outletItem.element.focus()\">\n                    <ng-template\n                        #outletItem=\"fdAvatarGroupItemPortal\"\n                        cdkPortalOutlet\n                        fdAvatarGroupItemPortal\n                        [forceVisibility]=\"item.forceVisibility\"\n                        [avatarGroupItem]=\"item\"\n                    >\n                    </ng-template>\n                </fd-popover-control>\n                @if (item.details) {\n                    <ng-template fdPopoverBody>\n                        <ng-template [ngTemplateOutlet]=\"item.details\"></ng-template>\n                    </ng-template>\n                }\n            </fd-popover>\n        }\n        <fd-popover\n            [noArrow]=\"false\"\n            [focusAutoCapture]=\"true\"\n            *fdAvatarGroupInternalOverflowButton=\"avatarGroupHostComponent._hiddenItems(); let hiddenItems\"\n        >\n            <fd-popover-control tabindex=\"-1\">\n                <ng-template\n                    [ngTemplateOutlet]=\"overflowButtonTemplate\"\n                    [ngTemplateOutletContext]=\"{ $implicit: hiddenItems }\"\n                ></ng-template>\n            </fd-popover-control>\n            <ng-template fdPopoverBody>\n                <ng-template\n                    [ngTemplateOutlet]=\"avatarGroupOverflowBodyTemplate\"\n                    [ngTemplateOutletContext]=\"{ $implicit: hiddenItems }\"\n                ></ng-template>\n            </ng-template>\n        </fd-popover>\n    </fd-avatar-group-host>\n} @else {\n    <fd-popover [noArrow]=\"false\" [focusAutoCapture]=\"true\" fdkResizeObserver (resized)=\"_detectChanges()\">\n        <fd-popover-control>\n            <fd-avatar-group-host\n                #avatarGroupHostComponent\n                [type]=\"type\"\n                [size]=\"size\"\n                [orientation]=\"orientation\"\n                [fdkFocusableItem]=\"true\"\n            >\n                @for (item of _avatars; track item) {\n                    <ng-template\n                        cdkPortalOutlet\n                        fdAvatarGroupItemPortal\n                        [forceVisibility]=\"item.forceVisibility\"\n                        [avatarGroupItem]=\"item\"\n                    >\n                    </ng-template>\n                }\n                <ng-template\n                    [fdAvatarGroupInternalOverflowButton]=\"avatarGroupHostComponent._hiddenItems()\"\n                    let-hiddenItems\n                >\n                    <ng-template\n                        [ngTemplateOutlet]=\"overflowButtonTemplate\"\n                        [ngTemplateOutletContext]=\"{ $implicit: hiddenItems }\"\n                    ></ng-template>\n                </ng-template>\n            </fd-avatar-group-host>\n        </fd-popover-control>\n        <ng-template fdPopoverBody>\n            <ng-template\n                [ngTemplateOutlet]=\"avatarGroupOverflowBodyTemplate\"\n                [ngTemplateOutletContext]=\"{ $implicit: _avatarRenderers }\"\n            ></ng-template>\n        </ng-template>\n    </fd-popover>\n}\n<ng-template #overflowButtonTemplate let-hiddenItems>\n    @if (_overflowButton) {\n        <ng-template\n            [ngTemplateOutlet]=\"_overflowButton._templateRef\"\n            [ngTemplateOutletContext]=\"{ hiddenItems: hiddenItems }\"\n        />\n    } @else {\n        <fd-avatar-group-overflow-button [size]=\"size\" [colorAccent]=\"1\">\n            +{{ hiddenItems.length }}\n        </fd-avatar-group-overflow-button>\n    }\n</ng-template>\n<ng-template #avatarGroupOverflowBodyTemplate let-hiddenItems>\n    @if (_avatarGroupPopoverBody) {\n        <ng-template\n            [ngTemplateOutlet]=\"_avatarGroupPopoverBody._templateRef\"\n            [ngTemplateOutletContext]=\"{ hiddenItems: hiddenItems }\"\n        />\n    } @else {\n        <fd-default-avatar-group-overflow-body [avatars]=\"hiddenItems\" [overflowPopoverTitle]=\"overflowPopoverTitle\" />\n    }\n</ng-template>\n", styles: [".fd-avatar{--fdAvatarZoomIconPosition:0;background-color:var(--fdAvatarBackgroundColor);background-position:50%;background-repeat:no-repeat;background-size:var(--fdAvatarBackgroundSize);border:0;border:var(--fdAvatarBorderWidth, .0625rem) solid var(--fdAvatarBorderColor);border-radius:var(--fdAvatarBorderRadius);-webkit-box-shadow:var(--fdAvatarBoxShadow);box-shadow:var(--fdAvatarBoxShadow);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdAvatarColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdAvatarFontSize);font-stretch:var(--fdAvatarFontStretch);font-weight:400;forced-color-adjust:none;height:var(--fdAvatarRatio);line-height:normal;margin-block:0;margin-inline:0;max-height:var(--fdAvatarRatio);max-width:var(--fdAvatarRatio);min-height:var(--fdAvatarRatio);min-width:var(--fdAvatarRatio);padding-block:0;padding-inline:0;position:relative;text-shadow:var(--fdAvatarTextShadow);vertical-align:middle;width:var(--fdAvatarRatio)}.fd-avatar:after,.fd-avatar:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-avatar.is-focus,.fd-avatar:focus{outline:none}.fd-avatar.is-focus:after,.fd-avatar:focus:after{border-color:var(--sapContent_FocusColor);border-radius:var(--fdAvatar_Focus_Outline_Radius);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset);pointer-events:none;position:absolute}.fd-avatar--interactive,.fd-avatar[role=button],.fd-avatar[tabindex=\"0\"]{cursor:pointer}.fd-avatar--interactive.is-hover,.fd-avatar--interactive:hover,.fd-avatar[role=button].is-hover,.fd-avatar[role=button]:hover,.fd-avatar[tabindex=\"0\"].is-hover,.fd-avatar[tabindex=\"0\"]:hover{--fdAvatarBorderColor:var(--fdAvatarBorderHoverColor,var(--sapAvatar_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarHoverBackgroundColor,var(--sapAvatar_6_Hover_Background))}.fd-avatar--interactive.is-disabled,.fd-avatar--interactive:disabled,.fd-avatar--interactive[aria-disabled=true],.fd-avatar[role=button].is-disabled,.fd-avatar[role=button]:disabled,.fd-avatar[role=button][aria-disabled=true],.fd-avatar[tabindex=\"0\"].is-disabled,.fd-avatar[tabindex=\"0\"]:disabled,.fd-avatar[tabindex=\"0\"][aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity)}.fd-avatar--interactive.is-active,.fd-avatar--interactive:active,.fd-avatar[role=button].is-active,.fd-avatar[role=button]:active,.fd-avatar[tabindex=\"0\"].is-active,.fd-avatar[tabindex=\"0\"]:active{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar--interactive.is-active.is-hover,.fd-avatar--interactive.is-active:hover,.fd-avatar--interactive:active.is-hover,.fd-avatar--interactive:active:hover,.fd-avatar[role=button].is-active.is-hover,.fd-avatar[role=button].is-active:hover,.fd-avatar[role=button]:active.is-hover,.fd-avatar[role=button]:active:hover,.fd-avatar[tabindex=\"0\"].is-active.is-hover,.fd-avatar[tabindex=\"0\"].is-active:hover,.fd-avatar[tabindex=\"0\"]:active.is-hover,.fd-avatar[tabindex=\"0\"]:active:hover{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar--interactive.is-toggled,.fd-avatar[role=button].is-toggled,.fd-avatar[tabindex=\"0\"].is-toggled{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar--interactive.is-toggled.is-hover,.fd-avatar--interactive.is-toggled:hover,.fd-avatar[role=button].is-toggled.is-hover,.fd-avatar[role=button].is-toggled:hover,.fd-avatar[tabindex=\"0\"].is-toggled.is-hover,.fd-avatar[tabindex=\"0\"].is-toggled:hover{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar--interactive.is-focus,.fd-avatar--interactive:focus,.fd-avatar[role=button].is-focus,.fd-avatar[role=button]:focus,.fd-avatar[tabindex=\"0\"].is-focus,.fd-avatar[tabindex=\"0\"]:focus{padding-block:.125rem;padding-inline:.125rem;z-index:5}.fd-avatar__zoom-icon{--fdAvatarZoomIconColor:var(--sapButton_Emphasized_TextColor);--fdAvatarZoomIconBorderColor:var(--sapButton_Emphasized_BorderColor);--fdAvatarZoomIconBackground:var(--sapButton_Emphasized_Background)}.fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdAvatarZoomIconBackground);border:.0625rem solid var(--fdAvatarZoomIconBorderColor);border-radius:100%;color:var(--fdAvatarZoomIconColor);font-size:var(--fdAvatarZoomIconFontSize);height:var(--fdAvatarZoomIconDimensions);min-width:var(--fdAvatarZoomIconDimensions);position:absolute;width:var(--fdAvatarZoomIconDimensions);z-index:5}.fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon],.fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon]{bottom:var(--fdAvatarZoomIconPosition);right:var(--fdAvatarZoomIconPosition)}.fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon][dir=rtl],[dir=rtl] .fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon]{left:var(--fdAvatarZoomIconPosition);right:auto}.fd-avatar__zoom-icon--positive{--fdAvatarZoomIconColor:var(--sapPositiveTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapSuccessBackground)}.fd-avatar__zoom-icon--caution{--fdAvatarZoomIconColor:var(--sapCriticalTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapWarningBackground)}.fd-avatar__zoom-icon--negative{--fdAvatarZoomIconColor:var(--sapNegativeTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapErrorBackground)}.fd-avatar__zoom-icon--information{--fdAvatarZoomIconColor:var(--sapInformativeTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapInformationBackground)}.fd-avatar__zoom-icon--indication-1{--fdAvatarZoomIconColor:var(--sapIndicationColor_1_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_1_Background)}.fd-avatar__zoom-icon--indication-2{--fdAvatarZoomIconColor:var(--sapIndicationColor_2_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_2_Background)}.fd-avatar__zoom-icon--indication-3{--fdAvatarZoomIconColor:var(--sapIndicationColor_3_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_3_Background)}.fd-avatar__zoom-icon--indication-4{--fdAvatarZoomIconColor:var(--sapIndicationColor_4_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_4_Background)}.fd-avatar__zoom-icon--indication-5{--fdAvatarZoomIconColor:var(--sapIndicationColor_5_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_5_Background)}.fd-avatar__zoom-icon--indication-6{--fdAvatarZoomIconColor:var(--sapIndicationColor_6_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_6_Background)}.fd-avatar__zoom-icon--indication-7{--fdAvatarZoomIconColor:var(--sapIndicationColor_7_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_7_Background)}.fd-avatar__zoom-icon--indication-8{--fdAvatarZoomIconColor:var(--sapIndicationColor_8_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_8_Background)}.fd-avatar__zoom-icon--indication-9{--fdAvatarZoomIconColor:var(--sapIndicationColor_9_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_9_Background)}.fd-avatar__zoom-icon--indication-10{--fdAvatarZoomIconColor:var(--sapIndicationColor_10_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_10_Background)}.fd-avatar__icon [class*=sap-icon],.fd-avatar__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-line-pack:center;align-content:center}.fd-avatar--circle{--fdAvatarBorderRadius:100%}.fd-avatar--circle.is-focus,.fd-avatar--circle:focus{outline:none}.fd-avatar--circle.is-focus:after,.fd-avatar--circle:focus:after{border-color:var(--sapContent_FocusColor);border-radius:var(--fdAvatar_Focus_Outline_Radius_Circle);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset);pointer-events:none;position:absolute}.fd-avatar--background-contain{--fdAvatarBackgroundSize:contain}.fd-avatar--transparent{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapAvatar_Lite_Background);--fdAvatarColor:var(--sapContent_IconColor);--fdAvatarBorderHoverColor:var(--sapContent_IconColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_Lite_Background)}.fd-avatar--tile{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapTile_Background);--fdAvatarColor:var(--sapTile_IconColor);--fdAvatarBorderHoverColor:var(--sapTile_IconColor);--fdAvatarHoverBackgroundColor:var(--sapTile_Background)}.fd-avatar--placeholder{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapContent_ImagePlaceholderBackground);--fdAvatarColor:var(--sapContent_ImagePlaceholderForegroundColor);--fdAvatarBorderHoverColor:var(--sapContent_ImagePlaceholderForegroundColor);--fdAvatarHoverBackgroundColor:var(--sapContent_ImagePlaceholderBackground)}.fd-avatar--thumbnail{--fdAvatarBorderColor:var(--fdAvatar_Thumbnail_BorderColor);--fdAvatarHoverBorderColor:var(--sapContent_IconColor);--fdAvatarBackgroundColor:var(--sapAvatar_Lite_Background);--fdAvatarHoverBackgroundColor:var(--sapAvatar_Lite_Background)}.fd-avatar--border{--fdAvatarBorderColor:var(--sapGroup_ContentBorderColor);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor)}.fd-avatar--overflow{cursor:pointer;--fdAvatarBorderWidth:var(--fdAvatar_Overflow_Border_Width);--fdAvatarBorderColor:var(--sapButton_BorderColor);--fdAvatarBackgroundColor:var(--sapButton_Background);--fdAvatarColor:var(--sapButton_TextColor);--fdAvatarHoverBackgroundColor:var(--sapButton_Hover_Background);--fdAvatarHoverBorderColor:var(--sapButton_Hover_BorderColor);--fdAvatarBorderActiveColor:var(--sapButton_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapButton_Active_Background);--fdAvatarActiveColor:var(--sapButton_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapButton_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapButton_Active_Background);--fdAvatarActiveHoverColor:var(--sapButton_Active_TextColor)}.fd-avatar--overflow.is-disabled,.fd-avatar--overflow:disabled,.fd-avatar--overflow[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity)}.fd-avatar--accent-color-1,.fd-avatar--accent-color-1.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_1_BorderColor);--fdAvatarColor:var(--sapAvatar_1_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_1_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_1_Hover_Background)}.fd-avatar--accent-color-2,.fd-avatar--accent-color-2.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_2_BorderColor);--fdAvatarColor:var(--sapAvatar_2_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_2_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_2_Hover_Background)}.fd-avatar--accent-color-3,.fd-avatar--accent-color-3.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_3_BorderColor);--fdAvatarColor:var(--sapAvatar_3_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_3_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_3_Hover_Background)}.fd-avatar--accent-color-4,.fd-avatar--accent-color-4.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_4_BorderColor);--fdAvatarColor:var(--sapAvatar_4_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_4_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_4_Hover_Background)}.fd-avatar--accent-color-5,.fd-avatar--accent-color-5.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_5_BorderColor);--fdAvatarColor:var(--sapAvatar_5_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_5_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_5_Hover_Background)}.fd-avatar--accent-color-6,.fd-avatar--accent-color-6.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_6_BorderColor);--fdAvatarColor:var(--sapAvatar_6_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_6_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_6_Hover_Background)}.fd-avatar--accent-color-7,.fd-avatar--accent-color-7.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_7_BorderColor);--fdAvatarColor:var(--sapAvatar_7_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_7_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_7_Hover_Background)}.fd-avatar--accent-color-8,.fd-avatar--accent-color-8.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_8_BorderColor);--fdAvatarColor:var(--sapAvatar_8_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_8_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_8_Hover_Background)}.fd-avatar--accent-color-9,.fd-avatar--accent-color-9.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_9_BorderColor);--fdAvatarColor:var(--sapAvatar_9_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_9_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_9_Hover_Background)}.fd-avatar--accent-color-10,.fd-avatar--accent-color-10.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_10_BorderColor);--fdAvatarColor:var(--sapAvatar_10_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_10_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_10_Hover_Background)}.fd-avatar--indication-color-1,.fd-avatar--indication-color-1.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_1_BorderColor);--fdAvatarColor:var(--sapIndicationColor_1_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_1_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_1_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_1_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_1_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_1_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_1_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_1_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_1_Active_TextColor)}.fd-avatar--indication-color-2,.fd-avatar--indication-color-2.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_2_BorderColor);--fdAvatarColor:var(--sapIndicationColor_2_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_2_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_2_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_2_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_2_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_2_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_2_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_2_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_2_Active_TextColor)}.fd-avatar--indication-color-3,.fd-avatar--indication-color-3.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_3_BorderColor);--fdAvatarColor:var(--sapIndicationColor_3_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_3_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_3_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_3_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_3_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_3_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_3_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_3_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_3_Active_TextColor)}.fd-avatar--indication-color-4,.fd-avatar--indication-color-4.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_4_BorderColor);--fdAvatarColor:var(--sapIndicationColor_4_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_4_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_4_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_4_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_4_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_4_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_4_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_4_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_4_Active_TextColor)}.fd-avatar--indication-color-5,.fd-avatar--indication-color-5.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_5_BorderColor);--fdAvatarColor:var(--sapIndicationColor_5_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_5_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_5_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_5_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_5_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_5_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_5_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_5_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_5_Active_TextColor)}.fd-avatar--indication-color-6,.fd-avatar--indication-color-6.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_6_BorderColor);--fdAvatarColor:var(--sapIndicationColor_6_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_6_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_6_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_6_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_6_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_6_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_6_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_6_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_6_Active_TextColor)}.fd-avatar--indication-color-7,.fd-avatar--indication-color-7.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_7_BorderColor);--fdAvatarColor:var(--sapIndicationColor_7_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_7_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_7_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_7_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_7_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_7_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_7_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_7_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_7_Active_TextColor)}.fd-avatar--indication-color-8,.fd-avatar--indication-color-8.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_8_BorderColor);--fdAvatarColor:var(--sapIndicationColor_8_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_8_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_8_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_8_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_8_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_8_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_8_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_8_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_8_Active_TextColor)}.fd-avatar--indication-color-9,.fd-avatar--indication-color-9.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_9_BorderColor);--fdAvatarColor:var(--sapIndicationColor_9_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_9_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_9_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_9_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_9_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_9_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_9_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_9_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_9_Active_TextColor)}.fd-avatar--indication-color-10,.fd-avatar--indication-color-10.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_10_BorderColor);--fdAvatarColor:var(--sapIndicationColor_10_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_10_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_10_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_10_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_10_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_10_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_10_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_10_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_10_Active_TextColor)}.fd-avatar--xs{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:2rem;--fdAvatarFontSize:1rem;--fdAvatarFontStretch:condensed}.fd-avatar--xs .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--xs .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--s{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:3rem;--fdAvatarFontSize:1.125rem;--fdAvatarFontStretch:condensed}.fd-avatar--s .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--s .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--sm{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:3rem;--fdAvatarFontSize:1.125rem;--fdAvatarFontStretch:condensed}.fd-avatar--sm .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--sm .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--m{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:4rem;--fdAvatarFontSize:1.5rem;--fdAvatarFontStretch:normal}.fd-avatar--m .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--m .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--md{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:4rem;--fdAvatarFontSize:1.5rem;--fdAvatarFontStretch:normal}.fd-avatar--md .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--md .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--l{--fdAvatarZoomIconOffset:-.1875rem;--fdAvatarRatio:5rem;--fdAvatarFontSize:2.25rem;--fdAvatarFontStretch:normal}.fd-avatar--l .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--l .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.25rem;--fdAvatarZoomIconFontSize:.875rem}.fd-avatar--lg{--fdAvatarZoomIconOffset:-.1875rem;--fdAvatarRatio:5rem;--fdAvatarFontSize:2.25rem;--fdAvatarFontStretch:normal}.fd-avatar--lg .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--lg .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.25rem;--fdAvatarZoomIconFontSize:.875rem}.fd-avatar--xl{--fdAvatarZoomIconOffset:-.25rem;--fdAvatarRatio:7rem;--fdAvatarFontSize:3rem;--fdAvatarFontStretch:normal}.fd-avatar--xl .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--xl .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.75rem;--fdAvatarZoomIconFontSize:1rem}.fd-avatar--accent-color-1.fd-avatar--shell,.fd-avatar--accent-color-10.fd-avatar--shell,.fd-avatar--accent-color-2.fd-avatar--shell,.fd-avatar--accent-color-3.fd-avatar--shell,.fd-avatar--accent-color-4.fd-avatar--shell,.fd-avatar--accent-color-5.fd-avatar--shell,.fd-avatar--accent-color-6.fd-avatar--shell,.fd-avatar--accent-color-7.fd-avatar--shell,.fd-avatar--accent-color-8.fd-avatar--shell,.fd-avatar--accent-color-9.fd-avatar--shell,.fd-avatar--indication-color-1.fd-avatar--shell,.fd-avatar--indication-color-10.fd-avatar--shell,.fd-avatar--indication-color-2.fd-avatar--shell,.fd-avatar--indication-color-3.fd-avatar--shell,.fd-avatar--indication-color-4.fd-avatar--shell,.fd-avatar--indication-color-5.fd-avatar--shell,.fd-avatar--indication-color-6.fd-avatar--shell,.fd-avatar--indication-color-7.fd-avatar--shell,.fd-avatar--indication-color-8.fd-avatar--shell,.fd-avatar--indication-color-9.fd-avatar--shell{border:.0625rem solid var(--sapShell_InteractiveBorderColor)}.fd-avatar--l,.fd-avatar--lg,.fd-avatar--m,.fd-avatar--md,.fd-avatar--s,.fd-avatar--sm,.fd-avatar--xl,.fd-avatar--xs{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-avatar--l:not(.fd-avatar--circle),.fd-avatar--lg:not(.fd-avatar--circle),.fd-avatar--m:not(.fd-avatar--circle),.fd-avatar--md:not(.fd-avatar--circle),.fd-avatar--s:not(.fd-avatar--circle),.fd-avatar--sm:not(.fd-avatar--circle),.fd-avatar--xl:not(.fd-avatar--circle),.fd-avatar--xs:not(.fd-avatar--circle){--fdAvatarZoomIconPosition:var(--fdAvatarZoomIconOffset)}.fd-avatar-group{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row}.fd-avatar-group:after,.fd-avatar-group:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-avatar-group .fd-avatar:not(:first-child){margin-block:var(--fdAvatarGroupItemsSpacingY) 0;margin-inline:var(--fdAvatarGroupItemsSpacingX) 0}.fd-avatar-group__overflow-body{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:1rem;padding-inline:0;padding-inline:1rem;white-space:normal}.fd-avatar-group__overflow-body:after,.fd-avatar-group__overflow-body:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-avatar-group__overflow-body--no-padding{padding-block:0;padding-inline:0}.fd-avatar-group__overflow-body--no-horizontal-scroll{overflow-x:hidden}.fd-avatar-group__overflow-body--no-vertical-scroll{overflow-y:hidden}.fd-avatar-group__overflow-body>.fd-avatar{margin-block:.25rem;margin-inline:.25rem}.fd-avatar-group--vertical{-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.fd-avatar-group--individual-type{gap:var(--fdAvatarGroupItemsGap)}.fd-avatar-group--individual-type.fd-avatar-group--xs{--fdAvatarGroupItemsGap:.0625rem}.fd-avatar-group--individual-type.fd-avatar-group--l,.fd-avatar-group--individual-type.fd-avatar-group--lg,.fd-avatar-group--individual-type.fd-avatar-group--m,.fd-avatar-group--individual-type.fd-avatar-group--md,.fd-avatar-group--individual-type.fd-avatar-group--s,.fd-avatar-group--individual-type.fd-avatar-group--sm{--fdAvatarGroupItemsGap:.125rem}.fd-avatar-group--individual-type.fd-avatar-group--xl{--fdAvatarGroupItemsGap:.25rem}.fd-avatar-group--group-type .fd-avatar{pointer-events:none}.fd-avatar-group--group-type.fd-avatar-group--xs{--fdAvatarGroupItemsSpacingX:-.5rem}.fd-avatar-group--group-type.fd-avatar-group--xs.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-.5rem}.fd-avatar-group--group-type.fd-avatar-group--s{--fdAvatarGroupItemsSpacingX:-1.25rem}.fd-avatar-group--group-type.fd-avatar-group--s.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-1.25rem}.fd-avatar-group--group-type.fd-avatar-group--sm{--fdAvatarGroupItemsSpacingX:-1.25rem}.fd-avatar-group--group-type.fd-avatar-group--sm.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-1.25rem}.fd-avatar-group--group-type.fd-avatar-group--m{--fdAvatarGroupItemsSpacingX:-1.625rem}.fd-avatar-group--group-type.fd-avatar-group--m.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-1.625rem}.fd-avatar-group--group-type.fd-avatar-group--md{--fdAvatarGroupItemsSpacingX:-1.625rem}.fd-avatar-group--group-type.fd-avatar-group--md.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-1.625rem}.fd-avatar-group--group-type.fd-avatar-group--l{--fdAvatarGroupItemsSpacingX:-2rem}.fd-avatar-group--group-type.fd-avatar-group--l.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-2rem}.fd-avatar-group--group-type.fd-avatar-group--lg{--fdAvatarGroupItemsSpacingX:-2rem}.fd-avatar-group--group-type.fd-avatar-group--lg.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-2rem}.fd-avatar-group--group-type.fd-avatar-group--xl{--fdAvatarGroupItemsSpacingX:-2.75rem}.fd-avatar-group--group-type.fd-avatar-group--xl.fd-avatar-group--vertical{--fdAvatarGroupItemsSpacingX:0;--fdAvatarGroupItemsSpacingY:-2.75rem}.fd-avatar-group--group-type.is-hover .fd-avatar,.fd-avatar-group--group-type:hover .fd-avatar{--fdAvatarBorderColor:var(--fdAvatarBorderHoverColor,var(--sapAvatar_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarHoverBackgroundColor,var(--sapAvatar_6_Hover_Background))}.fd-avatar-group--group-type.is-active .fd-avatar,.fd-avatar-group--group-type:active .fd-avatar{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar-group--group-type.is-active.is-hover .fd-avatar,.fd-avatar-group--group-type.is-active:hover .fd-avatar,.fd-avatar-group--group-type:active.is-hover .fd-avatar,.fd-avatar-group--group-type:active:hover .fd-avatar{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar-group--group-type.is-toggled .fd-avatar{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar-group--group-type.is-toggled.is-hover .fd-avatar,.fd-avatar-group--group-type.is-toggled:hover .fd-avatar{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar-group--group-type.is-disabled,.fd-avatar-group--group-type:disabled,.fd-avatar-group--group-type[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-avatar-group--group-type.is-focus,.fd-avatar-group--group-type:focus{z-index:5}.fd-avatar-group--group-type.is-focus.is-focus,.fd-avatar-group--group-type.is-focus:focus,.fd-avatar-group--group-type:focus.is-focus,.fd-avatar-group--group-type:focus:focus{outline:none}.fd-avatar-group--group-type.is-focus.is-focus:after,.fd-avatar-group--group-type.is-focus:focus:after,.fd-avatar-group--group-type:focus.is-focus:after,.fd-avatar-group--group-type:focus:focus:after{border-color:var(--sapContent_FocusColor);border-radius:var(--fdAvatarGroup_Focus_Outline_Radius);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:var(--fdAvatarGroup_Focus_Outline_Offset) var(--fdAvatarGroup_Focus_Outline_Offset) var(--fdAvatarGroup_Focus_Outline_Offset) var(--fdAvatarGroup_Focus_Outline_Offset);pointer-events:none;position:absolute}fd-popover{display:inline-block}fd-avatar-group{display:block}fd-avatar-group .fd-avatar-group.fd-avatar-group--individual-type{gap:initial}fd-avatar-group .fd-avatar-group.fd-avatar-group--individual-type>fd-popover>.fd-popover__control>fd-popover-control{display:block;height:100%}fd-avatar-group .fd-avatar-group.fd-avatar-group--individual-type>fd-popover>.fd-popover__control>fd-popover-control>.fd-avatar{margin-inline-start:var(--fdAvatarGroupItemsGap)}fd-avatar-group .fd-avatar-group.fd-avatar-group--individual-type>fd-popover:first-child>.fd-popover__control>fd-popover-control>.fd-avatar{margin-inline:0}fd-avatar-group>.fd-popover-custom{width:100%}fd-avatar-group>.fd-popover-custom .fd-popover__control{display:inline-block}fd-avatar-group>.fd-popover-custom .fd-avatar-group{display:inline-block}\n/*!\n * Fundamental Library Styles v0.40.1\n * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n */\n"] }]
        }], propDecorators: { type: [{
                type: Input
            }], orientation: [{
                type: Input
            }], size: [{
                type: Input
            }], overflowPopoverTitle: [{
                type: Input
            }], _avatarRenderers: [{
                type: ViewChildren,
                args: [AvatarGroupItemRendererDirective]
            }], _avatars: [{
                type: ContentChildren,
                args: [AvatarGroupItemDirective]
            }], _overflowButton: [{
                type: ContentChild,
                args: [AvatarGroupOverflowButtonDirective]
            }], _avatarGroupPopoverBody: [{
                type: ContentChild,
                args: [AvatarGroupOverflowBodyDirective]
            }] } });

/**
 * Avatar group overflow body component, used to provide a template for the avatar group overflow body.
 */
class AvatarGroupOverflowBodyComponent {
    constructor() {
        /** Remove the padding from the overflow body. */
        this.noPadding = false;
        /** Hide horizontal scrollbar from the overflow body. */
        this.noHorizontalScroll = true;
        /** Hide vertical scrollbar from the overflow body. */
        this.noVerticalScroll = true;
        /** Additional popover body class */
        this.additionalPopoverBodyClass = '';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupOverflowBodyComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: AvatarGroupOverflowBodyComponent, isStandalone: true, selector: "fd-avatar-group-overflow-body", inputs: { noPadding: "noPadding", noHorizontalScroll: "noHorizontalScroll", noVerticalScroll: "noVerticalScroll", additionalPopoverBodyClass: "additionalPopoverBodyClass" }, host: { classAttribute: "fd-popover__wrapper" }, ngImport: i0, template: "<ng-content select=\"[fd-popover-body-header]\"></ng-content>\n<div\n    class=\"fd-avatar-group__overflow-body\"\n    [class.fd-avatar-group__overflow-body--no-padding]=\"noPadding\"\n    [class.fd-avatar-group__overflow-body--no-horizontal-scroll]=\"noHorizontalScroll\"\n    [class.fd-avatar-group__overflow-body--no-vertical-scroll]=\"noVerticalScroll\"\n>\n    <ng-content select=\"[fd-avatar-group-overflow-body-content]\"></ng-content>\n</div>\n", styles: ["fd-avatar-group-overflow-body{display:flex;flex-direction:column}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupOverflowBodyComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-avatar-group-overflow-body', host: {
                        class: 'fd-popover__wrapper'
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, template: "<ng-content select=\"[fd-popover-body-header]\"></ng-content>\n<div\n    class=\"fd-avatar-group__overflow-body\"\n    [class.fd-avatar-group__overflow-body--no-padding]=\"noPadding\"\n    [class.fd-avatar-group__overflow-body--no-horizontal-scroll]=\"noHorizontalScroll\"\n    [class.fd-avatar-group__overflow-body--no-vertical-scroll]=\"noVerticalScroll\"\n>\n    <ng-content select=\"[fd-avatar-group-overflow-body-content]\"></ng-content>\n</div>\n", styles: ["fd-avatar-group-overflow-body{display:flex;flex-direction:column}\n"] }]
        }], propDecorators: { noPadding: [{
                type: Input
            }], noHorizontalScroll: [{
                type: Input
            }], noVerticalScroll: [{
                type: Input
            }], additionalPopoverBodyClass: [{
                type: Input
            }] } });

class AvatarGroupModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupModule, imports: [AvatarGroupComponent,
            AvatarGroupItemDirective,
            AvatarGroupOverflowButtonComponent,
            AvatarGroupOverflowButtonDirective,
            AvatarGroupOverflowBodyComponent,
            AvatarGroupOverflowBodyDirective,
            PortalModule], exports: [AvatarGroupComponent,
            AvatarGroupItemDirective,
            AvatarGroupOverflowButtonComponent,
            AvatarGroupOverflowButtonDirective,
            AvatarGroupOverflowBodyComponent,
            AvatarGroupOverflowBodyDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupModule, imports: [AvatarGroupComponent,
            PortalModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarGroupModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        AvatarGroupComponent,
                        AvatarGroupItemDirective,
                        AvatarGroupOverflowButtonComponent,
                        AvatarGroupOverflowButtonDirective,
                        AvatarGroupOverflowBodyComponent,
                        AvatarGroupOverflowBodyDirective,
                        PortalModule
                    ],
                    exports: [
                        AvatarGroupComponent,
                        AvatarGroupItemDirective,
                        AvatarGroupOverflowButtonComponent,
                        AvatarGroupOverflowButtonDirective,
                        AvatarGroupOverflowBodyComponent,
                        AvatarGroupOverflowBodyDirective
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AVATAR_GROUP_HOST_CONFIG, AvatarGroupComponent, AvatarGroupItemDirective, AvatarGroupModule, AvatarGroupOverflowBodyComponent, AvatarGroupOverflowBodyDirective, AvatarGroupOverflowButtonComponent, AvatarGroupOverflowButtonDirective };
//# sourceMappingURL=fundamental-ngx-core-avatar-group.mjs.map
