import * as i0 from '@angular/core';
import { Pipe, InjectionToken, EventEmitter, HostListener, ViewChild, HostBinding, Output, Input, Attribute, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import { __decorate, __metadata } from 'tslib';
import { getRandomColorAccent, ANY_LANGUAGE_LETTERS_REGEX, applyCssClass } from '@fundamental-ngx/cdk/utils';
import { FD_DEFAULT_ICON_FONT_FAMILY, IconComponent } from '@fundamental-ngx/core/icon';

class AvatarIconPipe {
    /**
     * Selects appropriate Avatar icon based on Avatar Value state and fallback icon.
     */
    transform(valueState, fallbackIcon) {
        let computedIcon = '';
        if (!valueState) {
            computedIcon = fallbackIcon || '';
        }
        switch (valueState) {
            case 'positive':
                computedIcon = 'sys-enter-2';
                break;
            case 'caution':
                computedIcon = 'warning';
                break;
            case 'negative':
                computedIcon = 'error';
                break;
            case 'information':
                computedIcon = 'information';
                break;
        }
        return `sap-icon--${computedIcon} ${valueState ? 'fd-avatar__zoom-icon--' + valueState : ''}`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarIconPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: AvatarIconPipe, isStandalone: true, name: "fdAvatarIcon" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarIconPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'fdAvatarIcon',
                    pure: true,
                    standalone: true
                }]
        }] });

const FD_AVATAR_COMPONENT = new InjectionToken('FdAvatarComponent');

let avatarUniqueId = 0;
const ALTER_ICON_OPTIONS = {
    CONTENT: 'content',
    ALT: 'alt',
    BACKUP: 'backup',
    DEFAULT_ICON: 'default-icon'
};
class AvatarComponent {
    /** Localized text for label */
    set label(value) {
        this.ariaLabel = value || null;
        this.abbreviate = this._getAbbreviate(value);
    }
    /** Background image resource: url or base64. */
    set image(value) {
        this._setImage(value);
    }
    get image() {
        return this._image;
    }
    /** Backup options to use when image hasn't been loaded successfully.
     * Options separated with "|" symbol.
     * Possible options: content, alt, backup, default-icon
     */
    set alterIcon(value) {
        this._alterIcon = value;
    }
    get alterIcon() {
        return this._alterIcon;
    }
    /** Backup image to load when image hasn't been loaded successfully.
     * Only applicable when using alterIcon input property.
     */
    set backupImage(value) {
        this._backupImage = value;
    }
    get backupImage() {
        return this._backupImage;
    }
    /**
     * @hidden
     */
    set bgImage(image) {
        this._bgImage = image;
        this._renderer.setStyle(this.elementRef.nativeElement, 'background-image', image);
    }
    get bgImage() {
        return this._bgImage;
    }
    /** @hidden */
    get role() {
        return this.zoomGlyph ? 'button' : 'img';
    }
    /** @hidden */
    set content(value) {
        this._content = value;
    }
    /** @hidden */
    get _tabindex() {
        if (this.hostTabindex != null) {
            return this.hostTabindex;
        }
        return this.clickable ? 0 : null;
    }
    /** If a default placeholder should be displayed */
    get showDefault() {
        return !this.abbreviate && !this._image && !this.glyph;
    }
    /** @hidden */
    constructor(elementRef, _cdr, _renderer, hostTabindex) {
        this.elementRef = elementRef;
        this._cdr = _cdr;
        this._renderer = _renderer;
        this.hostTabindex = hostTabindex;
        /** Id of the Avatar. */
        this.id = `fd-avatar-${avatarUniqueId++}`;
        /** Aria-label for Avatar. */
        this.ariaLabel = null;
        /** Aria-Labelledby for element describing Avatar. */
        this.ariaLabelledby = null;
        /** The size of the Avatar. Options include: *xs*, *s*, *m*, *l* and *xl*. */
        this.size = 'l';
        /** Font family of the icon. */
        this.font = FD_DEFAULT_ICON_FONT_FAMILY;
        /** The glyph name. */
        this.glyph = null;
        /** The glyph name for zoom icon. */
        this.zoomGlyph = null;
        /** Whether to apply a circle style to the Avatar. */
        this.circle = false;
        /** Whether to apply a transparent style to the Avatar. */
        this.transparent = false;
        /** Whether to apply background size contain style to the Avatar */
        this.contain = false;
        /** Whether to apply a placeholder background style to the Avatar. */
        this.placeholder = false;
        /** Whether to apply a tile background style to the Avatar. */
        this.tile = false;
        /** Whether to apply a border to the Avatar. */
        this.border = false;
        /** A number from 1 to 10 representing the background color of the Avatar.
         * This property will override the colorIndication property.
         */
        this.colorAccent = null;
        /** A number from 1 to 10 representing the background color of the Avatar using the Indication Colors. */
        this.colorIndication = null;
        /** Whether to apply random background color to the Avatar. */
        this.random = false;
        /** Whether component should be focusable & clicable */
        this.clickable = false;
        /** Event emitted when avatar clicked. Only fires if clickable input property set to true. */
        this.avatarClicked = new EventEmitter();
        /** Event emitted when zoom icon clicked. Only fires if zoomGlyph input property is set. */
        this.zoomGlyphClicked = new EventEmitter();
        /** @hidden */
        this.abbreviate = null;
        /** @hidden */
        this._image = null;
        /** @hidden */
        this._alterIcon = null;
        /** @hidden */
        this._content = null;
        /** @hidden */
        this._backupImage = null;
        /** @hidden */
        this._bgImage = null;
    }
    /** @hidden
     * CssClassBuilder interface implementation
     * function must return single string
     * function is responsible for order which css classes are applied
     */
    buildComponentCssClass() {
        return [
            'fd-avatar',
            this.size ? `fd-avatar--${this.size}` : '',
            this.colorAccent && !this.random ? `fd-avatar--accent-color-${this.colorAccent}` : '',
            this.random ? `fd-avatar--accent-color-${getRandomColorAccent()}` : '',
            this.colorIndication && this.colorAccent === null && !this.random
                ? `fd-avatar--indication-color-${this.colorIndication}`
                : '',
            this.circle ? 'fd-avatar--circle' : '',
            this.border ? 'fd-avatar--border' : '',
            this.transparent ? 'fd-avatar--transparent' : '',
            this.contain ? 'fd-avatar--background-contain' : '',
            this.placeholder ? 'fd-avatar--placeholder' : '',
            this.tile ? 'fd-avatar--tile' : '',
            this.class
        ];
    }
    /** @hidden */
    _onClick(event) {
        if (!this.clickable) {
            return;
        }
        event.preventDefault();
        this.avatarClicked.emit(event);
        if (this.zoomGlyph) {
            this.zoomGlyphClicked.next();
        }
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnChanges() {
        if (this.zoomGlyph) {
            this.clickable = true;
        }
        this.buildComponentCssClass();
    }
    /** @hidden */
    zoomClicked(event) {
        event.preventDefault();
        this.elementRef.nativeElement.focus();
        this.zoomGlyphClicked.next();
    }
    /** @hidden Get an abbreviate from the label or return null if not fit requirements */
    _getAbbreviate(label) {
        if (!label || this._image) {
            return null;
        }
        return this._generateAbbreviation(label);
    }
    /** @hidden Get the abbreviation string */
    _generateAbbreviation(label) {
        if (!label) {
            return null;
        }
        const maxLettersCount = 3;
        const firstLetters = label.split(' ').map((word) => word.charAt(0));
        const abbreviate = firstLetters.join('');
        if (firstLetters.length > maxLettersCount || !abbreviate.match(ANY_LANGUAGE_LETTERS_REGEX)) {
            return null;
        }
        return abbreviate;
    }
    /** @hidden */
    _setImage(value) {
        this._image = value;
        if (value) {
            this._verifyImageUrl(value, () => { }, this._onErrorCallback);
        }
        else {
            this.bgImage = null;
        }
    }
    /** @hidden */
    _verifyImageUrl(srcValue, onLoadCallback, onErrorCallback) {
        // Don't load the same image all the time check happens
        if (srcValue === this.bgImage) {
            return;
        }
        const img = new Image();
        img.onload = onLoadCallback.bind(this);
        img.onerror = onErrorCallback.bind(this);
        img.src = srcValue;
        this._assignBgImage(srcValue);
    }
    /** @hidden */
    _assignBgImage(srcValue) {
        this.bgImage = srcValue ? `url(${srcValue})` : null;
    }
    /** @hidden */
    _onErrorCallback() {
        if (!this._alterIcon) {
            this._showDefaultIcon();
            return;
        }
        const options = this._alterIcon.split('|');
        for (let i = 0; i < options.length; i++) {
            const option = options[i];
            if (option === ALTER_ICON_OPTIONS.CONTENT) {
                const contentValue = this._content?.nativeElement.textContent;
                if (contentValue) {
                    this.abbreviate = this._generateAbbreviation(contentValue);
                    break;
                }
                continue;
            }
            if (option === ALTER_ICON_OPTIONS.ALT) {
                const altValue = this.elementRef.nativeElement.getAttribute('alt');
                if (altValue) {
                    this.abbreviate = this._generateAbbreviation(altValue);
                    break;
                }
                continue;
            }
            if (option === ALTER_ICON_OPTIONS.BACKUP) {
                if (this._backupImage && this._backupImage !== '') {
                    // Check if backupImage can be loaded successfully
                    // If not, set default user icon
                    this._verifyImageUrl(this._backupImage, () => {
                        this._assignBgImage(this._backupImage);
                    }, () => {
                        this._showDefaultIcon();
                    });
                    break;
                }
                continue;
            }
            if (option === ALTER_ICON_OPTIONS.DEFAULT_ICON) {
                this._showDefaultIcon();
                break;
            }
            this._showDefaultIcon();
        }
    }
    /** @hidden */
    _showDefaultIcon() {
        this.abbreviate = null;
        this._image = null;
        this.glyph = null;
        this._cdr.markForCheck();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: i0.Renderer2 }, { token: 'tabindex', attribute: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: AvatarComponent, isStandalone: true, selector: "fd-avatar", inputs: { class: "class", id: "id", ariaLabel: "ariaLabel", ariaLabelledby: "ariaLabelledby", label: "label", size: "size", font: "font", glyph: "glyph", zoomGlyph: "zoomGlyph", circle: "circle", transparent: "transparent", contain: "contain", placeholder: "placeholder", tile: "tile", border: "border", colorAccent: "colorAccent", colorIndication: "colorIndication", random: "random", clickable: "clickable", valueState: "valueState", image: "image", alterIcon: "alterIcon", backupImage: "backupImage" }, outputs: { avatarClicked: "avatarClicked", zoomGlyphClicked: "zoomGlyphClicked" }, host: { listeners: { "click": "_onClick($event)", "keydown.enter": "_onClick($event)", "keydown.space": "_onClick($event)" }, properties: { "attr.tabindex": "_tabindex", "attr.id": "this.id", "attr.aria-label": "this.ariaLabel", "attr.alt": "this.ariaLabel", "attr.aria-labelledby": "this.ariaLabelledby", "attr.role": "this.role" } }, providers: [
            {
                provide: FD_AVATAR_COMPONENT,
                useExisting: AvatarComponent
            }
        ], viewQueries: [{ propertyName: "content", first: true, predicate: ["content"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "@if (abbreviate) {\n    {{ abbreviate }}\n}\n@if (zoomGlyph || valueState) {\n    <i\n        role=\"presentation\"\n        class=\"fd-avatar__zoom-icon\"\n        [class]=\"valueState | fdAvatarIcon: zoomGlyph\"\n        (mousedown)=\"zoomClicked($event)\"\n    >\n    </i>\n}\n@if (glyph || showDefault) {\n    <fd-icon\n        class=\"fd-avatar__icon\"\n        role=\"presentation\"\n        [font]=\"font\"\n        [glyph]=\"glyph || 'person-placeholder'\"\n    ></fd-icon>\n}\n<div #content [style.display]=\"'none'\">\n    <ng-content></ng-content>\n</div>\n", styles: [".fd-avatar{--fdAvatarZoomIconPosition:0;background-color:var(--fdAvatarBackgroundColor);background-position:50%;background-repeat:no-repeat;background-size:var(--fdAvatarBackgroundSize);border:0;border:var(--fdAvatarBorderWidth,.0625rem) solid var(--fdAvatarBorderColor);border-radius:var(--fdAvatarBorderRadius);-webkit-box-shadow:var(--fdAvatarBoxShadow);box-shadow:var(--fdAvatarBoxShadow);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdAvatarColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdAvatarFontSize);font-stretch:var(--fdAvatarFontStretch);font-weight:400;forced-color-adjust:none;height:var(--fdAvatarRatio);line-height:normal;margin-block:0;margin-inline:0;max-height:var(--fdAvatarRatio);max-width:var(--fdAvatarRatio);min-height:var(--fdAvatarRatio);min-width:var(--fdAvatarRatio);padding-block:0;padding-inline:0;position:relative;text-shadow:var(--fdAvatarTextShadow);vertical-align:middle;width:var(--fdAvatarRatio)}.fd-avatar:after,.fd-avatar:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-avatar.is-focus,.fd-avatar:focus{outline:none}.fd-avatar.is-focus:after,.fd-avatar:focus:after{border-color:var(--sapContent_FocusColor);border-radius:var(--fdAvatar_Focus_Outline_Radius);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset);pointer-events:none;position:absolute}.fd-avatar--interactive,.fd-avatar[role=button],.fd-avatar[tabindex=\"0\"]{cursor:pointer}.fd-avatar--interactive.is-hover,.fd-avatar--interactive:hover,.fd-avatar[role=button].is-hover,.fd-avatar[role=button]:hover,.fd-avatar[tabindex=\"0\"].is-hover,.fd-avatar[tabindex=\"0\"]:hover{--fdAvatarBorderColor:var(--fdAvatarBorderHoverColor,var(--sapAvatar_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarHoverBackgroundColor,var(--sapAvatar_6_Hover_Background))}.fd-avatar--interactive.is-disabled,.fd-avatar--interactive:disabled,.fd-avatar--interactive[aria-disabled=true],.fd-avatar[role=button].is-disabled,.fd-avatar[role=button]:disabled,.fd-avatar[role=button][aria-disabled=true],.fd-avatar[tabindex=\"0\"].is-disabled,.fd-avatar[tabindex=\"0\"]:disabled,.fd-avatar[tabindex=\"0\"][aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity)}.fd-avatar--interactive.is-active,.fd-avatar--interactive:active,.fd-avatar[role=button].is-active,.fd-avatar[role=button]:active,.fd-avatar[tabindex=\"0\"].is-active,.fd-avatar[tabindex=\"0\"]:active{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar--interactive.is-active.is-hover,.fd-avatar--interactive.is-active:hover,.fd-avatar--interactive:active.is-hover,.fd-avatar--interactive:active:hover,.fd-avatar[role=button].is-active.is-hover,.fd-avatar[role=button].is-active:hover,.fd-avatar[role=button]:active.is-hover,.fd-avatar[role=button]:active:hover,.fd-avatar[tabindex=\"0\"].is-active.is-hover,.fd-avatar[tabindex=\"0\"].is-active:hover,.fd-avatar[tabindex=\"0\"]:active.is-hover,.fd-avatar[tabindex=\"0\"]:active:hover{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar--interactive.is-toggled,.fd-avatar[role=button].is-toggled,.fd-avatar[tabindex=\"0\"].is-toggled{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar--interactive.is-toggled.is-hover,.fd-avatar--interactive.is-toggled:hover,.fd-avatar[role=button].is-toggled.is-hover,.fd-avatar[role=button].is-toggled:hover,.fd-avatar[tabindex=\"0\"].is-toggled.is-hover,.fd-avatar[tabindex=\"0\"].is-toggled:hover{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar--interactive.is-focus,.fd-avatar--interactive:focus,.fd-avatar[role=button].is-focus,.fd-avatar[role=button]:focus,.fd-avatar[tabindex=\"0\"].is-focus,.fd-avatar[tabindex=\"0\"]:focus{padding-block:.125rem;padding-inline:.125rem;z-index:5}.fd-avatar__zoom-icon{--fdAvatarZoomIconColor:var(--sapButton_Emphasized_TextColor);--fdAvatarZoomIconBorderColor:var(--sapButton_Emphasized_BorderColor);--fdAvatarZoomIconBackground:var(--sapButton_Emphasized_Background)}.fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdAvatarZoomIconBackground);border:.0625rem solid var(--fdAvatarZoomIconBorderColor);border-radius:100%;color:var(--fdAvatarZoomIconColor);font-size:var(--fdAvatarZoomIconFontSize);height:var(--fdAvatarZoomIconDimensions);min-width:var(--fdAvatarZoomIconDimensions);position:absolute;width:var(--fdAvatarZoomIconDimensions);z-index:5}.fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon],.fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon]{bottom:var(--fdAvatarZoomIconPosition);right:var(--fdAvatarZoomIconPosition)}.fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon][dir=rtl],[dir=rtl] .fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon]{left:var(--fdAvatarZoomIconPosition);right:auto}.fd-avatar__zoom-icon--positive{--fdAvatarZoomIconColor:var(--sapPositiveTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapSuccessBackground)}.fd-avatar__zoom-icon--caution{--fdAvatarZoomIconColor:var(--sapCriticalTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapWarningBackground)}.fd-avatar__zoom-icon--negative{--fdAvatarZoomIconColor:var(--sapNegativeTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapErrorBackground)}.fd-avatar__zoom-icon--information{--fdAvatarZoomIconColor:var(--sapInformativeTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapInformationBackground)}.fd-avatar__zoom-icon--indication-1{--fdAvatarZoomIconColor:var(--sapIndicationColor_1_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_1_Background)}.fd-avatar__zoom-icon--indication-2{--fdAvatarZoomIconColor:var(--sapIndicationColor_2_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_2_Background)}.fd-avatar__zoom-icon--indication-3{--fdAvatarZoomIconColor:var(--sapIndicationColor_3_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_3_Background)}.fd-avatar__zoom-icon--indication-4{--fdAvatarZoomIconColor:var(--sapIndicationColor_4_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_4_Background)}.fd-avatar__zoom-icon--indication-5{--fdAvatarZoomIconColor:var(--sapIndicationColor_5_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_5_Background)}.fd-avatar__zoom-icon--indication-6{--fdAvatarZoomIconColor:var(--sapIndicationColor_6_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_6_Background)}.fd-avatar__zoom-icon--indication-7{--fdAvatarZoomIconColor:var(--sapIndicationColor_7_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_7_Background)}.fd-avatar__zoom-icon--indication-8{--fdAvatarZoomIconColor:var(--sapIndicationColor_8_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_8_Background)}.fd-avatar__zoom-icon--indication-9{--fdAvatarZoomIconColor:var(--sapIndicationColor_9_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_9_Background)}.fd-avatar__zoom-icon--indication-10{--fdAvatarZoomIconColor:var(--sapIndicationColor_10_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_10_Background)}.fd-avatar__icon [class*=sap-icon],.fd-avatar__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-line-pack:center;align-content:center}.fd-avatar--circle{--fdAvatarBorderRadius:100%}.fd-avatar--circle.is-focus,.fd-avatar--circle:focus{outline:none}.fd-avatar--circle.is-focus:after,.fd-avatar--circle:focus:after{border-color:var(--sapContent_FocusColor);border-radius:var(--fdAvatar_Focus_Outline_Radius_Circle);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset);pointer-events:none;position:absolute}.fd-avatar--background-contain{--fdAvatarBackgroundSize:contain}.fd-avatar--transparent{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapAvatar_Lite_Background);--fdAvatarColor:var(--sapContent_IconColor);--fdAvatarBorderHoverColor:var(--sapContent_IconColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_Lite_Background)}.fd-avatar--tile{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapTile_Background);--fdAvatarColor:var(--sapTile_IconColor);--fdAvatarBorderHoverColor:var(--sapTile_IconColor);--fdAvatarHoverBackgroundColor:var(--sapTile_Background)}.fd-avatar--placeholder{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapContent_ImagePlaceholderBackground);--fdAvatarColor:var(--sapContent_ImagePlaceholderForegroundColor);--fdAvatarBorderHoverColor:var(--sapContent_ImagePlaceholderForegroundColor);--fdAvatarHoverBackgroundColor:var(--sapContent_ImagePlaceholderBackground)}.fd-avatar--thumbnail{--fdAvatarBorderColor:var(--fdAvatar_Thumbnail_BorderColor);--fdAvatarHoverBorderColor:var(--sapContent_IconColor);--fdAvatarBackgroundColor:var(--sapAvatar_Lite_Background);--fdAvatarHoverBackgroundColor:var(--sapAvatar_Lite_Background)}.fd-avatar--border{--fdAvatarBorderColor:var(--sapGroup_ContentBorderColor);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor)}.fd-avatar--overflow{cursor:pointer;--fdAvatarBorderWidth:var(--fdAvatar_Overflow_Border_Width);--fdAvatarBorderColor:var(--sapButton_BorderColor);--fdAvatarBackgroundColor:var(--sapButton_Background);--fdAvatarColor:var(--sapButton_TextColor);--fdAvatarHoverBackgroundColor:var(--sapButton_Hover_Background);--fdAvatarHoverBorderColor:var(--sapButton_Hover_BorderColor);--fdAvatarBorderActiveColor:var(--sapButton_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapButton_Active_Background);--fdAvatarActiveColor:var(--sapButton_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapButton_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapButton_Active_Background);--fdAvatarActiveHoverColor:var(--sapButton_Active_TextColor)}.fd-avatar--overflow.is-disabled,.fd-avatar--overflow:disabled,.fd-avatar--overflow[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity)}.fd-avatar--accent-color-1,.fd-avatar--accent-color-1.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_1_BorderColor);--fdAvatarColor:var(--sapAvatar_1_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_1_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_1_Hover_Background)}.fd-avatar--accent-color-2,.fd-avatar--accent-color-2.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_2_BorderColor);--fdAvatarColor:var(--sapAvatar_2_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_2_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_2_Hover_Background)}.fd-avatar--accent-color-3,.fd-avatar--accent-color-3.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_3_BorderColor);--fdAvatarColor:var(--sapAvatar_3_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_3_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_3_Hover_Background)}.fd-avatar--accent-color-4,.fd-avatar--accent-color-4.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_4_BorderColor);--fdAvatarColor:var(--sapAvatar_4_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_4_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_4_Hover_Background)}.fd-avatar--accent-color-5,.fd-avatar--accent-color-5.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_5_BorderColor);--fdAvatarColor:var(--sapAvatar_5_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_5_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_5_Hover_Background)}.fd-avatar--accent-color-6,.fd-avatar--accent-color-6.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_6_BorderColor);--fdAvatarColor:var(--sapAvatar_6_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_6_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_6_Hover_Background)}.fd-avatar--accent-color-7,.fd-avatar--accent-color-7.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_7_BorderColor);--fdAvatarColor:var(--sapAvatar_7_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_7_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_7_Hover_Background)}.fd-avatar--accent-color-8,.fd-avatar--accent-color-8.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_8_BorderColor);--fdAvatarColor:var(--sapAvatar_8_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_8_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_8_Hover_Background)}.fd-avatar--accent-color-9,.fd-avatar--accent-color-9.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_9_BorderColor);--fdAvatarColor:var(--sapAvatar_9_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_9_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_9_Hover_Background)}.fd-avatar--accent-color-10,.fd-avatar--accent-color-10.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_10_BorderColor);--fdAvatarColor:var(--sapAvatar_10_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_10_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_10_Hover_Background)}.fd-avatar--indication-color-1,.fd-avatar--indication-color-1.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_1_BorderColor);--fdAvatarColor:var(--sapIndicationColor_1_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_1_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_1_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_1_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_1_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_1_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_1_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_1_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_1_Active_TextColor)}.fd-avatar--indication-color-2,.fd-avatar--indication-color-2.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_2_BorderColor);--fdAvatarColor:var(--sapIndicationColor_2_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_2_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_2_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_2_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_2_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_2_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_2_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_2_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_2_Active_TextColor)}.fd-avatar--indication-color-3,.fd-avatar--indication-color-3.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_3_BorderColor);--fdAvatarColor:var(--sapIndicationColor_3_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_3_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_3_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_3_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_3_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_3_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_3_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_3_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_3_Active_TextColor)}.fd-avatar--indication-color-4,.fd-avatar--indication-color-4.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_4_BorderColor);--fdAvatarColor:var(--sapIndicationColor_4_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_4_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_4_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_4_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_4_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_4_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_4_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_4_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_4_Active_TextColor)}.fd-avatar--indication-color-5,.fd-avatar--indication-color-5.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_5_BorderColor);--fdAvatarColor:var(--sapIndicationColor_5_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_5_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_5_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_5_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_5_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_5_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_5_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_5_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_5_Active_TextColor)}.fd-avatar--indication-color-6,.fd-avatar--indication-color-6.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_6_BorderColor);--fdAvatarColor:var(--sapIndicationColor_6_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_6_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_6_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_6_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_6_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_6_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_6_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_6_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_6_Active_TextColor)}.fd-avatar--indication-color-7,.fd-avatar--indication-color-7.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_7_BorderColor);--fdAvatarColor:var(--sapIndicationColor_7_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_7_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_7_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_7_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_7_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_7_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_7_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_7_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_7_Active_TextColor)}.fd-avatar--indication-color-8,.fd-avatar--indication-color-8.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_8_BorderColor);--fdAvatarColor:var(--sapIndicationColor_8_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_8_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_8_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_8_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_8_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_8_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_8_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_8_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_8_Active_TextColor)}.fd-avatar--indication-color-9,.fd-avatar--indication-color-9.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_9_BorderColor);--fdAvatarColor:var(--sapIndicationColor_9_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_9_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_9_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_9_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_9_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_9_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_9_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_9_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_9_Active_TextColor)}.fd-avatar--indication-color-10,.fd-avatar--indication-color-10.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_10_BorderColor);--fdAvatarColor:var(--sapIndicationColor_10_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_10_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_10_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_10_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_10_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_10_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_10_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_10_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_10_Active_TextColor)}.fd-avatar--xs{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:2rem;--fdAvatarFontSize:1rem;--fdAvatarFontStretch:condensed}.fd-avatar--xs .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--xs .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--s{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:3rem;--fdAvatarFontSize:1.125rem;--fdAvatarFontStretch:condensed}.fd-avatar--s .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--s .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--sm{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:3rem;--fdAvatarFontSize:1.125rem;--fdAvatarFontStretch:condensed}.fd-avatar--sm .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--sm .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--m{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:4rem;--fdAvatarFontSize:1.5rem;--fdAvatarFontStretch:normal}.fd-avatar--m .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--m .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--md{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:4rem;--fdAvatarFontSize:1.5rem;--fdAvatarFontStretch:normal}.fd-avatar--md .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--md .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--l{--fdAvatarZoomIconOffset:-.1875rem;--fdAvatarRatio:5rem;--fdAvatarFontSize:2.25rem;--fdAvatarFontStretch:normal}.fd-avatar--l .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--l .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.25rem;--fdAvatarZoomIconFontSize:.875rem}.fd-avatar--lg{--fdAvatarZoomIconOffset:-.1875rem;--fdAvatarRatio:5rem;--fdAvatarFontSize:2.25rem;--fdAvatarFontStretch:normal}.fd-avatar--lg .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--lg .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.25rem;--fdAvatarZoomIconFontSize:.875rem}.fd-avatar--xl{--fdAvatarZoomIconOffset:-.25rem;--fdAvatarRatio:7rem;--fdAvatarFontSize:3rem;--fdAvatarFontStretch:normal}.fd-avatar--xl .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--xl .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.75rem;--fdAvatarZoomIconFontSize:1rem}.fd-avatar--accent-color-1.fd-avatar--shell,.fd-avatar--accent-color-10.fd-avatar--shell,.fd-avatar--accent-color-2.fd-avatar--shell,.fd-avatar--accent-color-3.fd-avatar--shell,.fd-avatar--accent-color-4.fd-avatar--shell,.fd-avatar--accent-color-5.fd-avatar--shell,.fd-avatar--accent-color-6.fd-avatar--shell,.fd-avatar--accent-color-7.fd-avatar--shell,.fd-avatar--accent-color-8.fd-avatar--shell,.fd-avatar--accent-color-9.fd-avatar--shell,.fd-avatar--indication-color-1.fd-avatar--shell,.fd-avatar--indication-color-10.fd-avatar--shell,.fd-avatar--indication-color-2.fd-avatar--shell,.fd-avatar--indication-color-3.fd-avatar--shell,.fd-avatar--indication-color-4.fd-avatar--shell,.fd-avatar--indication-color-5.fd-avatar--shell,.fd-avatar--indication-color-6.fd-avatar--shell,.fd-avatar--indication-color-7.fd-avatar--shell,.fd-avatar--indication-color-8.fd-avatar--shell,.fd-avatar--indication-color-9.fd-avatar--shell{border:.0625rem solid var(--sapShell_InteractiveBorderColor)}.fd-avatar--l,.fd-avatar--lg,.fd-avatar--m,.fd-avatar--md,.fd-avatar--s,.fd-avatar--sm,.fd-avatar--xl,.fd-avatar--xs{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-avatar--l:not(.fd-avatar--circle),.fd-avatar--lg:not(.fd-avatar--circle),.fd-avatar--m:not(.fd-avatar--circle),.fd-avatar--md:not(.fd-avatar--circle),.fd-avatar--s:not(.fd-avatar--circle),.fd-avatar--sm:not(.fd-avatar--circle),.fd-avatar--xl:not(.fd-avatar--circle),.fd-avatar--xs:not(.fd-avatar--circle){--fdAvatarZoomIconPosition:var(--fdAvatarZoomIconOffset)}\n/*! Bundled license information:\n\nfundamental-styles/dist/avatar.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "pipe", type: AvatarIconPipe, name: "fdAvatarIcon" }, { kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], AvatarComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-avatar', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: FD_AVATAR_COMPONENT,
                            useExisting: AvatarComponent
                        }
                    ], host: {
                        '[attr.tabindex]': '_tabindex'
                    }, imports: [AvatarIconPipe, IconComponent], template: "@if (abbreviate) {\n    {{ abbreviate }}\n}\n@if (zoomGlyph || valueState) {\n    <i\n        role=\"presentation\"\n        class=\"fd-avatar__zoom-icon\"\n        [class]=\"valueState | fdAvatarIcon: zoomGlyph\"\n        (mousedown)=\"zoomClicked($event)\"\n    >\n    </i>\n}\n@if (glyph || showDefault) {\n    <fd-icon\n        class=\"fd-avatar__icon\"\n        role=\"presentation\"\n        [font]=\"font\"\n        [glyph]=\"glyph || 'person-placeholder'\"\n    ></fd-icon>\n}\n<div #content [style.display]=\"'none'\">\n    <ng-content></ng-content>\n</div>\n", styles: [".fd-avatar{--fdAvatarZoomIconPosition:0;background-color:var(--fdAvatarBackgroundColor);background-position:50%;background-repeat:no-repeat;background-size:var(--fdAvatarBackgroundSize);border:0;border:var(--fdAvatarBorderWidth,.0625rem) solid var(--fdAvatarBorderColor);border-radius:var(--fdAvatarBorderRadius);-webkit-box-shadow:var(--fdAvatarBoxShadow);box-shadow:var(--fdAvatarBoxShadow);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdAvatarColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdAvatarFontSize);font-stretch:var(--fdAvatarFontStretch);font-weight:400;forced-color-adjust:none;height:var(--fdAvatarRatio);line-height:normal;margin-block:0;margin-inline:0;max-height:var(--fdAvatarRatio);max-width:var(--fdAvatarRatio);min-height:var(--fdAvatarRatio);min-width:var(--fdAvatarRatio);padding-block:0;padding-inline:0;position:relative;text-shadow:var(--fdAvatarTextShadow);vertical-align:middle;width:var(--fdAvatarRatio)}.fd-avatar:after,.fd-avatar:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-avatar.is-focus,.fd-avatar:focus{outline:none}.fd-avatar.is-focus:after,.fd-avatar:focus:after{border-color:var(--sapContent_FocusColor);border-radius:var(--fdAvatar_Focus_Outline_Radius);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset);pointer-events:none;position:absolute}.fd-avatar--interactive,.fd-avatar[role=button],.fd-avatar[tabindex=\"0\"]{cursor:pointer}.fd-avatar--interactive.is-hover,.fd-avatar--interactive:hover,.fd-avatar[role=button].is-hover,.fd-avatar[role=button]:hover,.fd-avatar[tabindex=\"0\"].is-hover,.fd-avatar[tabindex=\"0\"]:hover{--fdAvatarBorderColor:var(--fdAvatarBorderHoverColor,var(--sapAvatar_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarHoverBackgroundColor,var(--sapAvatar_6_Hover_Background))}.fd-avatar--interactive.is-disabled,.fd-avatar--interactive:disabled,.fd-avatar--interactive[aria-disabled=true],.fd-avatar[role=button].is-disabled,.fd-avatar[role=button]:disabled,.fd-avatar[role=button][aria-disabled=true],.fd-avatar[tabindex=\"0\"].is-disabled,.fd-avatar[tabindex=\"0\"]:disabled,.fd-avatar[tabindex=\"0\"][aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity)}.fd-avatar--interactive.is-active,.fd-avatar--interactive:active,.fd-avatar[role=button].is-active,.fd-avatar[role=button]:active,.fd-avatar[tabindex=\"0\"].is-active,.fd-avatar[tabindex=\"0\"]:active{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar--interactive.is-active.is-hover,.fd-avatar--interactive.is-active:hover,.fd-avatar--interactive:active.is-hover,.fd-avatar--interactive:active:hover,.fd-avatar[role=button].is-active.is-hover,.fd-avatar[role=button].is-active:hover,.fd-avatar[role=button]:active.is-hover,.fd-avatar[role=button]:active:hover,.fd-avatar[tabindex=\"0\"].is-active.is-hover,.fd-avatar[tabindex=\"0\"].is-active:hover,.fd-avatar[tabindex=\"0\"]:active.is-hover,.fd-avatar[tabindex=\"0\"]:active:hover{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar--interactive.is-toggled,.fd-avatar[role=button].is-toggled,.fd-avatar[tabindex=\"0\"].is-toggled{--fdAvatarBorderColor:var(--fdAvatarBorderActiveColor,var(--sapButton_Active_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveColor,var(--sapButton_Active_Background));--fdAvatarColor:var(--fdAvatarActiveColor,var(--sapButton_Active_TextColor))}.fd-avatar--interactive.is-toggled.is-hover,.fd-avatar--interactive.is-toggled:hover,.fd-avatar[role=button].is-toggled.is-hover,.fd-avatar[role=button].is-toggled:hover,.fd-avatar[tabindex=\"0\"].is-toggled.is-hover,.fd-avatar[tabindex=\"0\"].is-toggled:hover{--fdAvatarBorderColor:var(--fdAvatarBorderActiveHoverColor,var(--sapButton_Selected_Hover_BorderColor));--fdAvatarBackgroundColor:var(--fdAvatarBackgroundActiveHoverColor,var(--sapButton_Selected_Hover_Background));--fdAvatarColor:var(--fdAvatarActiveHoverColor,var(--sapButton_Selected_TextColor))}.fd-avatar--interactive.is-focus,.fd-avatar--interactive:focus,.fd-avatar[role=button].is-focus,.fd-avatar[role=button]:focus,.fd-avatar[tabindex=\"0\"].is-focus,.fd-avatar[tabindex=\"0\"]:focus{padding-block:.125rem;padding-inline:.125rem;z-index:5}.fd-avatar__zoom-icon{--fdAvatarZoomIconColor:var(--sapButton_Emphasized_TextColor);--fdAvatarZoomIconBorderColor:var(--sapButton_Emphasized_BorderColor);--fdAvatarZoomIconBackground:var(--sapButton_Emphasized_Background)}.fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdAvatarZoomIconBackground);border:.0625rem solid var(--fdAvatarZoomIconBorderColor);border-radius:100%;color:var(--fdAvatarZoomIconColor);font-size:var(--fdAvatarZoomIconFontSize);height:var(--fdAvatarZoomIconDimensions);min-width:var(--fdAvatarZoomIconDimensions);position:absolute;width:var(--fdAvatarZoomIconDimensions);z-index:5}.fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon],.fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon],.fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon]{bottom:var(--fdAvatarZoomIconPosition);right:var(--fdAvatarZoomIconPosition)}.fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon][dir=rtl],.fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon][dir=rtl],[dir=rtl] .fd-avatar__zoom-icon [class*=sap-icon] [class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon [class*=sap-icon][class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon[class*=sap-icon] [class*=sap-icon],[dir=rtl] .fd-avatar__zoom-icon[class*=sap-icon][class*=sap-icon]{left:var(--fdAvatarZoomIconPosition);right:auto}.fd-avatar__zoom-icon--positive{--fdAvatarZoomIconColor:var(--sapPositiveTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapSuccessBackground)}.fd-avatar__zoom-icon--caution{--fdAvatarZoomIconColor:var(--sapCriticalTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapWarningBackground)}.fd-avatar__zoom-icon--negative{--fdAvatarZoomIconColor:var(--sapNegativeTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapErrorBackground)}.fd-avatar__zoom-icon--information{--fdAvatarZoomIconColor:var(--sapInformativeTextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapInformationBackground)}.fd-avatar__zoom-icon--indication-1{--fdAvatarZoomIconColor:var(--sapIndicationColor_1_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_1_Background)}.fd-avatar__zoom-icon--indication-2{--fdAvatarZoomIconColor:var(--sapIndicationColor_2_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_2_Background)}.fd-avatar__zoom-icon--indication-3{--fdAvatarZoomIconColor:var(--sapIndicationColor_3_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_3_Background)}.fd-avatar__zoom-icon--indication-4{--fdAvatarZoomIconColor:var(--sapIndicationColor_4_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_4_Background)}.fd-avatar__zoom-icon--indication-5{--fdAvatarZoomIconColor:var(--sapIndicationColor_5_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_5_Background)}.fd-avatar__zoom-icon--indication-6{--fdAvatarZoomIconColor:var(--sapIndicationColor_6_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_6_Background)}.fd-avatar__zoom-icon--indication-7{--fdAvatarZoomIconColor:var(--sapIndicationColor_7_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_7_Background)}.fd-avatar__zoom-icon--indication-8{--fdAvatarZoomIconColor:var(--sapIndicationColor_8_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_8_Background)}.fd-avatar__zoom-icon--indication-9{--fdAvatarZoomIconColor:var(--sapIndicationColor_9_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_9_Background)}.fd-avatar__zoom-icon--indication-10{--fdAvatarZoomIconColor:var(--sapIndicationColor_10_TextColor);--fdAvatarZoomIconBorderColor: ;--fdAvatarZoomIconBackground:var(--sapIndicationColor_10_Background)}.fd-avatar__icon [class*=sap-icon],.fd-avatar__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-line-pack:center;align-content:center}.fd-avatar--circle{--fdAvatarBorderRadius:100%}.fd-avatar--circle.is-focus,.fd-avatar--circle:focus{outline:none}.fd-avatar--circle.is-focus:after,.fd-avatar--circle:focus:after{border-color:var(--sapContent_FocusColor);border-radius:var(--fdAvatar_Focus_Outline_Radius_Circle);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset) var(--fdAvatar_Focus_Outline_Offset);pointer-events:none;position:absolute}.fd-avatar--background-contain{--fdAvatarBackgroundSize:contain}.fd-avatar--transparent{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapAvatar_Lite_Background);--fdAvatarColor:var(--sapContent_IconColor);--fdAvatarBorderHoverColor:var(--sapContent_IconColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_Lite_Background)}.fd-avatar--tile{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapTile_Background);--fdAvatarColor:var(--sapTile_IconColor);--fdAvatarBorderHoverColor:var(--sapTile_IconColor);--fdAvatarHoverBackgroundColor:var(--sapTile_Background)}.fd-avatar--placeholder{--fdAvatarBorderColor:var(--sapAvatar_Lite_BorderColor);--fdAvatarBackgroundColor:var(--sapContent_ImagePlaceholderBackground);--fdAvatarColor:var(--sapContent_ImagePlaceholderForegroundColor);--fdAvatarBorderHoverColor:var(--sapContent_ImagePlaceholderForegroundColor);--fdAvatarHoverBackgroundColor:var(--sapContent_ImagePlaceholderBackground)}.fd-avatar--thumbnail{--fdAvatarBorderColor:var(--fdAvatar_Thumbnail_BorderColor);--fdAvatarHoverBorderColor:var(--sapContent_IconColor);--fdAvatarBackgroundColor:var(--sapAvatar_Lite_Background);--fdAvatarHoverBackgroundColor:var(--sapAvatar_Lite_Background)}.fd-avatar--border{--fdAvatarBorderColor:var(--sapGroup_ContentBorderColor);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor)}.fd-avatar--overflow{cursor:pointer;--fdAvatarBorderWidth:var(--fdAvatar_Overflow_Border_Width);--fdAvatarBorderColor:var(--sapButton_BorderColor);--fdAvatarBackgroundColor:var(--sapButton_Background);--fdAvatarColor:var(--sapButton_TextColor);--fdAvatarHoverBackgroundColor:var(--sapButton_Hover_Background);--fdAvatarHoverBorderColor:var(--sapButton_Hover_BorderColor);--fdAvatarBorderActiveColor:var(--sapButton_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapButton_Active_Background);--fdAvatarActiveColor:var(--sapButton_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapButton_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapButton_Active_Background);--fdAvatarActiveHoverColor:var(--sapButton_Active_TextColor)}.fd-avatar--overflow.is-disabled,.fd-avatar--overflow:disabled,.fd-avatar--overflow[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity)}.fd-avatar--accent-color-1,.fd-avatar--accent-color-1.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_1_BorderColor);--fdAvatarColor:var(--sapAvatar_1_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_1_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_1_Hover_Background)}.fd-avatar--accent-color-2,.fd-avatar--accent-color-2.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_2_BorderColor);--fdAvatarColor:var(--sapAvatar_2_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_2_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_2_Hover_Background)}.fd-avatar--accent-color-3,.fd-avatar--accent-color-3.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_3_BorderColor);--fdAvatarColor:var(--sapAvatar_3_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_3_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_3_Hover_Background)}.fd-avatar--accent-color-4,.fd-avatar--accent-color-4.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_4_BorderColor);--fdAvatarColor:var(--sapAvatar_4_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_4_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_4_Hover_Background)}.fd-avatar--accent-color-5,.fd-avatar--accent-color-5.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_5_BorderColor);--fdAvatarColor:var(--sapAvatar_5_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_5_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_5_Hover_Background)}.fd-avatar--accent-color-6,.fd-avatar--accent-color-6.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_6_BorderColor);--fdAvatarColor:var(--sapAvatar_6_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_6_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_6_Hover_Background)}.fd-avatar--accent-color-7,.fd-avatar--accent-color-7.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_7_BorderColor);--fdAvatarColor:var(--sapAvatar_7_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_7_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_7_Hover_Background)}.fd-avatar--accent-color-8,.fd-avatar--accent-color-8.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_8_BorderColor);--fdAvatarColor:var(--sapAvatar_8_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_8_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_8_Hover_Background)}.fd-avatar--accent-color-9,.fd-avatar--accent-color-9.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_9_BorderColor);--fdAvatarColor:var(--sapAvatar_9_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_9_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_9_Hover_Background)}.fd-avatar--accent-color-10,.fd-avatar--accent-color-10.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapAvatar_10_BorderColor);--fdAvatarColor:var(--sapAvatar_10_TextColor);--fdAvatarBackgroundColor:var(--sapAvatar_10_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapAvatar_10_Hover_Background)}.fd-avatar--indication-color-1,.fd-avatar--indication-color-1.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_1_BorderColor);--fdAvatarColor:var(--sapIndicationColor_1_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_1_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_1_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_1_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_1_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_1_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_1_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_1_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_1_Active_TextColor)}.fd-avatar--indication-color-2,.fd-avatar--indication-color-2.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_2_BorderColor);--fdAvatarColor:var(--sapIndicationColor_2_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_2_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_2_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_2_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_2_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_2_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_2_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_2_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_2_Active_TextColor)}.fd-avatar--indication-color-3,.fd-avatar--indication-color-3.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_3_BorderColor);--fdAvatarColor:var(--sapIndicationColor_3_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_3_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_3_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_3_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_3_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_3_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_3_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_3_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_3_Active_TextColor)}.fd-avatar--indication-color-4,.fd-avatar--indication-color-4.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_4_BorderColor);--fdAvatarColor:var(--sapIndicationColor_4_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_4_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_4_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_4_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_4_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_4_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_4_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_4_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_4_Active_TextColor)}.fd-avatar--indication-color-5,.fd-avatar--indication-color-5.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_5_BorderColor);--fdAvatarColor:var(--sapIndicationColor_5_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_5_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_5_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_5_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_5_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_5_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_5_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_5_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_5_Active_TextColor)}.fd-avatar--indication-color-6,.fd-avatar--indication-color-6.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_6_BorderColor);--fdAvatarColor:var(--sapIndicationColor_6_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_6_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_6_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_6_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_6_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_6_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_6_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_6_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_6_Active_TextColor)}.fd-avatar--indication-color-7,.fd-avatar--indication-color-7.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_7_BorderColor);--fdAvatarColor:var(--sapIndicationColor_7_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_7_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_7_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_7_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_7_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_7_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_7_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_7_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_7_Active_TextColor)}.fd-avatar--indication-color-8,.fd-avatar--indication-color-8.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_8_BorderColor);--fdAvatarColor:var(--sapIndicationColor_8_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_8_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_8_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_8_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_8_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_8_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_8_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_8_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_8_Active_TextColor)}.fd-avatar--indication-color-9,.fd-avatar--indication-color-9.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_9_BorderColor);--fdAvatarColor:var(--sapIndicationColor_9_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_9_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_9_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_9_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_9_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_9_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_9_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_9_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_9_Active_TextColor)}.fd-avatar--indication-color-10,.fd-avatar--indication-color-10.fd-avatar--overflow{--fdAvatarBorderColor:var(--sapIndicationColor_10_BorderColor);--fdAvatarColor:var(--sapIndicationColor_10_TextColor);--fdAvatarBackgroundColor:var(--sapIndicationColor_10_Background);--fdAvatarBorderHoverColor:var(--sapAvatar_Hover_BorderColor);--fdAvatarHoverBackgroundColor:var(--sapIndicationColor_10_Hover_Background);--fdAvatarBorderActiveColor:var(--sapIndicationColor_10_Active_BorderColor);--fdAvatarBackgroundActiveColor:var(--sapIndicationColor_10_Active_Background);--fdAvatarActiveColor:var(--sapIndicationColor_10_Active_TextColor);--fdAvatarBorderActiveHoverColor:var(--sapIndicationColor_10_Active_BorderColor);--fdAvatarBackgroundActiveHoverColor:var(--sapIndicationColor_10_Active_Background);--fdAvatarActiveHoverColor:var(--sapIndicationColor_10_Active_TextColor)}.fd-avatar--xs{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:2rem;--fdAvatarFontSize:1rem;--fdAvatarFontStretch:condensed}.fd-avatar--xs .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--xs .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--s{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:3rem;--fdAvatarFontSize:1.125rem;--fdAvatarFontStretch:condensed}.fd-avatar--s .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--s .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--sm{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:3rem;--fdAvatarFontSize:1.125rem;--fdAvatarFontStretch:condensed}.fd-avatar--sm .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--sm .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--m{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:4rem;--fdAvatarFontSize:1.5rem;--fdAvatarFontStretch:normal}.fd-avatar--m .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--m .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--md{--fdAvatarZoomIconOffset:-.125rem;--fdAvatarRatio:4rem;--fdAvatarFontSize:1.5rem;--fdAvatarFontStretch:normal}.fd-avatar--md .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--md .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.125rem;--fdAvatarZoomIconFontSize:.75rem}.fd-avatar--l{--fdAvatarZoomIconOffset:-.1875rem;--fdAvatarRatio:5rem;--fdAvatarFontSize:2.25rem;--fdAvatarFontStretch:normal}.fd-avatar--l .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--l .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.25rem;--fdAvatarZoomIconFontSize:.875rem}.fd-avatar--lg{--fdAvatarZoomIconOffset:-.1875rem;--fdAvatarRatio:5rem;--fdAvatarFontSize:2.25rem;--fdAvatarFontStretch:normal}.fd-avatar--lg .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--lg .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.25rem;--fdAvatarZoomIconFontSize:.875rem}.fd-avatar--xl{--fdAvatarZoomIconOffset:-.25rem;--fdAvatarRatio:7rem;--fdAvatarFontSize:3rem;--fdAvatarFontStretch:normal}.fd-avatar--xl .fd-avatar__zoom-icon [class*=sap-icon],.fd-avatar--xl .fd-avatar__zoom-icon[class*=sap-icon]{--fdAvatarZoomIconDimensions:1.75rem;--fdAvatarZoomIconFontSize:1rem}.fd-avatar--accent-color-1.fd-avatar--shell,.fd-avatar--accent-color-10.fd-avatar--shell,.fd-avatar--accent-color-2.fd-avatar--shell,.fd-avatar--accent-color-3.fd-avatar--shell,.fd-avatar--accent-color-4.fd-avatar--shell,.fd-avatar--accent-color-5.fd-avatar--shell,.fd-avatar--accent-color-6.fd-avatar--shell,.fd-avatar--accent-color-7.fd-avatar--shell,.fd-avatar--accent-color-8.fd-avatar--shell,.fd-avatar--accent-color-9.fd-avatar--shell,.fd-avatar--indication-color-1.fd-avatar--shell,.fd-avatar--indication-color-10.fd-avatar--shell,.fd-avatar--indication-color-2.fd-avatar--shell,.fd-avatar--indication-color-3.fd-avatar--shell,.fd-avatar--indication-color-4.fd-avatar--shell,.fd-avatar--indication-color-5.fd-avatar--shell,.fd-avatar--indication-color-6.fd-avatar--shell,.fd-avatar--indication-color-7.fd-avatar--shell,.fd-avatar--indication-color-8.fd-avatar--shell,.fd-avatar--indication-color-9.fd-avatar--shell{border:.0625rem solid var(--sapShell_InteractiveBorderColor)}.fd-avatar--l,.fd-avatar--lg,.fd-avatar--m,.fd-avatar--md,.fd-avatar--s,.fd-avatar--sm,.fd-avatar--xl,.fd-avatar--xs{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-avatar--l:not(.fd-avatar--circle),.fd-avatar--lg:not(.fd-avatar--circle),.fd-avatar--m:not(.fd-avatar--circle),.fd-avatar--md:not(.fd-avatar--circle),.fd-avatar--s:not(.fd-avatar--circle),.fd-avatar--sm:not(.fd-avatar--circle),.fd-avatar--xl:not(.fd-avatar--circle),.fd-avatar--xs:not(.fd-avatar--circle){--fdAvatarZoomIconPosition:var(--fdAvatarZoomIconOffset)}\n/*! Bundled license information:\n\nfundamental-styles/dist/avatar.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i0.Renderer2 }, { type: undefined, decorators: [{
                    type: Attribute,
                    args: ['tabindex']
                }] }], propDecorators: { class: [{
                type: Input
            }], id: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.id']
            }], ariaLabel: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-label']
            }, {
                type: HostBinding,
                args: ['attr.alt']
            }], ariaLabelledby: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-labelledby']
            }], label: [{
                type: Input
            }], size: [{
                type: Input
            }], font: [{
                type: Input
            }], glyph: [{
                type: Input
            }], zoomGlyph: [{
                type: Input
            }], circle: [{
                type: Input
            }], transparent: [{
                type: Input
            }], contain: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], tile: [{
                type: Input
            }], border: [{
                type: Input
            }], colorAccent: [{
                type: Input
            }], colorIndication: [{
                type: Input
            }], random: [{
                type: Input
            }], clickable: [{
                type: Input
            }], valueState: [{
                type: Input
            }], image: [{
                type: Input
            }], alterIcon: [{
                type: Input
            }], backupImage: [{
                type: Input
            }], avatarClicked: [{
                type: Output
            }], zoomGlyphClicked: [{
                type: Output
            }], role: [{
                type: HostBinding,
                args: ['attr.role']
            }], content: [{
                type: ViewChild,
                args: ['content']
            }], buildComponentCssClass: [], _onClick: [{
                type: HostListener,
                args: ['click', ['$event']]
            }, {
                type: HostListener,
                args: ['keydown.enter', ['$event']]
            }, {
                type: HostListener,
                args: ['keydown.space', ['$event']]
            }] } });

/**
 * @deprecated
 * Use `AvatarComponent` import instead.
 */
class AvatarModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: AvatarModule, imports: [AvatarComponent], exports: [AvatarComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarModule, imports: [AvatarComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: AvatarModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [AvatarComponent],
                    exports: [AvatarComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AvatarComponent, AvatarIconPipe, AvatarModule, FD_AVATAR_COMPONENT };
//# sourceMappingURL=fundamental-ngx-core-avatar.mjs.map
