import * as i1 from '@angular/cdk/portal';
import { DomPortal, PortalModule } from '@angular/cdk/portal';
import * as i0 from '@angular/core';
import { InjectionToken, ContentChild, ChangeDetectionStrategy, ViewEncapsulation, Component, EventEmitter, signal, computed, inject, ElementRef, DestroyRef, ViewChild, ContentChildren, Output, Input, NgModule } from '@angular/core';
import { FD_LINK_COMPONENT, LinkComponent } from '@fundamental-ngx/core/link';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { RtlService } from '@fundamental-ngx/cdk/utils';
import { IconComponent } from '@fundamental-ngx/core/icon';
import { MenuComponent, MenuItemComponent, MenuInteractiveComponent, MenuAddonDirective, MenuTitleDirective, MenuTriggerDirective, GlyphMenuAddonDirective } from '@fundamental-ngx/core/menu';
import { OverflowLayoutComponent, OverflowItemRefDirective, OverflowLayoutItemDirective, OverflowExpandDirective } from '@fundamental-ngx/core/overflow-layout';
import { FD_LANGUAGE, TranslationResolver, FdTranslatePipe } from '@fundamental-ngx/i18n';
import { ContentDensityModule } from '@fundamental-ngx/core/content-density';

const FD_BREADCRUMB_ITEM_COMPONENT = new InjectionToken('FdBreadcrumbItemComponent');
const FD_BREADCRUMB_COMPONENT = new InjectionToken('FdBreadcrumbComponent');

/**
 * Breadcrumb item directive. Must have child breadcrumb link directives.
 *
 * ```html
 * <fd-breadcrumb-item>
 *     <a fd-link [routerLink]="'#'">Breadcrumb Link</a>
 * </fd-breadcrumb-item>
 * ```
 */
class BreadcrumbItemComponent {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /** @hidden */
        this._attached = false;
    }
    /** @hidden */
    ngAfterViewInit() {
        this._attach();
    }
    /**
     * Sets breadcrumb item dom portal.
     */
    setPortal() {
        if (!this.portal) {
            this.portal = new DomPortal(this.elementRef);
        }
    }
    /** @hidden */
    _detach() {
        if (!this._attached) {
            return;
        }
        if (this.linkContentPortal?.isAttached) {
            this.linkContentPortal?.detach();
        }
        if (this.breadcrumbItemPortal?.isAttached) {
            this.breadcrumbItemPortal?.detach();
        }
        this._attached = false;
    }
    /** @hidden */
    _attach() {
        if (this._attached) {
            return;
        }
        if (this.breadcrumbLink && this.breadcrumbLink.contentSpan) {
            this.linkContentPortal = new DomPortal(this.breadcrumbLink.contentSpan.nativeElement);
        }
        this.breadcrumbItemPortal = new DomPortal(this.elementRef.nativeElement.firstElementChild);
        this._attached = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BreadcrumbItemComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: BreadcrumbItemComponent, isStandalone: true, selector: "fd-breadcrumb-item", host: { classAttribute: "fd-breadcrumb__item" }, providers: [
            {
                provide: FD_BREADCRUMB_ITEM_COMPONENT,
                useExisting: BreadcrumbItemComponent
            }
        ], queries: [{ propertyName: "breadcrumbLink", first: true, predicate: FD_LINK_COMPONENT, descendants: true }], ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BreadcrumbItemComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-breadcrumb-item',
                    template: '<ng-content></ng-content>',
                    host: {
                        class: 'fd-breadcrumb__item'
                    },
                    providers: [
                        {
                            provide: FD_BREADCRUMB_ITEM_COMPONENT,
                            useExisting: BreadcrumbItemComponent
                        }
                    ],
                    encapsulation: ViewEncapsulation.None,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { breadcrumbLink: [{
                type: ContentChild,
                args: [FD_LINK_COMPONENT]
            }] } });

/**
 * Breadcrumb parent wrapper directive. Must have breadcrumb item child directives.
 *
 * ```html
 * <fd-breadcrumb>
 *     <fd-breadcrumb-item>
 *         <a fd-link [routerLink]="'#'">Breadcrumb Link</a>
 *     </fd-breadcrumb-item>
 * </fd-breadcrumb>
 * ```
 */
class BreadcrumbComponent {
    constructor() {
        /** Whether to append items to the overflow dropdown in reverse order. Default is true. */
        this.reverse = false;
        /** Tabindex of the breadcrumb. */
        this.tabIndex = '0';
        /**
         * Event emitted when visible items count is changed.
         */
        this.visibleItemsCount = new EventEmitter();
        /**
         * Event emitted when hidden items count is changed.
         */
        this.hiddenItemsCount = new EventEmitter();
        /**
         * @hidden
         * Array of breadcrumb items.
         */
        this._items$ = signal([]);
        /** @hidden */
        this._placement$ = computed(() => (this._rtl$() ? 'bottom-end' : 'bottom-start'));
        /** Element reference. */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this._rtlService = inject(RtlService, {
            optional: true
        });
        /** @hidden */
        this._rtl$ = computed(() => !!this._rtlService?.rtlSignal());
        /** @hidden */
        this._lang$ = inject(FD_LANGUAGE);
        /** @hidden */
        this._translationResolver = new TranslationResolver();
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
    }
    /** @hidden */
    onResize() {
        this._overflowLayout.triggerRecalculation();
    }
    /**
     * Function that handles click, touch, enter and space events.
     */
    itemClicked(breadcrumbItem, $event) {
        $event.preventDefault();
        breadcrumbItem.breadcrumbLink.elementRef.nativeElement.click();
    }
    /** @hidden */
    ngOnInit() {
        this._lang$.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((lang) => {
            this._ariaLabel = this._translationResolver.resolve(lang, 'coreBreadcrumb.breadcrumbTrailLabel');
        });
    }
    /** @hidden */
    ngAfterViewInit() {
        this._setItems();
        this._contentItems.changes.subscribe(() => this._setItems());
        this._menuComponent._navContainerRole = 'dialog';
        this._menuComponent._menuListContainerRole = 'menu';
    }
    /** @hidden */
    _keyDownHandle(event) {
        this._menuComponent.toggle();
        event.preventDefault();
    }
    /** @hidden */
    _onHiddenChange(isHidden, breadcrumb) {
        if (!isHidden) {
            breadcrumb._detach();
        }
        else {
            breadcrumb._attach();
        }
    }
    /** @hidden */
    _onVisibleItemsCountChange(visibleItemsCount) {
        this.visibleItemsCount.emit(visibleItemsCount);
    }
    /** @hidden */
    _onHiddenItemsCountChange(hiddenItemsCount) {
        this.hiddenItemsCount.emit(hiddenItemsCount);
    }
    /** @hidden */
    _setItems() {
        this._contentItems.forEach((item) => item.setPortal());
        this._items$.set(this._contentItems.toArray());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BreadcrumbComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: BreadcrumbComponent, isStandalone: true, selector: "fd-breadcrumb", inputs: { reverse: "reverse", tabIndex: "tabIndex" }, outputs: { visibleItemsCount: "visibleItemsCount", hiddenItemsCount: "hiddenItemsCount" }, host: { attributes: { "role": "navigation" }, properties: { "attr.aria-label": "_ariaLabel" }, classAttribute: "fd-breadcrumb" }, providers: [
            {
                provide: FD_BREADCRUMB_COMPONENT,
                useExisting: BreadcrumbComponent
            }
        ], queries: [{ propertyName: "_contentItems", predicate: FD_BREADCRUMB_ITEM_COMPONENT }], viewQueries: [{ propertyName: "_menuComponent", first: true, predicate: MenuComponent, descendants: true }, { propertyName: "_overflowLayout", first: true, predicate: OverflowLayoutComponent, descendants: true }], ngImport: i0, template: "<fd-overflow-layout\n    [reverseHiddenItems]=\"!reverse\"\n    showMorePosition=\"left\"\n    [enableKeyboardNavigation]=\"false\"\n    (visibleItemsCount)=\"_onVisibleItemsCountChange($event)\"\n    (hiddenItemsCount)=\"_onHiddenItemsCountChange($event)\"\n    ariaRole=\"list\"\n>\n    @for (breadcrumb of _items$(); track breadcrumb) {\n        <div\n            *fdOverflowItemRef=\"breadcrumb; let hidden\"\n            fdOverflowLayoutItem\n            (hiddenChange)=\"_onHiddenChange($event, breadcrumb)\"\n        >\n            <ng-template [cdkPortalOutlet]=\"breadcrumb.portal\"></ng-template>\n        </div>\n    }\n    <ng-container *fdOverflowExpand=\"let breadcrumbs; items: _items$()\">\n        <fd-menu #menu [closeOnEscapeKey]=\"true\" [focusAutoCapture]=\"true\" [placement]=\"_placement$()\">\n            @for (breadcrumbItem of breadcrumbs; track breadcrumbItem) {\n                <li\n                    fd-menu-item\n                    [disabled]=\"\n                        breadcrumbItem.item.breadcrumbLink ? breadcrumbItem.item.breadcrumbLink.disabled : false\n                    \"\n                >\n                    <a fd-menu-interactive (click)=\"itemClicked(breadcrumbItem.item, $event)\">\n                        @if (breadcrumbItem?.item.breadcrumbLink) {\n                            @if (breadcrumbItem.item.breadcrumbLink._prefixIconName) {\n                                <fd-menu-addon\n                                    position=\"before\"\n                                    [glyph]=\"breadcrumbItem.item.breadcrumbLink._prefixIconName\"\n                                ></fd-menu-addon>\n                            }\n                            <span fd-menu-title>\n                                <ng-container [cdkPortalOutlet]=\"breadcrumbItem.item.linkContentPortal\"></ng-container>\n                            </span>\n                            @if (breadcrumbItem.item.breadcrumbLink._postfixIconName) {\n                                <fd-menu-addon\n                                    [glyph]=\"breadcrumbItem.item.breadcrumbLink._postfixIconName\"\n                                ></fd-menu-addon>\n                            }\n                        } @else {\n                            <span fd-menu-title>\n                                <ng-container\n                                    [cdkPortalOutlet]=\"breadcrumbItem.item.breadcrumbItemPortal\"\n                                ></ng-container>\n                            </span>\n                        }\n                    </a>\n                </li>\n            }\n        </fd-menu>\n        @if (breadcrumbs.length > 0) {\n            <span class=\"fd-breadcrumb__item\" [fdMenuTrigger]=\"menu\">\n                <a\n                    fd-link\n                    [attr.aria-label]=\"'coreBreadcrumb.overflowTitleMore' | fdTranslate\"\n                    aria-haspopup=\"menu\"\n                    tabindex=\"0\"\n                    class=\"fd-breadcrumb__collapsed\"\n                    (keydown.enter)=\"_keyDownHandle($event)\"\n                    (keydown.space)=\"_keyDownHandle($event)\"\n                >\n                    <fd-icon\n                        glyph=\"overflow\"\n                        [title]=\"'coreBreadcrumb.overflowTitleMore' | fdTranslate\"\n                        [ariaLabel]=\"'coreBreadcrumb.overflowTitleMore' | fdTranslate\"\n                    ></fd-icon>\n                    <fd-icon glyph=\"slim-arrow-down\"></fd-icon>\n                </a>\n            </span>\n        }\n    </ng-container>\n</fd-overflow-layout>\n<ng-content></ng-content>\n", styles: [".fd-breadcrumb{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-wrap:wrap;flex-wrap:wrap;--fdLink_Line_Height:1.5rem;list-style:none;-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-breadcrumb:after,.fd-breadcrumb:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-breadcrumb__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:.0625rem;padding-inline:0}.fd-breadcrumb__item:after,.fd-breadcrumb__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-breadcrumb__item:after{color:var(--sapTextColor);content:var(--fdBreadcrumb_Separator,\"/\");margin-inline:.25rem}.fd-breadcrumb__item:last-child:not(:has(a)){--fdBreadcrumb_Separator:none}.fd-breadcrumb__item .fd-breadcrumb__popover-body{border:none;border-top-left-radius:.125rem;border-top-right-radius:.125rem}.fd-breadcrumb--backslash{--fdBreadcrumb_Separator:\"\\\\\"}.fd-breadcrumb--double-slash{--fdBreadcrumb_Separator:\"//\"}.fd-breadcrumb--double-backslash{--fdBreadcrumb_Separator:\"\\\\\\\\\"}.fd-breadcrumb--greater-than{--fdBreadcrumb_Separator:\">\"}.fd-breadcrumb--double-greater-than{--fdBreadcrumb_Separator:\">>\"}.fd-breadcrumb{display:flex;white-space:nowrap}.fd-breadcrumb .fd-breadcrumb__collapsed{cursor:pointer}.fd-breadcrumb .fd-overflow-layout{justify-content:start}.fd-breadcrumb .fd-breadcrumb__item:last-child:after{content:\"/\"}.fd-breadcrumb .fd-overflow-layout__item--last .fd-breadcrumb__item:after{content:none}\n/*! Bundled license information:\n\nfundamental-styles/dist/breadcrumb.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "component", type: OverflowLayoutComponent, selector: "fd-overflow-layout", inputs: ["maxVisibleItems", "navigationTrigger", "showMorePosition", "renderShowMoreButton", "reverseHiddenItems", "enableKeyboardNavigation", "ariaRole", "moreItemsButtonText"], outputs: ["visibleItemsCount", "hiddenItemsCount", "hiddenItemsChange"] }, { kind: "directive", type: OverflowItemRefDirective, selector: "[fdOverflowItemRef]", inputs: ["fdOverflowItemRef"] }, { kind: "directive", type: OverflowLayoutItemDirective, selector: "[fdOverflowLayoutItem]", inputs: ["forceVisibility"], outputs: ["hiddenChange"] }, { kind: "ngmodule", type: PortalModule }, { kind: "directive", type: i1.CdkPortalOutlet, selector: "[cdkPortalOutlet]", inputs: ["cdkPortalOutlet"], outputs: ["attached"], exportAs: ["cdkPortalOutlet"] }, { kind: "directive", type: OverflowExpandDirective, selector: "[fdOverflowExpand]", inputs: ["fdOverflowExpandItems"] }, { kind: "component", type: MenuComponent, selector: "fd-menu", inputs: ["mobile", "disabled", "focusTrapped", "focusAutoCapture", "openOnHoverTime", "mobileConfig", "ariaLabel", "ariaLabelledby", "id"], outputs: ["activePath"] }, { kind: "component", type: MenuItemComponent, selector: "li[fd-menu-item]", inputs: ["disabled", "itemId", "submenu", "parentSubmenu", "hasSeparator"], outputs: ["onSelect"], exportAs: ["fd-menu-item"] }, { kind: "component", type: MenuInteractiveComponent, selector: "[fd-menu-interactive]" }, { kind: "component", type: MenuAddonDirective, selector: "fd-menu-addon", inputs: ["position", "submenuIndicator", "ariaHidden"] }, { kind: "directive", type: MenuTitleDirective, selector: "[fd-menu-title]" }, { kind: "directive", type: MenuTriggerDirective, selector: "[fdMenuTrigger]", inputs: ["fdMenuTrigger"] }, { kind: "component", type: LinkComponent, selector: "[fdLink], [fd-link]", inputs: ["class", "emphasized", "disabled", "inverted", "subtle", "undecorated"] }, { kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BreadcrumbComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-breadcrumb', host: {
                        class: 'fd-breadcrumb',
                        role: 'navigation',
                        '[attr.aria-label]': '_ariaLabel'
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: FD_BREADCRUMB_COMPONENT,
                            useExisting: BreadcrumbComponent
                        }
                    ], imports: [
                        OverflowLayoutComponent,
                        OverflowItemRefDirective,
                        OverflowLayoutItemDirective,
                        PortalModule,
                        OverflowExpandDirective,
                        MenuComponent,
                        MenuItemComponent,
                        MenuInteractiveComponent,
                        GlyphMenuAddonDirective,
                        MenuAddonDirective,
                        MenuTitleDirective,
                        MenuTriggerDirective,
                        LinkComponent,
                        IconComponent,
                        FdTranslatePipe
                    ], template: "<fd-overflow-layout\n    [reverseHiddenItems]=\"!reverse\"\n    showMorePosition=\"left\"\n    [enableKeyboardNavigation]=\"false\"\n    (visibleItemsCount)=\"_onVisibleItemsCountChange($event)\"\n    (hiddenItemsCount)=\"_onHiddenItemsCountChange($event)\"\n    ariaRole=\"list\"\n>\n    @for (breadcrumb of _items$(); track breadcrumb) {\n        <div\n            *fdOverflowItemRef=\"breadcrumb; let hidden\"\n            fdOverflowLayoutItem\n            (hiddenChange)=\"_onHiddenChange($event, breadcrumb)\"\n        >\n            <ng-template [cdkPortalOutlet]=\"breadcrumb.portal\"></ng-template>\n        </div>\n    }\n    <ng-container *fdOverflowExpand=\"let breadcrumbs; items: _items$()\">\n        <fd-menu #menu [closeOnEscapeKey]=\"true\" [focusAutoCapture]=\"true\" [placement]=\"_placement$()\">\n            @for (breadcrumbItem of breadcrumbs; track breadcrumbItem) {\n                <li\n                    fd-menu-item\n                    [disabled]=\"\n                        breadcrumbItem.item.breadcrumbLink ? breadcrumbItem.item.breadcrumbLink.disabled : false\n                    \"\n                >\n                    <a fd-menu-interactive (click)=\"itemClicked(breadcrumbItem.item, $event)\">\n                        @if (breadcrumbItem?.item.breadcrumbLink) {\n                            @if (breadcrumbItem.item.breadcrumbLink._prefixIconName) {\n                                <fd-menu-addon\n                                    position=\"before\"\n                                    [glyph]=\"breadcrumbItem.item.breadcrumbLink._prefixIconName\"\n                                ></fd-menu-addon>\n                            }\n                            <span fd-menu-title>\n                                <ng-container [cdkPortalOutlet]=\"breadcrumbItem.item.linkContentPortal\"></ng-container>\n                            </span>\n                            @if (breadcrumbItem.item.breadcrumbLink._postfixIconName) {\n                                <fd-menu-addon\n                                    [glyph]=\"breadcrumbItem.item.breadcrumbLink._postfixIconName\"\n                                ></fd-menu-addon>\n                            }\n                        } @else {\n                            <span fd-menu-title>\n                                <ng-container\n                                    [cdkPortalOutlet]=\"breadcrumbItem.item.breadcrumbItemPortal\"\n                                ></ng-container>\n                            </span>\n                        }\n                    </a>\n                </li>\n            }\n        </fd-menu>\n        @if (breadcrumbs.length > 0) {\n            <span class=\"fd-breadcrumb__item\" [fdMenuTrigger]=\"menu\">\n                <a\n                    fd-link\n                    [attr.aria-label]=\"'coreBreadcrumb.overflowTitleMore' | fdTranslate\"\n                    aria-haspopup=\"menu\"\n                    tabindex=\"0\"\n                    class=\"fd-breadcrumb__collapsed\"\n                    (keydown.enter)=\"_keyDownHandle($event)\"\n                    (keydown.space)=\"_keyDownHandle($event)\"\n                >\n                    <fd-icon\n                        glyph=\"overflow\"\n                        [title]=\"'coreBreadcrumb.overflowTitleMore' | fdTranslate\"\n                        [ariaLabel]=\"'coreBreadcrumb.overflowTitleMore' | fdTranslate\"\n                    ></fd-icon>\n                    <fd-icon glyph=\"slim-arrow-down\"></fd-icon>\n                </a>\n            </span>\n        }\n    </ng-container>\n</fd-overflow-layout>\n<ng-content></ng-content>\n", styles: [".fd-breadcrumb{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-wrap:wrap;flex-wrap:wrap;--fdLink_Line_Height:1.5rem;list-style:none;-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-breadcrumb:after,.fd-breadcrumb:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-breadcrumb__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:.0625rem;padding-inline:0}.fd-breadcrumb__item:after,.fd-breadcrumb__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-breadcrumb__item:after{color:var(--sapTextColor);content:var(--fdBreadcrumb_Separator,\"/\");margin-inline:.25rem}.fd-breadcrumb__item:last-child:not(:has(a)){--fdBreadcrumb_Separator:none}.fd-breadcrumb__item .fd-breadcrumb__popover-body{border:none;border-top-left-radius:.125rem;border-top-right-radius:.125rem}.fd-breadcrumb--backslash{--fdBreadcrumb_Separator:\"\\\\\"}.fd-breadcrumb--double-slash{--fdBreadcrumb_Separator:\"//\"}.fd-breadcrumb--double-backslash{--fdBreadcrumb_Separator:\"\\\\\\\\\"}.fd-breadcrumb--greater-than{--fdBreadcrumb_Separator:\">\"}.fd-breadcrumb--double-greater-than{--fdBreadcrumb_Separator:\">>\"}.fd-breadcrumb{display:flex;white-space:nowrap}.fd-breadcrumb .fd-breadcrumb__collapsed{cursor:pointer}.fd-breadcrumb .fd-overflow-layout{justify-content:start}.fd-breadcrumb .fd-breadcrumb__item:last-child:after{content:\"/\"}.fd-breadcrumb .fd-overflow-layout__item--last .fd-breadcrumb__item:after{content:none}\n/*! Bundled license information:\n\nfundamental-styles/dist/breadcrumb.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], propDecorators: { reverse: [{
                type: Input
            }], tabIndex: [{
                type: Input
            }], visibleItemsCount: [{
                type: Output
            }], hiddenItemsCount: [{
                type: Output
            }], _contentItems: [{
                type: ContentChildren,
                args: [FD_BREADCRUMB_ITEM_COMPONENT]
            }], _menuComponent: [{
                type: ViewChild,
                args: [MenuComponent]
            }], _overflowLayout: [{
                type: ViewChild,
                args: [OverflowLayoutComponent]
            }] } });

const components = [BreadcrumbComponent, BreadcrumbItemComponent, LinkComponent, ContentDensityModule];
class BreadcrumbModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BreadcrumbModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: BreadcrumbModule, imports: [BreadcrumbComponent, BreadcrumbItemComponent, LinkComponent, ContentDensityModule], exports: [BreadcrumbComponent, BreadcrumbItemComponent, LinkComponent, ContentDensityModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BreadcrumbModule, imports: [BreadcrumbComponent, LinkComponent, ContentDensityModule, ContentDensityModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BreadcrumbModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...components],
                    exports: [...components]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BreadcrumbComponent, BreadcrumbItemComponent, BreadcrumbModule, FD_BREADCRUMB_COMPONENT, FD_BREADCRUMB_ITEM_COMPONENT };
//# sourceMappingURL=fundamental-ngx-core-breadcrumb.mjs.map
