import * as i0 from '@angular/core';
import { InjectionToken, Injectable, input, booleanAttribute, Optional, ChangeDetectionStrategy, ViewEncapsulation, Component, inject, ChangeDetectorRef, ContentChildren, Directive, ContentChild, DestroyRef, signal, ElementRef, NgZone, isDevMode, HostListener, HostBinding, ViewChild, Input, ComponentRef, EmbeddedViewRef, Type, TemplateRef, PLATFORM_ID, Injector, Inject, NgModule } from '@angular/core';
import * as i3$2 from '@angular/cdk/portal';
import { PortalModule, CdkPortalOutlet, ComponentPortal } from '@angular/cdk/portal';
import { AsyncPipe, NgTemplateOutlet, isPlatformBrowser } from '@angular/common';
import * as i1 from '@fundamental-ngx/cdk/utils';
import { DynamicPortalComponent, TemplateDirective, FocusTrapService, RtlService, KeyUtil, ResizeDirective, ResizeHandleDirective, applyCssClass, InitialFocusDirective, DynamicComponentContainer, DynamicComponentService, TemplateModule } from '@fundamental-ngx/cdk/utils';
import { BusyIndicatorComponent } from '@fundamental-ngx/core/busy-indicator';
import * as i3 from '@fundamental-ngx/core/scrollbar';
import { ScrollbarDirective } from '@fundamental-ngx/core/scrollbar';
import { Subject, BehaviorSubject, Subscription, fromEvent, of, asyncScheduler } from 'rxjs';
import { IconComponent } from '@fundamental-ngx/core/icon';
import { FD_BUTTON_BAR_COMPONENT, BarComponent, BarRightDirective, BarLeftDirective, BarElementDirective, ButtonBarComponent, BarMiddleDirective } from '@fundamental-ngx/core/bar';
import { ContentDensityDirective, contentDensityObserverProviders } from '@fundamental-ngx/core/content-density';
import { startWith, filter, debounceTime, observeOn, take } from 'rxjs/operators';
import { TitleToken, TitleComponent } from '@fundamental-ngx/core/title';
import * as i2 from '@angular/cdk/overlay';
import { CdkScrollable, OverlayConfig, OverlayContainer } from '@angular/cdk/overlay';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { __decorate, __metadata } from 'tslib';
import * as i3$1 from '@angular/cdk/a11y';
import { A11yModule } from '@angular/cdk/a11y';
import { CdkDrag, CdkDragHandle } from '@angular/cdk/drag-drop';
import { ESCAPE } from '@angular/cdk/keycodes';
import { Router, NavigationStart } from '@angular/router';
import { trigger, state, transition, style, animate } from '@angular/animations';

const FD_DIALOG_BODY_COMPONENT = new InjectionToken('FdDialogBodyComponent');
const FD_DIALOG_FOCUS_TRAP_ERROR = new InjectionToken('FdDialogFocusTrapError');

class DialogConfigBase {
    constructor() {
        /** Aria Modal for the dialog component element */
        this.ariaModal = false;
        /** Whether the dialog should have a backdrop. */
        this.hasBackdrop = true;
        /** Whether clicking on the backdrop should close the dialog. Only works if hasBackdrop is true. */
        this.backdropClickCloseable = false;
        /** Whether the escape key should close the dialog. */
        this.escKeyCloseable = true;
        /** Whether the dialog should be focus trapped. */
        this.focusTrapped = true;
        /** The container that the dialog is appended to. By default, it is appended to the body. */
        this.container = 'body';
        /** Whether the dialog should have vertical padding. */
        this.verticalPadding = true;
        /** Whether the dialog should have horizontal padding. */
        this.horizontalPadding = true;
        /** Whether to completely disable dialog body paddings. */
        this.disablePaddings = false;
        /** Whether the dialog should have responsive horizontal padding changing with Dialogs window width.
         * max-width: 599px                         - .fd-dialog__content--s
         * min-width: 600px and max-width: 1023px   - .fd-dialog__content--m
         * min-width: 1024px and max-width: 1439px  - .fd-dialog__content--l
         * min-width: 1440px                        - .fd-dialog__content--xl
         * */
        this.responsivePadding = false;
        /** Whether to close the dialog on router navigation start. */
        this.closeOnNavigation = true;
    }
}

/**
 * Configuration for opening a dialog with the DialogService.
 */
const DIALOG_DEFAULT_CONFIG = new InjectionToken('Default DialogConfig');
class DialogConfig extends DialogConfigBase {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogConfig, deps: null, target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogConfig }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogConfig, decorators: [{
            type: Injectable
        }] });

var FD_DIALOG_DISMISS_REASON;
(function (FD_DIALOG_DISMISS_REASON) {
    FD_DIALOG_DISMISS_REASON["ESCAPE"] = "escape";
    FD_DIALOG_DISMISS_REASON["BACKDROP"] = "backdrop";
    FD_DIALOG_DISMISS_REASON["NAVIGATION_CHANGE"] = "navigation change";
})(FD_DIALOG_DISMISS_REASON || (FD_DIALOG_DISMISS_REASON = {}));
class DialogRefBase {
    /** @hidden */
    constructor() {
        /** @hidden */
        this._endClose$ = new Subject();
        /** @hidden */
        this._afterClosed = new Subject();
        /** @hidden */
        this._afterLoaded = new Subject();
        this.afterClosed = this._afterClosed.asObservable();
        this.afterLoaded = this._afterLoaded.asObservable();
    }
    /**
     * Closes the dialog and emits the result to the afterClosed observable.
     * @param result Value passed back to the observable as a result.
     */
    close(result) {
        this._endClose$.next();
        this._endClose$.complete();
        this._afterClosed.next(result);
        this._afterClosed.complete();
    }
    /**
     * Dismisses the dialog and passes the argument to the afterClosed observable as an error.
     * @param reason Value passed back to the observable as an error.
     */
    dismiss(reason) {
        this._afterClosed.error(reason);
    }
    /** Function that is called after the view of modal is initialised. */
    loaded() {
        this._afterLoaded.next(true);
    }
}

/* eslint-disable @typescript-eslint/member-ordering */
/**
 * Reference to a dialog component
 * It can be injected into the content component through the constructor.
 * For a template, it is declared as part of the implicit context, see examples.
 */
class DialogRef extends DialogRefBase {
    constructor() {
        super(...arguments);
        /** @hidden */
        this._onHide = new BehaviorSubject(false);
        /** @hidden */
        this._onLoading = new BehaviorSubject(false);
        /** @hidden */
        this._fullScreen = new BehaviorSubject(false);
        /** Observable that is triggered whenever the dialog should be visually hidden or visible.*/
        this.onHide = this._onHide.asObservable();
        /** Observable that is triggered whenever the dialog should be displayed in loading state.*/
        this.onLoading = this._onLoading.asObservable();
        /** Observable that is triggered whenever the full-screen state being changed. */
        this.fullScreen = this._fullScreen.asObservable();
    }
    /**
     * Visually hides the dialog.
     * @param isHidden Value used to determine if dialog window should be hidden or visible.
     */
    hide(isHidden) {
        this._onHide.next(isHidden);
    }
    /**
     * Displays the dialog in loading state.
     * @param loadingData Value used to determine if dialog window should be displayed in loading state.
     */
    loading(loadingData) {
        if (typeof loadingData === 'boolean') {
            return this.loading({ isLoading: loadingData });
        }
        this.loadingLabel = loadingData.loadingLabel;
        this.loadingContent = loadingData.loadingContent;
        this.isLoading = loadingData.isLoading;
        this._onLoading.next(loadingData.isLoading);
    }
    /**
     * Toggles full-screen mode of the Dialog.
     */
    toggleFullScreen() {
        this._fullScreen.next(!this._fullScreen.value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogRef, deps: null, target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogRef }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogRef, decorators: [{
            type: Injectable
        }] });

/**
 * Applies fundamental layout and styling to the contents of a dialog body.
 *
 * ```html
 * <fd-dialog-body>
 *     <!-- Content -->
 * </fd-dialog-body>
 * ```
 */
class DialogBodyComponent {
    /** @hidden */
    constructor(elementRef, dialogConfig, dialogRef) {
        this.elementRef = elementRef;
        this.dialogConfig = dialogConfig;
        this.dialogRef = dialogRef;
        /**
         * property to remove the horizontal and vertical paddings from the body
         * default is set to false
         */
        this.disablePaddings = input(false, { transform: booleanAttribute });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogBodyComponent, deps: [{ token: i0.ElementRef }, { token: DialogConfig, optional: true }, { token: DialogRef, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: DialogBodyComponent, isStandalone: true, selector: "fd-dialog-body", inputs: { disablePaddings: { classPropertyName: "disablePaddings", publicName: "disablePaddings", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "class.fd-dialog__body": "true", "class.fd-settings__dialog-body": "dialogConfig.settings", "class.fd-dialog__body--no-vertical-padding": "!dialogConfig.verticalPadding", "class.fd-dialog__body--no-horizontal-padding": "!dialogConfig.horizontalPadding", "style.min-height": "dialogConfig.bodyMinHeight", "style.padding": "dialogConfig.disablePaddings || disablePaddings() || dialogConfig.settings ? 0 : \"1rem\"" } }, providers: [
            {
                provide: FD_DIALOG_BODY_COMPONENT,
                useExisting: DialogBodyComponent
            }
        ], hostDirectives: [{ directive: i3.ScrollbarDirective }], ngImport: i0, template: "<section>\n    <ng-content></ng-content>\n\n    @if (dialogRef.onLoading | async) {\n        <div class=\"fd-dialog__loader fd-busy-indicator-dialog\">\n            @if (dialogRef.loadingContent) {\n                <fdk-dynamic-portal class=\"fd-text\" [auto]=\"dialogRef.loadingContent\"></fdk-dynamic-portal>\n            }\n            <fd-busy-indicator [loading]=\"true\" size=\"l\" [label]=\"dialogRef.loadingLabel\"></fd-busy-indicator>\n        </div>\n    }\n</section>\n", dependencies: [{ kind: "component", type: DynamicPortalComponent, selector: "fdk-dynamic-portal", inputs: ["domElement", "component", "template", "auto"], outputs: ["attached"] }, { kind: "component", type: BusyIndicatorComponent, selector: "fd-busy-indicator", inputs: ["loading", "size", "block", "ariaLabel", "ariaValueText", "title", "label", "ariaLive"] }, { kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "ngmodule", type: PortalModule }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogBodyComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-dialog-body', host: {
                        '[class.fd-dialog__body]': 'true',
                        '[class.fd-settings__dialog-body]': 'dialogConfig.settings',
                        '[class.fd-dialog__body--no-vertical-padding]': '!dialogConfig.verticalPadding',
                        '[class.fd-dialog__body--no-horizontal-padding]': '!dialogConfig.horizontalPadding',
                        '[style.min-height]': 'dialogConfig.bodyMinHeight',
                        '[style.padding]': 'dialogConfig.disablePaddings || disablePaddings() || dialogConfig.settings ? 0 : "1rem"'
                    }, providers: [
                        {
                            provide: FD_DIALOG_BODY_COMPONENT,
                            useExisting: DialogBodyComponent
                        }
                    ], encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, hostDirectives: [ScrollbarDirective], standalone: true, imports: [DynamicPortalComponent, BusyIndicatorComponent, AsyncPipe, PortalModule], template: "<section>\n    <ng-content></ng-content>\n\n    @if (dialogRef.onLoading | async) {\n        <div class=\"fd-dialog__loader fd-busy-indicator-dialog\">\n            @if (dialogRef.loadingContent) {\n                <fdk-dynamic-portal class=\"fd-text\" [auto]=\"dialogRef.loadingContent\"></fdk-dynamic-portal>\n            }\n            <fd-busy-indicator [loading]=\"true\" size=\"l\" [label]=\"dialogRef.loadingLabel\"></fd-busy-indicator>\n        </div>\n    }\n</section>\n" }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: DialogConfig, decorators: [{
                    type: Optional
                }] }, { type: DialogRef, decorators: [{
                    type: Optional
                }] }] });

/**
 * Directive that applies fundamental dialog styling to a dialog close button.
 *
 * ```html
 * <button fd-dialog-close-button></button>
 * ```
 */
class DialogCloseButtonComponent {
    constructor() {
        /** Displays dialog close button in mobile mode */
        this.mobile = input(false);
        /** add title dynamically to add a tooltip */
        this.title = input();
        /** add aria label dynamically to add to the button */
        this.ariaLabel = input();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogCloseButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "20.0.2", type: DialogCloseButtonComponent, isStandalone: true, selector: "[fd-dialog-close-button]", inputs: { mobile: { classPropertyName: "mobile", publicName: "mobile", isSignal: true, isRequired: false, transformFunction: null }, title: { classPropertyName: "title", publicName: "title", isSignal: true, isRequired: false, transformFunction: null }, ariaLabel: { classPropertyName: "ariaLabel", publicName: "ariaLabel", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "attr.aria-label": "\"close\"", "class.fd-button": "true", "class.is-compact": "!mobile()", "class.fd-button--transparent": "true", "attr.title": "title()" } }, ngImport: i0, template: `<fd-icon glyph="decline"></fd-icon><ng-content></ng-content>`, isInline: true, dependencies: [{ kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogCloseButtonComponent, decorators: [{
            type: Component,
            args: [{
                    // eslint-disable-next-line @angular-eslint/component-selector
                    selector: '[fd-dialog-close-button]',
                    host: {
                        '[attr.aria-label]': '"close"',
                        '[class.fd-button]': 'true',
                        '[class.is-compact]': '!mobile()',
                        '[class.fd-button--transparent]': 'true',
                        '[attr.title]': 'title()'
                    },
                    encapsulation: ViewEncapsulation.None,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    template: `<fd-icon glyph="decline"></fd-icon><ng-content></ng-content>`,
                    imports: [IconComponent]
                }]
        }] });

class DialogFooterBase {
    constructor() {
        /** @hidden */
        this._cdr = inject(ChangeDetectorRef);
    }
    /** @hidden */
    ngAfterContentInit() {
        this._assignCustomTemplates();
    }
    /** @hidden */
    _listenForButtonChanges(className) {
        const addClassToButton = (button) => {
            if (button && !button.class.includes(className)) {
                button.class = button.class + className;
                button.buildComponentCssClass();
            }
        };
        this.buttons.changes.pipe(startWith(1)).subscribe(() => this.buttons.forEach((button) => {
            addClassToButton(button._buttonComponent);
        }));
    }
    /** @hidden Assign custom templates */
    _assignCustomTemplates() {
        const footerTemplate = this.customTemplates.find((template) => template.name === 'footer');
        this.footerTemplate = footerTemplate ? footerTemplate.templateRef : undefined;
        this._cdr.detectChanges();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogFooterBase, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: DialogFooterBase, isStandalone: true, queries: [{ propertyName: "customTemplates", predicate: TemplateDirective }, { propertyName: "buttons", predicate: FD_BUTTON_BAR_COMPONENT }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogFooterBase, decorators: [{
            type: Directive
        }], propDecorators: { customTemplates: [{
                type: ContentChildren,
                args: [TemplateDirective]
            }], buttons: [{
                type: ContentChildren,
                args: [FD_BUTTON_BAR_COMPONENT]
            }] } });

const DialogButtonClass = 'fd-dialog__decisive-button';
/**
 * Building block of the dialog used to create dialog button.
 *
 * ```html
 * <fd-dialog-footer><!--Content--></fd-dialog-footer>
 *
 * Complex footer:
 * <fd-dialog-footer>
 *     <ng-template fdkTemplate="footer"><!--Content--></ng-template>
 * </fd-dialog-footer>
 * ```
 * */
class DialogFooterComponent extends DialogFooterBase {
    constructor() {
        super(...arguments);
        /** @hidden */
        this.dialogConfig = inject(DialogConfig, { optional: true }) || {};
    }
    /** @hidden */
    ngAfterContentInit() {
        super.ngAfterContentInit();
    }
    /** @hidden */
    ngAfterViewInit() {
        this._listenForButtonChanges(DialogButtonClass);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogFooterComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: DialogFooterComponent, isStandalone: true, selector: "fd-dialog-footer", usesInheritance: true, ngImport: i0, template: "<footer>\n    <div fd-bar class=\"fd-dialog__footer\" barDesign=\"footer\" [fdContentDensity]=\"dialogConfig.contentDensity ?? ''\">\n        <ng-template [ngTemplateOutlet]=\"footerTemplate ? footerTemplate : defaultTemplate\"></ng-template>\n\n        <ng-template #defaultTemplate>\n            <div fd-bar-right>\n                <ng-content></ng-content>\n            </div>\n        </ng-template>\n    </div>\n</footer>\n", dependencies: [{ kind: "component", type: BarComponent, selector: "[fd-bar]", inputs: ["class", "barDesign", "inPage", "inHomePage", "size", "role"] }, { kind: "directive", type: BarRightDirective, selector: "[fd-bar-right]" }, { kind: "directive", type: ContentDensityDirective, selector: "[fdContentDensity]:not([fdCompact]):not([fdCondensed]):not([fdCozy]),                [fdCompact]:not([fdContentDensity]):not([fdCondensed]):not([fdCozy]),                [fdCondensed]:not([fdContentDensity]):not([fdCompact]):not([fdCozy]),                [fdCozy]:not([fdContentDensity]):not([fdCompact]):not([fdCondensed])", inputs: ["fdContentDensity", "fdCompact", "fdCondensed", "fdCozy"], exportAs: ["fdContentDensity"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogFooterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-dialog-footer', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, standalone: true, imports: [BarComponent, BarRightDirective, ContentDensityDirective, NgTemplateOutlet], template: "<footer>\n    <div fd-bar class=\"fd-dialog__footer\" barDesign=\"footer\" [fdContentDensity]=\"dialogConfig.contentDensity ?? ''\">\n        <ng-template [ngTemplateOutlet]=\"footerTemplate ? footerTemplate : defaultTemplate\"></ng-template>\n\n        <ng-template #defaultTemplate>\n            <div fd-bar-right>\n                <ng-content></ng-content>\n            </div>\n        </ng-template>\n    </div>\n</footer>\n" }]
        }] });

class DialogHeaderBase {
    constructor() {
        /** @hidden */
        this._changeDetectorRef = inject(ChangeDetectorRef);
    }
    /** @hidden */
    set defaultTitleSize(title) {
        if (title && !title.headerSize) {
            title.headerSize = 5;
            this._changeDetectorRef.detectChanges();
        }
    }
    /** @hidden */
    ngAfterContentInit() {
        this._assignCustomTemplates();
    }
    /** @hidden Assign custom templates */
    _assignCustomTemplates() {
        this.customTemplates.forEach((template) => {
            switch (template.name) {
                case 'header':
                    this.headerTemplate = template.templateRef;
                    break;
                case 'subheader':
                    this.subHeaderTemplate = template.templateRef;
                    break;
            }
        });
        this._changeDetectorRef.detectChanges();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogHeaderBase, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: DialogHeaderBase, isStandalone: true, queries: [{ propertyName: "defaultTitleSize", first: true, predicate: TitleToken, descendants: true }, { propertyName: "customTemplates", predicate: TemplateDirective }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogHeaderBase, decorators: [{
            type: Directive
        }], propDecorators: { defaultTitleSize: [{
                type: ContentChild,
                args: [TitleToken]
            }], customTemplates: [{
                type: ContentChildren,
                args: [TemplateDirective]
            }] } });

/**
 * Applies fundamental layout and styling to the contents of a dialog header.
 *
 * ```html
 * <fd-dialog-header>
 *     <h1 fd-title>Title</h1>
 *     <button fd-dialog-close-button></button>
 * </fd-dialog-header>
 * ```
 */
class DialogHeaderComponent extends DialogHeaderBase {
    constructor() {
        super(...arguments);
        /** @hidden */
        this.dialogConfig = inject(DialogConfig, { optional: true }) || {};
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogHeaderComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: DialogHeaderComponent, isStandalone: true, selector: "fd-dialog-header", usesInheritance: true, ngImport: i0, template: "<header>\n    <div\n        fd-bar\n        role=\"group\"\n        class=\"fd-dialog__header\"\n        [fdContentDensity]=\"dialogConfig.contentDensity ?? ''\"\n        [barDesign]=\"subHeaderTemplate ? 'header-with-subheader' : 'header'\"\n    >\n        <ng-template [ngTemplateOutlet]=\"headerTemplate ? headerTemplate : defaultTemplate\"></ng-template>\n        <ng-template #defaultTemplate>\n            <div fd-bar-left>\n                <fd-bar-element [fullWidth]=\"true\">\n                    <ng-content select=\"[fd-title]\"></ng-content>\n                </fd-bar-element>\n            </div>\n            <div fd-bar-right>\n                <fd-bar-element>\n                    @if (!dialogConfig.mobile) {\n                        <ng-content select=\"[fd-dialog-full-screen-toggler-button]\"></ng-content>\n                    }\n                    <ng-content select=\"[fd-dialog-close-button]\"></ng-content>\n                </fd-bar-element>\n            </div>\n        </ng-template>\n    </div>\n    @if (subHeaderTemplate) {\n        <div\n            fd-bar\n            class=\"fd-dialog__subheader\"\n            barDesign=\"subheader\"\n            [fdContentDensity]=\"dialogConfig.contentDensity ?? ''\"\n        >\n            <ng-template [ngTemplateOutlet]=\"subHeaderTemplate\"></ng-template>\n        </div>\n    }\n</header>\n", dependencies: [{ kind: "component", type: BarComponent, selector: "[fd-bar]", inputs: ["class", "barDesign", "inPage", "inHomePage", "size", "role"] }, { kind: "directive", type: BarLeftDirective, selector: "[fd-bar-left]" }, { kind: "directive", type: BarRightDirective, selector: "[fd-bar-right]" }, { kind: "directive", type: BarElementDirective, selector: "fd-bar-element", inputs: ["fullWidth"] }, { kind: "directive", type: ContentDensityDirective, selector: "[fdContentDensity]:not([fdCompact]):not([fdCondensed]):not([fdCozy]),                [fdCompact]:not([fdContentDensity]):not([fdCondensed]):not([fdCozy]),                [fdCondensed]:not([fdContentDensity]):not([fdCompact]):not([fdCozy]),                [fdCozy]:not([fdContentDensity]):not([fdCompact]):not([fdCondensed])", inputs: ["fdContentDensity", "fdCompact", "fdCondensed", "fdCozy"], exportAs: ["fdContentDensity"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-dialog-header', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, imports: [
                        BarComponent,
                        BarLeftDirective,
                        BarRightDirective,
                        BarElementDirective,
                        ContentDensityDirective,
                        NgTemplateOutlet
                    ], template: "<header>\n    <div\n        fd-bar\n        role=\"group\"\n        class=\"fd-dialog__header\"\n        [fdContentDensity]=\"dialogConfig.contentDensity ?? ''\"\n        [barDesign]=\"subHeaderTemplate ? 'header-with-subheader' : 'header'\"\n    >\n        <ng-template [ngTemplateOutlet]=\"headerTemplate ? headerTemplate : defaultTemplate\"></ng-template>\n        <ng-template #defaultTemplate>\n            <div fd-bar-left>\n                <fd-bar-element [fullWidth]=\"true\">\n                    <ng-content select=\"[fd-title]\"></ng-content>\n                </fd-bar-element>\n            </div>\n            <div fd-bar-right>\n                <fd-bar-element>\n                    @if (!dialogConfig.mobile) {\n                        <ng-content select=\"[fd-dialog-full-screen-toggler-button]\"></ng-content>\n                    }\n                    <ng-content select=\"[fd-dialog-close-button]\"></ng-content>\n                </fd-bar-element>\n            </div>\n        </ng-template>\n    </div>\n    @if (subHeaderTemplate) {\n        <div\n            fd-bar\n            class=\"fd-dialog__subheader\"\n            barDesign=\"subheader\"\n            [fdContentDensity]=\"dialogConfig.contentDensity ?? ''\"\n        >\n            <ng-template [ngTemplateOutlet]=\"subHeaderTemplate\"></ng-template>\n        </div>\n    }\n</header>\n" }]
        }] });

/** Service used to dynamically generate a dialog. */
class DialogBaseService {
    constructor() {
        /** @hidden Collection of existing dialog references */
        this._dialogs = [];
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
    }
    /**
     * Status of the dialog service.
     * Returns true if there are open dialogs, false otherwise.
     */
    hasOpenDialogs() {
        return this._dialogs && this._dialogs.length > 0;
    }
    /** Dismisses all currently open dialogs. */
    dismissAll(reason) {
        this._dialogs.forEach((item) => {
            item.instance.ref.dismiss(reason);
            item.destroy();
        });
        this._dialogs = [];
    }
    /** @hidden Extends configuration using default values*/
    _applyDefaultConfig(config, defaultConfig) {
        return { ...defaultConfig, ...config };
    }
    /** @hidden Destroy existing dialog */
    _destroyDialog(dialog) {
        this._dialogs = this._dialogs.filter((d) => d !== dialog);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogBaseService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogBaseService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogBaseService, decorators: [{
            type: Injectable
        }] });

class DialogFullScreenTogglerButtonComponent {
    constructor() {
        /** Displays dialog close button in mobile mode */
        this.mobile = input(false);
        /** DialogRef direct reference. Used with template-based dialogs. */
        this.dialogRef = input();
        /** add title dynamically to add a tooltip */
        this.title = input();
        /** @hidden */
        this._fullscreen$ = signal(false);
        /** @hidden */
        this._ref = inject(DialogRef, {
            optional: true
        });
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
    }
    /** @hidden */
    ngOnInit() {
        const ref = this._ref || this.dialogRef();
        ref?.fullScreen.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((isFullScreen) => {
            this._fullscreen$.set(isFullScreen);
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogFullScreenTogglerButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "20.0.2", type: DialogFullScreenTogglerButtonComponent, isStandalone: true, selector: "[fd-dialog-full-screen-toggler-button]", inputs: { mobile: { classPropertyName: "mobile", publicName: "mobile", isSignal: true, isRequired: false, transformFunction: null }, dialogRef: { classPropertyName: "dialogRef", publicName: "dialogRef", isSignal: true, isRequired: false, transformFunction: null }, title: { classPropertyName: "title", publicName: "title", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "class.fd-button": "true", "class.is-compact": "!mobile()", "class.fd-button--transparent": "true", "attr.title": "title()" } }, ngImport: i0, template: `<fd-icon [glyph]="_fullscreen$() ? 'exitfullscreen' : 'full-screen'"></fd-icon>`, isInline: true, dependencies: [{ kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogFullScreenTogglerButtonComponent, decorators: [{
            type: Component,
            args: [{
                    // eslint-disable-next-line @angular-eslint/component-selector
                    selector: '[fd-dialog-full-screen-toggler-button]',
                    imports: [IconComponent],
                    template: `<fd-icon [glyph]="_fullscreen$() ? 'exitfullscreen' : 'full-screen'"></fd-icon>`,
                    encapsulation: ViewEncapsulation.None,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    host: {
                        '[class.fd-button]': 'true',
                        '[class.is-compact]': '!mobile()',
                        '[class.fd-button--transparent]': 'true',
                        '[attr.title]': 'title()'
                    }
                }]
        }] });

/** @hidden Returns dialog size based on width
 * @param width - dialog window width
 **/
function dialogWidthToSize(width) {
    if (width < 599) {
        return 'sm';
    }
    else if (width < 1023) {
        return 'md';
    }
    else if (width < 1439) {
        return 'lg';
    }
    return 'xl';
}

function coerceMetricValue(value) {
    return typeof value === 'number' ? `${value}px` : value;
}
class DialogBase {
    constructor() {
        /** @hidden */
        this._focusTrapService = inject(FocusTrapService);
        /** @hidden */
        this._changeDetectorRef = inject(ChangeDetectorRef);
        /** @hidden */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this._router = inject(Router);
        /** @hidden */
        this._rtlService = inject(RtlService, { optional: true });
        /** @hidden */
        this._subscriptions = new Subscription();
        /**
         * @hidden
         * Used to mute errors of focus trap during unit tests (jsdom incompatibility).
         */
        this._focusTrapError = inject(FD_DIALOG_FOCUS_TRAP_ERROR, {
            optional: true
        });
        /** @hidden */
        this._zone = inject(NgZone);
    }
    /** @hidden Listen and close dialog on Escape key */
    closeDialogEsc(event) {
        if (this._config.escKeyCloseable && KeyUtil.isKeyCode(event, ESCAPE)) {
            this._ref.dismiss(FD_DIALOG_DISMISS_REASON.ESCAPE);
        }
    }
    /** @hidden Listen and close dialog on Backdrop click */
    closeDialog(target) {
        if (this._config.backdropClickCloseable && target === this.elementRef.nativeElement) {
            this._ref.dismiss(FD_DIALOG_DISMISS_REASON.BACKDROP);
        }
    }
    /** @hidden */
    ngOnInit() {
        this._listenAndCloseOnNavigation();
        this._subscriptions.add(this._rtlService?.rtl.subscribe((isRtl) => {
            this._dir = isRtl ? 'rtl' : 'ltr';
            this._changeDetectorRef.detectChanges();
        }));
    }
    /** @hidden */
    ngAfterViewInit() {
        this._trapFocus();
        this._setPosition();
        this._setWidthHeight();
        this._listenOnWindowResize();
        this.adjustResponsivePadding();
        this._ref.loaded();
    }
    /** @hidden */
    ngOnDestroy() {
        this._deactivateFocusTrap();
        this._subscriptions.unsubscribe();
    }
    /** @hidden Determine dialog padding size based on dialogs window width */
    adjustResponsivePadding() {
        if (this._config.responsivePadding) {
            const dialogWidth = this.dialogWindow.nativeElement.getBoundingClientRect().width;
            this.dialogPaddingSize = dialogWidthToSize(dialogWidth);
            this._changeDetectorRef.detectChanges();
        }
    }
    /** @hidden Listen on NavigationStart event and dismiss the dialog */
    _listenAndCloseOnNavigation() {
        if (this._router) {
            this._subscriptions.add(this._router.events
                .pipe(filter((event) => event instanceof NavigationStart && !!this._config.closeOnNavigation))
                .subscribe(() => this._ref.dismiss(FD_DIALOG_DISMISS_REASON.NAVIGATION_CHANGE)));
        }
    }
    /** @hidden Trap focus inside dialog window */
    _trapFocus() {
        if (this._config.focusTrapped) {
            this._subscriptions.add(this._onMicrotaskEmpty().subscribe(() => {
                try {
                    this._focusTrapId = this._focusTrapService.createFocusTrap(this.dialogWindow.nativeElement, {
                        clickOutsideDeactivates: this._config.backdropClickCloseable && this._config.hasBackdrop,
                        escapeDeactivates: false,
                        fallbackFocus: this.dialogWindow.nativeElement,
                        allowOutsideClick: () => true
                    });
                }
                catch (e) {
                    isDevMode() && this._focusTrapError !== true && console.error(e);
                }
            }));
        }
    }
    /** @hidden */
    _deactivateFocusTrap() {
        this._focusTrapService.deactivateFocusTrap(this._focusTrapId);
    }
    /** @hidden Set dialog window position */
    _setPosition() {
        if (this._config.position) {
            this.dialogWindow.nativeElement.style.top = coerceMetricValue(this._config.position.top);
            this.dialogWindow.nativeElement.style.bottom = coerceMetricValue(this._config.position.bottom);
            this.dialogWindow.nativeElement.style.left = coerceMetricValue(this._config.position.left);
            this.dialogWindow.nativeElement.style.right = coerceMetricValue(this._config.position.right);
        }
        else {
            this.dialogWindow.nativeElement.style.position = 'relative';
        }
    }
    /** @hidden Set dialog window width and height */
    _setWidthHeight() {
        this.dialogWindow.nativeElement.style.width = coerceMetricValue(this._config.width);
        this.dialogWindow.nativeElement.style.height = coerceMetricValue(this._config.height);
        this.dialogWindow.nativeElement.style.minWidth = coerceMetricValue(this._config.minWidth);
        this.dialogWindow.nativeElement.style.minHeight = coerceMetricValue(this._config.minHeight);
        this.dialogWindow.nativeElement.style.maxWidth = coerceMetricValue(this._config.maxWidth);
        this.dialogWindow.nativeElement.style.maxHeight = coerceMetricValue(this._config.maxHeight);
    }
    /** @hidden Listen on window resize and adjust padding */
    _listenOnWindowResize() {
        if (this._config.responsivePadding) {
            this._subscriptions.add(fromEvent(window, 'resize')
                .pipe(debounceTime(100))
                .subscribe(() => this.adjustResponsivePadding()));
        }
    }
    /** @hidden */
    _onMicrotaskEmpty() {
        return this._zone.hasPendingMicrotasks
            ? this._zone.onMicrotaskEmpty.pipe(observeOn(asyncScheduler), take(1))
            : of(null);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogBase, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: DialogBase, isStandalone: true, host: { listeners: { "keydown": "closeDialogEsc($event)", "mousedown": "closeDialog($event.target)" }, properties: { "attr.dir": "this._dir" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogBase, decorators: [{
            type: Directive
        }], propDecorators: { _dir: [{
                type: HostBinding,
                args: ['attr.dir']
            }], closeDialogEsc: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }], closeDialog: [{
                type: HostListener,
                args: ['mousedown', ['$event.target']]
            }] } });

let titleUniqueId = 1;
class DialogTitleDirective {
    /** @hidden */
    constructor(dialogConfig) {
        this.dialogConfig = dialogConfig;
        /** Title ID attribute, generated automatically if not provided */
        this.id = input(`fd-dialog-title-` + titleUniqueId++);
    }
    /** @hidden */
    ngAfterViewInit() {
        if (this.dialogConfig && !this.dialogConfig.ariaLabelledBy) {
            this.dialogConfig.ariaLabelledBy = this.id();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogTitleDirective, deps: [{ token: DialogConfig, optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.2", type: DialogTitleDirective, isStandalone: true, selector: "[fd-dialog-title]", inputs: { id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "attr.id": "id()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-dialog-title]',
                    host: {
                        '[attr.id]': 'id()'
                    },
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: DialogConfig, decorators: [{
                    type: Optional
                }] }] });

/**
 * Dialog component.
 *
 * ```html
 * <fd-dialog>
 *      <fd-dialog-header></fd-dialog-header>
 *      <fd-dialog-body></fd-dialog-body>
 *      <fd-dialog-footer></fd-dialog-footer>
 * </fd-dialog>
 * ```
 */
class DialogComponent extends DialogBase {
    /** Custom classes */
    set class(userClass) {
        this._class = userClass;
    }
    /** DialogRef - should be used for Template based Dialog implementation */
    // eslint-disable-next-line @angular-eslint/no-input-rename
    set embeddedDialogRef(value) {
        this._dialogRef = value;
    }
    get embeddedDialogRef() {
        return this._dialogRef;
    }
    /** DialogConfig - should be used for Template based Dialog implementation */
    // eslint-disable-next-line @angular-eslint/no-input-rename
    set embeddedDialogConfig(value) {
        this.dialogConfig = value;
    }
    /** @hidden If dialog sub-components didn't receive DialogConfig from Injector, DialogConfig is passed from parent.
     * This is necessary when dialog has been passed as TemplateRef and created as EmbeddedView.
     * In such case parent injector of DialogComponent is the component that DECLARED the TemplateRef.
     **/
    set dialogHeaderConfig(component) {
        if (component) {
            component.dialogConfig = this.dialogConfig;
        }
    }
    /** @hidden */
    set dialogBodyConfig(component) {
        if (component) {
            component.dialogRef = this._dialogRef;
            component.dialogConfig = this.dialogConfig;
        }
    }
    /** @hidden */
    set dialogFooterConfig(component) {
        if (component) {
            component.dialogConfig = this.dialogConfig;
        }
    }
    /** @hidden */
    set dialogTitle(component) {
        if (component) {
            component.dialogConfig = this.dialogConfig;
        }
    }
    /** @hidden */
    constructor(dialogConfig, _dialogRef) {
        super();
        this.dialogConfig = dialogConfig;
        this._dialogRef = _dialogRef;
        /**
         * @hidden
         * Whether the Dialog in full-screen mode.
         */
        this._fullScreen = false;
        /** @hidden */
        this._class = '';
    }
    /** @hidden */
    get _config() {
        return this.dialogConfig;
    }
    /** @hidden */
    get _ref() {
        return this._dialogRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [
            this.dialogConfig.hasBackdrop ? 'fd-dialog' : 'fd-dialog--no-backdrop',
            this.dialogConfig.container !== 'body' || this.dialogConfig.position ? 'fd-dialog--targeted' : '',
            this.showDialogWindow ? 'fd-dialog--active' : '',
            this.dialogConfig.settings ? 'fd-settings' : '',
            this._class,
            this.dialogConfig.backdropClass ? this.dialogConfig.backdropClass : ''
        ];
    }
    /** @hidden */
    ngOnInit() {
        super.ngOnInit();
        this._listenOnHidden();
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngAfterViewInit() {
        super.ngAfterViewInit();
        this._listenOnHidden();
        this._listenOnFullScreen();
    }
    /** @hidden */
    ngOnDestroy() {
        super.ngOnDestroy();
        if (this._onHidden) {
            this._onHidden.unsubscribe();
        }
    }
    /** @hidden */
    _listenOnFullScreen() {
        this._subscriptions.add(this._ref.fullScreen.subscribe((isFullScreen) => {
            this._fullScreen = isFullScreen;
            this._changeDetectorRef.detectChanges();
            this.adjustResponsivePadding();
        }));
    }
    /** @hidden Listen on Dialog visibility */
    _listenOnHidden() {
        if (this._onHidden) {
            this._onHidden.unsubscribe();
        }
        this._onHidden = this._dialogRef.onHide.subscribe((isHidden) => {
            this.showDialogWindow = !isHidden;
            this.buildComponentCssClass();
            if (!this._focusTrapId) {
                return;
            }
            const focusTrapInstance = this._focusTrapService.getFocusTrapInstance(this._focusTrapId);
            if (isHidden) {
                focusTrapInstance?.pause();
            }
            else {
                focusTrapInstance?.unpause();
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogComponent, deps: [{ token: DialogConfig, optional: true }, { token: DialogRef, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: DialogComponent, isStandalone: true, selector: "fd-dialog", inputs: { class: "class", embeddedDialogRef: ["dialogRef", "embeddedDialogRef"], embeddedDialogConfig: ["dialogConfig", "embeddedDialogConfig"] }, host: { attributes: { "tabindex": "-1" } }, providers: [contentDensityObserverProviders({ alwaysAddModifiers: true })], queries: [{ propertyName: "dialogHeaderConfig", first: true, predicate: DialogHeaderComponent, descendants: true }, { propertyName: "dialogBodyConfig", first: true, predicate: DialogBodyComponent, descendants: true }, { propertyName: "dialogFooterConfig", first: true, predicate: DialogFooterComponent, descendants: true }, { propertyName: "dialogTitle", first: true, predicate: DialogTitleDirective, descendants: true }], viewQueries: [{ propertyName: "dialogWindow", first: true, predicate: ["dialogWindow"], descendants: true }], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<div\n    #dialogWindow\n    role=\"dialog\"\n    tabindex=\"-1\"\n    aria-modal=\"true\"\n    fdkResize\n    cdkTrapFocus\n    cdkDrag\n    cdkDragBoundary=\".fd-dialog\"\n    fd-scrollbar\n    [fdkResizeBoundary]=\"elementRef.nativeElement\"\n    class=\"fd-dialog__content\"\n    [class]=\"dialogConfig.dialogPanelClass\"\n    [class.cdk-drag]=\"dialogConfig.draggable\"\n    [class.fd-dialog__content--s]=\"dialogPaddingSize === 'sm'\"\n    [class.fd-dialog__content--m]=\"dialogPaddingSize === 'md'\"\n    [class.fd-dialog__content--l]=\"dialogPaddingSize === 'lg'\"\n    [class.fd-dialog__content--xl]=\"dialogPaddingSize === 'xl'\"\n    [class.fd-dialog__content--mobile]=\"dialogConfig.mobile || _fullScreen\"\n    [class.fd-dialog__content--no-mobile-stretch]=\"dialogConfig.mobileOuterSpacing\"\n    [class.fd-dialog__content--draggable-grab]=\"dialogConfig.draggable && !isDragged\"\n    [class.fd-dialog__content--draggable-grabbing]=\"dialogConfig.draggable && isDragged\"\n    [class.fd-dialog__content-full-screen]=\"_fullScreen\"\n    [class.fd-settings__dialog-content]=\"dialogConfig.settings\"\n    [cdkDragDisabled]=\"!dialogConfig.draggable\"\n    [fdkResizeDisabled]=\"!dialogConfig.resizable\"\n    [attr.id]=\"dialogConfig.id\"\n    [attr.aria-label]=\"dialogConfig.ariaLabel\"\n    [attr.aria-labelledby]=\"dialogConfig.ariaLabelledBy\"\n    [attr.aria-describedby]=\"dialogConfig.ariaDescribedBy\"\n    (cdkDragStarted)=\"isDragged = true\"\n    (cdkDragEnded)=\"isDragged = false\"\n    (onResizeEnd)=\"adjustResponsivePadding()\"\n>\n    @if (dialogConfig.resizable && !_fullScreen && !dialogConfig.mobile) {\n        <span fdkResizeHandle class=\"fd-dialog__resize-handle\" role=\"presentation\" aria-hidden=\"true\"></span>\n    }\n    <div cdkDragHandle [cdkDragHandleDisabled]=\"!dialogConfig.draggable\">\n        <ng-content select=\"fd-dialog-header\"></ng-content>\n    </div>\n    <ng-content select=\"fd-dialog-body\"></ng-content>\n    <ng-content select=\"fd-dialog-footer\"></ng-content>\n</div>\n", styles: ["@charset \"UTF-8\";.fd-dialog{position:fixed;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.fd-dialog,.fd-dialog:before{height:100%;left:0;top:0;width:100%}.fd-dialog:before{background-color:var(--sapBlockLayer_Background);content:\"\";opacity:var(--sapBlockLayer_Opacity);position:absolute}.fd-dialog__content{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;border-radius:var(--sapElement_BorderCornerRadius);-webkit-box-shadow:var(--sapContent_Shadow3);box-shadow:var(--sapContent_Shadow3);-ms-flex-direction:column;flex-direction:column;max-height:calc(100vh - 6%);max-width:calc(100vw - 10%);min-height:7.5rem;min-width:20rem;outline:none;position:absolute}.fd-dialog__body{overflow:auto;-webkit-box-flex:1;-ms-flex-positive:1;background-color:var(--sapGroup_ContentBackground);flex-grow:1}.fd-dialog__footer.fd-bar,.fd-dialog__header.fd-bar,.fd-dialog__subheader.fd-bar{padding-inline:1rem 1rem;-ms-flex-negative:0;flex-shrink:0}.fd-dialog__content--mobile{border-radius:0;height:100vh;max-height:100vh;max-width:100vw;width:100vw}.fd-dialog{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:none;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dialog:after,.fd-dialog:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dialog--active{display:-webkit-box;display:-ms-flexbox;display:flex}.fd-dialog__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dialog__content:after,.fd-dialog__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dialog__content--def .fd-dialog__body,.fd-dialog__content--def .fd-dialog__footer.fd-bar,.fd-dialog__content--def .fd-dialog__header.fd-bar,.fd-dialog__content--def .fd-dialog__subheader.fd-bar,.fd-dialog__content--s .fd-dialog__body,.fd-dialog__content--s .fd-dialog__footer.fd-bar,.fd-dialog__content--s .fd-dialog__header.fd-bar,.fd-dialog__content--s .fd-dialog__subheader.fd-bar{padding-inline:1rem 1rem}.fd-dialog__content--l .fd-dialog__body,.fd-dialog__content--l .fd-dialog__footer.fd-bar,.fd-dialog__content--l .fd-dialog__header.fd-bar,.fd-dialog__content--l .fd-dialog__subheader.fd-bar,.fd-dialog__content--m .fd-dialog__body,.fd-dialog__content--m .fd-dialog__footer.fd-bar,.fd-dialog__content--m .fd-dialog__header.fd-bar,.fd-dialog__content--m .fd-dialog__subheader.fd-bar{padding-inline:2rem 2rem}.fd-dialog__content--xl .fd-dialog__body,.fd-dialog__content--xl .fd-dialog__footer.fd-bar,.fd-dialog__content--xl .fd-dialog__header.fd-bar,.fd-dialog__content--xl .fd-dialog__subheader.fd-bar{padding-inline:3rem 3rem}.fd-dialog__content--mobile .fd-dialog__body,.fd-dialog__content--mobile .fd-dialog__footer,.fd-dialog__content--mobile .fd-dialog__header,.fd-dialog__content--mobile .fd-menu__item:first-child,.fd-dialog__content--mobile .fd-menu__item:first-child .fd-menu__link:after,.fd-dialog__content--mobile .fd-menu__item:last-child,.fd-dialog__content--mobile .fd-menu__item:last-child .fd-menu__link:after{border-radius:0}.fd-dialog__content--no-mobile-stretch{border-radius:var(--sapElement_BorderCornerRadius);max-height:calc(100vh - 6%);max-width:calc(100vw - 10%)}.fd-dialog__content--draggable-grab.is-hover .fd-dialog__header,.fd-dialog__content--draggable-grab:hover .fd-dialog__header{cursor:move;cursor:-webkit-grab;cursor:grab}.fd-dialog__content--draggable-grabbing.is-hover .fd-dialog__header,.fd-dialog__content--draggable-grabbing:hover .fd-dialog__header{cursor:move;cursor:-webkit-grabbing;cursor:grabbing}.fd-dialog__header.fd-bar{border-top-left-radius:var(--sapElement_BorderCornerRadius);border-top-right-radius:var(--sapElement_BorderCornerRadius)}.fd-dialog__footer.fd-bar{border-bottom-left-radius:var(--sapElement_BorderCornerRadius);border-bottom-right-radius:var(--sapElement_BorderCornerRadius)}.fd-dialog__footer.fd-bar .fd-dialog__decisive-button,.fd-dialog__header.fd-bar .fd-dialog__decisive-button{min-width:4rem;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.fd-dialog__body{border:0;border-radius:var(--sapElement_BorderCornerRadius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:1rem 1rem;padding-inline:0;position:relative}.fd-dialog__body:after,.fd-dialog__body:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dialog__body--no-vertical-padding{padding-block:0}.fd-dialog__body--no-horizontal-padding{padding-inline:0}.fd-dialog__body:not(:first-child){border-top-left-radius:0;border-top-right-radius:0}.fd-dialog__body:not(:last-child){border-bottom-left-radius:0;border-bottom-right-radius:0}.fd-dialog__loader{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:1.5rem;padding-block:0;padding-inline:0;text-align:center;-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-dialog__loader:after,.fd-dialog__loader:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dialog__resize-handle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:1.5rem;line-height:normal;margin-block:0;margin-inline:0;min-width:1.5rem;padding-block:0;padding-inline:0;right:-.5rem;width:1.5rem;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start;-webkit-box-pack:start;-ms-flex-pack:start;bottom:-.5rem;cursor:se-resize;font-size:1rem;justify-content:flex-start;line-height:1rem;overflow:hidden;position:absolute;z-index:2}.fd-dialog__resize-handle:after,.fd-dialog__resize-handle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dialog__resize-handle[dir=rtl],[dir=rtl] .fd-dialog__resize-handle{cursor:sw-resize;left:-.5rem;right:auto;-webkit-transform:scaleX(-1);transform:scaleX(-1);-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-dialog__resize-handle:after{color:var(--sapButton_Lite_TextColor);content:\"\\e24f\";font-family:SAP-icons;height:1rem;min-width:1rem;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none;width:1rem}.fd-dialog--no-backdrop:not(.fd-dialog--targeted){left:50%;position:fixed;top:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);z-index:1000}.fd-settings .fd-settings__dialog-content{height:var(--fdSettings_Dialog_Content_Height,42.5rem);max-height:var(--fdSettings_Dialog_Content_Max_Height,42.5rem);max-width:var(--fdSettings_Dialog_Content_Max_Width,60rem);min-height:var(--fdSettings_Dialog_Content_Min_Height,42.5rem);min-width:var(--fdSettings_Dialog_Content_Min_Width,60rem)}.fd-settings .fd-settings__dialog-body{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;padding-block:0;padding-inline:0}.fd-settings .fd-settings__list:is(:first-child){overflow-y:auto}.fd-settings .fd-settings__list a:after{content:var(--fdSettings_List_Nav_Indicator_Content,none)}.fd-settings .fd-settings__list--footer{border-top:.0625rem solid var(--sapList_BorderColor)}.fd-settings .fd-settings__tab-bar{height:100%;overflow-y:hidden}.fd-settings .fd-settings__header{-webkit-margin-before:var(--fdSettings_Header_Margin_Top,1rem);margin-block-start:var(--fdSettings_Header_Margin_Top,1rem)}.fd-settings__list-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%;max-width:var(--fdSettings_List_Area_Width,20rem);min-width:var(--fdSettings_List_Area_Width,20rem);width:var(--fdSettings_List_Area_Width,20rem);-webkit-border-end:var(--fdSettings_List_Area_Border,.0625rem solid var(--sapList_BorderColor));border-inline-end:var(--fdSettings_List_Area_Border,.0625rem solid var(--sapList_BorderColor))}.fd-settings__list-area:after,.fd-settings__list-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-settings__list-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;height:100%;justify-content:space-between;overflow:hidden;position:relative}.fd-settings__list-container:after,.fd-settings__list-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-settings__detail-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%;width:100%}.fd-settings__detail-area:after,.fd-settings__detail-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-settings__detail-area:has(.fd-settings__tab-bar) .fd-settings__header{--fdBar_Shadow:none}.fd-settings__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:100%;line-height:normal;margin-block:0;margin-inline:0;overflow-y:auto;padding-block:0;padding-block:1rem;padding-inline:0;padding-inline:1rem;width:100%}.fd-settings__content:after,.fd-settings__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-settings__content--no-padding{padding-block:0;padding-inline:0}.fd-settings__content--no-background{background:transparent}.fd-settings__container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;height:100%;width:100%}.fd-settings__container:after,.fd-settings__container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-settings:has(.fd-settings__container--sm){--fdSettings_List_Area_Width:100%;--fdSettings_Header_Margin_Top:0;--fdSettings_List_Nav_Indicator_Content:\"\\e1ed\";--fdSettings_Dialog_Content_Min_Width:100%;--fdSettings_Dialog_Content_Min_Height:100%;--fdSettings_Dialog_Content_Max_Width:100%;--fdSettings_Dialog_Content_Max_Height:100%;--fdSettings_List_Area_Border:none}.fd-settings:has(.fd-settings__container--sm) .fd-settings__dialog-content{border-radius:0;-webkit-box-shadow:none;box-shadow:none}.fd-settings:has(.fd-settings__container--sm) .fd-settings__dialog-body{border-radius:0}.fd-settings:has(.fd-settings__container--md){--fdSettings_List_Area_Width:100%;--fdSettings_Header_Margin_Top:0;--fdSettings_List_Nav_Indicator_Content:\"\\e1ed\";--fdSettings_Dialog_Content_Min_Width:80%;--fdSettings_Dialog_Content_Min_Height:88%;--fdSettings_Dialog_Content_Max_Width:40rem;--fdSettings_Dialog_Content_Max_Height:42.5rem;--fdSettings_List_Area_Border:none}.fd-settings:has(.fd-settings__container--lg),.fd-settings:has(.fd-settings__container--xl){--fdSettings_List_Area_Width:20rem;--fdSettings_Header_Margin_Top:1rem;--fdSettings_List_Nav_Indicator_Content:none;--fdSettings_Dialog_Content_Min_Width:60rem;--fdSettings_Dialog_Content_Min_Height:42.5rem;--fdSettings_Dialog_Content_Max_Width:60rem;--fdSettings_Dialog_Content_Max_Height:42.5rem}.fd-dialog{z-index:999}.fd-dialog__resize-handle{z-index:1001}.fd-dialog__content-full-screen{position:relative!important;inset:0!important;width:100%!important;height:100%!important;min-width:100%!important;max-width:100%!important;min-height:100%!important;max-height:100%!important;transform:none!important}.fd-dialog__content.fd-dialog__content--mobile{height:100%;max-height:100%;max-width:100%;width:100%;position:fixed!important}.fd-dialog__content.fd-dialog__content--mobile .fd-dialog__header.fd-bar{border-top-left-radius:0;border-top-right-radius:0}.fd-dialog__content.fd-dialog__content--mobile .fd-dialog__footer.fd-bar{border-bottom-left-radius:0;border-bottom-right-radius:0}.fd-dialog__footer{overflow:hidden}.fd-dialog__content:has(.fd-dialog__resize-handle){overflow:visible!important}\n/*! Bundled license information:\n\nfundamental-styles/dist/settings.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "directive", type: ResizeDirective, selector: "[fdkResize]", inputs: ["fdkResizeBoundary", "fdkResizeDisabled", "fdkResizeClass", "fdkResizeHandleLocation", "fdkResizeResizeHandleRef"], outputs: ["onResizeStart", "onResizeEnd"] }, { kind: "ngmodule", type: A11yModule }, { kind: "directive", type: i3$1.CdkTrapFocus, selector: "[cdkTrapFocus]", inputs: ["cdkTrapFocus", "cdkTrapFocusAutoCapture"], exportAs: ["cdkTrapFocus"] }, { kind: "directive", type: CdkDrag, selector: "[cdkDrag]", inputs: ["cdkDragData", "cdkDragLockAxis", "cdkDragRootElement", "cdkDragBoundary", "cdkDragStartDelay", "cdkDragFreeDragPosition", "cdkDragDisabled", "cdkDragConstrainPosition", "cdkDragPreviewClass", "cdkDragPreviewContainer", "cdkDragScale"], outputs: ["cdkDragStarted", "cdkDragReleased", "cdkDragEnded", "cdkDragEntered", "cdkDragExited", "cdkDragDropped", "cdkDragMoved"], exportAs: ["cdkDrag"] }, { kind: "directive", type: ScrollbarDirective, selector: "[fdScrollbar], [fd-scrollbar]", inputs: ["noHorizontalScroll", "noVerticalScroll", "alwaysVisible"] }, { kind: "directive", type: ResizeHandleDirective, selector: "[fdkResizeHandle]" }, { kind: "directive", type: CdkDragHandle, selector: "[cdkDragHandle]", inputs: ["cdkDragHandleDisabled"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], DialogComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-dialog', host: {
                        tabindex: '-1'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, providers: [contentDensityObserverProviders({ alwaysAddModifiers: true })], imports: [
                        ResizeDirective,
                        A11yModule,
                        CdkDrag,
                        CdkScrollable,
                        ScrollbarDirective,
                        ResizeHandleDirective,
                        CdkDragHandle
                    ], template: "<div\n    #dialogWindow\n    role=\"dialog\"\n    tabindex=\"-1\"\n    aria-modal=\"true\"\n    fdkResize\n    cdkTrapFocus\n    cdkDrag\n    cdkDragBoundary=\".fd-dialog\"\n    fd-scrollbar\n    [fdkResizeBoundary]=\"elementRef.nativeElement\"\n    class=\"fd-dialog__content\"\n    [class]=\"dialogConfig.dialogPanelClass\"\n    [class.cdk-drag]=\"dialogConfig.draggable\"\n    [class.fd-dialog__content--s]=\"dialogPaddingSize === 'sm'\"\n    [class.fd-dialog__content--m]=\"dialogPaddingSize === 'md'\"\n    [class.fd-dialog__content--l]=\"dialogPaddingSize === 'lg'\"\n    [class.fd-dialog__content--xl]=\"dialogPaddingSize === 'xl'\"\n    [class.fd-dialog__content--mobile]=\"dialogConfig.mobile || _fullScreen\"\n    [class.fd-dialog__content--no-mobile-stretch]=\"dialogConfig.mobileOuterSpacing\"\n    [class.fd-dialog__content--draggable-grab]=\"dialogConfig.draggable && !isDragged\"\n    [class.fd-dialog__content--draggable-grabbing]=\"dialogConfig.draggable && isDragged\"\n    [class.fd-dialog__content-full-screen]=\"_fullScreen\"\n    [class.fd-settings__dialog-content]=\"dialogConfig.settings\"\n    [cdkDragDisabled]=\"!dialogConfig.draggable\"\n    [fdkResizeDisabled]=\"!dialogConfig.resizable\"\n    [attr.id]=\"dialogConfig.id\"\n    [attr.aria-label]=\"dialogConfig.ariaLabel\"\n    [attr.aria-labelledby]=\"dialogConfig.ariaLabelledBy\"\n    [attr.aria-describedby]=\"dialogConfig.ariaDescribedBy\"\n    (cdkDragStarted)=\"isDragged = true\"\n    (cdkDragEnded)=\"isDragged = false\"\n    (onResizeEnd)=\"adjustResponsivePadding()\"\n>\n    @if (dialogConfig.resizable && !_fullScreen && !dialogConfig.mobile) {\n        <span fdkResizeHandle class=\"fd-dialog__resize-handle\" role=\"presentation\" aria-hidden=\"true\"></span>\n    }\n    <div cdkDragHandle [cdkDragHandleDisabled]=\"!dialogConfig.draggable\">\n        <ng-content select=\"fd-dialog-header\"></ng-content>\n    </div>\n    <ng-content select=\"fd-dialog-body\"></ng-content>\n    <ng-content select=\"fd-dialog-footer\"></ng-content>\n</div>\n", styles: ["@charset \"UTF-8\";.fd-dialog{position:fixed;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.fd-dialog,.fd-dialog:before{height:100%;left:0;top:0;width:100%}.fd-dialog:before{background-color:var(--sapBlockLayer_Background);content:\"\";opacity:var(--sapBlockLayer_Opacity);position:absolute}.fd-dialog__content{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;border-radius:var(--sapElement_BorderCornerRadius);-webkit-box-shadow:var(--sapContent_Shadow3);box-shadow:var(--sapContent_Shadow3);-ms-flex-direction:column;flex-direction:column;max-height:calc(100vh - 6%);max-width:calc(100vw - 10%);min-height:7.5rem;min-width:20rem;outline:none;position:absolute}.fd-dialog__body{overflow:auto;-webkit-box-flex:1;-ms-flex-positive:1;background-color:var(--sapGroup_ContentBackground);flex-grow:1}.fd-dialog__footer.fd-bar,.fd-dialog__header.fd-bar,.fd-dialog__subheader.fd-bar{padding-inline:1rem 1rem;-ms-flex-negative:0;flex-shrink:0}.fd-dialog__content--mobile{border-radius:0;height:100vh;max-height:100vh;max-width:100vw;width:100vw}.fd-dialog{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:none;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dialog:after,.fd-dialog:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dialog--active{display:-webkit-box;display:-ms-flexbox;display:flex}.fd-dialog__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dialog__content:after,.fd-dialog__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dialog__content--def .fd-dialog__body,.fd-dialog__content--def .fd-dialog__footer.fd-bar,.fd-dialog__content--def .fd-dialog__header.fd-bar,.fd-dialog__content--def .fd-dialog__subheader.fd-bar,.fd-dialog__content--s .fd-dialog__body,.fd-dialog__content--s .fd-dialog__footer.fd-bar,.fd-dialog__content--s .fd-dialog__header.fd-bar,.fd-dialog__content--s .fd-dialog__subheader.fd-bar{padding-inline:1rem 1rem}.fd-dialog__content--l .fd-dialog__body,.fd-dialog__content--l .fd-dialog__footer.fd-bar,.fd-dialog__content--l .fd-dialog__header.fd-bar,.fd-dialog__content--l .fd-dialog__subheader.fd-bar,.fd-dialog__content--m .fd-dialog__body,.fd-dialog__content--m .fd-dialog__footer.fd-bar,.fd-dialog__content--m .fd-dialog__header.fd-bar,.fd-dialog__content--m .fd-dialog__subheader.fd-bar{padding-inline:2rem 2rem}.fd-dialog__content--xl .fd-dialog__body,.fd-dialog__content--xl .fd-dialog__footer.fd-bar,.fd-dialog__content--xl .fd-dialog__header.fd-bar,.fd-dialog__content--xl .fd-dialog__subheader.fd-bar{padding-inline:3rem 3rem}.fd-dialog__content--mobile .fd-dialog__body,.fd-dialog__content--mobile .fd-dialog__footer,.fd-dialog__content--mobile .fd-dialog__header,.fd-dialog__content--mobile .fd-menu__item:first-child,.fd-dialog__content--mobile .fd-menu__item:first-child .fd-menu__link:after,.fd-dialog__content--mobile .fd-menu__item:last-child,.fd-dialog__content--mobile .fd-menu__item:last-child .fd-menu__link:after{border-radius:0}.fd-dialog__content--no-mobile-stretch{border-radius:var(--sapElement_BorderCornerRadius);max-height:calc(100vh - 6%);max-width:calc(100vw - 10%)}.fd-dialog__content--draggable-grab.is-hover .fd-dialog__header,.fd-dialog__content--draggable-grab:hover .fd-dialog__header{cursor:move;cursor:-webkit-grab;cursor:grab}.fd-dialog__content--draggable-grabbing.is-hover .fd-dialog__header,.fd-dialog__content--draggable-grabbing:hover .fd-dialog__header{cursor:move;cursor:-webkit-grabbing;cursor:grabbing}.fd-dialog__header.fd-bar{border-top-left-radius:var(--sapElement_BorderCornerRadius);border-top-right-radius:var(--sapElement_BorderCornerRadius)}.fd-dialog__footer.fd-bar{border-bottom-left-radius:var(--sapElement_BorderCornerRadius);border-bottom-right-radius:var(--sapElement_BorderCornerRadius)}.fd-dialog__footer.fd-bar .fd-dialog__decisive-button,.fd-dialog__header.fd-bar .fd-dialog__decisive-button{min-width:4rem;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.fd-dialog__body{border:0;border-radius:var(--sapElement_BorderCornerRadius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:1rem 1rem;padding-inline:0;position:relative}.fd-dialog__body:after,.fd-dialog__body:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dialog__body--no-vertical-padding{padding-block:0}.fd-dialog__body--no-horizontal-padding{padding-inline:0}.fd-dialog__body:not(:first-child){border-top-left-radius:0;border-top-right-radius:0}.fd-dialog__body:not(:last-child){border-bottom-left-radius:0;border-bottom-right-radius:0}.fd-dialog__loader{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:1.5rem;padding-block:0;padding-inline:0;text-align:center;-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-dialog__loader:after,.fd-dialog__loader:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dialog__resize-handle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:1.5rem;line-height:normal;margin-block:0;margin-inline:0;min-width:1.5rem;padding-block:0;padding-inline:0;right:-.5rem;width:1.5rem;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start;-webkit-box-pack:start;-ms-flex-pack:start;bottom:-.5rem;cursor:se-resize;font-size:1rem;justify-content:flex-start;line-height:1rem;overflow:hidden;position:absolute;z-index:2}.fd-dialog__resize-handle:after,.fd-dialog__resize-handle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dialog__resize-handle[dir=rtl],[dir=rtl] .fd-dialog__resize-handle{cursor:sw-resize;left:-.5rem;right:auto;-webkit-transform:scaleX(-1);transform:scaleX(-1);-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-dialog__resize-handle:after{color:var(--sapButton_Lite_TextColor);content:\"\\e24f\";font-family:SAP-icons;height:1rem;min-width:1rem;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none;width:1rem}.fd-dialog--no-backdrop:not(.fd-dialog--targeted){left:50%;position:fixed;top:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);z-index:1000}.fd-settings .fd-settings__dialog-content{height:var(--fdSettings_Dialog_Content_Height,42.5rem);max-height:var(--fdSettings_Dialog_Content_Max_Height,42.5rem);max-width:var(--fdSettings_Dialog_Content_Max_Width,60rem);min-height:var(--fdSettings_Dialog_Content_Min_Height,42.5rem);min-width:var(--fdSettings_Dialog_Content_Min_Width,60rem)}.fd-settings .fd-settings__dialog-body{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;padding-block:0;padding-inline:0}.fd-settings .fd-settings__list:is(:first-child){overflow-y:auto}.fd-settings .fd-settings__list a:after{content:var(--fdSettings_List_Nav_Indicator_Content,none)}.fd-settings .fd-settings__list--footer{border-top:.0625rem solid var(--sapList_BorderColor)}.fd-settings .fd-settings__tab-bar{height:100%;overflow-y:hidden}.fd-settings .fd-settings__header{-webkit-margin-before:var(--fdSettings_Header_Margin_Top,1rem);margin-block-start:var(--fdSettings_Header_Margin_Top,1rem)}.fd-settings__list-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%;max-width:var(--fdSettings_List_Area_Width,20rem);min-width:var(--fdSettings_List_Area_Width,20rem);width:var(--fdSettings_List_Area_Width,20rem);-webkit-border-end:var(--fdSettings_List_Area_Border,.0625rem solid var(--sapList_BorderColor));border-inline-end:var(--fdSettings_List_Area_Border,.0625rem solid var(--sapList_BorderColor))}.fd-settings__list-area:after,.fd-settings__list-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-settings__list-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;height:100%;justify-content:space-between;overflow:hidden;position:relative}.fd-settings__list-container:after,.fd-settings__list-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-settings__detail-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%;width:100%}.fd-settings__detail-area:after,.fd-settings__detail-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-settings__detail-area:has(.fd-settings__tab-bar) .fd-settings__header{--fdBar_Shadow:none}.fd-settings__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:100%;line-height:normal;margin-block:0;margin-inline:0;overflow-y:auto;padding-block:0;padding-block:1rem;padding-inline:0;padding-inline:1rem;width:100%}.fd-settings__content:after,.fd-settings__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-settings__content--no-padding{padding-block:0;padding-inline:0}.fd-settings__content--no-background{background:transparent}.fd-settings__container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;height:100%;width:100%}.fd-settings__container:after,.fd-settings__container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-settings:has(.fd-settings__container--sm){--fdSettings_List_Area_Width:100%;--fdSettings_Header_Margin_Top:0;--fdSettings_List_Nav_Indicator_Content:\"\\e1ed\";--fdSettings_Dialog_Content_Min_Width:100%;--fdSettings_Dialog_Content_Min_Height:100%;--fdSettings_Dialog_Content_Max_Width:100%;--fdSettings_Dialog_Content_Max_Height:100%;--fdSettings_List_Area_Border:none}.fd-settings:has(.fd-settings__container--sm) .fd-settings__dialog-content{border-radius:0;-webkit-box-shadow:none;box-shadow:none}.fd-settings:has(.fd-settings__container--sm) .fd-settings__dialog-body{border-radius:0}.fd-settings:has(.fd-settings__container--md){--fdSettings_List_Area_Width:100%;--fdSettings_Header_Margin_Top:0;--fdSettings_List_Nav_Indicator_Content:\"\\e1ed\";--fdSettings_Dialog_Content_Min_Width:80%;--fdSettings_Dialog_Content_Min_Height:88%;--fdSettings_Dialog_Content_Max_Width:40rem;--fdSettings_Dialog_Content_Max_Height:42.5rem;--fdSettings_List_Area_Border:none}.fd-settings:has(.fd-settings__container--lg),.fd-settings:has(.fd-settings__container--xl){--fdSettings_List_Area_Width:20rem;--fdSettings_Header_Margin_Top:1rem;--fdSettings_List_Nav_Indicator_Content:none;--fdSettings_Dialog_Content_Min_Width:60rem;--fdSettings_Dialog_Content_Min_Height:42.5rem;--fdSettings_Dialog_Content_Max_Width:60rem;--fdSettings_Dialog_Content_Max_Height:42.5rem}.fd-dialog{z-index:999}.fd-dialog__resize-handle{z-index:1001}.fd-dialog__content-full-screen{position:relative!important;inset:0!important;width:100%!important;height:100%!important;min-width:100%!important;max-width:100%!important;min-height:100%!important;max-height:100%!important;transform:none!important}.fd-dialog__content.fd-dialog__content--mobile{height:100%;max-height:100%;max-width:100%;width:100%;position:fixed!important}.fd-dialog__content.fd-dialog__content--mobile .fd-dialog__header.fd-bar{border-top-left-radius:0;border-top-right-radius:0}.fd-dialog__content.fd-dialog__content--mobile .fd-dialog__footer.fd-bar{border-bottom-left-radius:0;border-bottom-right-radius:0}.fd-dialog__footer{overflow:hidden}.fd-dialog__content:has(.fd-dialog__resize-handle){overflow:visible!important}\n/*! Bundled license information:\n\nfundamental-styles/dist/settings.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: DialogConfig, decorators: [{
                    type: Optional
                }] }, { type: DialogRef, decorators: [{
                    type: Optional
                }] }], propDecorators: { class: [{
                type: Input
            }], embeddedDialogRef: [{
                type: Input,
                args: ['dialogRef']
            }], embeddedDialogConfig: [{
                type: Input,
                args: ['dialogConfig']
            }], dialogWindow: [{
                type: ViewChild,
                args: ['dialogWindow']
            }], dialogHeaderConfig: [{
                type: ContentChild,
                args: [DialogHeaderComponent]
            }], dialogBodyConfig: [{
                type: ContentChild,
                args: [DialogBodyComponent]
            }], dialogFooterConfig: [{
                type: ContentChild,
                args: [DialogFooterComponent]
            }], dialogTitle: [{
                type: ContentChild,
                args: [DialogTitleDirective]
            }], buildComponentCssClass: [] } });

let dTitleId = 0;
let dContentId = 0;
/** Dialog component used to create the dialog in object based approach */
class DialogDefaultComponent {
    /** @hidden */
    constructor(_changeDetectorRef, _dialogConfig) {
        this._changeDetectorRef = _changeDetectorRef;
        this._dialogConfig = _dialogConfig;
        /**
         * dialog title id
         * if not set, a default value is provided
         */
        this.dialogTitleId = 'fd-dialog-title-id-' + dTitleId++;
        /**
         * dialog content id
         * if not set, a default value is provided
         */
        this.dialogContentId = 'fd-dialog-content-id-' + dContentId++;
    }
    /** @hidden
     * TODO: Inspect why DialogDefaultComponents needs change detection re-run to render adjusted content (dialog header title)
     * */
    ngAfterViewInit() {
        if (this._dialogConfig) {
            this._dialogConfig.ariaLabelledBy ??= this.dialogTitleId;
            this._dialogConfig.ariaDescribedBy ??= this.dialogContentId;
        }
        this._changeDetectorRef.detectChanges();
    }
    /** Whether there is a approve button, or cancel button text */
    _showFooter() {
        return (!!this._defaultDialogContent &&
            !!(this._defaultDialogContent.cancelButton || this._defaultDialogContent.approveButton));
    }
    /** @hidden */
    _closeButtonClicked() {
        this._defaultDialogContent?.closeButtonCallback?.();
    }
    /** @hidden */
    _approveButtonClicked() {
        this._defaultDialogContent?.approveButtonCallback?.();
    }
    /** @hidden */
    _cancelButtonClicked() {
        this._defaultDialogContent?.cancelButtonCallback?.();
    }
    /** @hidden */
    _fullScreenButtonClicked() {
        this._defaultDialogContent?.fullScreenButtonCallback?.();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogDefaultComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: DialogConfig }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: DialogDefaultComponent, isStandalone: true, selector: "fd-dialog-default", ngImport: i0, template: "<fd-dialog>\n    <fd-dialog-header>\n        <div\n            role=\"heading\"\n            [attr.aria-level]=\"_defaultDialogContent?.titleHeadingLevel || 1\"\n            fd-title\n            [id]=\"_defaultDialogContent?.titleId || dialogTitleId\"\n        >\n            {{ _defaultDialogContent?.title }}\n        </div>\n        @if (_defaultDialogContent?.allowFullScreen) {\n            <button\n                fd-dialog-full-screen-toggler-button\n                #fullScreenTogglerButton\n                [title]=\"\n                    (fullScreenTogglerButton._fullscreen$()\n                        ? _defaultDialogContent?.fullScreenMinifyButtonText\n                        : _defaultDialogContent?.fullScreenExpandButtonText) || ''\n                \"\n                (click)=\"_fullScreenButtonClicked()\"\n            ></button>\n        }\n        @if (_defaultDialogContent?.closeButtonCallback) {\n            <button\n                fd-dialog-close-button\n                [title]=\"_defaultDialogContent?.closeButtonTitle || ''\"\n                [ariaLabel]=\"_defaultDialogContent?.closeButtonAriaLabel || ''\"\n                (click)=\"_closeButtonClicked()\"\n            ></button>\n        }\n        @if (_defaultDialogContent?.subHeader) {\n            <ng-template fdkTemplate=\"subheader\">\n                <ng-template [ngTemplateOutlet]=\"_defaultDialogContent!.subHeader!\"></ng-template>\n            </ng-template>\n        }\n    </fd-dialog-header>\n    @if (_defaultDialogContent?.content) {\n        <fd-dialog-body [id]=\"_defaultDialogContent?.contentId || dialogContentId\">\n            <ng-template [ngTemplateOutlet]=\"_defaultDialogContent?.content!\"></ng-template>\n        </fd-dialog-body>\n    }\n    @if (_showFooter()) {\n        <fd-dialog-footer>\n            @if (_defaultDialogContent?.approveButton) {\n                <fd-button-bar\n                    fdType=\"emphasized\"\n                    fdkInitialFocus\n                    [label]=\"_defaultDialogContent?.approveButton || ''\"\n                    [fdCozy]=\"_defaultDialogConfiguration.mobile\"\n                    (click)=\"_approveButtonClicked()\"\n                    [ariaLabel]=\"_defaultDialogContent?.approveButtonAriaLabel\"\n                    [id]=\"_defaultDialogContent?.approveButtonId\"\n                >\n                </fd-button-bar>\n            }\n            @if (_defaultDialogContent?.cancelButton) {\n                <fd-button-bar\n                    [label]=\"_defaultDialogContent?.cancelButton || ''\"\n                    [fdCozy]=\"_defaultDialogConfiguration.mobile\"\n                    (click)=\"_cancelButtonClicked()\"\n                    [ariaLabel]=\"_defaultDialogContent?.closeButtonAriaLabel\"\n                    [id]=\"_defaultDialogContent?.cancelButtonId\"\n                >\n                </fd-button-bar>\n            }\n        </fd-dialog-footer>\n    }\n</fd-dialog>\n", dependencies: [{ kind: "component", type: DialogComponent, selector: "fd-dialog", inputs: ["class", "dialogRef", "dialogConfig"] }, { kind: "component", type: DialogHeaderComponent, selector: "fd-dialog-header" }, { kind: "component", type: TitleComponent, selector: "[fd-title], [fdTitle]", inputs: ["headerSize", "wrap"], exportAs: ["fd-title"] }, { kind: "component", type: DialogFullScreenTogglerButtonComponent, selector: "[fd-dialog-full-screen-toggler-button]", inputs: ["mobile", "dialogRef", "title"] }, { kind: "component", type: DialogCloseButtonComponent, selector: "[fd-dialog-close-button]", inputs: ["mobile", "title", "ariaLabel"] }, { kind: "directive", type: TemplateDirective, selector: "[fdkTemplate]", inputs: ["fdkTemplate"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: DialogBodyComponent, selector: "fd-dialog-body", inputs: ["disablePaddings"] }, { kind: "component", type: DialogFooterComponent, selector: "fd-dialog-footer" }, { kind: "component", type: ButtonBarComponent, selector: "fd-button-bar", inputs: ["fullWidth", "fdType", "title", "ariaLabelledby", "id"] }, { kind: "directive", type: InitialFocusDirective, selector: "[fdkInitialFocus]", inputs: ["fdkInitialFocus", "enabled", "focusLastElement"] }, { kind: "directive", type: ContentDensityDirective, selector: "[fdContentDensity]:not([fdCompact]):not([fdCondensed]):not([fdCozy]),                [fdCompact]:not([fdContentDensity]):not([fdCondensed]):not([fdCozy]),                [fdCondensed]:not([fdContentDensity]):not([fdCompact]):not([fdCozy]),                [fdCozy]:not([fdContentDensity]):not([fdCompact]):not([fdCondensed])", inputs: ["fdContentDensity", "fdCompact", "fdCondensed", "fdCozy"], exportAs: ["fdContentDensity"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogDefaultComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-dialog-default', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        DialogComponent,
                        DialogHeaderComponent,
                        TitleComponent,
                        DialogFullScreenTogglerButtonComponent,
                        DialogCloseButtonComponent,
                        TemplateDirective,
                        NgTemplateOutlet,
                        CdkScrollable,
                        ScrollbarDirective,
                        DialogBodyComponent,
                        DialogFooterComponent,
                        ButtonBarComponent,
                        InitialFocusDirective,
                        ContentDensityDirective
                    ], template: "<fd-dialog>\n    <fd-dialog-header>\n        <div\n            role=\"heading\"\n            [attr.aria-level]=\"_defaultDialogContent?.titleHeadingLevel || 1\"\n            fd-title\n            [id]=\"_defaultDialogContent?.titleId || dialogTitleId\"\n        >\n            {{ _defaultDialogContent?.title }}\n        </div>\n        @if (_defaultDialogContent?.allowFullScreen) {\n            <button\n                fd-dialog-full-screen-toggler-button\n                #fullScreenTogglerButton\n                [title]=\"\n                    (fullScreenTogglerButton._fullscreen$()\n                        ? _defaultDialogContent?.fullScreenMinifyButtonText\n                        : _defaultDialogContent?.fullScreenExpandButtonText) || ''\n                \"\n                (click)=\"_fullScreenButtonClicked()\"\n            ></button>\n        }\n        @if (_defaultDialogContent?.closeButtonCallback) {\n            <button\n                fd-dialog-close-button\n                [title]=\"_defaultDialogContent?.closeButtonTitle || ''\"\n                [ariaLabel]=\"_defaultDialogContent?.closeButtonAriaLabel || ''\"\n                (click)=\"_closeButtonClicked()\"\n            ></button>\n        }\n        @if (_defaultDialogContent?.subHeader) {\n            <ng-template fdkTemplate=\"subheader\">\n                <ng-template [ngTemplateOutlet]=\"_defaultDialogContent!.subHeader!\"></ng-template>\n            </ng-template>\n        }\n    </fd-dialog-header>\n    @if (_defaultDialogContent?.content) {\n        <fd-dialog-body [id]=\"_defaultDialogContent?.contentId || dialogContentId\">\n            <ng-template [ngTemplateOutlet]=\"_defaultDialogContent?.content!\"></ng-template>\n        </fd-dialog-body>\n    }\n    @if (_showFooter()) {\n        <fd-dialog-footer>\n            @if (_defaultDialogContent?.approveButton) {\n                <fd-button-bar\n                    fdType=\"emphasized\"\n                    fdkInitialFocus\n                    [label]=\"_defaultDialogContent?.approveButton || ''\"\n                    [fdCozy]=\"_defaultDialogConfiguration.mobile\"\n                    (click)=\"_approveButtonClicked()\"\n                    [ariaLabel]=\"_defaultDialogContent?.approveButtonAriaLabel\"\n                    [id]=\"_defaultDialogContent?.approveButtonId\"\n                >\n                </fd-button-bar>\n            }\n            @if (_defaultDialogContent?.cancelButton) {\n                <fd-button-bar\n                    [label]=\"_defaultDialogContent?.cancelButton || ''\"\n                    [fdCozy]=\"_defaultDialogConfiguration.mobile\"\n                    (click)=\"_cancelButtonClicked()\"\n                    [ariaLabel]=\"_defaultDialogContent?.closeButtonAriaLabel\"\n                    [id]=\"_defaultDialogContent?.cancelButtonId\"\n                >\n                </fd-button-bar>\n            }\n        </fd-dialog-footer>\n    }\n</fd-dialog>\n" }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: DialogConfig }] });

const dialogFade = trigger('state', [
    state('void, hidden', style({
        opacity: 0,
        position: 'relative',
        zIndex: 999
    })),
    state('visible', style({
        opacity: 1,
        position: 'relative',
        zIndex: 999
    })),
    transition('* => visible', animate('150ms cubic-bezier(0, 0, 0.2, 1)')),
    transition('* => void, * => hidden', animate('75ms cubic-bezier(0.4, 0.0, 1, 1)', style({
        opacity: 0,
        position: 'relative',
        zIndex: 999
    })))
]);

/** Dialog container where the dialog content is embedded. */
class DialogContainerComponent extends DynamicComponentContainer {
    /** Custom classes */
    set class(userClass) {
        this._class = userClass;
        this.buildComponentCssClass();
    }
    /** The state of the Dialog animations. */
    get _animationState() {
        return this._animationStateSignal();
    }
    /** @hidden */
    constructor(dialogConfig, ref, _destroyRef, elementRef, _cdr, injector) {
        super(elementRef, injector);
        this.dialogConfig = dialogConfig;
        this.ref = ref;
        this._destroyRef = _destroyRef;
        this._cdr = _cdr;
        /** @hidden */
        this._class = '';
        /** @hidden */
        this._animationStateSignal = signal('void');
    }
    /** @hidden */
    buildComponentCssClass() {
        return [this.dialogConfig.containerClass ? this.dialogConfig.containerClass : '', this._class];
    }
    /** Handle end of animations, updating the state of the Message Toast. */
    onAnimationEnd(event) {
        const { toState } = event;
        if (toState === 'hidden') {
            this.ref._endClose$.next();
            this.ref._endClose$.complete();
        }
    }
    /** @hidden */
    ngAfterViewInit() {
        setTimeout(() => {
            this._loadContent();
            this._listenOnClose();
        });
    }
    /** @hidden */
    _attached(event) {
        if (event instanceof ComponentRef) {
            event.changeDetectorRef.markForCheck();
        }
        else if (event instanceof EmbeddedViewRef) {
            event.markForCheck();
        }
    }
    /** @hidden Load received content */
    _loadContent() {
        if (this._cdr.destroyed) {
            return;
        }
        if (this.childContent instanceof Type) {
            this._createFromComponent(this.childContent);
        }
        else if (this.childContent instanceof TemplateRef) {
            this._createFromTemplate(this.childContent, this._templateContext());
        }
        else {
            this._createFromDefaultDialog(this.childContent);
        }
        this._animationStateSignal.set('visible');
    }
    /** @hidden Returns context for embedded template */
    _templateContext() {
        return { $implicit: this.ref, dialogConfig: this.dialogConfig };
    }
    /** @hidden Load Dialog component from passed object */
    _createFromDefaultDialog(config) {
        this._createFromComponent(DialogDefaultComponent);
        const instance = this._componentRef.instance;
        instance._defaultDialogContent = config;
        instance._defaultDialogConfiguration = this.dialogConfig;
    }
    /**
     * @hidden
     * We need to wait until animation plays, and then send signal to the service to destroy the component.
     */
    _listenOnClose() {
        const callback = () => {
            this._animationStateSignal.set('hidden');
        };
        this.ref.afterClosed.pipe(takeUntilDestroyed(this._destroyRef)).subscribe({
            next: () => callback(),
            error: () => callback()
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogContainerComponent, deps: [{ token: DialogConfig }, { token: DialogRef }, { token: i0.DestroyRef }, { token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: i0.Injector }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: DialogContainerComponent, isStandalone: true, selector: "fd-dialog-container", inputs: { class: "class" }, host: { listeners: { "@state.done": "onAnimationEnd($event)" }, properties: { "@state": "this._animationState" } }, viewQueries: [{ propertyName: "portalOutlet", first: true, predicate: CdkPortalOutlet, descendants: true }], usesInheritance: true, ngImport: i0, template: '<ng-template (attached)="_attached($event)" cdkPortalOutlet></ng-template>', isInline: true, styles: [":host:not(:first-of-type) ::ng-deep .fd-dialog:before{opacity:0}\n"], dependencies: [{ kind: "ngmodule", type: PortalModule }, { kind: "directive", type: i3$2.CdkPortalOutlet, selector: "[cdkPortalOutlet]", inputs: ["cdkPortalOutlet"], outputs: ["attached"], exportAs: ["cdkPortalOutlet"] }], animations: [dialogFade], encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], DialogContainerComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogContainerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-dialog-container', template: '<ng-template (attached)="_attached($event)" cdkPortalOutlet></ng-template>', animations: [dialogFade], encapsulation: ViewEncapsulation.None, standalone: true, imports: [PortalModule], styles: [":host:not(:first-of-type) ::ng-deep .fd-dialog:before{opacity:0}\n"] }]
        }], ctorParameters: () => [{ type: DialogConfig }, { type: DialogRef }, { type: i0.DestroyRef }, { type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i0.Injector }], propDecorators: { class: [{
                type: Input
            }], portalOutlet: [{
                type: ViewChild,
                args: [CdkPortalOutlet]
            }], _animationState: [{
                type: HostBinding,
                args: ['@state']
            }], buildComponentCssClass: [], onAnimationEnd: [{
                type: HostListener,
                args: ['@state.done', ['$event']]
            }] } });

/** Service used to create a dialog. */
class DialogService extends DialogBaseService {
    /** @hidden */
    constructor(_defaultConfig, _rtlService, _injector, _overlay) {
        super();
        this._defaultConfig = _defaultConfig;
        this._rtlService = _rtlService;
        this._injector = _injector;
        this._overlay = _overlay;
        /** @hidden */
        this.platformId = inject(PLATFORM_ID);
        if (isPlatformBrowser(this.platformId)) {
            this.htmlElement = document.querySelector('html');
        }
    }
    /**
     * Opens a dialog component with provided content.
     * @param content Content of the dialog component.
     * @param dialogConfig Configuration of the dialog component.
     * @param parentInjector Parent injector instance.
     */
    open(content, dialogConfig, parentInjector) {
        const dialogRef = new DialogRef();
        let previouslyFocusedElement = null;
        if (dialogConfig?.focusTrapped && document.activeElement) {
            previouslyFocusedElement = document.activeElement;
        }
        if (!parentInjector) {
            parentInjector = this._injector;
        }
        dialogConfig = this._applyDefaultConfig(dialogConfig || {}, this._defaultConfig || new DialogConfig());
        dialogRef.data = dialogConfig.data;
        const injector = Injector.create({
            providers: [
                { provide: DialogConfig, useValue: dialogConfig },
                { provide: DialogRef, useValue: dialogRef },
                { provide: RtlService, useValue: this._rtlService },
                { provide: DialogService, useValue: this }
            ],
            parent: parentInjector
        });
        const overlayRef = this._overlay.create(new OverlayConfig());
        if (dialogConfig.container && dialogConfig.container !== 'body' && typeof dialogConfig.container !== 'string') {
            dialogConfig.container.append(overlayRef.hostElement);
        }
        const portal = new ComponentPortal(DialogContainerComponent, null, injector);
        const componentRef = overlayRef.attach(portal);
        componentRef.instance.childContent = content;
        componentRef.instance.dialogConfig = dialogConfig;
        this._dialogs.push(componentRef);
        this.htmlElement && (this.htmlElement.style.overflow = 'hidden');
        dialogRef._endClose$.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._destroyDialog(componentRef);
            componentRef.destroy();
            overlayRef.dispose();
            this.htmlElement && (this.htmlElement.style.overflow = '');
            if (dialogConfig?.focusTrapped && previouslyFocusedElement) {
                previouslyFocusedElement.focus();
            }
        });
        return dialogRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogService, deps: [{ token: DIALOG_DEFAULT_CONFIG, optional: true }, { token: i1.RtlService, optional: true }, { token: i0.Injector }, { token: i2.Overlay }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: DialogConfig, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [DIALOG_DEFAULT_CONFIG]
                }] }, { type: i1.RtlService, decorators: [{
                    type: Optional
                }] }, { type: i0.Injector }, { type: i2.Overlay }] });

class DialogTemplateDirective {
    constructor() {
        /** Custom dialog config model. */
        this.fdDialogTemplateConfig = input();
        /** @hidden */
        this.templateRef = inject((TemplateRef));
    }
    /** @hidden */
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogTemplateDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.2", type: DialogTemplateDirective, isStandalone: true, selector: "[fdDialogTemplate]", inputs: { fdDialogTemplateConfig: { classPropertyName: "fdDialogTemplateConfig", publicName: "fdDialogTemplateConfig", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogTemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdDialogTemplate]',
                    standalone: true
                }]
        }] });

/**
 * Provides necessary services for dialog functionality to properly work.
 * @returns Array of Providers.
 */
function provideDialogService() {
    return [DialogService, DynamicComponentService];
}

const declarations = [
    DialogComponent,
    DialogBodyComponent,
    DialogFooterComponent,
    DialogHeaderComponent,
    DialogDefaultComponent,
    DialogContainerComponent,
    DialogCloseButtonComponent,
    DialogTitleDirective,
    DialogFullScreenTogglerButtonComponent,
    DialogTemplateDirective
];
/**
 * @deprecated
 * Use following imports instead:
 * `DialogComponent`,
 * `DialogBodyComponent`,
 * `DialogFooterComponent`,
 * `DialogHeaderComponent`,
 * `DialogCloseButtonComponent`,
 * `DialogTitleDirective`,
 * `DialogFullScreenTogglerButtonComponent`
 *
 * in order to provide dialog service, use `provideDialogService()`
 */
class DialogModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: DialogModule, imports: [DialogComponent,
            DialogBodyComponent,
            DialogFooterComponent,
            DialogHeaderComponent,
            DialogDefaultComponent,
            DialogContainerComponent,
            DialogCloseButtonComponent,
            DialogTitleDirective,
            DialogFullScreenTogglerButtonComponent,
            DialogTemplateDirective, 
            // Keeping these two items for backwards compatibility.
            TemplateModule,
            BarComponent,
            BarLeftDirective,
            BarMiddleDirective,
            BarRightDirective,
            BarElementDirective,
            ButtonBarComponent,
            TitleComponent], exports: [DialogComponent,
            DialogBodyComponent,
            DialogFooterComponent,
            DialogHeaderComponent,
            DialogDefaultComponent,
            DialogContainerComponent,
            DialogCloseButtonComponent,
            DialogTitleDirective,
            DialogFullScreenTogglerButtonComponent,
            DialogTemplateDirective, 
            // Keeping these two items for backwards compatibility.
            TemplateModule,
            BarComponent,
            BarLeftDirective,
            BarMiddleDirective,
            BarRightDirective,
            BarElementDirective,
            ButtonBarComponent,
            TitleComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogModule, providers: [provideDialogService()], imports: [DialogComponent,
            DialogBodyComponent,
            DialogFooterComponent,
            DialogHeaderComponent,
            DialogDefaultComponent,
            DialogContainerComponent,
            DialogCloseButtonComponent,
            DialogFullScreenTogglerButtonComponent, 
            // Keeping these two items for backwards compatibility.
            TemplateModule,
            BarComponent,
            ButtonBarComponent,
            TitleComponent, 
            // Keeping these two items for backwards compatibility.
            TemplateModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        declarations,
                        // Keeping these two items for backwards compatibility.
                        TemplateModule,
                        BarComponent,
                        BarLeftDirective,
                        BarMiddleDirective,
                        BarRightDirective,
                        BarElementDirective,
                        ButtonBarComponent,
                        TitleComponent
                    ],
                    exports: [
                        declarations,
                        // Keeping these two items for backwards compatibility.
                        TemplateModule,
                        BarComponent,
                        BarLeftDirective,
                        BarMiddleDirective,
                        BarRightDirective,
                        BarElementDirective,
                        ButtonBarComponent,
                        TitleComponent
                    ],
                    providers: [provideDialogService()]
                }]
        }] });

class DialogContentBase {
    constructor() {
        /** Dialog Title Heading Level. Default is 1 */
        this.titleHeadingLevel = 1;
    }
}

class DialogDefaultContent extends DialogContentBase {
}

/**
 * Represents the positioning of the dialog on the screen.
 */
class DialogPosition {
}

class DialogOverlayContainer extends OverlayContainer {
    /**
     * This method returns the overlay container element. It will lazily
     * create the element the first time it is called to facilitate using
     * the container in non-browser environments.
     * @returns the container element
     */
    getContainerElement() {
        const containerElement = super.getContainerElement();
        containerElement.classList.add('fd-dialog-overlay-container');
        return containerElement;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogOverlayContainer, deps: null, target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogOverlayContainer }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DialogOverlayContainer, decorators: [{
            type: Injectable
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DIALOG_DEFAULT_CONFIG, DialogBase, DialogBaseService, DialogBodyComponent, DialogButtonClass, DialogCloseButtonComponent, DialogComponent, DialogConfig, DialogConfigBase, DialogContainerComponent, DialogContentBase, DialogDefaultComponent, DialogDefaultContent, DialogFooterBase, DialogFooterComponent, DialogFullScreenTogglerButtonComponent, DialogHeaderBase, DialogHeaderComponent, DialogModule, DialogOverlayContainer, DialogPosition, DialogRef, DialogRefBase, DialogService, DialogTemplateDirective, DialogTitleDirective, FD_DIALOG_BODY_COMPONENT, FD_DIALOG_DISMISS_REASON, FD_DIALOG_FOCUS_TRAP_ERROR, dialogFade, provideDialogService };
//# sourceMappingURL=fundamental-ngx-core-dialog.mjs.map
