import * as i0 from '@angular/core';
import { inject, TemplateRef, Directive, Input, ViewEncapsulation, ChangeDetectionStrategy, Component, ElementRef, ContentChild, InjectionToken, signal, Injectable, computed, input, EventEmitter, Optional, ViewChild, Output, HostBinding, viewChild, DestroyRef, ContentChildren, Inject, NgModule } from '@angular/core';
import { ToolbarComponent, ToolbarItemDirective } from '@fundamental-ngx/core/toolbar';
import { NgTemplateOutlet } from '@angular/common';
import * as i1 from '@fundamental-ngx/core/content-density';
import { contentDensityObserverProviders } from '@fundamental-ngx/core/content-density';
import { Subject, fromEvent, startWith, asyncScheduler } from 'rxjs';
import { FD_BREADCRUMB_COMPONENT } from '@fundamental-ngx/core/breadcrumb';
import { DYNAMIC_PAGE_HEADER_TOKEN, FD_TABLIST } from '@fundamental-ngx/core/shared';
import { IgnoreClickOnSelectionDirective, resizeObservable } from '@fundamental-ngx/cdk/utils';
import { ButtonComponent } from '@fundamental-ngx/core/button';
import { IconComponent } from '@fundamental-ngx/core/icon';
import { FD_LANGUAGE, resolveTranslationSignalFn } from '@fundamental-ngx/i18n';
import { map, debounceTime, observeOn } from 'rxjs/operators';
import * as i3 from '@fundamental-ngx/core/flexible-column-layout';
import { FD_FLEXIBLE_COLUMN_LAYOUT_COMPONENT } from '@fundamental-ngx/core/flexible-column-layout';
import { CdkScrollable } from '@angular/cdk/overlay';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { ScrollbarDirective } from '@fundamental-ngx/core/scrollbar';

const DYNAMIC_PAGE_CLASS_NAME = {
    dynamicPage: 'fd-dynamic-page',
    dynamicPageTitleArea: 'fd-dynamic-page__title-area',
    dynamicPageMainContainer: 'fd-dynamic-page__main-container',
    dynamicPageBreadcrumbTitleContainer: 'fd-dynamic-page__breadcrumb-title-container',
    dynamicPageTitleAreaCollapsed: 'fd-dynamic-page__title-area--collapsed',
    dynamicPageTitleContainer: 'fd-dynamic-page__title-container',
    dynamicPageTitle: 'fd-dynamic-page__title',
    dynamicPageBreadcrumb: 'fd-dynamic-page__breadcrumb',
    dynamicPageKeyInfo: 'fd-dynamic-page__title-content',
    dynamicPageToolbar: 'fd-dynamic-page__toolbar',
    dynamicPageLayoutActionsToolbar: 'fd-dynamic-page__toolbar--actions',
    dynamicPageLayoutContentToolbar: 'fd-dynamic-page__toolbar--content',
    dynamicPageHeader: 'fd-dynamic-page__header',
    dynamicPageCollapsibleHeader: 'fd-dynamic-page__collapsible-header',
    dynamicPageCollapsibleHeaderPinCollapseNoShadow: 'fd-dynamic-page__collapsible-header-visibility-container--no-shadow',
    dynamicPageTabs: 'fd-dynamic-page__tabs',
    dynamicPageTabsAddShadow: 'fd-dynamic-page__tabs--add-shadow',
    dynamicPageContent: 'fd-dynamic-page__content',
    dynamicPageSummarizedTitleArea: 'fd-dynamic-page__summarized-title-area',
    dynamicPageSummarizedTitleAreaExtraLarge: 'fd-dynamic-page__summarized-title-area',
    dynamicPageSummarizedTitleAreaNoShadow: 'fd-dynamic-page__summarized-title-area--no-shadow',
    dynamicPageSummarizedTitle: 'fd-dynamic-page__summarized-title',
    dynamicPageSummarizedTitleCollapsed: 'fd-dynamic-page__summarized-title-area--collapsed'
};

class DynamicPageHeaderSubtitleDirective {
    constructor() {
        /** Template reference. */
        this.templateRef = inject(TemplateRef);
    }
    /** @hidden */
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageHeaderSubtitleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: DynamicPageHeaderSubtitleDirective, isStandalone: true, selector: "[fdDynamicPageHeaderSubtitle]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageHeaderSubtitleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdDynamicPageHeaderSubtitle]',
                    standalone: true
                }]
        }] });

class DynamicPageHeaderTitleDirective {
    constructor() {
        /** Template reference. */
        this.templateRef = inject(TemplateRef);
    }
    /** @hidden */
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageHeaderTitleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: DynamicPageHeaderTitleDirective, isStandalone: true, selector: "[fdDynamicPageHeaderTitle]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageHeaderTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdDynamicPageHeaderTitle]',
                    standalone: true
                }]
        }] });

const addClassNameToElement = (renderer, element, className) => {
    renderer.addClass(element, className);
};
/** @hidden Returns dynamic page size based on width
 * @param width - dynamic page window width
 **/
function dynamicPageWidthToSize(width) {
    if (width < 599) {
        return 'small';
    }
    else if (width < 1023) {
        return 'medium';
    }
    else if (width < 1439) {
        return 'large';
    }
    return 'extra-large';
}

class DynamicPageContentComponent {
    /** @hidden */
    constructor(_renderer, elementRef, _cdr) {
        this._renderer = _renderer;
        this.elementRef = elementRef;
        this._cdr = _cdr;
        /** @hidden */
        this._showSpacer = false;
    }
    /** @hidden */
    ngOnInit() {
        this._addClassNameToHostElement(DYNAMIC_PAGE_CLASS_NAME.dynamicPageContent);
    }
    /** @hidden */
    _toggleSpacer(state) {
        this._showSpacer = state;
        this._cdr.markForCheck();
    }
    /** @hidden */
    _addClassNameToHostElement(className) {
        addClassNameToElement(this._renderer, this.elementRef.nativeElement, className);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageContentComponent, deps: [{ token: i0.Renderer2 }, { token: i0.ElementRef }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: DynamicPageContentComponent, isStandalone: true, selector: "fd-dynamic-page-content", inputs: { tabLabel: "tabLabel", id: "id" }, ngImport: i0, template: "<ng-content></ng-content>\n@if (_showSpacer) {\n    <div class=\"footer-spacer\"></div>\n}\n", styles: ["fd-dynamic-page .fd-dynamic-page .fd-dynamic-page__content{display:block;height:100%}fd-dynamic-page .fd-dynamic-page .fd-dynamic-page__content:has(.fdp-table){padding-top:0}fd-dynamic-page .fd-dynamic-page .fd-dynamic-page__content .fdp-table{margin-top:16px}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageContentComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-dynamic-page-content', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, imports: [], template: "<ng-content></ng-content>\n@if (_showSpacer) {\n    <div class=\"footer-spacer\"></div>\n}\n", styles: ["fd-dynamic-page .fd-dynamic-page .fd-dynamic-page__content{display:block;height:100%}fd-dynamic-page .fd-dynamic-page .fd-dynamic-page__content:has(.fdp-table){padding-top:0}fd-dynamic-page .fd-dynamic-page .fd-dynamic-page__content .fdp-table{margin-top:16px}\n"] }]
        }], ctorParameters: () => [{ type: i0.Renderer2 }, { type: i0.ElementRef }, { type: i0.ChangeDetectorRef }], propDecorators: { tabLabel: [{
                type: Input
            }], id: [{
                type: Input
            }] } });

class DynamicPageFooterComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageFooterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: DynamicPageFooterComponent, isStandalone: true, selector: "fd-dynamic-page-footer", ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageFooterComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-dynamic-page-footer',
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    standalone: true
                }]
        }] });

class DynamicPageBaseActions {
    /** @hidden */
    addClassToToolbar(_class, elementRef) {
        // adds global actions classes to its toolbar
        const toolbarEl = elementRef.nativeElement.querySelector('.fd-toolbar');
        if (toolbarEl) {
            toolbarEl.classList.add(_class);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageBaseActions, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: DynamicPageBaseActions, isStandalone: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageBaseActions, decorators: [{
            type: Directive
        }] });

class DynamicPageGlobalActionsComponent extends DynamicPageBaseActions {
    constructor() {
        super(...arguments);
        /** @hidden */
        this._elementRef = inject(ElementRef);
    }
    /** @hidden */
    ngAfterContentInit() {
        this.addClassToToolbar(DYNAMIC_PAGE_CLASS_NAME.dynamicPageToolbar, this._elementRef);
    }
    /** @hidden */
    _setSize(size) {
        if (this._toolbarComponent) {
            this._handleOverflow(size === 'small');
        }
    }
    /** @hidden */
    _handleOverflow(shouldBeHidden) {
        this._toolbarComponent.forceOverflow = shouldBeHidden;
        this._toolbarComponent.shouldOverflow = shouldBeHidden;
        this._toolbarComponent.detectChanges();
        setTimeout(() => {
            this._toolbarComponent.updateCollapsibleItems();
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageGlobalActionsComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: DynamicPageGlobalActionsComponent, isStandalone: true, selector: "fd-dynamic-page-global-actions", host: { attributes: { "role": "toolbar" } }, queries: [{ propertyName: "_toolbarComponent", first: true, predicate: ToolbarComponent, descendants: true }], usesInheritance: true, ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageGlobalActionsComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-dynamic-page-global-actions',
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    host: {
                        role: 'toolbar'
                    },
                    standalone: true
                }]
        }], propDecorators: { _toolbarComponent: [{
                type: ContentChild,
                args: [ToolbarComponent]
            }] } });

class DynamicPageLayoutActionsComponent extends DynamicPageBaseActions {
    constructor() {
        super(...arguments);
        /** @hidden */
        this._elementRef = inject(ElementRef);
    }
    /** @hidden */
    ngAfterContentInit() {
        this.addClassToToolbar(DYNAMIC_PAGE_CLASS_NAME.dynamicPageLayoutActionsToolbar, this._elementRef);
        this.addClassToToolbar(DYNAMIC_PAGE_CLASS_NAME.dynamicPageToolbar, this._elementRef);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageLayoutActionsComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: DynamicPageLayoutActionsComponent, isStandalone: true, selector: "fd-dynamic-page-layout-actions", host: { attributes: { "role": "toolbar" }, properties: { "style.margin-inline-start": "\"auto\"" } }, queries: [{ propertyName: "toolbarComponent", first: true, predicate: ToolbarComponent, descendants: true }], usesInheritance: true, ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageLayoutActionsComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-dynamic-page-layout-actions',
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    host: {
                        role: 'toolbar',
                        '[style.margin-inline-start]': '"auto"'
                    },
                    standalone: true
                }]
        }], propDecorators: { toolbarComponent: [{
                type: ContentChild,
                args: [ToolbarComponent]
            }] } });

class DynamicPageTitleContentComponent {
    /** @hidden */
    constructor(_changeDetRef, _contentDensityObserver) {
        this._changeDetRef = _changeDetRef;
        this._contentDensityObserver = _contentDensityObserver;
    }
    /** @hidden */
    _setSize(size) {
        this._size = size;
        this._changeDetRef.detectChanges();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageTitleContentComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i1.ContentDensityObserver }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: DynamicPageTitleContentComponent, isStandalone: true, selector: "fd-dynamic-page-title-content", providers: [contentDensityObserverProviders()], ngImport: i0, template: `
        @if (_size === 'small') {
            <fd-toolbar
                fdType="transparent"
                (click)="$event.stopPropagation()"
                class="dynamicPageLayoutContentToolbar"
                [clearBorder]="true"
                [forceOverflow]="true"
                [shouldOverflow]="true"
            >
                <div fd-toolbar-item>
                    <ng-template [ngTemplateOutlet]="templateContentRef"></ng-template>
                </div>
            </fd-toolbar>
        }
        @if (_size !== 'small') {
            <div class="fd-dynamic-page__title-content">
                <ng-template [ngTemplateOutlet]="templateContentRef"></ng-template>
            </div>
        }
        <ng-template #templateContentRef>
            <ng-content></ng-content>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "component", type: ToolbarComponent, selector: "fd-toolbar", inputs: ["titleId", "class", "shouldOverflow", "fdType", "title", "active", "clearBorder", "forceOverflow", "tabindex", "headingLevel", "ariaLabel", "ariaLabelledBy"] }, { kind: "directive", type: ToolbarItemDirective, selector: "[fd-toolbar-item], [fdOverflowGroup], [fdOverflowPriority]", inputs: ["fdOverflowPriority", "fdOverflowGroup"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageTitleContentComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-dynamic-page-title-content',
                    template: `
        @if (_size === 'small') {
            <fd-toolbar
                fdType="transparent"
                (click)="$event.stopPropagation()"
                class="dynamicPageLayoutContentToolbar"
                [clearBorder]="true"
                [forceOverflow]="true"
                [shouldOverflow]="true"
            >
                <div fd-toolbar-item>
                    <ng-template [ngTemplateOutlet]="templateContentRef"></ng-template>
                </div>
            </fd-toolbar>
        }
        @if (_size !== 'small') {
            <div class="fd-dynamic-page__title-content">
                <ng-template [ngTemplateOutlet]="templateContentRef"></ng-template>
            </div>
        }
        <ng-template #templateContentRef>
            <ng-content></ng-content>
        </ng-template>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    providers: [contentDensityObserverProviders()],
                    imports: [ToolbarComponent, ToolbarItemDirective, NgTemplateOutlet]
                }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i1.ContentDensityObserver }] });

const FD_DYNAMIC_PAGE_BREADCRUMB_COMPONENT = new InjectionToken('DynamicPageBreadcrumbComponent');

class DynamicPageBreadcrumbComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageBreadcrumbComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: DynamicPageBreadcrumbComponent, isStandalone: true, selector: "fd-dynamic-page-breadcrumb", providers: [
            {
                provide: FD_DYNAMIC_PAGE_BREADCRUMB_COMPONENT,
                useExisting: DynamicPageBreadcrumbComponent
            }
        ], ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageBreadcrumbComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-dynamic-page-breadcrumb',
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    providers: [
                        {
                            provide: FD_DYNAMIC_PAGE_BREADCRUMB_COMPONENT,
                            useExisting: DynamicPageBreadcrumbComponent
                        }
                    ],
                    standalone: true
                }]
        }] });

class DynamicPageService {
    constructor() {
        /** @hidden */
        this.collapsed = signal(false);
        /** @hidden */
        this.pinned = signal(false);
        /** @hidden */
        this.pixelsSizeChanged = signal(0);
        /** @hidden */
        this.subheaderVisibilityChange = new Subject();
        /** @hidden */
        this.focusLayoutAction = new Subject();
    }
    /** @hidden */
    toggleCollapsed() {
        this.collapsed.update((collapsed) => !collapsed);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageService, decorators: [{
            type: Injectable
        }] });

const ActionSquashBreakpointPx = 1280;
let dynamicPageTitleId = 0;
class DynamicPageHeaderComponent {
    /** @hidden */
    constructor(_elementRef, _renderer, _dynamicPageService, _changeDetRef) {
        this._elementRef = _elementRef;
        this._renderer = _renderer;
        this._dynamicPageService = _dynamicPageService;
        this._changeDetRef = _changeDetRef;
        /** Whether title should wrap instead of truncation. */
        this.titleWrap = false;
        /** Whether subtitle should wrap instead of truncation. */
        this.subtitleWrap = false;
        /** @hidden */
        this._actionsSquashed$ = computed(() => this._dynamicPageService.pixelsSizeChanged() < ActionSquashBreakpointPx);
        /**
         * Heading level of the dynamic page header title.
         */
        this.headingLevel = input(2);
        /** @hidden */
        this._headingLevel = computed(() => this.headingLevel() ? Number.parseInt(`${this.headingLevel()}`.replace(/\D/g, ''), 10) : 2);
        /** Dynamic page title id, it has some default value if not set,  */
        this.titleId = input('fd-dynamic-page-title-id-' + dynamicPageTitleId++);
        /** @hidden **/
        this._onDestroy$ = new Subject();
    }
    /** @hidden */
    ngOnInit() {
        this._addClassNameToHostElement(DYNAMIC_PAGE_CLASS_NAME.dynamicPageTitleArea);
    }
    /** @hidden */
    ngAfterViewInit() {
        this._addCustomClassToBreadcrumb();
    }
    /** @hidden */
    ngOnDestroy() {
        this._onDestroy$.next();
        this._onDestroy$.complete();
    }
    /**
     * sets size which in turn adds corresponding padding for the size type.
     * size can be `small`, `medium`, `large`, or `extra-large`.
     */
    set size(sizeType) {
        this._setSize(sizeType);
        this._size = sizeType;
    }
    /** @hidden */
    stopPropagation(event) {
        event.stopPropagation();
    }
    /**
     * @hidden
     * sets the padding classes
     * @param sizeType
     */
    _setSize(sizeType) {
        setTimeout(() => {
            this._breadcrumbComponent?.onResize();
            this._globalActions?._setSize(sizeType);
            this._contentToolbar?._setSize(sizeType);
            this._changeDetRef.detectChanges();
        });
    }
    /** @hidden */
    _addClassNameToHostElement(className) {
        addClassNameToElement(this._renderer, this._elementRef.nativeElement, className);
    }
    /** @hidden */
    _addClassNameToCustomElement(element, className) {
        addClassNameToElement(this._renderer, element, className);
    }
    /** @hidden */
    _addCustomClassToBreadcrumb() {
        if (this._breadcrumbComponent) {
            this._addClassNameToCustomElement(this._breadcrumbComponent.elementRef.nativeElement, DYNAMIC_PAGE_CLASS_NAME.dynamicPageBreadcrumb);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageHeaderComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: DynamicPageService }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: DynamicPageHeaderComponent, isStandalone: true, selector: "fd-dynamic-page-header", inputs: { title: { classPropertyName: "title", publicName: "title", isSignal: false, isRequired: false, transformFunction: null }, titleWrap: { classPropertyName: "titleWrap", publicName: "titleWrap", isSignal: false, isRequired: false, transformFunction: null }, subtitle: { classPropertyName: "subtitle", publicName: "subtitle", isSignal: false, isRequired: false, transformFunction: null }, subtitleWrap: { classPropertyName: "subtitleWrap", publicName: "subtitleWrap", isSignal: false, isRequired: false, transformFunction: null }, headingLevel: { classPropertyName: "headingLevel", publicName: "headingLevel", isSignal: true, isRequired: false, transformFunction: null }, titleId: { classPropertyName: "titleId", publicName: "titleId", isSignal: true, isRequired: false, transformFunction: null } }, providers: [
            {
                provide: DYNAMIC_PAGE_HEADER_TOKEN,
                useExisting: DynamicPageHeaderComponent
            }
        ], queries: [{ propertyName: "_subtitleTemplate", first: true, predicate: DynamicPageHeaderSubtitleDirective, descendants: true }, { propertyName: "_titleTemplate", first: true, predicate: DynamicPageHeaderTitleDirective, descendants: true }, { propertyName: "_dynamicPageBreadcrumbComponent", first: true, predicate: FD_DYNAMIC_PAGE_BREADCRUMB_COMPONENT, descendants: true }, { propertyName: "_breadcrumbComponent", first: true, predicate: FD_BREADCRUMB_COMPONENT, descendants: true }, { propertyName: "_globalActions", first: true, predicate: DynamicPageGlobalActionsComponent, descendants: true }, { propertyName: "_layoutActions", first: true, predicate: DynamicPageLayoutActionsComponent, descendants: true }, { propertyName: "_contentToolbar", first: true, predicate: DynamicPageTitleContentComponent, descendants: true }], ngImport: i0, template: "<div class=\"fd-dynamic-page__main-container\">\n    <div class=\"fd-dynamic-page__breadcrumb-title-container\">\n        @if (_dynamicPageBreadcrumbComponent || _actionsSquashed$()) {\n            <div class=\"fd-dynamic-page__breadcrumb-container\">\n                @if (_dynamicPageBreadcrumbComponent) {\n                    <nav\n                        aria-label=\"Breadcrumbs\"\n                        class=\"fd-dynamic-page__breadcrumb-wrapper\"\n                        (click)=\"stopPropagation($event)\"\n                    >\n                        <ng-content select=\"fd-dynamic-page-breadcrumb\"></ng-content>\n                    </nav>\n                }\n\n                @if (_actionsSquashed$()) {\n                    <ng-template [ngTemplateOutlet]=\"dynamicPageLayoutActionsRef\"></ng-template>\n                }\n            </div>\n        }\n        <div class=\"fd-dynamic-page__title-container\">\n            @if (_dynamicPageService.collapsed()) {\n                <ng-content select=\"fd-facet\"></ng-content>\n            }\n            <div class=\"fd-dynamic-page__title-subtitle-container\">\n                <div class=\"fd-dynamic-page__title-container\">\n                    <span\n                        role=\"heading\"\n                        class=\"fd-dynamic-page__title\"\n                        [attr.aria-level]=\"_headingLevel()\"\n                        [id]=\"titleId()\"\n                        [class.fd-dynamic-page__title--wrap]=\"titleWrap\"\n                        fdkIgnoreClickOnSelection\n                    >\n                        <ng-template [ngTemplateOutlet]=\"_titleTemplate ? titleRef : defaultTitle\"></ng-template>\n                    </span>\n                    <ng-content select=\"fd-dynamic-page-title-content\"></ng-content>\n                    <div class=\"fd-dynamic-page__toolbar-container\" (click)=\"stopPropagation($event)\">\n                        <ng-template [ngTemplateOutlet]=\"dynamicPageGlobalActionsRef\"></ng-template>\n                        @if (!_actionsSquashed$()) {\n                            <ng-template [ngTemplateOutlet]=\"dynamicPageLayoutActionsRef\"></ng-template>\n                        }\n                    </div>\n                </div>\n                @if (_dynamicPageService.collapsed() && (subtitle || _subtitleTemplate)) {\n                    <span\n                        role=\"heading\"\n                        [attr.aria-level]=\"_headingLevel() + 1\"\n                        class=\"fd-dynamic-page__subtitle\"\n                        [class.fd-dynamic-page__subtitle--wrap]=\"subtitleWrap\"\n                        fdkIgnoreClickOnSelection\n                    >\n                        <ng-template\n                            [ngTemplateOutlet]=\"_subtitleTemplate ? subtitleRef : defaultSubtitle\"\n                        ></ng-template>\n                    </span>\n                }\n            </div>\n        </div>\n    </div>\n</div>\n@if (!_dynamicPageService.collapsed() && (subtitle || _subtitleTemplate)) {\n    <span\n        class=\"fd-dynamic-page__subtitle\"\n        role=\"heading\"\n        [attr.aria-level]=\"_headingLevel() + 1\"\n        [class.fd-dynamic-page__subtitle--wrap]=\"subtitleWrap\"\n        fdkIgnoreClickOnSelection\n    >\n        <ng-template [ngTemplateOutlet]=\"_subtitleTemplate ? subtitleRef : defaultSubtitle\"></ng-template>\n    </span>\n}\n<ng-template #dynamicPageGlobalActionsRef>\n    <ng-content select=\"fd-dynamic-page-global-actions\"></ng-content>\n</ng-template>\n<ng-template #dynamicPageLayoutActionsRef>\n    <ng-content select=\"fd-dynamic-page-layout-actions\"></ng-content>\n</ng-template>\n<ng-template #titleRef>\n    <ng-template\n        [ngTemplateOutlet]=\"_titleTemplate!.templateRef\"\n        [ngTemplateOutletContext]=\"{ $implicit: _dynamicPageService.collapsed() }\"\n    ></ng-template>\n</ng-template>\n<ng-template #subtitleRef>\n    <ng-template\n        [ngTemplateOutlet]=\"_subtitleTemplate!.templateRef\"\n        [ngTemplateOutletContext]=\"{ $implicit: _dynamicPageService.collapsed() }\"\n    ></ng-template>\n</ng-template>\n<ng-template #defaultSubtitle>\n    {{ subtitle }}\n</ng-template>\n<ng-template #titleRef>\n    <ng-template\n        [ngTemplateOutlet]=\"_titleTemplate!.templateRef\"\n        [ngTemplateOutletContext]=\"{ $implicit: _dynamicPageService.collapsed() }\"\n    ></ng-template>\n</ng-template>\n<ng-template #defaultTitle>\n    {{ title }}\n</ng-template>\n", styles: [".fd-dynamic-page__breadcrumb-wrapper{width:100%;max-width:60%}\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: IgnoreClickOnSelectionDirective, selector: "[fdkIgnoreClickOnSelection]" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-dynamic-page-header', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, providers: [
                        {
                            provide: DYNAMIC_PAGE_HEADER_TOKEN,
                            useExisting: DynamicPageHeaderComponent
                        }
                    ], imports: [NgTemplateOutlet, IgnoreClickOnSelectionDirective], template: "<div class=\"fd-dynamic-page__main-container\">\n    <div class=\"fd-dynamic-page__breadcrumb-title-container\">\n        @if (_dynamicPageBreadcrumbComponent || _actionsSquashed$()) {\n            <div class=\"fd-dynamic-page__breadcrumb-container\">\n                @if (_dynamicPageBreadcrumbComponent) {\n                    <nav\n                        aria-label=\"Breadcrumbs\"\n                        class=\"fd-dynamic-page__breadcrumb-wrapper\"\n                        (click)=\"stopPropagation($event)\"\n                    >\n                        <ng-content select=\"fd-dynamic-page-breadcrumb\"></ng-content>\n                    </nav>\n                }\n\n                @if (_actionsSquashed$()) {\n                    <ng-template [ngTemplateOutlet]=\"dynamicPageLayoutActionsRef\"></ng-template>\n                }\n            </div>\n        }\n        <div class=\"fd-dynamic-page__title-container\">\n            @if (_dynamicPageService.collapsed()) {\n                <ng-content select=\"fd-facet\"></ng-content>\n            }\n            <div class=\"fd-dynamic-page__title-subtitle-container\">\n                <div class=\"fd-dynamic-page__title-container\">\n                    <span\n                        role=\"heading\"\n                        class=\"fd-dynamic-page__title\"\n                        [attr.aria-level]=\"_headingLevel()\"\n                        [id]=\"titleId()\"\n                        [class.fd-dynamic-page__title--wrap]=\"titleWrap\"\n                        fdkIgnoreClickOnSelection\n                    >\n                        <ng-template [ngTemplateOutlet]=\"_titleTemplate ? titleRef : defaultTitle\"></ng-template>\n                    </span>\n                    <ng-content select=\"fd-dynamic-page-title-content\"></ng-content>\n                    <div class=\"fd-dynamic-page__toolbar-container\" (click)=\"stopPropagation($event)\">\n                        <ng-template [ngTemplateOutlet]=\"dynamicPageGlobalActionsRef\"></ng-template>\n                        @if (!_actionsSquashed$()) {\n                            <ng-template [ngTemplateOutlet]=\"dynamicPageLayoutActionsRef\"></ng-template>\n                        }\n                    </div>\n                </div>\n                @if (_dynamicPageService.collapsed() && (subtitle || _subtitleTemplate)) {\n                    <span\n                        role=\"heading\"\n                        [attr.aria-level]=\"_headingLevel() + 1\"\n                        class=\"fd-dynamic-page__subtitle\"\n                        [class.fd-dynamic-page__subtitle--wrap]=\"subtitleWrap\"\n                        fdkIgnoreClickOnSelection\n                    >\n                        <ng-template\n                            [ngTemplateOutlet]=\"_subtitleTemplate ? subtitleRef : defaultSubtitle\"\n                        ></ng-template>\n                    </span>\n                }\n            </div>\n        </div>\n    </div>\n</div>\n@if (!_dynamicPageService.collapsed() && (subtitle || _subtitleTemplate)) {\n    <span\n        class=\"fd-dynamic-page__subtitle\"\n        role=\"heading\"\n        [attr.aria-level]=\"_headingLevel() + 1\"\n        [class.fd-dynamic-page__subtitle--wrap]=\"subtitleWrap\"\n        fdkIgnoreClickOnSelection\n    >\n        <ng-template [ngTemplateOutlet]=\"_subtitleTemplate ? subtitleRef : defaultSubtitle\"></ng-template>\n    </span>\n}\n<ng-template #dynamicPageGlobalActionsRef>\n    <ng-content select=\"fd-dynamic-page-global-actions\"></ng-content>\n</ng-template>\n<ng-template #dynamicPageLayoutActionsRef>\n    <ng-content select=\"fd-dynamic-page-layout-actions\"></ng-content>\n</ng-template>\n<ng-template #titleRef>\n    <ng-template\n        [ngTemplateOutlet]=\"_titleTemplate!.templateRef\"\n        [ngTemplateOutletContext]=\"{ $implicit: _dynamicPageService.collapsed() }\"\n    ></ng-template>\n</ng-template>\n<ng-template #subtitleRef>\n    <ng-template\n        [ngTemplateOutlet]=\"_subtitleTemplate!.templateRef\"\n        [ngTemplateOutletContext]=\"{ $implicit: _dynamicPageService.collapsed() }\"\n    ></ng-template>\n</ng-template>\n<ng-template #defaultSubtitle>\n    {{ subtitle }}\n</ng-template>\n<ng-template #titleRef>\n    <ng-template\n        [ngTemplateOutlet]=\"_titleTemplate!.templateRef\"\n        [ngTemplateOutletContext]=\"{ $implicit: _dynamicPageService.collapsed() }\"\n    ></ng-template>\n</ng-template>\n<ng-template #defaultTitle>\n    {{ title }}\n</ng-template>\n", styles: [".fd-dynamic-page__breadcrumb-wrapper{width:100%;max-width:60%}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: DynamicPageService }, { type: i0.ChangeDetectorRef }], propDecorators: { title: [{
                type: Input
            }], titleWrap: [{
                type: Input
            }], subtitle: [{
                type: Input
            }], subtitleWrap: [{
                type: Input
            }], _subtitleTemplate: [{
                type: ContentChild,
                args: [DynamicPageHeaderSubtitleDirective]
            }], _titleTemplate: [{
                type: ContentChild,
                args: [DynamicPageHeaderTitleDirective]
            }], _dynamicPageBreadcrumbComponent: [{
                type: ContentChild,
                args: [FD_DYNAMIC_PAGE_BREADCRUMB_COMPONENT]
            }], _breadcrumbComponent: [{
                type: ContentChild,
                args: [FD_BREADCRUMB_COMPONENT]
            }], _globalActions: [{
                type: ContentChild,
                args: [DynamicPageGlobalActionsComponent]
            }], _layoutActions: [{
                type: ContentChild,
                args: [DynamicPageLayoutActionsComponent]
            }], _contentToolbar: [{
                type: ContentChild,
                args: [DynamicPageTitleContentComponent]
            }] } });

/**
 * Default options for core dynamic-page
 * @deprecated use i18n coreDynamicPage key instead
 */
class DynamicPageConfig {
    constructor() {
        /**
         * aria label for expand/collapse button when the Dynamic Page is collapsed
         */
        this.expandLabel = 'Expand Header';
        /**
         * aria label for expand/collapse button when the Dynamic Page is expanded
         */
        this.collapseLabel = 'Collapse Header';
        /**
         * aria label for pin button when the Dynamic Page should be pinned
         */
        this.pinLabel = 'Pin Header';
        /**
         * aria label for pin button when the Panel should be unpinned
         */
        this.unpinLabel = 'Unpin Header';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageConfig, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageConfig }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageConfig, decorators: [{
            type: Injectable
        }] });

/**
 * Patch header i18n texts
 */
function patchHeaderI18nTexts(config) {
    const lang$ = inject(FD_LANGUAGE, { skipSelf: true });
    if (config) {
        return lang$.pipe(map((lang) => ({
            ...lang,
            coreDynamicPage: {
                ...config
            }
        })));
    }
    return lang$;
}

let dynamicPageSubHeaderId = 0;
class DynamicPageSubheaderComponent {
    /**
     * the initial state of the header. Set to true if header should be collapsed.
     */
    set collapsed(collapsed) {
        this._dynamicPageService.collapsed.set(collapsed);
        this._dynamicPageService.subheaderVisibilityChange.next();
    }
    get collapsed() {
        return this._dynamicPageService.collapsed();
    }
    /**
     * Aria Label for the toggle button
     * @hidden
     **/
    get _toggleButtonAriaLabel() {
        const expandLabel = this.expandLabel || this._defaultExpandLabel();
        const collapseLabel = this.collapseLabel || this._defaultCollapseLabel();
        return this._collapsed ? expandLabel : collapseLabel;
    }
    /**
     * Aria Label for the pin button
     * @hidden
     **/
    get _pinButtonAriaLabel() {
        const pinLabel = this.pinAriaLabel || this._defaultPinLabel();
        const unpinLabel = this.unpinAriaLabel || this._defaultUnpinLabel();
        return this._pinned ? unpinLabel : pinLabel;
    }
    /** @hidden */
    constructor(_dynamicPageService) {
        this._dynamicPageService = _dynamicPageService;
        /**
         * whether the header can be collapsed. True by default. If set to false, both pin/collapse buttons disappear
         * and the header stays visible
         */
        this.collapsible = true;
        /**
         * whether the header should be allowed to be pinned or unpinned. When set, the pin button shows up.
         * Pinning the header will make the header stay visible and the collapse button(if present) will disappear until unpinned.
         */
        this.pinnable = false;
        /**
         * id for header
         */
        this.id = `fd-dynamic-page-header-id-${dynamicPageSubHeaderId++}`;
        /**
         * aria label for header
         */
        this.headerAriaLabel = 'Collapsed Header';
        /** Collapse/Expand change event raised */
        this.collapsedChange = new EventEmitter();
        /**
         * id for collapsible header
         */
        this.collapsibleHeaderId = `${this.id}-collapsible`;
        /**
         * tracking if pin button is pinned
         */
        this._pinned = false;
        /**
         * @hidden
         * tracking expand/collapse button
         */
        this._collapsed = false;
        /** @hidden */
        this._resolveTranslationSignal = resolveTranslationSignalFn();
        /** @hidden */
        this._defaultExpandLabel = this._resolveTranslationSignal('coreDynamicPage.expandLabel');
        /** @hidden */
        this._defaultCollapseLabel = this._resolveTranslationSignal('coreDynamicPage.collapseLabel');
        /** @hidden */
        this._defaultPinLabel = this._resolveTranslationSignal('coreDynamicPage.pinLabel');
        /** @hidden */
        this._defaultUnpinLabel = this._resolveTranslationSignal('coreDynamicPage.unpinLabel');
    }
    /**
     * toggles the state of the header and
     * handles expanded/collapsed event
     */
    toggleCollapse() {
        this._pinned = false;
        this.collapsed = !this.collapsed;
        this.collapsedChange.emit(this._collapsed);
    }
    /**
     * @hidden
     * click action on pin button
     */
    togglePinned() {
        this._pinned = !this._pinned;
        this._dynamicPageService.pinned.set(this._pinned);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageSubheaderComponent, deps: [{ token: DynamicPageService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: DynamicPageSubheaderComponent, isStandalone: true, selector: "fd-dynamic-page-subheader", inputs: { collapsible: "collapsible", pinnable: "pinnable", collapsed: "collapsed", expandLabel: "expandLabel", collapseLabel: "collapseLabel", id: "id", headerAriaLabel: "headerAriaLabel", pinAriaLabel: "pinAriaLabel", unpinAriaLabel: "unpinAriaLabel" }, outputs: { collapsedChange: "collapsedChange" }, host: { properties: { "attr.id": "this.id" } }, providers: [
            {
                provide: FD_LANGUAGE,
                useFactory: patchHeaderI18nTexts,
                deps: [[new Optional(), DynamicPageConfig]]
            }
        ], viewQueries: [{ propertyName: "pinCollapseContainer", first: true, predicate: ["pincollapseContainer"], descendants: true }], ngImport: i0, template: "<div class=\"fd-dynamic-page__collapsible-header-container\">\n    <section\n        role=\"region\"\n        class=\"fd-dynamic-page__collapsible-header\"\n        [attr.aria-label]=\"headerAriaLabel\"\n        [attr.aria-hidden]=\"_dynamicPageService.collapsed()\"\n        [attr.id]=\"collapsibleHeaderId\"\n        #headerContent\n    >\n        <ng-content></ng-content>\n    </section>\n    @if (collapsible) {\n        <div class=\"fd-dynamic-page__collapsible-header-visibility-container\" #pincollapseContainer>\n            <div class=\"fd-dynamic-page__collapsible-header-visibility-container--left-gradient\"></div>\n            <div role=\"toolbar\" class=\"fd-dynamic-page__collapsible-header-visibility-container--button-group\">\n                <button\n                    fd-button\n                    class=\"fd-dynamic-page__collapse-button\"\n                    aria-haspopup=\"true\"\n                    [ariaLabel]=\"_toggleButtonAriaLabel\"\n                    [attr.title]=\"_toggleButtonAriaLabel\"\n                    [attr.aria-expanded]=\"!_dynamicPageService.collapsed()\"\n                    [attr.aria-controls]=\"id\"\n                    (click)=\"toggleCollapse()\"\n                >\n                    <fd-icon [glyph]=\"_dynamicPageService.collapsed() ? 'slim-arrow-down' : 'slim-arrow-up'\"></fd-icon>\n                </button>\n                @if (pinnable && !_dynamicPageService.collapsed()) {\n                    <button\n                        fd-button\n                        class=\"fd-dynamic-page__pin-button\"\n                        [ariaLabel]=\"_pinButtonAriaLabel\"\n                        [attr.title]=\"_pinButtonAriaLabel\"\n                        [toggled]=\"_pinned\"\n                        (click)=\"togglePinned()\"\n                    >\n                        <fd-icon glyph=\"pushpin-off\"></fd-icon>\n                    </button>\n                }\n            </div>\n            <div class=\"fd-dynamic-page__collapsible-header-visibility-container--right-gradient\"></div>\n        </div>\n    }\n</div>\n", dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageSubheaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-dynamic-page-subheader', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, imports: [ButtonComponent, IconComponent], providers: [
                        {
                            provide: FD_LANGUAGE,
                            useFactory: patchHeaderI18nTexts,
                            deps: [[new Optional(), DynamicPageConfig]]
                        }
                    ], template: "<div class=\"fd-dynamic-page__collapsible-header-container\">\n    <section\n        role=\"region\"\n        class=\"fd-dynamic-page__collapsible-header\"\n        [attr.aria-label]=\"headerAriaLabel\"\n        [attr.aria-hidden]=\"_dynamicPageService.collapsed()\"\n        [attr.id]=\"collapsibleHeaderId\"\n        #headerContent\n    >\n        <ng-content></ng-content>\n    </section>\n    @if (collapsible) {\n        <div class=\"fd-dynamic-page__collapsible-header-visibility-container\" #pincollapseContainer>\n            <div class=\"fd-dynamic-page__collapsible-header-visibility-container--left-gradient\"></div>\n            <div role=\"toolbar\" class=\"fd-dynamic-page__collapsible-header-visibility-container--button-group\">\n                <button\n                    fd-button\n                    class=\"fd-dynamic-page__collapse-button\"\n                    aria-haspopup=\"true\"\n                    [ariaLabel]=\"_toggleButtonAriaLabel\"\n                    [attr.title]=\"_toggleButtonAriaLabel\"\n                    [attr.aria-expanded]=\"!_dynamicPageService.collapsed()\"\n                    [attr.aria-controls]=\"id\"\n                    (click)=\"toggleCollapse()\"\n                >\n                    <fd-icon [glyph]=\"_dynamicPageService.collapsed() ? 'slim-arrow-down' : 'slim-arrow-up'\"></fd-icon>\n                </button>\n                @if (pinnable && !_dynamicPageService.collapsed()) {\n                    <button\n                        fd-button\n                        class=\"fd-dynamic-page__pin-button\"\n                        [ariaLabel]=\"_pinButtonAriaLabel\"\n                        [attr.title]=\"_pinButtonAriaLabel\"\n                        [toggled]=\"_pinned\"\n                        (click)=\"togglePinned()\"\n                    >\n                        <fd-icon glyph=\"pushpin-off\"></fd-icon>\n                    </button>\n                }\n            </div>\n            <div class=\"fd-dynamic-page__collapsible-header-visibility-container--right-gradient\"></div>\n        </div>\n    }\n</div>\n" }]
        }], ctorParameters: () => [{ type: DynamicPageService }], propDecorators: { collapsible: [{
                type: Input
            }], pinnable: [{
                type: Input
            }], collapsed: [{
                type: Input
            }], expandLabel: [{
                type: Input
            }], collapseLabel: [{
                type: Input
            }], id: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.id']
            }], headerAriaLabel: [{
                type: Input
            }], pinAriaLabel: [{
                type: Input
            }], unpinAriaLabel: [{
                type: Input
            }], collapsedChange: [{
                type: Output
            }], pinCollapseContainer: [{
                type: ViewChild,
                args: ['pincollapseContainer']
            }] } });

class DynamicPageWrapperDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageWrapperDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: DynamicPageWrapperDirective, isStandalone: true, selector: "[fdDynamicPageWrapper], [fd-dynamic-page-wrapper]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageWrapperDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdDynamicPageWrapper], [fd-dynamic-page-wrapper]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }] });

const FD_DYNAMIC_PAGE = new InjectionToken('FD_DYNAMIC_PAGE');

class DynamicPageComponent {
    /**
     * sets size which in turn adds corresponding padding for the size type.
     * size can be `small`, `medium`, `large`, or `extra-large`.
     */
    set size(size) {
        this._size = size;
        this._propagateSizeToChildren();
    }
    get size() {
        return this._size;
    }
    /** @hidden */
    constructor(_cd, _elementRef, _renderer, _dynamicPageService, _columnLayout, _dynamicPageWrapper) {
        this._cd = _cd;
        this._elementRef = _elementRef;
        this._renderer = _renderer;
        this._dynamicPageService = _dynamicPageService;
        this._columnLayout = _columnLayout;
        this._dynamicPageWrapper = _dynamicPageWrapper;
        /** Whether DynamicPage should snap on scroll */
        this.disableSnapOnScroll = false;
        /**
         * aria roledescription for the page
         * default: "Dynamic Page"
         *
         */
        this.ariaRoledescription = 'Dynamic Page';
        /**
         * sets background for content to `list`, `transparent`, or `solid` background color.
         * Default is `solid`.
         */
        this.background = 'solid';
        /** Whether DynamicPage should have responsive sides spacing changing with Page window width.
         * max-width: 599px                         - small
         * min-width: 600px and max-width: 1023px   - medium
         * min-width: 1024px and max-width: 1439px  - large
         * min-width: 1440px                        - extra large
         */
        this.autoResponsive = true;
        /** Offset in PX
         * Should be added, when there is something else at the bottom and dynamic page is not expanded to bottom's corners
         */
        this.offset = 0;
        /**
         * Whether dynamic page should be expanded in whole page.
         */
        this.expandContent = true;
        /**
         * Whether dynamic page has position relative.
         * This is needed in cases where Dynamic Page is used in Flexible Column Layout and has a floating footer
         */
        this.positionRelative = false;
        /** Whether the dynamic page is collapsed */
        this.collapsed = computed(() => this._dynamicPageService.collapsed());
        /** @hidden */
        this._size = 'extra-large';
        /** @hidden */
        this._headerCollapsible = true;
        /** @hidden */
        this._isExpanded = computed(() => !this._dynamicPageService.collapsed());
        /** @hidden */
        this._headerButton = viewChild('headerButton');
        /** @hidden **/
        this._destroyRef = inject(DestroyRef);
    }
    /** @hidden */
    ngAfterViewInit() {
        this._sizeChangeHandle();
        this._removeShadowWhenTabComponent();
        this._listenOnResize();
        this._listenOnCollapse();
        this._propagatePropertiesToChildren();
        this._setContentFooterSpacer();
        if (!this.disableSnapOnScroll && this._pageSubheaderComponent?.collapsible) {
            this._addScrollListeners();
        }
        if (this._columnLayout && this.autoResponsive) {
            this._listenToLayoutChange();
        }
        setTimeout(() => this._setContainerPositions());
        this._cd.detectChanges();
    }
    /** toggle the visibility of the header on click of title area. */
    toggleCollapse() {
        if (this._headerCollapsible) {
            this._dynamicPageService.toggleCollapsed();
            this._headerButton()?.nativeElement.focus();
        }
    }
    /**
     * Triggers recheck for spacing and sizing of elements inside DynamicPage.
     */
    refreshSize() {
        this._setContainerPositions();
        this._sizeChangeHandle();
    }
    /** @hidden */
    _getScrollElement() {
        return this._tabComponent?.scrollableElement?.nativeElement || this._scrollbar?.elementRef.nativeElement;
    }
    /** Set the positions of the tabs and content with respect to the window */
    _setContainerPositions() {
        this._setDynamicPageHeight();
    }
    /** @hidden */
    _propagatePropertiesToChildren() {
        this._headerCollapsible = this._pageSubheaderComponent?.collapsible;
        this._propagateSizeToChildren();
    }
    /** @hidden
     * Functionality handling column layout changes,
     * - recalculate height of content element
     * - recheck size depending on width of DynamicPage
     */
    _listenToLayoutChange() {
        this._columnLayout.layoutChange.pipe(debounceTime(50), takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this.refreshSize();
            this._sizeChangeHandle();
        });
    }
    /** @hidden */
    _propagateSizeToChildren() {
        if (this._headerComponent) {
            this._headerComponent.size = this.size;
        }
        this._setContainerPositions();
    }
    /** @hidden */
    _listenOnCollapse() {
        this._dynamicPageService.subheaderVisibilityChange
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe(() => this._setContainerPositions());
    }
    /** @hidden */
    _getCalculatedFullHeight(element) {
        if (!element) {
            return null;
        }
        const distanceFromTop = element.getBoundingClientRect().top;
        return 'calc(100vh - ' + (distanceFromTop + this.offset) + 'px)';
    }
    /** @hidden */
    _sizeChangeHandle() {
        if (!this._elementRef || !this.autoResponsive) {
            return;
        }
        const dynamicPageWidth = this._elementRef.nativeElement.getBoundingClientRect().width;
        this._dynamicPageService.pixelsSizeChanged.set(dynamicPageWidth);
        const size = dynamicPageWidthToSize(dynamicPageWidth);
        if (size !== this.size) {
            this.size = size;
            this._cd.detectChanges();
        }
    }
    /** @hidden */
    _addScrollListeners() {
        const element = this._getScrollElement();
        if (element) {
            fromEvent(element, 'scroll')
                .pipe(debounceTime(10), takeUntilDestroyed(this._destroyRef))
                .subscribe(() => {
                const collapse = !this._dynamicPageService.pinned() &&
                    (element.scrollTop > 0 || element.scrollHeight <= element.clientHeight);
                this._dynamicPageService.collapsed.set(collapse);
            });
        }
    }
    /** @hidden Listen for window resize and adjust tab and content positions accordingly */
    _listenOnResize() {
        const listener = this._dynamicPageWrapper ? this._listenToWrapperResize() : this._listenToWindowResize();
        listener.pipe(debounceTime(100), takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._setContainerPositions();
            this._sizeChangeHandle();
        });
    }
    /** @hidden */
    _listenToWrapperResize() {
        return resizeObservable(this._dynamicPageWrapper.elementRef.nativeElement);
    }
    /** @hidden */
    _listenToWindowResize() {
        return fromEvent(window, 'resize').pipe(map(() => []));
    }
    /** @hidden
     * set top position of DynamicPage on scrolling
     */
    _setDynamicPageHeight() {
        if (!this._dynamicPageElement || !this.expandContent) {
            return;
        }
        const element = this._dynamicPageElement.nativeElement;
        this._renderer.setStyle(element, 'height', this._getCalculatedFullHeight(element));
    }
    /** @hidden */
    _removeShadowWhenTabComponent() {
        if (!this._pageSubheaderComponent?.collapsible || !this._tabComponent) {
            return;
        }
        const pinCollapseShadowElement = this._pageSubheaderComponent?.pinCollapseContainer;
        if (pinCollapseShadowElement) {
            addClassNameToElement(this._renderer, pinCollapseShadowElement.nativeElement, DYNAMIC_PAGE_CLASS_NAME.dynamicPageCollapsibleHeaderPinCollapseNoShadow);
        }
    }
    /** @hidden */
    _setContentFooterSpacer() {
        this._contentComponent.changes
            .pipe(startWith(this._contentComponent.toArray()), observeOn(asyncScheduler), takeUntilDestroyed(this._destroyRef))
            .subscribe((components) => {
            components.forEach((content, index) => {
                /** show spacer when:
                 * a) footer + no tabs = only last
                 * b) footer + tabs, not stacked = all
                 * c) footer + tabs, stacked = only last
                 */
                content._toggleSpacer(this._footerComponent && (!this._tabComponent?.stackContent || index === components.length - 1));
            });
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.ElementRef }, { token: i0.Renderer2 }, { token: DynamicPageService }, { token: FD_FLEXIBLE_COLUMN_LAYOUT_COMPONENT, optional: true }, { token: DynamicPageWrapperDirective, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: DynamicPageComponent, isStandalone: true, selector: "fd-dynamic-page", inputs: { disableSnapOnScroll: "disableSnapOnScroll", ariaLabel: "ariaLabel", ariaRoledescription: "ariaRoledescription", background: "background", autoResponsive: "autoResponsive", size: "size", offset: "offset", expandContent: "expandContent", positionRelative: "positionRelative" }, providers: [
            DynamicPageService,
            {
                provide: FD_DYNAMIC_PAGE,
                useExisting: DynamicPageComponent
            }
        ], queries: [{ propertyName: "_pageSubheaderComponent", first: true, predicate: DynamicPageSubheaderComponent, descendants: true }, { propertyName: "_headerComponent", first: true, predicate: DynamicPageHeaderComponent, descendants: true }, { propertyName: "_footerComponent", first: true, predicate: DynamicPageFooterComponent, descendants: true }, { propertyName: "_tabComponent", first: true, predicate: FD_TABLIST, descendants: true }, { propertyName: "_contentComponent", predicate: DynamicPageContentComponent, descendants: true }], viewQueries: [{ propertyName: "_headerButton", first: true, predicate: ["headerButton"], descendants: true, isSignal: true }, { propertyName: "_dynamicPageElement", first: true, predicate: ["dynamicPageElement"], descendants: true }, { propertyName: "_scrollbar", first: true, predicate: ScrollbarDirective, descendants: true }], ngImport: i0, template: "<article\n    #dynamicPageElement\n    class=\"fd-dynamic-page\"\n    [class.fd-dynamic-page--sm]=\"size === 'small'\"\n    [class.fd-dynamic-page--md]=\"size === 'medium'\"\n    [class.fd-dynamic-page--lg]=\"size === 'large'\"\n    [class.fd-dynamic-page--xl]=\"size === 'extra-large'\"\n    [class.fd-dynamic-page--transparent-bg]=\"background === 'transparent'\"\n    [class.fd-dynamic-page--list-bg]=\"background === 'list'\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-roledescription]=\"ariaRoledescription\"\n    [style.position]=\"positionRelative ? 'relative' : null\"\n>\n    <header class=\"fd-dynamic-page__header\" [class.fd-dynamic-page__header--not-collapsible]=\"!_headerCollapsible\">\n        <div (click)=\"toggleCollapse()\">\n            @if (_headerCollapsible) {\n                <span\n                    #headerButton\n                    role=\"button\"\n                    [attr.aria-expanded]=\"_isExpanded()\"\n                    [attr.aria-labelledby]=\"_headerComponent.titleId()\"\n                    aria-label=\"Toggle header\"\n                    tabindex=\"0\"\n                    (keydown.enter)=\"toggleCollapse()\"\n                    class=\"fd-dynamic-page__header-button\"\n                >\n                </span>\n            }\n            <ng-content select=\"fd-dynamic-page-header\"></ng-content>\n        </div>\n        <ng-content select=\"fd-dynamic-page-subheader\"></ng-content>\n    </header>\n    <ng-content select=\"fd-tab-list\"></ng-content>\n    <ng-content select=\"fd-wizard\"></ng-content>\n    <ng-content select=\"fdp-icon-tab-bar\"></ng-content>\n    @if (!_tabComponent) {\n        <div fd-scrollbar>\n            <ng-content select=\"fd-dynamic-page-content\"></ng-content>\n        </div>\n    } @else {\n        <div>\n            <ng-content select=\"fd-dynamic-page-content\"></ng-content>\n        </div>\n    }\n    <footer>\n        <ng-content select=\"fd-dynamic-page-footer\"></ng-content>\n    </footer>\n</article>\n", styles: [".fd-dynamic-page{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.fd-dynamic-page:after,.fd-dynamic-page:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__header-button,.fd-dynamic-page__sr-only{position:absolute;clip:rect(0 0 0 0);border:0;height:1px;margin-block:-1px;margin-inline:-1px;overflow:hidden;padding-block:0;padding-inline:0;white-space:nowrap;width:1px}.fd-dynamic-page__header-button.is-focus,.fd-dynamic-page__header-button:focus{z-index:5}.fd-dynamic-page__header-button.is-focus+.fd-dynamic-page__title-area,.fd-dynamic-page__header-button:focus+.fd-dynamic-page__title-area{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.25rem}.fd-dynamic-page__header-fixed{left:0;position:fixed;right:0;top:0;z-index:3}.fd-dynamic-page__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__header:after,.fd-dynamic-page__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;min-height:3rem;word-wrap:break-word;background-color:var(--sapObjectHeader_Background);z-index:1}.fd-dynamic-page__title-area:after,.fd-dynamic-page__title-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-area.is-hover,.fd-dynamic-page__title-area:hover{background:var(--sapObjectHeader_Hover_Background);border-bottom:var(--fdDynamicPage_Hover_Border_Bottom);cursor:pointer}.fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page__title-area--collapsed .fd-dynamic-page__title{font-size:var(--fdDynamicPage_Title_Collapsed_Font_Size)}.fd-dynamic-page__title-area[aria-hidden=true]{display:none}.fd-dynamic-page__main-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__main-container:after,.fd-dynamic-page__main-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-dynamic-page__title-container:after,.fd-dynamic-page__title-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:.5rem .25rem;padding-inline:0}.fd-dynamic-page__breadcrumb:after,.fd-dynamic-page__breadcrumb:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb-title-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-flex:1;-ms-flex:1;flex:1;min-width:0}.fd-dynamic-page__breadcrumb-title-container:after,.fd-dynamic-page__breadcrumb-title-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__breadcrumb-container:after,.fd-dynamic-page__breadcrumb-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdDynamicPage_Title_Color);font-family:var(--sapFontFamily);font-family:var(--fdDynamicPage_Title_Font_Family);font-size:var(--sapFontSize);font-size:var(--fdDynamicPage_Title_Font_Size);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__title:after,.fd-dynamic-page__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title .fd-link{color:var(--sapGroup_TitleTextColor);font-size:var(--sapFontHeader3Size);max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;vertical-align:bottom;white-space:nowrap}.fd-dynamic-page__title--wrap{white-space:normal}.fd-dynamic-page__subtitle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdDynamicPage_Subtitle_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:.25rem;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__subtitle:after,.fd-dynamic-page__subtitle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__subtitle--wrap{white-space:normal}.fd-dynamic-page__title-content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;padding-inline:1rem 0;text-overflow:ellipsis;vertical-align:baseline;white-space:nowrap}.fd-dynamic-page__title-content:after,.fd-dynamic-page__title-content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-subtitle-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__title-subtitle-container:after,.fd-dynamic-page__title-subtitle-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__toolbar-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-margin-start:auto;margin-inline-start:auto}.fd-dynamic-page__toolbar-container:after,.fd-dynamic-page__toolbar-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page .fd-dynamic-page__toolbar{margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-start:1rem;background:transparent;padding-inline-start:1rem}.fd-dynamic-page .fd-dynamic-page__toolbar--actions,.fd-dynamic-page .fd-dynamic-page__toolbar--content{padding-block:0;padding-inline:0}.fd-dynamic-page__summarized-title-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;word-wrap:break-word;background:var(--sapObjectHeader_Background);-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow);height:2rem;z-index:1}.fd-dynamic-page__summarized-title-area:after,.fd-dynamic-page__summarized-title-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__summarized-title-area.is-focus,.fd-dynamic-page__summarized-title-area:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.25rem}.fd-dynamic-page__summarized-title-area--no-shadow{-webkit-box-shadow:none;box-shadow:none}.fd-dynamic-page__summarized-title-area[aria-hidden=true]{display:none}.fd-dynamic-page__summarized-title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontHeader5Size);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__summarized-title:after,.fd-dynamic-page__summarized-title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dynamic-page__collapsible-header-container:after,.fd-dynamic-page__collapsible-header-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header{background-color:var(--sapObjectHeader_Background);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:1rem;padding-inline:0}.fd-dynamic-page__collapsible-header:after,.fd-dynamic-page__collapsible-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header[aria-hidden=true]{display:none}.fd-dynamic-page .fd-dynamic-page__tabs{margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dynamic-page .fd-dynamic-page__tabs--overflow{overflow:hidden}.fd-dynamic-page .fd-dynamic-page__tabs--add-shadow,.fd-dynamic-page__collapsible-header-visibility-container{-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow)}.fd-dynamic-page__collapsible-header-visibility-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:var(--sapObjectHeader_Background);min-height:.0625rem;z-index:2}.fd-dynamic-page__collapsible-header-visibility-container:after,.fd-dynamic-page__collapsible-header-visibility-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-visibility-container--left-gradient{background-image:var(--fdDynamicPage_Button_Left_Gradient);height:.0625rem;width:4rem}.fd-dynamic-page__collapsible-header-visibility-container--left-gradient[dir=rtl],[dir=rtl] .fd-dynamic-page__collapsible-header-visibility-container--left-gradient{background-image:var(--fdDynamicPage_Button_Right_Gradient)}.fd-dynamic-page__collapsible-header-visibility-container--right-gradient{background-image:var(--fdDynamicPage_Button_Right_Gradient);height:.0625rem;width:4rem}.fd-dynamic-page__collapsible-header-visibility-container--right-gradient[dir=rtl],[dir=rtl] .fd-dynamic-page__collapsible-header-visibility-container--right-gradient{background-image:var(--fdDynamicPage_Button_Left_Gradient)}.fd-dynamic-page__collapsible-header-visibility-container--button-group{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdDynamicPage_Button_Group_Background);height:.0625rem;width:4.25rem;z-index:1}.fd-dynamic-page__collapsible-header-visibility-container--button-group:after,.fd-dynamic-page__collapsible-header-visibility-container--button-group:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-visibility-container[aria-hidden=true]{display:none}.fd-dynamic-page__collapsible-header-visibility-container--no-shadow{-webkit-box-shadow:none;box-shadow:none}.fd-dynamic-page__collapse-button,.fd-dynamic-page__expand-button,.fd-dynamic-page__pin-button{--fdButtonBackgroundColor:var(--fdDynamicPage_Button_Pin_Background);height:1.5rem;margin-block:0;margin-inline:.25rem;min-width:1.5rem;padding-block:0;padding-inline:0;width:1.5rem}.fd-dynamic-page__collapse-button:before,.fd-dynamic-page__expand-button:before,.fd-dynamic-page__pin-button:before{bottom:-.25rem;height:2rem;top:-.25rem;width:100%}.fd-dynamic-page__collapse-button[aria-hidden=true],.fd-dynamic-page__expand-button[aria-hidden=true],.fd-dynamic-page__pin-button[aria-hidden=true]{display:none}.fd-dynamic-page__content{background-color:var(--sapBackgroundColor);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow-y:auto;padding-block:0;padding-inline:0}.fd-dynamic-page__content:after,.fd-dynamic-page__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__footer{bottom:0;left:0;margin-block:0 .5rem;margin-inline:.5rem;position:fixed;right:0}.fd-dynamic-page--sm .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--sm .fd-dynamic-page__collapsible-header,.fd-dynamic-page--sm .fd-dynamic-page__content{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__tabs{padding-block:0;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__breadcrumb{padding-block:0;padding-inline:0}.fd-dynamic-page--sm .fd-dynamic-page__title-container{-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-dynamic-page--sm .fd-dynamic-page__toolbar{-webkit-padding-start:1rem;padding-inline-start:1rem;-webkit-margin-start:auto;margin-inline-start:auto}.fd-dynamic-page--sm .fd-dynamic-page__toolbar--content{-webkit-margin-start:0;margin-inline-start:0}.fd-dynamic-page--lg .fd-dynamic-page__title-area,.fd-dynamic-page--md .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__title-area--collapsed,.fd-dynamic-page--md .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--lg .fd-dynamic-page__collapsible-header,.fd-dynamic-page--lg .fd-dynamic-page__content,.fd-dynamic-page--md .fd-dynamic-page__collapsible-header,.fd-dynamic-page--md .fd-dynamic-page__content{padding-block:1rem;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__tabs,.fd-dynamic-page--md .fd-dynamic-page__tabs{padding-block:0;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__summarized-title-area,.fd-dynamic-page--md .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--xl .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--xl .fd-dynamic-page__collapsible-header,.fd-dynamic-page--xl .fd-dynamic-page__content{padding-block:1rem;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__tabs{padding-block:0;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--md .fd-dynamic-page__toolbar{padding-block:0;padding-inline:0}.fd-dynamic-page--list-bg .fd-dynamic-page__content{background-color:var(--fdDynamicPage_Content_List_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__content{background-color:var(--fdDynamicPage_Content_Transparent_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__title-area{background:var(--fdDynamicPage_Title_Header_Transparent_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__collapsible-header{background-color:var(--fdDynamicPage_Title_Header_Transparent_Background)}.footer-spacer{height:3rem}.content-sticker{position:static}.fd-dynamic-page__header--not-collapsible .fd-dynamic-page__title-area.is-hover,.fd-dynamic-page__header--not-collapsible .fd-dynamic-page__title-area:hover{background-color:var(--sapObjectHeader_Background, #fff);cursor:default}.fd-dynamic-page__collapsible-header-visibility-container--button-group{z-index:6}.fd-tabs .fd-dynamic-page__content{display:block;height:auto!important}.fd-dynamic-page{height:100%}.fd-dynamic-page .fd-bar--floating-footer{z-index:6}.fd-dynamic-page .fd-tabs-custom{overflow:auto;background-color:#f7f7f7;background-color:var(--sapBackgroundColor, #f7f7f7);flex:1}.fd-dynamic-page .fd-dynamic-page__content,.fd-dynamic-page .fd-dynamic-page__title-subtitle-container{flex:1}.fd-dynamic-page--transparent-bg .fd-tabs-custom{background-color:transparent;background-color:var(--fdDynamicPage_Content_Transparent_Background, transparent)}.fd-dynamic-page--list-bg .fd-tabs-custom{background-color:#fff;background-color:var(--fdDynamicPage_Content_List_Background, var(--sapGroup_ContentBackground, #fff))}.fd-dynamic-page--xl .fd-bar--floating-footer{margin:1rem 3rem}.fd-dynamic-page--lg .fd-bar--floating-footer,.fd-dynamic-page--md .fd-bar--floating-footer{margin:1rem 2rem}.fd-dynamic-page--sm .fd-bar--floating-footer{margin:1rem .5rem}.fd-dynamic-page--sm .fd-dynamic-page__title-container{align-items:center}.fd-dynamic-page--sm .fd-dynamic-page__title-container .fd-facet.fd-facet--image{margin-inline-end:1rem}.fd-dynamic-page__collapsible-header:empty{padding:0!important}.fd-dynamic-page__collapsible-header:has(.fd-has-display-none){padding-block:0;padding-inline:0}.fd-dynamic-page .fd-dynamic-page__title-container .fd-facet.fd-facet--image{margin-inline-end:1rem}.fd-dynamic-page__header.fd-dynamic-page__header--not-collapsible{position:relative;box-shadow:var(--sapContent_HeaderShadow)}.fd-dynamic-page__header{z-index:15}.fd-dynamic-page__header.fd-dynamic-page__header--not-collapsible:has(+fdp-icon-tab-bar){box-shadow:none}\n/*! Bundled license information:\n\nfundamental-styles/dist/dynamic-page.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "directive", type: ScrollbarDirective, selector: "[fdScrollbar], [fd-scrollbar]", inputs: ["noHorizontalScroll", "noVerticalScroll", "alwaysVisible"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-dynamic-page', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, providers: [
                        DynamicPageService,
                        {
                            provide: FD_DYNAMIC_PAGE,
                            useExisting: DynamicPageComponent
                        }
                    ], imports: [CdkScrollable, ScrollbarDirective], template: "<article\n    #dynamicPageElement\n    class=\"fd-dynamic-page\"\n    [class.fd-dynamic-page--sm]=\"size === 'small'\"\n    [class.fd-dynamic-page--md]=\"size === 'medium'\"\n    [class.fd-dynamic-page--lg]=\"size === 'large'\"\n    [class.fd-dynamic-page--xl]=\"size === 'extra-large'\"\n    [class.fd-dynamic-page--transparent-bg]=\"background === 'transparent'\"\n    [class.fd-dynamic-page--list-bg]=\"background === 'list'\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-roledescription]=\"ariaRoledescription\"\n    [style.position]=\"positionRelative ? 'relative' : null\"\n>\n    <header class=\"fd-dynamic-page__header\" [class.fd-dynamic-page__header--not-collapsible]=\"!_headerCollapsible\">\n        <div (click)=\"toggleCollapse()\">\n            @if (_headerCollapsible) {\n                <span\n                    #headerButton\n                    role=\"button\"\n                    [attr.aria-expanded]=\"_isExpanded()\"\n                    [attr.aria-labelledby]=\"_headerComponent.titleId()\"\n                    aria-label=\"Toggle header\"\n                    tabindex=\"0\"\n                    (keydown.enter)=\"toggleCollapse()\"\n                    class=\"fd-dynamic-page__header-button\"\n                >\n                </span>\n            }\n            <ng-content select=\"fd-dynamic-page-header\"></ng-content>\n        </div>\n        <ng-content select=\"fd-dynamic-page-subheader\"></ng-content>\n    </header>\n    <ng-content select=\"fd-tab-list\"></ng-content>\n    <ng-content select=\"fd-wizard\"></ng-content>\n    <ng-content select=\"fdp-icon-tab-bar\"></ng-content>\n    @if (!_tabComponent) {\n        <div fd-scrollbar>\n            <ng-content select=\"fd-dynamic-page-content\"></ng-content>\n        </div>\n    } @else {\n        <div>\n            <ng-content select=\"fd-dynamic-page-content\"></ng-content>\n        </div>\n    }\n    <footer>\n        <ng-content select=\"fd-dynamic-page-footer\"></ng-content>\n    </footer>\n</article>\n", styles: [".fd-dynamic-page{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.fd-dynamic-page:after,.fd-dynamic-page:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__header-button,.fd-dynamic-page__sr-only{position:absolute;clip:rect(0 0 0 0);border:0;height:1px;margin-block:-1px;margin-inline:-1px;overflow:hidden;padding-block:0;padding-inline:0;white-space:nowrap;width:1px}.fd-dynamic-page__header-button.is-focus,.fd-dynamic-page__header-button:focus{z-index:5}.fd-dynamic-page__header-button.is-focus+.fd-dynamic-page__title-area,.fd-dynamic-page__header-button:focus+.fd-dynamic-page__title-area{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.25rem}.fd-dynamic-page__header-fixed{left:0;position:fixed;right:0;top:0;z-index:3}.fd-dynamic-page__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__header:after,.fd-dynamic-page__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;min-height:3rem;word-wrap:break-word;background-color:var(--sapObjectHeader_Background);z-index:1}.fd-dynamic-page__title-area:after,.fd-dynamic-page__title-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-area.is-hover,.fd-dynamic-page__title-area:hover{background:var(--sapObjectHeader_Hover_Background);border-bottom:var(--fdDynamicPage_Hover_Border_Bottom);cursor:pointer}.fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page__title-area--collapsed .fd-dynamic-page__title{font-size:var(--fdDynamicPage_Title_Collapsed_Font_Size)}.fd-dynamic-page__title-area[aria-hidden=true]{display:none}.fd-dynamic-page__main-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__main-container:after,.fd-dynamic-page__main-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-dynamic-page__title-container:after,.fd-dynamic-page__title-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:.5rem .25rem;padding-inline:0}.fd-dynamic-page__breadcrumb:after,.fd-dynamic-page__breadcrumb:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb-title-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-flex:1;-ms-flex:1;flex:1;min-width:0}.fd-dynamic-page__breadcrumb-title-container:after,.fd-dynamic-page__breadcrumb-title-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__breadcrumb-container:after,.fd-dynamic-page__breadcrumb-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdDynamicPage_Title_Color);font-family:var(--sapFontFamily);font-family:var(--fdDynamicPage_Title_Font_Family);font-size:var(--sapFontSize);font-size:var(--fdDynamicPage_Title_Font_Size);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__title:after,.fd-dynamic-page__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title .fd-link{color:var(--sapGroup_TitleTextColor);font-size:var(--sapFontHeader3Size);max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;vertical-align:bottom;white-space:nowrap}.fd-dynamic-page__title--wrap{white-space:normal}.fd-dynamic-page__subtitle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdDynamicPage_Subtitle_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:.25rem;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__subtitle:after,.fd-dynamic-page__subtitle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__subtitle--wrap{white-space:normal}.fd-dynamic-page__title-content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;padding-inline:1rem 0;text-overflow:ellipsis;vertical-align:baseline;white-space:nowrap}.fd-dynamic-page__title-content:after,.fd-dynamic-page__title-content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-subtitle-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__title-subtitle-container:after,.fd-dynamic-page__title-subtitle-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__toolbar-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-margin-start:auto;margin-inline-start:auto}.fd-dynamic-page__toolbar-container:after,.fd-dynamic-page__toolbar-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page .fd-dynamic-page__toolbar{margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-start:1rem;background:transparent;padding-inline-start:1rem}.fd-dynamic-page .fd-dynamic-page__toolbar--actions,.fd-dynamic-page .fd-dynamic-page__toolbar--content{padding-block:0;padding-inline:0}.fd-dynamic-page__summarized-title-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;word-wrap:break-word;background:var(--sapObjectHeader_Background);-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow);height:2rem;z-index:1}.fd-dynamic-page__summarized-title-area:after,.fd-dynamic-page__summarized-title-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__summarized-title-area.is-focus,.fd-dynamic-page__summarized-title-area:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.25rem}.fd-dynamic-page__summarized-title-area--no-shadow{-webkit-box-shadow:none;box-shadow:none}.fd-dynamic-page__summarized-title-area[aria-hidden=true]{display:none}.fd-dynamic-page__summarized-title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontHeader5Size);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__summarized-title:after,.fd-dynamic-page__summarized-title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dynamic-page__collapsible-header-container:after,.fd-dynamic-page__collapsible-header-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header{background-color:var(--sapObjectHeader_Background);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:1rem;padding-inline:0}.fd-dynamic-page__collapsible-header:after,.fd-dynamic-page__collapsible-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header[aria-hidden=true]{display:none}.fd-dynamic-page .fd-dynamic-page__tabs{margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dynamic-page .fd-dynamic-page__tabs--overflow{overflow:hidden}.fd-dynamic-page .fd-dynamic-page__tabs--add-shadow,.fd-dynamic-page__collapsible-header-visibility-container{-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow)}.fd-dynamic-page__collapsible-header-visibility-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:var(--sapObjectHeader_Background);min-height:.0625rem;z-index:2}.fd-dynamic-page__collapsible-header-visibility-container:after,.fd-dynamic-page__collapsible-header-visibility-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-visibility-container--left-gradient{background-image:var(--fdDynamicPage_Button_Left_Gradient);height:.0625rem;width:4rem}.fd-dynamic-page__collapsible-header-visibility-container--left-gradient[dir=rtl],[dir=rtl] .fd-dynamic-page__collapsible-header-visibility-container--left-gradient{background-image:var(--fdDynamicPage_Button_Right_Gradient)}.fd-dynamic-page__collapsible-header-visibility-container--right-gradient{background-image:var(--fdDynamicPage_Button_Right_Gradient);height:.0625rem;width:4rem}.fd-dynamic-page__collapsible-header-visibility-container--right-gradient[dir=rtl],[dir=rtl] .fd-dynamic-page__collapsible-header-visibility-container--right-gradient{background-image:var(--fdDynamicPage_Button_Left_Gradient)}.fd-dynamic-page__collapsible-header-visibility-container--button-group{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdDynamicPage_Button_Group_Background);height:.0625rem;width:4.25rem;z-index:1}.fd-dynamic-page__collapsible-header-visibility-container--button-group:after,.fd-dynamic-page__collapsible-header-visibility-container--button-group:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-visibility-container[aria-hidden=true]{display:none}.fd-dynamic-page__collapsible-header-visibility-container--no-shadow{-webkit-box-shadow:none;box-shadow:none}.fd-dynamic-page__collapse-button,.fd-dynamic-page__expand-button,.fd-dynamic-page__pin-button{--fdButtonBackgroundColor:var(--fdDynamicPage_Button_Pin_Background);height:1.5rem;margin-block:0;margin-inline:.25rem;min-width:1.5rem;padding-block:0;padding-inline:0;width:1.5rem}.fd-dynamic-page__collapse-button:before,.fd-dynamic-page__expand-button:before,.fd-dynamic-page__pin-button:before{bottom:-.25rem;height:2rem;top:-.25rem;width:100%}.fd-dynamic-page__collapse-button[aria-hidden=true],.fd-dynamic-page__expand-button[aria-hidden=true],.fd-dynamic-page__pin-button[aria-hidden=true]{display:none}.fd-dynamic-page__content{background-color:var(--sapBackgroundColor);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow-y:auto;padding-block:0;padding-inline:0}.fd-dynamic-page__content:after,.fd-dynamic-page__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__footer{bottom:0;left:0;margin-block:0 .5rem;margin-inline:.5rem;position:fixed;right:0}.fd-dynamic-page--sm .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--sm .fd-dynamic-page__collapsible-header,.fd-dynamic-page--sm .fd-dynamic-page__content{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__tabs{padding-block:0;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__breadcrumb{padding-block:0;padding-inline:0}.fd-dynamic-page--sm .fd-dynamic-page__title-container{-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-dynamic-page--sm .fd-dynamic-page__toolbar{-webkit-padding-start:1rem;padding-inline-start:1rem;-webkit-margin-start:auto;margin-inline-start:auto}.fd-dynamic-page--sm .fd-dynamic-page__toolbar--content{-webkit-margin-start:0;margin-inline-start:0}.fd-dynamic-page--lg .fd-dynamic-page__title-area,.fd-dynamic-page--md .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__title-area--collapsed,.fd-dynamic-page--md .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--lg .fd-dynamic-page__collapsible-header,.fd-dynamic-page--lg .fd-dynamic-page__content,.fd-dynamic-page--md .fd-dynamic-page__collapsible-header,.fd-dynamic-page--md .fd-dynamic-page__content{padding-block:1rem;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__tabs,.fd-dynamic-page--md .fd-dynamic-page__tabs{padding-block:0;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__summarized-title-area,.fd-dynamic-page--md .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--xl .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--xl .fd-dynamic-page__collapsible-header,.fd-dynamic-page--xl .fd-dynamic-page__content{padding-block:1rem;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__tabs{padding-block:0;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--md .fd-dynamic-page__toolbar{padding-block:0;padding-inline:0}.fd-dynamic-page--list-bg .fd-dynamic-page__content{background-color:var(--fdDynamicPage_Content_List_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__content{background-color:var(--fdDynamicPage_Content_Transparent_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__title-area{background:var(--fdDynamicPage_Title_Header_Transparent_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__collapsible-header{background-color:var(--fdDynamicPage_Title_Header_Transparent_Background)}.footer-spacer{height:3rem}.content-sticker{position:static}.fd-dynamic-page__header--not-collapsible .fd-dynamic-page__title-area.is-hover,.fd-dynamic-page__header--not-collapsible .fd-dynamic-page__title-area:hover{background-color:var(--sapObjectHeader_Background, #fff);cursor:default}.fd-dynamic-page__collapsible-header-visibility-container--button-group{z-index:6}.fd-tabs .fd-dynamic-page__content{display:block;height:auto!important}.fd-dynamic-page{height:100%}.fd-dynamic-page .fd-bar--floating-footer{z-index:6}.fd-dynamic-page .fd-tabs-custom{overflow:auto;background-color:#f7f7f7;background-color:var(--sapBackgroundColor, #f7f7f7);flex:1}.fd-dynamic-page .fd-dynamic-page__content,.fd-dynamic-page .fd-dynamic-page__title-subtitle-container{flex:1}.fd-dynamic-page--transparent-bg .fd-tabs-custom{background-color:transparent;background-color:var(--fdDynamicPage_Content_Transparent_Background, transparent)}.fd-dynamic-page--list-bg .fd-tabs-custom{background-color:#fff;background-color:var(--fdDynamicPage_Content_List_Background, var(--sapGroup_ContentBackground, #fff))}.fd-dynamic-page--xl .fd-bar--floating-footer{margin:1rem 3rem}.fd-dynamic-page--lg .fd-bar--floating-footer,.fd-dynamic-page--md .fd-bar--floating-footer{margin:1rem 2rem}.fd-dynamic-page--sm .fd-bar--floating-footer{margin:1rem .5rem}.fd-dynamic-page--sm .fd-dynamic-page__title-container{align-items:center}.fd-dynamic-page--sm .fd-dynamic-page__title-container .fd-facet.fd-facet--image{margin-inline-end:1rem}.fd-dynamic-page__collapsible-header:empty{padding:0!important}.fd-dynamic-page__collapsible-header:has(.fd-has-display-none){padding-block:0;padding-inline:0}.fd-dynamic-page .fd-dynamic-page__title-container .fd-facet.fd-facet--image{margin-inline-end:1rem}.fd-dynamic-page__header.fd-dynamic-page__header--not-collapsible{position:relative;box-shadow:var(--sapContent_HeaderShadow)}.fd-dynamic-page__header{z-index:15}.fd-dynamic-page__header.fd-dynamic-page__header--not-collapsible:has(+fdp-icon-tab-bar){box-shadow:none}\n/*! Bundled license information:\n\nfundamental-styles/dist/dynamic-page.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i0.ElementRef }, { type: i0.Renderer2 }, { type: DynamicPageService }, { type: i3.FlexibleColumnLayoutComponent, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [FD_FLEXIBLE_COLUMN_LAYOUT_COMPONENT]
                }] }, { type: DynamicPageWrapperDirective, decorators: [{
                    type: Optional
                }] }], propDecorators: { disableSnapOnScroll: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], ariaRoledescription: [{
                type: Input
            }], background: [{
                type: Input
            }], autoResponsive: [{
                type: Input
            }], size: [{
                type: Input
            }], offset: [{
                type: Input
            }], expandContent: [{
                type: Input
            }], positionRelative: [{
                type: Input
            }], _pageSubheaderComponent: [{
                type: ContentChild,
                args: [DynamicPageSubheaderComponent]
            }], _headerComponent: [{
                type: ContentChild,
                args: [DynamicPageHeaderComponent]
            }], _contentComponent: [{
                type: ContentChildren,
                args: [DynamicPageContentComponent, { descendants: true }]
            }], _footerComponent: [{
                type: ContentChild,
                args: [DynamicPageFooterComponent]
            }], _tabComponent: [{
                type: ContentChild,
                args: [FD_TABLIST]
            }], _dynamicPageElement: [{
                type: ViewChild,
                args: ['dynamicPageElement']
            }], _scrollbar: [{
                type: ViewChild,
                args: [ScrollbarDirective]
            }] } });

const components = [
    DynamicPageComponent,
    DynamicPageHeaderComponent,
    DynamicPageGlobalActionsComponent,
    DynamicPageLayoutActionsComponent,
    DynamicPageSubheaderComponent,
    DynamicPageContentComponent,
    DynamicPageFooterComponent,
    DynamicPageTitleContentComponent,
    DynamicPageWrapperDirective,
    DynamicPageHeaderSubtitleDirective,
    DynamicPageHeaderTitleDirective,
    DynamicPageBreadcrumbComponent
];
class DynamicPageModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageModule, imports: [DynamicPageComponent,
            DynamicPageHeaderComponent,
            DynamicPageGlobalActionsComponent,
            DynamicPageLayoutActionsComponent,
            DynamicPageSubheaderComponent,
            DynamicPageContentComponent,
            DynamicPageFooterComponent,
            DynamicPageTitleContentComponent,
            DynamicPageWrapperDirective,
            DynamicPageHeaderSubtitleDirective,
            DynamicPageHeaderTitleDirective,
            DynamicPageBreadcrumbComponent], exports: [DynamicPageComponent,
            DynamicPageHeaderComponent,
            DynamicPageGlobalActionsComponent,
            DynamicPageLayoutActionsComponent,
            DynamicPageSubheaderComponent,
            DynamicPageContentComponent,
            DynamicPageFooterComponent,
            DynamicPageTitleContentComponent,
            DynamicPageWrapperDirective,
            DynamicPageHeaderSubtitleDirective,
            DynamicPageHeaderTitleDirective,
            DynamicPageBreadcrumbComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageModule, imports: [DynamicPageSubheaderComponent,
            DynamicPageTitleContentComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: DynamicPageModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...components],
                    exports: [...components]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ActionSquashBreakpointPx, DYNAMIC_PAGE_CLASS_NAME, DynamicPageBaseActions, DynamicPageBreadcrumbComponent, DynamicPageComponent, DynamicPageConfig, DynamicPageContentComponent, DynamicPageFooterComponent, DynamicPageGlobalActionsComponent, DynamicPageHeaderComponent, DynamicPageHeaderSubtitleDirective, DynamicPageHeaderTitleDirective, DynamicPageLayoutActionsComponent, DynamicPageModule, DynamicPageService, DynamicPageSubheaderComponent, DynamicPageTitleContentComponent, DynamicPageWrapperDirective, FD_DYNAMIC_PAGE, FD_DYNAMIC_PAGE_BREADCRUMB_COMPONENT, addClassNameToElement, dynamicPageWidthToSize, patchHeaderI18nTexts };
//# sourceMappingURL=fundamental-ngx-core-dynamic-page.mjs.map
