import { __decorate, __metadata } from 'tslib';
import * as i1 from '@angular/cdk/portal';
import { DomPortal, PortalModule } from '@angular/cdk/portal';
import * as i0 from '@angular/core';
import { InjectionToken, inject, DestroyRef, Optional, Self, Input, ViewChild, ContentChildren, Inject, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import * as i2 from '@angular/router';
import { RouterLink } from '@angular/router';
import { applyCssClass } from '@fundamental-ngx/cdk/utils';
import { FD_ICON_COMPONENT } from '@fundamental-ngx/core/icon';
import { startWith, map, tap } from 'rxjs';

const LINK_CLASS_NAME = {
    linkContent: 'fd-link__content'
};

const FD_LINK_COMPONENT = new InjectionToken('FdLinkComponent');

class LinkComponent {
    /** @hidden */
    constructor(elementRef, changeDetectorRef, routerLink) {
        this.elementRef = elementRef;
        this.changeDetectorRef = changeDetectorRef;
        this.routerLink = routerLink;
        /** @hidden */
        this._destroyed$ = inject(DestroyRef);
    }
    /**
     * @hidden
     * CssClassBuilder interface implementation
     * function is responsible for order which css classes are applied
     */
    buildComponentCssClass() {
        return [
            'fd-link',
            this.emphasized ? 'fd-link--emphasized' : '',
            this.disabled ? 'is-disabled' : '',
            this.inverted ? `fd-link--inverted` : '',
            this.subtle ? 'fd-link--subtle' : '',
            this.undecorated ? 'fd-link--undecorated' : '',
            this.class
        ];
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngAfterViewInit() {
        this.iconComponents.changes
            .pipe(startWith(this.iconComponents), map((c) => c.toArray()), map((icons) => 
        // We are only interested in the first descendant of the content element
        icons.filter((icon) => icon.elementRef.nativeElement.parentElement === this.contentSpan.nativeElement)), map((icons) => {
            if (icons.length === 0) {
                return {};
            }
            const prefix = icons[0].elementRef.nativeElement === this.contentSpan.nativeElement.childNodes[0]
                ? icons[0].elementRef.nativeElement
                : null;
            const postfix = icons[icons.length - 1].elementRef.nativeElement ===
                this.contentSpan.nativeElement.childNodes[this.contentSpan.nativeElement.childNodes.length - 1]
                ? icons[icons.length - 1].elementRef.nativeElement
                : null;
            if (prefix) {
                this._prefixIconName = this.iconComponents.first.glyph;
            }
            else {
                this._prefixIconName = '';
            }
            if (postfix) {
                this._postfixIconName = this.iconComponents.last.glyph;
            }
            else {
                this._postfixIconName = '';
            }
            return { prefix, postfix };
        }), tap(() => {
            if (this._prefixPortal?.isAttached) {
                this._prefixPortal.detach();
            }
            if (this._postfixPortal?.isAttached) {
                this._postfixPortal.detach();
            }
        }), tap(({ prefix, postfix }) => {
            this._prefixPortal = prefix ? new DomPortal(prefix) : null;
            this._postfixPortal = postfix ? new DomPortal(postfix) : null;
        }), tap(() => {
            this.changeDetectorRef.detectChanges();
        }), takeUntilDestroyed(this._destroyed$))
            .subscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: LinkComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: 'linkRouterTarget' }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: LinkComponent, isStandalone: true, selector: "[fdLink], [fd-link]", inputs: { class: "class", emphasized: "emphasized", disabled: "disabled", inverted: "inverted", subtle: "subtle", undecorated: "undecorated" }, providers: [
            {
                provide: FD_LINK_COMPONENT,
                useExisting: LinkComponent
            },
            {
                provide: 'linkRouterTarget',
                useFactory: (withHref, routerLink) => withHref || routerLink,
                deps: [
                    [new Optional(), new Self(), RouterLink],
                    [new Optional(), new Self(), RouterLink]
                ]
            }
        ], queries: [{ propertyName: "iconComponents", predicate: FD_ICON_COMPONENT }], viewQueries: [{ propertyName: "contentSpan", first: true, predicate: ["content"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "@if (_prefixPortal) {\n    <span class=\"fd-link__icon-container\">\n        <ng-container *cdkPortalOutlet=\"_prefixPortal\"></ng-container>\n    </span>\n}\n<span class=\"fd-link__content\" #content [class.fd-link__content--icon-line-height]=\"_postfixPortal || _prefixPortal\">\n    <ng-content></ng-content>\n</span>\n@if (_postfixPortal) {\n    <span class=\"fd-link__icon-container\">\n        <ng-container *cdkPortalOutlet=\"_postfixPortal\"></ng-container>\n    </span>\n}\n", styles: [".fd-link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapLinkColor);cursor:pointer;display:var(--fdLink_Display, inline-block);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-shadow:var(--sapContent_TextShadow);-webkit-box-align:center;-ms-flex-align:center;align-items:center;line-height:inherit;line-height:var(--fdLink_Line_Height, 1.125rem);-webkit-text-decoration:var(--fdLink_Text_Decoration, none);text-decoration:var(--fdLink_Text_Decoration, none);text-underline-offset:.125rem;-webkit-transition:all .125s ease-in;transition:all .125s ease-in}.fd-link:after,.fd-link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-link__content{-webkit-text-decoration:var(--fdLink_Text_Content_Decoration, none);text-decoration:var(--fdLink_Text_Content_Decoration, none)}.fd-link.is-hover,.fd-link:hover{--fdLink_Text_Decoration:var(--fdLink_Text_Decoration_Hover,none);--fdLink_Text_Content_Decoration:var(--fdLink_Text_Content_Decoration_Hover,none)}.fd-link.is-focus,.fd-link:focus{--fdLink_Text_Decoration:var(--fdLink_Text_Decoration_Focus,none);--fdLink_Text_Content_Decoration:var(--fdLink_Text_Content_Decoration_Focus,none)}.fd-link.is-active,.fd-link:active{--fdLink_Text_Decoration:var(--fdLink_Text_Decoration_Active,none);--fdLink_Text_Content_Decoration:var(--fdLink_Text_Content_Decoration_Active,none)}.fd-link.is-disabled,.fd-link:disabled,.fd-link[aria-disabled=true]{--fdLink_Text_Decoration:var(--fdLink_Text_Decoration_Disabled,none);--fdLink_Text_Content_Decoration:var(--fdLink_Text_Content_Decoration_Disabled,none)}.fd-link--subtle{--fdLink_Text_Content_Decoration:var(--fdLink_Text_Content_Decoration_Subtle,none);--fdLink_Text_Content_Decoration_Hover:var(--fdLink_Text_Content_Decoration_Subtle_Hover,none);--fdLink_Text_Content_Decoration_Active:var(--fdLink_Text_Content_Decoration_Subtle_Active,none);--fdLink_Text_Decoration:var(--fdLink_Text_Decoration_Subtle,none);--fdLink_Text_Decoration_Hover:var(--fdLink_Text_Decoration_Subtle_Hover,none);--fdLink_Text_Decoration_Active:var(--fdLink_Text_Decoration_Subtle_Active,none)}.fd-link--undecorated{--fdLink_Text_Decoration:none;--fdLink_Text_Decoration_Subtle:none;--fdLink_Text_Decoration_Subtle_Hover:none;--fdLink_Text_Decoration_Subtle_Active:none;--fdLink_Text_Decoration_Hover:none;--fdLink_Text_Decoration_Focus:none;--fdLink_Text_Decoration_Active:none;--fdLink_Text_Decoration_Visited:none;--fdLink_Text_Decoration_Disabled:none;--fdLink_Text_Content_Decoration:none;--fdLink_Text_Content_Decoration_Subtle:none;--fdLink_Text_Content_Decoration_Subtle_Hover:none;--fdLink_Text_Content_Decoration_Subtle_Active:none;--fdLink_Text_Content_Decoration_Hover:none;--fdLink_Text_Content_Decoration_Focus:none;--fdLink_Text_Content_Decoration_Active:none;--fdLink_Text_Content_Decoration_Visited:none;--fdLink_Text_Content_Decoration_Disabled:none}.fd-link--emphasized{font-family:var(--sapFontBoldFamily)}.fd-link:visited{color:var(--sapLink_Visited_Color)}.fd-link.is-hover,.fd-link:hover{color:var(--sapLink_Hover_Color)}.fd-link.is-focus,.fd-link:focus{background-color:var(--fdLink_Focus_Background);border-radius:var(--fdLink_Focus_Border_Radius);-webkit-box-shadow:none;box-shadow:none;color:var(--fdLink_Text_Focus_Color);outline:var(--fdLink_Hover_Outline_Color) var(--fdLink_Hover_Outline_Style) var(--fdLink_Hover_Outline_Width);outline-offset:var(--fdLink_Hover_Outline_Offset);text-shadow:var(--fdLink_Focus_Text_Shadow)}.fd-link.is-active,.fd-link:active{color:var(--sapLink_Active_Color)}.fd-link.is-active.is-focus,.fd-link.is-active:focus,.fd-link:active.is-focus,.fd-link:active:focus{background-color:transparent;z-index:5}.fd-link--inverted{text-shadow:none}.fd-link--inverted,.fd-link--inverted.is-hover,.fd-link--inverted:hover{color:var(--sapLink_InvertedColor)}.fd-link--inverted.is-focus,.fd-link--inverted:focus{outline-color:var(--sapContent_ContrastFocusColor);z-index:5}.fd-link--subtle{color:var(--sapLink_SubtleColor)}.fd-link.is-disabled,.fd-link:disabled,.fd-link[aria-disabled=true]{color:var(--sapLinkColor);opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-link>img{vertical-align:bottom}.fd-link [class*=sap-icon],.fd-link[class*=sap-icon]{color:var(--sapLinkColor);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-link [class*=sap-icon]:first-child,.fd-link[class*=sap-icon]:first-child{-webkit-margin-end:var(--fdLink_Icon_Spacing, 0);margin-inline-end:var(--fdLink_Icon_Spacing, 0)}.fd-link [class*=sap-icon]:last-child,.fd-link[class*=sap-icon]:last-child{-webkit-margin-start:var(--fdLink_Icon_Spacing, 0);margin-inline-start:var(--fdLink_Icon_Spacing, 0)}.fd-link.is-hover [class*=sap-icon],.fd-link.is-hover[class*=sap-icon],.fd-link:hover [class*=sap-icon],.fd-link:hover[class*=sap-icon]{color:var(--sapLink_Hover_Color);-webkit-text-decoration:var(--fdLink_Text_Decoration_Hover);text-decoration:var(--fdLink_Text_Decoration_Hover)}.fd-link.is-focus,.fd-link:focus{z-index:5}.fd-link.is-focus [class*=sap-icon],.fd-link.is-focus[class*=sap-icon],.fd-link:focus [class*=sap-icon],.fd-link:focus[class*=sap-icon]{color:var(--fdLink_Text_Focus_Color);-webkit-text-decoration:var(--fdLink_Text_Decoration_Focus);text-decoration:var(--fdLink_Text_Decoration_Focus)}.fd-link.is-active [class*=sap-icon],.fd-link.is-active[class*=sap-icon],.fd-link:active [class*=sap-icon],.fd-link:active[class*=sap-icon]{color:var(--sapLink_Active_Color);-webkit-text-decoration:var(--fdLink_Text_Decoration_Active);text-decoration:var(--fdLink_Text_Decoration_Active)}.fd-link:visited:not(:focus) [class*=sap-icon],.fd-link:visited:not(:focus)[class*=sap-icon]{color:var(--sapLink_Visited_Color)}.fd-link__content--icon-line-height{line-height:var(--sapContent_LineHeight)}.fd-link__icon-container{display:inline-flex;justify-content:center;align-items:center}.fd-link__icon-container:first-child{margin-inline-end:var(--fdLink_Icon_Spacing, 0)}.fd-link__icon-container:last-child{margin-inline-start:var(--fdLink_Icon_Spacing, 0)}\n/*!\n * Fundamental Library Styles v0.40.1\n * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n */\n"], dependencies: [{ kind: "ngmodule", type: PortalModule }, { kind: "directive", type: i1.CdkPortalOutlet, selector: "[cdkPortalOutlet]", inputs: ["cdkPortalOutlet"], outputs: ["attached"], exportAs: ["cdkPortalOutlet"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], LinkComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: LinkComponent, decorators: [{
            type: Component,
            args: [{ selector: '[fdLink], [fd-link]', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: FD_LINK_COMPONENT,
                            useExisting: LinkComponent
                        },
                        {
                            provide: 'linkRouterTarget',
                            useFactory: (withHref, routerLink) => withHref || routerLink,
                            deps: [
                                [new Optional(), new Self(), RouterLink],
                                [new Optional(), new Self(), RouterLink]
                            ]
                        }
                    ], imports: [PortalModule], template: "@if (_prefixPortal) {\n    <span class=\"fd-link__icon-container\">\n        <ng-container *cdkPortalOutlet=\"_prefixPortal\"></ng-container>\n    </span>\n}\n<span class=\"fd-link__content\" #content [class.fd-link__content--icon-line-height]=\"_postfixPortal || _prefixPortal\">\n    <ng-content></ng-content>\n</span>\n@if (_postfixPortal) {\n    <span class=\"fd-link__icon-container\">\n        <ng-container *cdkPortalOutlet=\"_postfixPortal\"></ng-container>\n    </span>\n}\n", styles: [".fd-link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapLinkColor);cursor:pointer;display:var(--fdLink_Display, inline-block);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-shadow:var(--sapContent_TextShadow);-webkit-box-align:center;-ms-flex-align:center;align-items:center;line-height:inherit;line-height:var(--fdLink_Line_Height, 1.125rem);-webkit-text-decoration:var(--fdLink_Text_Decoration, none);text-decoration:var(--fdLink_Text_Decoration, none);text-underline-offset:.125rem;-webkit-transition:all .125s ease-in;transition:all .125s ease-in}.fd-link:after,.fd-link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-link__content{-webkit-text-decoration:var(--fdLink_Text_Content_Decoration, none);text-decoration:var(--fdLink_Text_Content_Decoration, none)}.fd-link.is-hover,.fd-link:hover{--fdLink_Text_Decoration:var(--fdLink_Text_Decoration_Hover,none);--fdLink_Text_Content_Decoration:var(--fdLink_Text_Content_Decoration_Hover,none)}.fd-link.is-focus,.fd-link:focus{--fdLink_Text_Decoration:var(--fdLink_Text_Decoration_Focus,none);--fdLink_Text_Content_Decoration:var(--fdLink_Text_Content_Decoration_Focus,none)}.fd-link.is-active,.fd-link:active{--fdLink_Text_Decoration:var(--fdLink_Text_Decoration_Active,none);--fdLink_Text_Content_Decoration:var(--fdLink_Text_Content_Decoration_Active,none)}.fd-link.is-disabled,.fd-link:disabled,.fd-link[aria-disabled=true]{--fdLink_Text_Decoration:var(--fdLink_Text_Decoration_Disabled,none);--fdLink_Text_Content_Decoration:var(--fdLink_Text_Content_Decoration_Disabled,none)}.fd-link--subtle{--fdLink_Text_Content_Decoration:var(--fdLink_Text_Content_Decoration_Subtle,none);--fdLink_Text_Content_Decoration_Hover:var(--fdLink_Text_Content_Decoration_Subtle_Hover,none);--fdLink_Text_Content_Decoration_Active:var(--fdLink_Text_Content_Decoration_Subtle_Active,none);--fdLink_Text_Decoration:var(--fdLink_Text_Decoration_Subtle,none);--fdLink_Text_Decoration_Hover:var(--fdLink_Text_Decoration_Subtle_Hover,none);--fdLink_Text_Decoration_Active:var(--fdLink_Text_Decoration_Subtle_Active,none)}.fd-link--undecorated{--fdLink_Text_Decoration:none;--fdLink_Text_Decoration_Subtle:none;--fdLink_Text_Decoration_Subtle_Hover:none;--fdLink_Text_Decoration_Subtle_Active:none;--fdLink_Text_Decoration_Hover:none;--fdLink_Text_Decoration_Focus:none;--fdLink_Text_Decoration_Active:none;--fdLink_Text_Decoration_Visited:none;--fdLink_Text_Decoration_Disabled:none;--fdLink_Text_Content_Decoration:none;--fdLink_Text_Content_Decoration_Subtle:none;--fdLink_Text_Content_Decoration_Subtle_Hover:none;--fdLink_Text_Content_Decoration_Subtle_Active:none;--fdLink_Text_Content_Decoration_Hover:none;--fdLink_Text_Content_Decoration_Focus:none;--fdLink_Text_Content_Decoration_Active:none;--fdLink_Text_Content_Decoration_Visited:none;--fdLink_Text_Content_Decoration_Disabled:none}.fd-link--emphasized{font-family:var(--sapFontBoldFamily)}.fd-link:visited{color:var(--sapLink_Visited_Color)}.fd-link.is-hover,.fd-link:hover{color:var(--sapLink_Hover_Color)}.fd-link.is-focus,.fd-link:focus{background-color:var(--fdLink_Focus_Background);border-radius:var(--fdLink_Focus_Border_Radius);-webkit-box-shadow:none;box-shadow:none;color:var(--fdLink_Text_Focus_Color);outline:var(--fdLink_Hover_Outline_Color) var(--fdLink_Hover_Outline_Style) var(--fdLink_Hover_Outline_Width);outline-offset:var(--fdLink_Hover_Outline_Offset);text-shadow:var(--fdLink_Focus_Text_Shadow)}.fd-link.is-active,.fd-link:active{color:var(--sapLink_Active_Color)}.fd-link.is-active.is-focus,.fd-link.is-active:focus,.fd-link:active.is-focus,.fd-link:active:focus{background-color:transparent;z-index:5}.fd-link--inverted{text-shadow:none}.fd-link--inverted,.fd-link--inverted.is-hover,.fd-link--inverted:hover{color:var(--sapLink_InvertedColor)}.fd-link--inverted.is-focus,.fd-link--inverted:focus{outline-color:var(--sapContent_ContrastFocusColor);z-index:5}.fd-link--subtle{color:var(--sapLink_SubtleColor)}.fd-link.is-disabled,.fd-link:disabled,.fd-link[aria-disabled=true]{color:var(--sapLinkColor);opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-link>img{vertical-align:bottom}.fd-link [class*=sap-icon],.fd-link[class*=sap-icon]{color:var(--sapLinkColor);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-link [class*=sap-icon]:first-child,.fd-link[class*=sap-icon]:first-child{-webkit-margin-end:var(--fdLink_Icon_Spacing, 0);margin-inline-end:var(--fdLink_Icon_Spacing, 0)}.fd-link [class*=sap-icon]:last-child,.fd-link[class*=sap-icon]:last-child{-webkit-margin-start:var(--fdLink_Icon_Spacing, 0);margin-inline-start:var(--fdLink_Icon_Spacing, 0)}.fd-link.is-hover [class*=sap-icon],.fd-link.is-hover[class*=sap-icon],.fd-link:hover [class*=sap-icon],.fd-link:hover[class*=sap-icon]{color:var(--sapLink_Hover_Color);-webkit-text-decoration:var(--fdLink_Text_Decoration_Hover);text-decoration:var(--fdLink_Text_Decoration_Hover)}.fd-link.is-focus,.fd-link:focus{z-index:5}.fd-link.is-focus [class*=sap-icon],.fd-link.is-focus[class*=sap-icon],.fd-link:focus [class*=sap-icon],.fd-link:focus[class*=sap-icon]{color:var(--fdLink_Text_Focus_Color);-webkit-text-decoration:var(--fdLink_Text_Decoration_Focus);text-decoration:var(--fdLink_Text_Decoration_Focus)}.fd-link.is-active [class*=sap-icon],.fd-link.is-active[class*=sap-icon],.fd-link:active [class*=sap-icon],.fd-link:active[class*=sap-icon]{color:var(--sapLink_Active_Color);-webkit-text-decoration:var(--fdLink_Text_Decoration_Active);text-decoration:var(--fdLink_Text_Decoration_Active)}.fd-link:visited:not(:focus) [class*=sap-icon],.fd-link:visited:not(:focus)[class*=sap-icon]{color:var(--sapLink_Visited_Color)}.fd-link__content--icon-line-height{line-height:var(--sapContent_LineHeight)}.fd-link__icon-container{display:inline-flex;justify-content:center;align-items:center}.fd-link__icon-container:first-child{margin-inline-end:var(--fdLink_Icon_Spacing, 0)}.fd-link__icon-container:last-child{margin-inline-start:var(--fdLink_Icon_Spacing, 0)}\n/*!\n * Fundamental Library Styles v0.40.1\n * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n */\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i2.RouterLink, decorators: [{
                    type: Inject,
                    args: ['linkRouterTarget']
                }] }], propDecorators: { iconComponents: [{
                type: ContentChildren,
                args: [FD_ICON_COMPONENT]
            }], contentSpan: [{
                type: ViewChild,
                args: ['content']
            }], class: [{
                type: Input
            }], emphasized: [{
                type: Input
            }], disabled: [{
                type: Input
            }], inverted: [{
                type: Input
            }], subtle: [{
                type: Input
            }], undecorated: [{
                type: Input
            }], buildComponentCssClass: [] } });

class LinkModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: LinkModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: LinkModule, imports: [LinkComponent], exports: [LinkComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: LinkModule, imports: [LinkComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: LinkModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [LinkComponent],
                    exports: [LinkComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { FD_LINK_COMPONENT, LINK_CLASS_NAME, LinkComponent, LinkModule };
//# sourceMappingURL=fundamental-ngx-core-link.mjs.map
