import * as i2 from '@angular/cdk/portal';
import { ComponentPortal, PortalModule, CdkPortalOutlet, DomPortal } from '@angular/cdk/portal';
import * as i0 from '@angular/core';
import { InjectionToken, inject, DestroyRef, Input, Directive, ElementRef, ViewChild, HostBinding, Component, HostListener, ContentChild, Optional, Injectable, EventEmitter, forwardRef, booleanAttribute, Output, Inject, ViewEncapsulation, ChangeDetectionStrategy, TemplateRef, ContentChildren, Renderer2, NgZone, signal, computed, Injector, NgModule } from '@angular/core';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { IconComponent } from '@fundamental-ngx/core/icon';
import { Subject, combineLatest, tap, first, map, Subscription, fromEvent, defer, timer, BehaviorSubject, of, switchMap as switchMap$1, merge, delayWhen, startWith as startWith$1 } from 'rxjs';
import { distinctUntilChanged, takeUntil, filter, switchMap, startWith, take } from 'rxjs/operators';
import { NgTemplateOutlet } from '@angular/common';
import { RIGHT_ARROW, LEFT_ARROW, DOWN_ARROW, UP_ARROW, SPACE, ENTER, ESCAPE } from '@angular/cdk/keycodes';
import * as i2$1 from '@fundamental-ngx/cdk/utils';
import { KeyUtil, TemplateModule, InitialFocusDirective, TemplateDirective, DynamicComponentService, InitialFocusModule } from '@fundamental-ngx/cdk/utils';
import * as i1 from '@fundamental-ngx/cdk/forms';
import { CvaControl, FD_FORM_FIELD_CONTROL, CvaDirective } from '@fundamental-ngx/cdk/forms';
import * as i5 from '@fundamental-ngx/core/content-density';
import { ContentDensityDirective, contentDensityObserverProviders, ContentDensityModule } from '@fundamental-ngx/core/content-density';
import * as i3 from '@fundamental-ngx/core/popover';
import { BasePopoverClass, PopoverService, PopoverModule } from '@fundamental-ngx/core/popover';
import * as i1$1 from '@fundamental-ngx/core/dialog';
import { DialogComponent, DialogBodyComponent, DialogHeaderComponent, DialogCloseButtonComponent, DialogFooterComponent } from '@fundamental-ngx/core/dialog';
import { BarLeftDirective, BarRightDirective, BarElementDirective, ButtonBarComponent } from '@fundamental-ngx/core/bar';
import { ButtonComponent } from '@fundamental-ngx/core/button';
import { MobileModeBase, MobileModeControl } from '@fundamental-ngx/core/mobile-mode';
import { TitleComponent, TitleModule } from '@fundamental-ngx/core/title';

const TOGGLE_MENU_ITEM = new InjectionToken('TOGGLE_MENU_ITEM');
const FD_MENU_COMPONENT = new InjectionToken('FD_MENU_COMPONENT');
const FD_MENU_ITEM_COMPONENT = new InjectionToken('FD_MENU_ITEM_COMPONENT');

class GlyphMenuAddonDirective {
    /**
     *  The icon name to display. See the icon page for the list of icons
     * here: https://sap.github.io/fundamental-ngx/icon
     **/
    set glyph(glyph) {
        this._glyphName$.next(glyph);
    }
    /** @hidden */
    constructor() {
        /**
         * Toggle buttons always need a space, so we check if it is in a toggle button
         * */
        this.isInToggleButton = !!inject(TOGGLE_MENU_ITEM, { optional: true });
        /** @hidden */
        this._menuComponent = inject(FD_MENU_COMPONENT, { optional: true });
        /** @hidden */
        this._addonGlyphPortalOutlet$ = new Subject();
        /** @hidden */
        this._glyphName$ = new Subject();
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        combineLatest([this._addonGlyphPortalOutlet$, this._glyphName$])
            .pipe(tap(([, glyphName]) => {
            glyphName || this.isInToggleButton ? this._addGlyphAddonToMenu() : this._removeGlyphAddonFromMenu();
        }), tap(([outlet, glyphName]) => {
            if (!glyphName) {
                outlet.detach();
                return;
            }
            const componentRef = outlet.attachComponentPortal(new ComponentPortal(IconComponent));
            componentRef.instance.glyph = glyphName;
            componentRef.instance.elementRef.nativeElement.setAttribute('role', 'presentation');
            if (this.isInToggleButton) {
                componentRef.instance.elementRef.nativeElement.classList.add('fd-menu__checkmark');
            }
            componentRef.changeDetectorRef.detectChanges();
        }), takeUntilDestroyed(this._destroyRef))
            .subscribe();
    }
    /** @hidden */
    setGlyphPortalOutlet(outlet) {
        this._addonGlyphPortalOutlet$.next(outlet);
    }
    /** @hidden */
    renderElement(element) {
        return this._addonGlyphPortalOutlet$.pipe(first(), tap((outlet) => outlet.detach()), map((outlet) => outlet.attach(element)));
    }
    /** @hidden */
    ngOnDestroy() {
        this._removeGlyphAddonFromMenu();
    }
    /** @hidden */
    _addGlyphAddonToMenu() {
        this._menuComponent?.registerAddon(this);
    }
    /** @hidden */
    _removeGlyphAddonFromMenu() {
        this._menuComponent?.unregisterAddon(this);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: GlyphMenuAddonDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: GlyphMenuAddonDirective, isStandalone: true, selector: "[fdMenuAddonGlyph], [fd-menu-addon-glyph]", inputs: { glyph: "glyph" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: GlyphMenuAddonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdMenuAddonGlyph], [fd-menu-addon-glyph]',
                    standalone: true
                }]
        }], ctorParameters: () => [], propDecorators: { glyph: [{
                type: Input
            }] } });

// eslint-disable-next-line @angular-eslint/component-class-suffix
class MenuAddonDirective {
    constructor() {
        /** Whether is used as submenu indicator */
        this.submenuIndicator = false;
        /** Sets Aria hidden attribute */
        this.ariaHidden = true;
        /** @hidden */
        this.fdAddonAfterClass = true;
        /** @hidden */
        this.fdAddonBeforeClass = false;
        /** @hidden */
        this._addonGlyph = inject(GlyphMenuAddonDirective);
        /** @hidden */
        this.elementRef = inject(ElementRef);
    }
    /** Whether addon is used before or after text */
    // eslint-disable-next-line @angular-eslint/no-input-rename
    set setAddonPosition(position) {
        this.fdAddonBeforeClass = position === 'before';
        this.fdAddonAfterClass = position === 'after';
    }
    /** @hidden */
    set addonPortalOutlet(portalOutlet) {
        this._addonGlyph.setGlyphPortalOutlet(portalOutlet);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuAddonDirective, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: MenuAddonDirective, isStandalone: true, selector: "fd-menu-addon", inputs: { setAddonPosition: ["position", "setAddonPosition"], submenuIndicator: "submenuIndicator", ariaHidden: "ariaHidden" }, host: { properties: { "class.fd-menu__addon-after--submenu": "this.submenuIndicator", "attr.aria-hidden": "this.ariaHidden", "class.fd-menu__addon-after": "this.fdAddonAfterClass", "class.fd-menu__addon-before": "this.fdAddonBeforeClass" } }, viewQueries: [{ propertyName: "addonPortalOutlet", first: true, predicate: CdkPortalOutlet, descendants: true }], hostDirectives: [{ directive: GlyphMenuAddonDirective, inputs: ["glyph", "glyph"] }], ngImport: i0, template: ` <ng-template cdkPortalOutlet></ng-template> `, isInline: true, dependencies: [{ kind: "ngmodule", type: PortalModule }, { kind: "directive", type: i2.CdkPortalOutlet, selector: "[cdkPortalOutlet]", inputs: ["cdkPortalOutlet"], outputs: ["attached"], exportAs: ["cdkPortalOutlet"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuAddonDirective, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-menu-addon',
                    template: ` <ng-template cdkPortalOutlet></ng-template> `,
                    hostDirectives: [{ directive: GlyphMenuAddonDirective, inputs: ['glyph'] }],
                    imports: [PortalModule]
                }]
        }], propDecorators: { setAddonPosition: [{
                type: Input,
                args: ['position']
            }], submenuIndicator: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.fd-menu__addon-after--submenu']
            }], ariaHidden: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-hidden']
            }], fdAddonAfterClass: [{
                type: HostBinding,
                args: ['class.fd-menu__addon-after']
            }], fdAddonBeforeClass: [{
                type: HostBinding,
                args: ['class.fd-menu__addon-before']
            }], addonPortalOutlet: [{
                type: ViewChild,
                args: [CdkPortalOutlet]
            }] } });

class MenuItemInputDirective {
    constructor() {
        /** @hidden */
        this.elementRef = inject(ElementRef);
    }
    /**
     * This is needed to prevent the click event from bubbling up to the menu item
     * and potentially closing the menu or triggering other actions.
     */
    onInteraction($event) {
        if ($event.target === this.elementRef.nativeElement) {
            $event.stopPropagation();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuItemInputDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: MenuItemInputDirective, isStandalone: true, selector: "input[fd-form-control][fd-menu-item-input]", host: { listeners: { "keydown": "onInteraction($event)", "click": "onInteraction($event)" }, classAttribute: "fd-menu__input" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuItemInputDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: 'input[fd-form-control][fd-menu-item-input]',
                    host: {
                        class: 'fd-menu__input'
                    },
                    standalone: true
                }]
        }], propDecorators: { onInteraction: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }, {
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

/**
 * The directive that represents the menu title.
 */
class MenuTitleDirective {
    /** Returns element title text */
    get title() {
        return this._elementRef.nativeElement.textContent;
    }
    /** @hidden */
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        /** @hidden */
        this.fdMenuTitleClass = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuTitleDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: MenuTitleDirective, isStandalone: true, selector: "[fd-menu-title]", host: { properties: { "class.fd-menu__title": "this.fdMenuTitleClass", "attr.title": "this.title" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-menu-title]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { fdMenuTitleClass: [{
                type: HostBinding,
                args: ['class.fd-menu__title']
            }], title: [{
                type: HostBinding,
                args: ['attr.title']
            }] } });

class MenuInteractiveComponent {
    constructor() {
        /** @hidden */
        this.tabindex = 0;
        /** @hidden */
        this.disabled = false;
        /** @hidden */
        this.selected = false;
        /** @hidden */
        this.ariaHaspopup = false;
        /** @hidden */
        this.fdMenuLinkClass = true;
        /** @hidden */
        this._fromSplitButton = false;
        /** @hidden */
        this.elementRef = inject(ElementRef);
    }
    /** @hidden */
    set _addon(addon) {
        if (addon?.elementRef.nativeElement === this.elementRef.nativeElement.querySelector('fd-menu-addon:first-child')) {
            this._startAddonInstance = addon;
        }
    }
    /** @hidden */
    get startAddon() {
        if (!this._startAddonInstance) {
            this.addonPortalOutlet.detach();
            this._startAddonInstance = this.addonPortalOutlet.attachComponentPortal(new ComponentPortal(MenuAddonDirective)).instance;
            this._startAddonInstance.setAddonPosition = 'before';
        }
        return this._startAddonInstance;
    }
    /** @hidden */
    _handleKeydown($event) {
        if (this._input && $event.target === this.elementRef.nativeElement) {
            this._input.elementRef.nativeElement.focus();
        }
    }
    /** @hidden */
    setSelected(isSelected) {
        this.selected = isSelected && (this.ariaHaspopup || this._fromSplitButton);
        if (this.ariaHaspopup || this._fromSplitButton) {
            this.ariaExpanded = isSelected;
        }
    }
    /** @hidden */
    setDisabled(isDisabled) {
        this.disabled = isDisabled;
        this.tabindex = isDisabled ? -1 : 0;
    }
    /** @hidden */
    setSubmenu(hasSubmenu, itemId) {
        this.ariaHaspopup = hasSubmenu;
        this.ariaControls = hasSubmenu ? itemId || this.ariaControls : null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuInteractiveComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: MenuInteractiveComponent, isStandalone: true, selector: "[fd-menu-interactive]", host: { attributes: { "role": "menuitem" }, listeners: { "keydown.enter": "_handleKeydown($event)", "keydown.space": "_handleKeydown($event)" }, properties: { "attr.tabindex": "this.tabindex", "class.is-disabled": "this.disabled", "attr.aria-controls": "this.ariaControls", "class.is-selected": "this.selected", "attr.aria-expanded": "this.ariaExpanded", "attr.aria-haspopup": "this.ariaHaspopup", "class.has-child": "this.ariaHaspopup", "class.fd-menu__link": "this.fdMenuLinkClass" } }, queries: [{ propertyName: "_addon", first: true, predicate: MenuAddonDirective, descendants: true }, { propertyName: "_input", first: true, predicate: MenuItemInputDirective, descendants: true }], viewQueries: [{ propertyName: "addonPortalOutlet", first: true, predicate: CdkPortalOutlet, descendants: true }], ngImport: i0, template: `
        <ng-template cdkPortalOutlet></ng-template>
        <ng-content></ng-content>
    `, isInline: true, dependencies: [{ kind: "ngmodule", type: PortalModule }, { kind: "directive", type: i2.CdkPortalOutlet, selector: "[cdkPortalOutlet]", inputs: ["cdkPortalOutlet"], outputs: ["attached"], exportAs: ["cdkPortalOutlet"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuInteractiveComponent, decorators: [{
            type: Component,
            args: [{
                    // eslint-disable-next-line @angular-eslint/component-selector
                    selector: '[fd-menu-interactive]',
                    template: `
        <ng-template cdkPortalOutlet></ng-template>
        <ng-content></ng-content>
    `,
                    host: {
                        role: 'menuitem'
                    },
                    imports: [PortalModule]
                }]
        }], propDecorators: { addonPortalOutlet: [{
                type: ViewChild,
                args: [CdkPortalOutlet]
            }], _addon: [{
                type: ContentChild,
                args: [MenuAddonDirective]
            }], tabindex: [{
                type: HostBinding,
                args: ['attr.tabindex']
            }], disabled: [{
                type: HostBinding,
                args: ['class.is-disabled']
            }], ariaControls: [{
                type: HostBinding,
                args: ['attr.aria-controls']
            }], selected: [{
                type: HostBinding,
                args: ['class.is-selected']
            }], ariaExpanded: [{
                type: HostBinding,
                args: ['attr.aria-expanded']
            }], ariaHaspopup: [{
                type: HostBinding,
                args: ['attr.aria-haspopup']
            }, {
                type: HostBinding,
                args: ['class.has-child']
            }], fdMenuLinkClass: [{
                type: HostBinding,
                args: ['class.fd-menu__link']
            }], _input: [{
                type: ContentChild,
                args: [MenuItemInputDirective]
            }], _handleKeydown: [{
                type: HostListener,
                args: ['keydown.enter', ['$event']]
            }, {
                type: HostListener,
                args: ['keydown.space', ['$event']]
            }] } });

class MenuService {
    /** @hidden */
    get _isRtl() {
        return this._rtlService?.rtl.value;
    }
    /** @hidden */
    constructor(_renderer, _rtlService) {
        this._renderer = _renderer;
        this._rtlService = _rtlService;
        /** Collection of active menu nodes */
        this.activeNodePath = [];
        /** Collection of active menu nodes */
        this._isMobileMode = new Subject();
    }
    /** Reference to menu component */
    get menuComponent() {
        return this._menuComponent;
    }
    /** Returns menu mode observable */
    get isMobileMode() {
        return this._isMobileMode.pipe(distinctUntilChanged());
    }
    /** Sets menu mode */
    setMenuMode(value) {
        this._isMobileMode.next(value);
    }
    /** Sets given menu item as focused */
    setFocused(menuItem) {
        this.focusedNode = this.menuMap.get(menuItem);
        this.focusedNode?.item?.focus();
    }
    /**
     * Sets state of a given menu item
     * @param isActive - Whether should be set as active or inactive
     * @param menuItem `MenuItemComponent` that should be set as active or inactive
     */
    setActive(isActive, menuItem) {
        if (!menuItem || (isActive && menuItem.disabled)) {
            return;
        }
        if (isActive) {
            this._addToActivePath(menuItem);
        }
        else {
            this._removeFromActivePath(menuItem);
        }
        this._emitActivePath();
    }
    /**
     * Close active sibling submenu if any
     * @param menuItem to look for active siblings
     */
    setInactiveSiblingMenuItem(menuItem) {
        this._removeActiveSibling(menuItem);
        this._emitActivePath();
    }
    /** Initializes menu service based on given Menu Component */
    setMenuComponent(menu) {
        this._menuComponent = menu;
        this.menuMap = this._buildMenuMap(this._menuComponent);
    }
    /** Clears Active Node Path and resets Focused Node */
    resetMenuState() {
        this._clearActivePath();
        this.focusedNode = undefined;
        this._emitActivePath();
    }
    /** - Updates the structure of the menu
     *  - Validates Active Node Path
     *  - Validates Focused Node */
    rebuildMenu() {
        this.menuMap = this._buildMenuMap(this._menuComponent);
        const deadNode = this.activeNodePath.find((node) => !this.menuMap.has(node.item));
        if (deadNode?.item) {
            this.setActive(false, deadNode.item);
        }
        const invalidFocusedElement = this.focusedNode && !this.menuMap.get(this.focusedNode.item);
        if (invalidFocusedElement) {
            this.focusedNode =
                this.activeNodePath[this.activeNodePath.length - 1] || this.menuMap.get(null).children[0];
        }
    }
    /** Adds Menu keyboard support */
    addKeyboardSupport(elementRef) {
        this.removeKeyboardSupport();
        this._setKeyboardSupport(elementRef);
    }
    /** Removes Menu keyboard support */
    removeKeyboardSupport() {
        if (this._destroyKeyboardHandlerListener) {
            this._destroyKeyboardHandlerListener();
        }
    }
    /** @hidden */
    ngOnDestroy() {
        this.removeKeyboardSupport();
    }
    /** @hidden Returns siblings of given node */
    _nodeSiblings(node) {
        return node.parent ? node.parent.children : this.menuMap.get(null)?.children;
    }
    /** @hidden Adds given element to the Active Node Path and setts as active*/
    _addToActivePath(menuItem) {
        const menuNode = this.menuMap.get(menuItem);
        this._removeActiveSibling(menuItem);
        if (menuNode) {
            this.activeNodePath.push(menuNode);
            menuNode.item?.setSelected(true);
        }
    }
    /** @hidden Removes given element and all its successors from the Active Node Path and setts as inactive*/
    _removeFromActivePath(menuItem) {
        const menuNode = this.menuMap.get(menuItem);
        if (menuNode) {
            const pathIndex = this.activeNodePath.findIndex((i) => i.item === menuNode.item);
            if (pathIndex !== -1) {
                this.activeNodePath
                    .splice(pathIndex)
                    .forEach((removedActiveNode) => removedActiveNode.item?.setSelected(false));
            }
        }
    }
    /** @hidden Removes all elements from the Active Node Path and sets them as closed */
    _clearActivePath() {
        if (this.activeNodePath.length) {
            this._removeFromActivePath(this.activeNodePath[0].item);
        }
    }
    /** @hidden
     * - Builds Menu Nodes based on Menu Items
     * - Creates Map of the Menu Nodes */
    _buildMenuMap(menu) {
        function buildNode(menuItem) {
            return {
                item: menuItem,
                parent: null,
                children: menuItem.submenu
                    ? menuItem.submenu.menuItems.map((subMenuItem) => buildNode(subMenuItem))
                    : []
            };
        }
        function setParents(node, parent) {
            node.parent = parent;
            node.children.forEach((childNode) => setParents(childNode, node));
        }
        function toMap(node, map = new Map()) {
            map.set(node.item, node);
            node.children.forEach((childNode) => toMap(childNode, map));
            return map;
        }
        const rootItems = menu._menuItems.filter((rootItem) => !rootItem.parentSubmenu);
        /** root item */
        const menuTree = {
            item: null,
            parent: null,
            children: rootItems.map((item) => buildNode(item))
        };
        setParents(menuTree, null);
        return toMap(menuTree);
    }
    /** @hidden Removes active sibling of a given menu item from the Active Path */
    _removeActiveSibling(menuItem) {
        const menuNode = this.menuMap.get(menuItem);
        const children = menuNode?.parent?.children.map((i) => i.item);
        const activeSibling = this.activeNodePath.find((i) => children?.includes(i.item));
        if (activeSibling) {
            const activeParentIndex = this.activeNodePath.indexOf(menuNode?.parent);
            this._removeFromActivePath(activeParentIndex !== -1 ? activeSibling.item : this.activeNodePath[0].item);
        }
    }
    /** @hidden Adds keyboard support */
    _setKeyboardSupport(elementRef) {
        this._destroyKeyboardHandlerListener = this._renderer.listen(elementRef.nativeElement, 'keydown', (event) => this._handleKey(event));
    }
    /** @hidden */
    _handleKey(event) {
        const focusRight = (node) => {
            setTimeout(() => this.setFocused(node.children[0].item));
        };
        let matched = true;
        if (!this.focusedNode) {
            return;
        }
        if ((KeyUtil.isKeyCode(event, RIGHT_ARROW) && !this._isRtl) ||
            (KeyUtil.isKeyCode(event, LEFT_ARROW) && this._isRtl)) {
            if (this.focusedNode?.children.length) {
                this.setActive(true, this.focusedNode.item);
                focusRight(this.focusedNode);
            }
        }
        else if ((KeyUtil.isKeyCode(event, LEFT_ARROW) && !this._isRtl) ||
            (KeyUtil.isKeyCode(event, RIGHT_ARROW) && this._isRtl)) {
            if (this.focusedNode.parent?.item) {
                this.setActive(false, this.focusedNode.parent.item);
                this.setFocused(this.focusedNode.parent.item);
            }
        }
        else if (KeyUtil.isKeyCode(event, DOWN_ARROW)) {
            const closest = this._closestEnabled(this.focusedNode, 'down');
            if (closest) {
                this.setFocused(closest.item);
            }
        }
        else if (KeyUtil.isKeyCode(event, UP_ARROW)) {
            const closest = this._closestEnabled(this.focusedNode, 'up');
            if (closest) {
                this.setFocused(closest.item);
            }
        }
        else if (KeyUtil.isKeyCode(event, [SPACE, ENTER])) {
            const focusedNode = this.focusedNode;
            this.setActive(true, focusedNode?.item);
            focusedNode.item?.click();
            if (focusedNode.children.length) {
                focusRight(focusedNode);
            }
        }
        else if (KeyUtil.isKeyCode(event, ESCAPE) && this.menuComponent.closeOnEscapeKey) {
            this.menuComponent.close();
        }
        else {
            matched = false;
        }
        if (matched) {
            event.preventDefault();
        }
    }
    /** @hidden Emits an array of active menu items */
    _emitActivePath() {
        this.menuComponent.activePath.emit(this.activeNodePath.map((node) => node.item));
    }
    /** @hidden Depending on direction returns closest enabled sibling of given node */
    _closestEnabled(node, direction) {
        const siblings = direction === 'up' ? [...(this._nodeSiblings(node) ?? [])].reverse() : this._nodeSiblings(node);
        if (siblings) {
            const startIndex = siblings.indexOf(node) + 1;
            for (let i = startIndex; i < siblings.length; i++) {
                if (siblings[i].item && !siblings[i].item.disabled) {
                    return siblings[i];
                }
            }
        }
        return null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuService, deps: [{ token: i0.Renderer2 }, { token: i2$1.RtlService, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i0.Renderer2 }, { type: i2$1.RtlService, decorators: [{
                    type: Optional
                }] }] });

let menuUniqueId$1 = 0;
const SUBMENU = new InjectionToken('Submenu component dependency');
class MenuItemComponent {
    /** @hidden */
    constructor(elementRef, menuService, _changeDetectorRef, _submenu) {
        this.elementRef = elementRef;
        this.menuService = menuService;
        this._changeDetectorRef = _changeDetectorRef;
        this._submenu = _submenu;
        /** Set the Menu Item as disabled/enabled */
        this.disabled = false;
        /** Menu Item id attribute value */
        this.itemId = `fd-menu-item-${menuUniqueId$1++}`;
        /** Whether the menu item has a separator */
        this.hasSeparator = false;
        /** Emitted when the menu item is selected. */
        this.onSelect = new EventEmitter();
        /** @hidden Whether sub-menu is currently visible*/
        this.submenuVisible = false;
        /** @hidden */
        this._subscriptions = new Subscription();
        /** @hidden */
        this._hoverSubscriptions = new Subscription();
    }
    /** @hidden */
    ngOnInit() {
        if (this.parentSubmenu) {
            this._submenu = this.parentSubmenu;
            this._submenu._registerItem(this);
        }
    }
    /** @hidden */
    ngAfterContentInit() {
        this._setMenuService();
        this._initialiseItemState();
        this._listenOnMenuLinkClick();
        this._listenOnOuterFocus();
        this._listenOnMenuMode();
    }
    /** @hidden */
    ngOnChanges(changes) {
        if (changes['disabled'] && !changes['disabled'].firstChange) {
            this.menuInteractive.setDisabled(this.disabled);
        }
        if (changes['submenu'] && !changes['submenu'].firstChange) {
            this.menuInteractive.setSubmenu(!!this.submenu, this.submenu ? this.itemId : undefined);
        }
    }
    /** @hidden */
    ngOnDestroy() {
        if (this.parentSubmenu) {
            this._submenu?._unregisterItem(this);
        }
        this._subscriptions.unsubscribe();
        this._hoverSubscriptions.unsubscribe();
    }
    /** Whether menu item has popup (desktop mode)  */
    get hasPopup() {
        return !!this.submenu && (!this.menuService?.menuComponent || !this.menuService?.menuComponent.mobile);
    }
    /** Focuses Menu Item interactive element */
    focus() {
        if (this.menuInteractive) {
            this.menuInteractive.elementRef.nativeElement.focus();
        }
    }
    /** Clicks Menu Item interactive element */
    click() {
        if (this.menuInteractive) {
            this.menuInteractive.elementRef.nativeElement.click();
            this._changeDetectorRef.markForCheck();
        }
    }
    /** @hidden Sets menu item as selected/unselected based on isSelected flag */
    setSelected(isSelected, fromSplit) {
        this.menuInteractive.setSelected(isSelected);
        this.submenuVisible = isSelected && !!this.submenu;
        if (!fromSplit) {
            this.onSelect.emit();
        }
        this._changeDetectorRef.markForCheck();
    }
    /** @hidden Creates click listener on menu item interactive element */
    _listenOnMenuLinkClick() {
        this._subscriptions.add(fromEvent(this.menuInteractive.elementRef.nativeElement, 'click').subscribe(() => this.menuService?.setActive(true, this)));
    }
    /** @hidden Creates hover listeners for activating/deactivating menu item */
    _listenOnMenuLinkHover() {
        const hoverSubscriptions = new Subscription();
        const mouseEnter$ = fromEvent(this.menuInteractive.elementRef.nativeElement, 'mouseenter');
        const mouseLeave$ = fromEvent(this.menuInteractive.elementRef.nativeElement, 'mouseleave');
        const timerFactory$ = defer(() => timer(this.menuService ? this.menuService.menuComponent.openOnHoverTime : 0).pipe(takeUntil(mouseLeave$)));
        // Set active on hover
        hoverSubscriptions.add(mouseEnter$
            .pipe(filter(() => !!this.menuService), switchMap(() => timerFactory$))
            .subscribe(() => {
            if (this.submenu) {
                // Open submenu
                this.menuService.setActive(true, this);
            }
            if (!this.submenu) {
                // Close sibling submenu if opened
                this.menuService.setInactiveSiblingMenuItem(this);
            }
        }));
        return hoverSubscriptions;
    }
    /** @hidden Initializes menu link state based on item initial state */
    _initialiseItemState() {
        this.menuInteractive.setSubmenu(!!this.submenu, this.itemId);
        this.menuInteractive.setDisabled(this.disabled);
    }
    /** @hidden Checks for Menu Service dependency and passes it if further */
    _setMenuService() {
        this.menuService = this.menuService || this._submenu?.menuService || null;
        if (this.submenu && this.menuService) {
            this.submenu.menuService = this.menuService;
        }
    }
    /** @hidden Listen on menu mode and set proper mode listeners */
    _listenOnMenuMode() {
        this.menuService?.isMobileMode.subscribe((isMobile) => {
            this._hoverSubscriptions.unsubscribe();
            if (!isMobile) {
                this._hoverSubscriptions = this._listenOnMenuLinkHover();
            }
        });
    }
    /** @hidden Updates focused menu item on outer focus */
    _listenOnOuterFocus() {
        this._subscriptions.add(fromEvent(this.menuInteractive.elementRef.nativeElement, 'focus').subscribe(() => {
            if (this.menuService && this.menuService.focusedNode !== this.menuService.menuMap.get(this)) {
                this.menuService.setFocused(this);
            }
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuItemComponent, deps: [{ token: i0.ElementRef }, { token: MenuService, optional: true }, { token: i0.ChangeDetectorRef }, { token: SUBMENU, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: MenuItemComponent, isStandalone: true, selector: "li[fd-menu-item]", inputs: { disabled: "disabled", itemId: "itemId", submenu: "submenu", parentSubmenu: "parentSubmenu", hasSeparator: ["hasSeparator", "hasSeparator", booleanAttribute] }, outputs: { onSelect: "onSelect" }, host: { properties: { "attr.role": "\"menuitem\"", "class.fd-menu__item": "true", "class.fd-menu--full-width": "menuService?.menuComponent?.mobile || false", "class.has-separator": "this.hasSeparator" } }, providers: [
            {
                provide: FD_MENU_ITEM_COMPONENT,
                useExisting: forwardRef(() => MenuItemComponent)
            }
        ], queries: [{ propertyName: "menuItemTitle", first: true, predicate: MenuTitleDirective, descendants: true }, { propertyName: "menuInteractive", first: true, predicate: MenuInteractiveComponent, descendants: true }], exportAs: ["fd-menu-item"], usesOnChanges: true, ngImport: i0, template: "<ng-content></ng-content>\n@if (hasPopup && submenu) {\n    <ul\n        class=\"fd-menu__sublist\"\n        role=\"menu\"\n        [attr.id]=\"itemId\"\n        [attr.aria-hidden]=\"!submenuVisible\"\n        [attr.aria-label]=\"submenu.ariaLabel\"\n        [attr.aria-labelledby]=\"submenu.ariaLabelledby\"\n    >\n        <ng-template [ngTemplateOutlet]=\"submenu.templateRef\"></ng-template>\n    </ul>\n}\n", dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'li[fd-menu-item]', exportAs: 'fd-menu-item', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: {
                        '[attr.role]': '"menuitem"',
                        '[class.fd-menu__item]': 'true',
                        '[class.fd-menu--full-width]': 'menuService?.menuComponent?.mobile || false'
                    }, imports: [NgTemplateOutlet], providers: [
                        {
                            provide: FD_MENU_ITEM_COMPONENT,
                            useExisting: forwardRef(() => MenuItemComponent)
                        }
                    ], template: "<ng-content></ng-content>\n@if (hasPopup && submenu) {\n    <ul\n        class=\"fd-menu__sublist\"\n        role=\"menu\"\n        [attr.id]=\"itemId\"\n        [attr.aria-hidden]=\"!submenuVisible\"\n        [attr.aria-label]=\"submenu.ariaLabel\"\n        [attr.aria-labelledby]=\"submenu.ariaLabelledby\"\n    >\n        <ng-template [ngTemplateOutlet]=\"submenu.templateRef\"></ng-template>\n    </ul>\n}\n" }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: MenuService, decorators: [{
                    type: Optional
                }] }, { type: i0.ChangeDetectorRef }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [SUBMENU]
                }] }], propDecorators: { disabled: [{
                type: Input
            }], itemId: [{
                type: Input
            }], submenu: [{
                type: Input
            }], parentSubmenu: [{
                type: Input
            }], hasSeparator: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }, {
                type: HostBinding,
                args: ['class.has-separator']
            }], 
        // eslint-disable-next-line @angular-eslint/no-output-on-prefix
        onSelect: [{
                type: Output
            }], menuItemTitle: [{
                type: ContentChild,
                args: [MenuTitleDirective]
            }], menuInteractive: [{
                type: ContentChild,
                args: [MenuInteractiveComponent]
            }] } });
class SubmenuComponent {
    constructor() {
        /** @hidden */
        this._registeredItems = [];
        /** @hidden */
        this._menuItemsChange$ = new Subject();
    }
    /** @hidden */
    get menuItems() {
        return this._projectedItems.length ? this._projectedItems.toArray() : this._registeredItems;
    }
    /** @hidden */
    ngAfterContentInit() {
        this._projectedItems.changes.subscribe(() => this._menuItemsChange$.next());
    }
    /** @hidden method for manually registering item when it's not visible for @ContentChildren */
    _registerItem(item) {
        this._registeredItems.push(item);
        this._menuItemsChange$.next();
    }
    /** @hidden method for manually unregistering item when it's not visible for @ContentChildren */
    _unregisterItem(item) {
        this._registeredItems = this._registeredItems.filter((i) => i !== item);
        this._menuItemsChange$.next();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SubmenuComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: SubmenuComponent, isStandalone: true, selector: "fd-submenu", inputs: { ariaLabel: "ariaLabel", ariaLabelledby: "ariaLabelledby" }, providers: [{ provide: SUBMENU, useExisting: SubmenuComponent }], queries: [{ propertyName: "_projectedItems", predicate: FD_MENU_ITEM_COMPONENT }], viewQueries: [{ propertyName: "templateRef", first: true, predicate: TemplateRef, descendants: true }], exportAs: ["fdSubmenu"], ngImport: i0, template: `
        <ng-template>
            <ng-content></ng-content>
        </ng-template>
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SubmenuComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-submenu',
                    template: `
        <ng-template>
            <ng-content></ng-content>
        </ng-template>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    providers: [{ provide: SUBMENU, useExisting: SubmenuComponent }],
                    exportAs: 'fdSubmenu',
                    standalone: true
                }]
        }], propDecorators: { ariaLabel: [{
                type: Input
            }], ariaLabelledby: [{
                type: Input
            }], templateRef: [{
                type: ViewChild,
                args: [TemplateRef]
            }], _projectedItems: [{
                type: ContentChildren,
                args: [FD_MENU_ITEM_COMPONENT]
            }] } });

class MenuShortcutDirective {
    /** @hidden */
    constructor(_menuItem, _elementRef) {
        this._menuItem = _menuItem;
        this._elementRef = _elementRef;
        /** Hide shortcuts in mobile mode */
        this.hideOnMobile = true;
        /** @hidden */
        this.fdMenuShortcutClass = true;
        /** @hidden */
        this._subscriptions = new Subscription();
    }
    /** @hidden */
    ngAfterViewInit() {
        this._hideOnMobile();
    }
    /** @hidden */
    ngOnDestroy() {
        this._subscriptions.unsubscribe();
    }
    /** @hidden */
    _hideOnMobile() {
        this._subscriptions.add(this._menuItem.menuService?.isMobileMode.pipe(filter(() => this.hideOnMobile)).subscribe((isMobile) => {
            if (isMobile) {
                this._elementRef.nativeElement.style.display = 'none';
            }
            else {
                this._elementRef.nativeElement.style.display = null;
            }
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuShortcutDirective, deps: [{ token: MenuItemComponent }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: MenuShortcutDirective, isStandalone: true, selector: "[fd-menu-shortcut]", inputs: { hideOnMobile: "hideOnMobile" }, host: { properties: { "class.fd-menu__shortcut": "this.fdMenuShortcutClass" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuShortcutDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-menu-shortcut]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: MenuItemComponent }, { type: i0.ElementRef }], propDecorators: { hideOnMobile: [{
                type: Input
            }], fdMenuShortcutClass: [{
                type: HostBinding,
                args: ['class.fd-menu__shortcut']
            }] } });

class MenuTriggerDirective {
    /** Set reference to Menu Component */
    set menu(menu) {
        this._unsubscribeFromMenu();
        if (menu) {
            menu.trigger = this._elementRef;
            this._subscribeToMenu(menu);
        }
        this._setAriaAttributes(menu);
    }
    /** @hidden */
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        /** @hidden */
        this._menuSubscription = new Subscription();
    }
    /** @hidden */
    ngOnDestroy() {
        this._unsubscribeFromMenu();
    }
    /** @hidden */
    _subscribeToMenu(menu) {
        this._menuSubscription.add(menu.isOpenChange.subscribe(() => {
            this._setAriaAttributes(menu);
        }));
    }
    /** @hidden */
    _unsubscribeFromMenu() {
        this._menuSubscription.unsubscribe();
        this._menuSubscription = new Subscription();
    }
    /** @hidden */
    _setAriaAttributes(menu) {
        this.ariaHasPopup = !!menu;
        this.ariaExpanded = menu?.isOpen;
        this.ariaControls = menu?.isOpen ? menu.id : null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuTriggerDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: MenuTriggerDirective, isStandalone: true, selector: "[fdMenuTrigger]", inputs: { menu: ["fdMenuTrigger", "menu"] }, host: { properties: { "attr.aria-haspopup": "this.ariaHasPopup", "attr.aria-controls": "this.ariaControls", "attr.aria-expanded": "this.ariaExpanded" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuTriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdMenuTrigger]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { menu: [{
                type: Input,
                args: ['fdMenuTrigger']
            }], ariaHasPopup: [{
                type: HostBinding,
                args: ['attr.aria-haspopup']
            }], ariaControls: [{
                type: HostBinding,
                args: ['attr.aria-controls']
            }], ariaExpanded: [{
                type: HostBinding,
                args: ['attr.aria-expanded']
            }] } });

const strictEquals = (a, b) => a === b;
class SegmentedButtonHeaderDirective {
    /** @hidden */
    constructor() {
        /** @hidden */
        this.valueComparator = strictEquals;
        /** @hidden */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this.menuItem = inject(FD_MENU_ITEM_COMPONENT, { host: true });
        /** @hidden */
        this._cvaControl = inject(CvaControl);
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._options$ = new BehaviorSubject([]);
        this.menuItem.hasSeparator = true;
    }
    /** @hidden */
    setOptions(options) {
        this._options$.next(options);
    }
    /** @hidden */
    ngAfterViewInit() {
        this._cvaControl.listenToChanges();
        combineLatest([this._options$, this._cvaControl.cvaDirective?.ngControl?.valueChanges || of(undefined)])
            .pipe(tap(([options, value]) => {
            options.forEach((option, index) => {
                option.menuItem.hasSeparator = index === options.length - 1;
                option.selected = this.valueComparator(option.value, value);
            });
        }), switchMap$1(([options]) => merge(...options.map((option) => option.clicked.pipe(map(() => option.value))))), tap((val) => this._cvaControl.cvaDirective?.setValue(val)), takeUntilDestroyed(this._destroyRef))
            .subscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SegmentedButtonHeaderDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: SegmentedButtonHeaderDirective, isStandalone: true, selector: "li[fd-menu-item][fdMenuSegmentedButtonHeader]", inputs: { valueComparator: "valueComparator" }, providers: [
            CvaControl,
            { provide: FD_FORM_FIELD_CONTROL, useExisting: SegmentedButtonHeaderDirective, multi: true }
        ], hostDirectives: [{ directive: i1.CvaDirective, inputs: ["id", "inputId", "stateMessage", "stateMessage", "disabled", "disabled", "readonly", "readonly", "name", "name"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SegmentedButtonHeaderDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'li[fd-menu-item][fdMenuSegmentedButtonHeader]',
                    standalone: true,
                    hostDirectives: [
                        {
                            directive: CvaDirective,
                            inputs: ['id:inputId', 'stateMessage', 'disabled', 'readonly', 'name']
                        }
                    ],
                    providers: [
                        CvaControl,
                        { provide: FD_FORM_FIELD_CONTROL, useExisting: SegmentedButtonHeaderDirective, multi: true }
                    ]
                }]
        }], ctorParameters: () => [], propDecorators: { valueComparator: [{
                type: Input
            }] } });

class SegmentedButtonOptionDirective {
    /** @hidden */
    constructor() {
        /** @hidden */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this.menuItem = inject(FD_MENU_ITEM_COMPONENT, { host: true });
        /** @hidden */
        this.renderer2 = inject(Renderer2);
        /** @hidden */
        this._clicked = new Subject();
        /** @hidden */
        this._viewInit$ = new Subject();
        /** @hidden */
        this._selected$ = new BehaviorSubject(false);
        this.clicked = this._clicked.asObservable();
        const ngZone = inject(NgZone);
        combineLatest([this._viewInit$.pipe(delayWhen(() => ngZone.onStable.asObservable())), this._selected$])
            .pipe(tap(() => {
            if (!this._dotElement) {
                this._createDot();
            }
        }), tap(([, selected]) => {
            selected ? this._showDot() : this._hideDot();
        }), takeUntilDestroyed())
            .subscribe();
    }
    /** @hidden */
    _onClick($event) {
        $event.preventDefault();
        this._clicked.next();
    }
    /** @hidden */
    ngAfterViewInit() {
        this._viewInit$.next();
    }
    /** @hidden */
    _createDot() {
        this._dotElement = this.renderer2.createElement('span');
        this.renderer2.appendChild(this.elementRef.nativeElement, this._dotElement);
        this.renderer2.addClass(this._dotElement, 'fd-menu__active-dot');
        this.renderer2.setAttribute(this._dotElement, 'role', 'presentation');
        this._hideDot();
        const addonDirective = this.menuItem.menuInteractive.startAddon;
        const addonGlyph = addonDirective._addonGlyph;
        addonGlyph.renderElement(new DomPortal(this._dotElement)).subscribe();
    }
    /** @hidden */
    _showDot() {
        this.renderer2.setAttribute(this._dotElement, 'aria-hidden', 'false');
        this.renderer2.setStyle(this._dotElement, 'display', 'inline-block');
    }
    /** @hidden */
    _hideDot() {
        this.renderer2.setAttribute(this._dotElement, 'aria-hidden', 'true');
        this.renderer2.setStyle(this._dotElement, 'display', 'none');
    }
    /** @hidden */
    set selected(isSelected) {
        this._selected$.next(isSelected);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SegmentedButtonOptionDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: SegmentedButtonOptionDirective, isStandalone: true, selector: "li[fd-menu-item][fdMenuSegmentedButtonOption]", inputs: { value: "value" }, host: { listeners: { "click": "_onClick($event)", "keydown.enter": "_onClick($event)", "keydown.space": "_onClick($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SegmentedButtonOptionDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'li[fd-menu-item][fdMenuSegmentedButtonOption]',
                    standalone: true
                }]
        }], ctorParameters: () => [], propDecorators: { value: [{
                type: Input
            }], _onClick: [{
                type: HostListener,
                args: ['click', ['$event']]
            }, {
                type: HostListener,
                args: ['keydown.enter', ['$event']]
            }, {
                type: HostListener,
                args: ['keydown.space', ['$event']]
            }] } });

class ToggleButtonDirective {
    constructor() {
        /** @hidden */
        this._cvaControl = inject(CvaControl);
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._interactiveItemComponent = inject(MenuInteractiveComponent, { host: true });
    }
    /**
     * Listen on interaction events that should cause the value update
     * */
    onClick() {
        this._cvaControl.cvaDirective?.setValue(!this._cvaControl.cvaDirective.value);
    }
    /** @hidden */
    ngAfterViewInit() {
        this._cvaControl.listenToChanges();
        this._cvaControl.cvaDirective?.ngControl?.valueChanges
            ?.pipe(tap((value) => {
            this._interactiveItemComponent.startAddon._addonGlyph.glyph = value ? 'accept' : undefined;
        }), takeUntilDestroyed(this._destroyRef))
            .subscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ToggleButtonDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: ToggleButtonDirective, isStandalone: true, selector: "button[fd-menu-interactive][toggle]", host: { listeners: { "click": "onClick($event)" } }, providers: [
            CvaControl,
            { provide: FD_FORM_FIELD_CONTROL, useExisting: ToggleButtonDirective, multi: true },
            { provide: TOGGLE_MENU_ITEM, useExisting: ToggleButtonDirective }
        ], hostDirectives: [{ directive: i1.CvaDirective, inputs: ["id", "inputId", "stateMessage", "stateMessage", "disabled", "disabled", "readonly", "readonly", "name", "name"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ToggleButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'button[fd-menu-interactive][toggle]',
                    standalone: true,
                    hostDirectives: [
                        {
                            directive: CvaDirective,
                            inputs: ['id:inputId', 'stateMessage', 'disabled', 'readonly', 'name']
                        }
                    ],
                    providers: [
                        CvaControl,
                        { provide: FD_FORM_FIELD_CONTROL, useExisting: ToggleButtonDirective, multi: true },
                        { provide: TOGGLE_MENU_ITEM, useExisting: ToggleButtonDirective }
                    ]
                }]
        }], propDecorators: { onClick: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

/**
 * @deprecated
 * Use `hasSeparator` input on a `fd-menu-item` instead.
 */
class MenuSeparatorDirective {
    /** @hidden */
    constructor() {
        /** @hidden */
        this.elementRef = inject(ElementRef);
        console.error('<fd-menu-separator> has been removed. Use `hasSeparator` input on a `fd-menu-item` instead.', this.elementRef.nativeElement);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuSeparatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: MenuSeparatorDirective, isStandalone: true, selector: "fd-menu-separator", host: { properties: { "style.display": "\"none\"" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuSeparatorDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: 'fd-menu-separator',
                    host: {
                        '[style.display]': '"none"'
                    },
                    standalone: true
                }]
        }], ctorParameters: () => [] });

class DefaultMenuItem {
}

const MENU_COMPONENT = new InjectionToken('MenuInterface');

class MenuMobileComponent extends MobileModeBase {
    /** @hidden */
    set _watch(_dialogBody) {
        if (_dialogBody) {
            this._menuService.addKeyboardSupport(_dialogBody.elementRef);
        }
    }
    /** @hidden */
    constructor(_menuService, _ngZone, _rtlService, menuComponent) {
        super(menuComponent, MobileModeControl.MENU);
        this._menuService = _menuService;
        this._ngZone = _ngZone;
        this._rtlService = _rtlService;
        /** Current menu title */
        this.title$ = signal('');
        /** Whether current menu level is submenu */
        this.isSubmenu$ = signal(false);
        /** @hidden External content */
        this.childContent = null;
        /** @hidden Currently rendered menu view */
        this.view$ = signal(null);
        /** @hidden Navigation icon name based on RTL */
        this.navigationIcon$ = computed(() => this._rtlService?.rtlSignal() ? 'navigation-right-arrow' : 'navigation-left-arrow');
    }
    /** @hidden */
    ngOnInit() {
        this._listenOnActivePathChange();
        this._listenOnMenuOpenChange();
    }
    /** Closes the Dialog and Menu component */
    close() {
        this.dialogRef.close();
        this._component.close();
    }
    /** Navigate back to parent level of submenu */
    backToParentLevel() {
        const menuItem = this._menuService.activeNodePath[this._menuService.activeNodePath.length - 1].item;
        this._menuService.setActive(false, menuItem);
        this._executeOnStable(() => {
            menuItem?.focus();
        });
    }
    /** @hidden Opens the Dialog */
    _openDialog() {
        this.dialogRef = this._dialogService.open(this.dialogTemplate, {
            mobile: true,
            disablePaddings: true,
            ...this.dialogConfig,
            escKeyCloseable: false,
            backdropClickCloseable: false,
            container: this._elementRef.nativeElement
        });
    }
    /** @hidden Listens on Active Path changes and updates mobile view */
    _listenOnActivePathChange() {
        const initialItemPath = this._menuService.activeNodePath
            .map((node) => node.item)
            .filter((v) => !!v);
        this._component.activePath
            .pipe(startWith(initialItemPath), takeUntilDestroyed(this._destroyRef))
            .subscribe((items) => this._setMenuView(items));
    }
    /**
     * @hidden
     * Executes a function when the zone is stable.
     */
    _executeOnStable(fn) {
        if (this._ngZone.isStable) {
            fn();
        }
        else {
            this._ngZone.onStable.pipe(take(1)).subscribe(fn);
        }
    }
    /** @hidden Sets menu view, title and isSubmenu flag */
    _setMenuView(items) {
        const lastItem = items[items.length - 1];
        this.isSubmenu$.set(!!items.length);
        this.title$.set(this._getDialogTitle(lastItem));
        this.view$.set(this._getMenuView(lastItem));
        this._executeOnStable(() => {
            this._menuService.focusedNode?.item?.focus();
        });
    }
    /** @hidden Opens/closes the Dialog based on Menu isOpenChange events */
    _listenOnMenuOpenChange() {
        this._component.isOpenChange
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe((isOpen) => (isOpen ? this._openDialog() : this.dialogRef.close()));
    }
    /** @hidden Returns dialog title */
    _getDialogTitle(menuItem) {
        if (this.isSubmenu$()) {
            return menuItem.menuItemTitle ? menuItem.menuItemTitle.title : '';
        }
        return this.mobileConfig.title || '';
    }
    /** @hidden Returns dialog content view */
    _getMenuView(menuItem) {
        if (this.isSubmenu$()) {
            return menuItem.submenu ? menuItem.submenu.templateRef : this.view$();
        }
        return this.childContent;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuMobileComponent, deps: [{ token: MenuService }, { token: i0.NgZone }, { token: i2$1.RtlService, optional: true }, { token: MENU_COMPONENT }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: MenuMobileComponent, isStandalone: true, selector: "fd-menu-mobile", viewQueries: [{ propertyName: "dialogTemplate", first: true, predicate: ["dialogTemplate"], descendants: true }, { propertyName: "_watch", first: true, predicate: DialogBodyComponent, descendants: true }], usesInheritance: true, ngImport: i0, template: "<ng-template [fdDialogTemplate] let-dialog let-dialogConfig=\"dialogConfig\" #dialogTemplate>\n    <fd-dialog [dialogConfig]=\"dialogConfig\" [dialogRef]=\"dialog\">\n        <fd-dialog-header>\n            <ng-template fdkTemplate=\"header\">\n                <div fd-bar-left>\n                    @if (isSubmenu$()) {\n                        <fd-bar-element>\n                            <button\n                                fd-button\n                                fdType=\"transparent\"\n                                id=\"menu-mobile-navigate-back\"\n                                fdCozy\n                                [attr.aria-label]=\"'Go to previous menu level: ' + title$()\"\n                                [glyph]=\"navigationIcon$()\"\n                                (click)=\"backToParentLevel()\"\n                            ></button>\n                        </fd-bar-element>\n                    }\n                    <fd-bar-element>\n                        <h1 fd-title>{{ title$() }}</h1>\n                    </fd-bar-element>\n                </div>\n                <div fd-bar-right>\n                    <fd-bar-element>\n                        @if (this.mobileConfig.hasCloseButton) {\n                            <button fd-dialog-close-button [mobile]=\"true\" (click)=\"close()\"></button>\n                        }\n                    </fd-bar-element>\n                </div>\n            </ng-template>\n        </fd-dialog-header>\n        <fd-dialog-body>\n            <ng-template [ngTemplateOutlet]=\"(isSubmenu$() ? subMenuTemplate : view$()) || null\"> </ng-template>\n        </fd-dialog-body>\n        @if (mobileConfig.approveButtonText || mobileConfig.cancelButtonText) {\n            <fd-dialog-footer>\n                @if (mobileConfig.approveButtonText) {\n                    <fd-button-bar fdType=\"emphasized\" [label]=\"mobileConfig.approveButtonText\" (click)=\"close()\">\n                    </fd-button-bar>\n                }\n                @if (mobileConfig.cancelButtonText) {\n                    <fd-button-bar fdkInitialFocus [label]=\"mobileConfig.cancelButtonText\" (click)=\"close()\">\n                    </fd-button-bar>\n                }\n            </fd-dialog-footer>\n        }\n    </fd-dialog>\n</ng-template>\n<ng-template #subMenuTemplate>\n    <nav class=\"fd-menu fd-menu--mobile\">\n        <ul class=\"fd-menu__sublist\">\n            <ng-template [ngTemplateOutlet]=\"view$()\"></ng-template>\n        </ul>\n    </nav>\n</ng-template>\n", dependencies: [{ kind: "ngmodule", type: TemplateModule }, { kind: "directive", type: i2$1.TemplateDirective, selector: "[fdkTemplate]", inputs: ["fdkTemplate"] }, { kind: "directive", type: BarLeftDirective, selector: "[fd-bar-left]" }, { kind: "directive", type: BarRightDirective, selector: "[fd-bar-right]" }, { kind: "directive", type: BarElementDirective, selector: "fd-bar-element", inputs: ["fullWidth"] }, { kind: "component", type: ButtonBarComponent, selector: "fd-button-bar", inputs: ["fullWidth", "fdType", "title", "ariaLabelledby", "id"] }, { kind: "component", type: TitleComponent, selector: "[fd-title], [fdTitle]", inputs: ["headerSize", "wrap"], exportAs: ["fd-title"] }, { kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "directive", type: ContentDensityDirective, selector: "[fdContentDensity]:not([fdCompact]):not([fdCondensed]):not([fdCozy]),                [fdCompact]:not([fdContentDensity]):not([fdCondensed]):not([fdCozy]),                [fdCondensed]:not([fdContentDensity]):not([fdCompact]):not([fdCozy]),                [fdCozy]:not([fdContentDensity]):not([fdCompact]):not([fdCondensed])", inputs: ["fdContentDensity", "fdCompact", "fdCondensed", "fdCozy"], exportAs: ["fdContentDensity"] }, { kind: "ngmodule", type: TitleModule }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: InitialFocusDirective, selector: "[fdkInitialFocus]", inputs: ["fdkInitialFocus", "enabled", "focusLastElement"] }, { kind: "component", type: DialogComponent, selector: "fd-dialog", inputs: ["class", "dialogRef", "dialogConfig"] }, { kind: "component", type: DialogBodyComponent, selector: "fd-dialog-body", inputs: ["disablePaddings"] }, { kind: "component", type: DialogHeaderComponent, selector: "fd-dialog-header" }, { kind: "component", type: DialogCloseButtonComponent, selector: "[fd-dialog-close-button]", inputs: ["mobile", "title", "ariaLabel"] }, { kind: "component", type: DialogFooterComponent, selector: "fd-dialog-footer" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuMobileComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-menu-mobile', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, imports: [
                        TemplateModule,
                        BarLeftDirective,
                        BarRightDirective,
                        BarElementDirective,
                        ButtonBarComponent,
                        TitleComponent,
                        TemplateDirective,
                        BarLeftDirective,
                        BarRightDirective,
                        BarElementDirective,
                        ButtonBarComponent,
                        ButtonComponent,
                        ContentDensityDirective,
                        TitleModule,
                        NgTemplateOutlet,
                        InitialFocusDirective,
                        DialogComponent,
                        DialogBodyComponent,
                        DialogHeaderComponent,
                        DialogCloseButtonComponent,
                        DialogFooterComponent
                    ], template: "<ng-template [fdDialogTemplate] let-dialog let-dialogConfig=\"dialogConfig\" #dialogTemplate>\n    <fd-dialog [dialogConfig]=\"dialogConfig\" [dialogRef]=\"dialog\">\n        <fd-dialog-header>\n            <ng-template fdkTemplate=\"header\">\n                <div fd-bar-left>\n                    @if (isSubmenu$()) {\n                        <fd-bar-element>\n                            <button\n                                fd-button\n                                fdType=\"transparent\"\n                                id=\"menu-mobile-navigate-back\"\n                                fdCozy\n                                [attr.aria-label]=\"'Go to previous menu level: ' + title$()\"\n                                [glyph]=\"navigationIcon$()\"\n                                (click)=\"backToParentLevel()\"\n                            ></button>\n                        </fd-bar-element>\n                    }\n                    <fd-bar-element>\n                        <h1 fd-title>{{ title$() }}</h1>\n                    </fd-bar-element>\n                </div>\n                <div fd-bar-right>\n                    <fd-bar-element>\n                        @if (this.mobileConfig.hasCloseButton) {\n                            <button fd-dialog-close-button [mobile]=\"true\" (click)=\"close()\"></button>\n                        }\n                    </fd-bar-element>\n                </div>\n            </ng-template>\n        </fd-dialog-header>\n        <fd-dialog-body>\n            <ng-template [ngTemplateOutlet]=\"(isSubmenu$() ? subMenuTemplate : view$()) || null\"> </ng-template>\n        </fd-dialog-body>\n        @if (mobileConfig.approveButtonText || mobileConfig.cancelButtonText) {\n            <fd-dialog-footer>\n                @if (mobileConfig.approveButtonText) {\n                    <fd-button-bar fdType=\"emphasized\" [label]=\"mobileConfig.approveButtonText\" (click)=\"close()\">\n                    </fd-button-bar>\n                }\n                @if (mobileConfig.cancelButtonText) {\n                    <fd-button-bar fdkInitialFocus [label]=\"mobileConfig.cancelButtonText\" (click)=\"close()\">\n                    </fd-button-bar>\n                }\n            </fd-dialog-footer>\n        }\n    </fd-dialog>\n</ng-template>\n<ng-template #subMenuTemplate>\n    <nav class=\"fd-menu fd-menu--mobile\">\n        <ul class=\"fd-menu__sublist\">\n            <ng-template [ngTemplateOutlet]=\"view$()\"></ng-template>\n        </ul>\n    </nav>\n</ng-template>\n" }]
        }], ctorParameters: () => [{ type: MenuService }, { type: i0.NgZone }, { type: i2$1.RtlService, decorators: [{
                    type: Optional
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MENU_COMPONENT]
                }] }], propDecorators: { dialogTemplate: [{
                type: ViewChild,
                args: ['dialogTemplate']
            }], _watch: [{
                type: ViewChild,
                args: [DialogBodyComponent]
            }] } });

let menuUniqueId = 0;
/**
 * The component that represents a menu.
 */
class MenuComponent extends BasePopoverClass {
    /** Set menu in mobile mode */
    set mobile(value) {
        this._mobile = value;
        this._menuService.setMenuMode(this.mobile);
    }
    get mobile() {
        return this._mobile;
    }
    /** @hidden */
    get hasAddons() {
        return this._addons.size > 0;
    }
    /** @hidden */
    get _popoverConfig() {
        return {
            ...this,
            additionalBodyClass: (this.additionalBodyClass ?? '') + ' fd-popover--menu'
        };
    }
    /** @hidden */
    constructor(elementRef, dialogConfig, _rendered, _menuService, _changeDetectorRef, _popoverService, _injector, _viewContainerRef, _dynamicComponentService, _contentDensityObserver) {
        super();
        this.elementRef = elementRef;
        this.dialogConfig = dialogConfig;
        this._rendered = _rendered;
        this._menuService = _menuService;
        this._changeDetectorRef = _changeDetectorRef;
        this._popoverService = _popoverService;
        this._injector = _injector;
        this._viewContainerRef = _viewContainerRef;
        this._dynamicComponentService = _dynamicComponentService;
        this._contentDensityObserver = _contentDensityObserver;
        /** Whether the popover is disabled. */
        this.disabled = false;
        /** Whether the popover should be focusTrapped. */
        this.focusTrapped = true;
        /**
         * Whether the popover should automatically move focus into the trapped region upon
         * initialization and return focus to the previous activeElement upon destruction.
         */
        this.focusAutoCapture = true;
        /** Open submenu on hover after given milliseconds */
        this.openOnHoverTime = 0;
        /** Display menu without integrated popover */
        this.mobileConfig = { cancelButtonText: 'Cancel' };
        /** Id of the control. */
        this.id = `fd-menu-${menuUniqueId++}`;
        /** Emits array of active menu items */
        this.activePath = new EventEmitter();
        /** @hidden */
        this._navContainerRole = 'menu';
        /** @hidden */
        this._menuListContainerRole = 'none';
        /** @hidden Whether use a menu in mobile mode */
        this._mobile = false;
        /** @hidden */
        this._addons = new Set();
        /** @hidden */
        this._subscriptions = new Subscription();
    }
    /** @hidden */
    ngOnInit() {
        /** keep isOpen up to date */
        this.isOpenChange.subscribe((isOpen) => {
            this.isOpen = isOpen;
            // when popover got closed by its own mechanism (e.x. click outside)
            // we need to clean up a menu as well
            if (!isOpen) {
                this._cleanUpMenuAfterClose();
            }
            this._changeDetectorRef.markForCheck();
        });
    }
    /** Register addon */
    registerAddon(addon) {
        this._addons.add(addon);
        this._changeDetectorRef.markForCheck();
    }
    /** Unregister addon */
    unregisterAddon(addon) {
        this._addons.delete(addon);
        this._changeDetectorRef.markForCheck();
    }
    /** @hidden */
    ngAfterContentInit() {
        this._menuService.setMenuComponent(this);
        this._listenOnMenuItemsChange();
    }
    /** @hidden */
    ngAfterViewInit() {
        this._menuService.isMobileMode.subscribe((isMobile) => {
            this._setupView();
            // Since it is mobile, it's needed to disable popoverService
            if (isMobile) {
                this._popoverService.deactivate();
            }
        });
        this._menuService.setMenuMode(this.mobile);
        combineLatest([
            this._menuItems.changes.pipe(startWith$1(this._menuItems), map((items) => items.toArray())),
            this._segmentedButtonHeaderItems.changes.pipe(startWith$1(this._segmentedButtonHeaderItems), map((items) => items.toArray())),
            this._segmentedButtonOptions.changes.pipe(startWith$1(this._segmentedButtonOptions), map((items) => items.toArray()))
        ])
            .pipe(map(([menuItems, segmentedButtonHeaderItems, segmentedButtonOptions]) => menuItems.map((item, index) => ({
            menuItem: item,
            segmentedButtonHeaderItem: segmentedButtonHeaderItems.find((headerItem) => headerItem.elementRef.nativeElement === item.elementRef.nativeElement),
            segmentedButtonOption: segmentedButtonOptions.find((option) => option.elementRef.nativeElement === item.elementRef.nativeElement),
            index
        }))), map((items) => {
            let headers = items.filter((item) => !!item.segmentedButtonHeaderItem);
            const options = items.filter((item) => !!item.segmentedButtonOption);
            headers = headers.map((header, headerIndex) => ({
                ...header,
                options: options.reduce((acc, option) => {
                    const lastOption = acc[acc.length - 1];
                    const optionIndex = option.index;
                    if (!lastOption || optionIndex === lastOption.index + 1) {
                        if (headerIndex === headers.length - 1 && optionIndex > header.index) {
                            acc.push(option);
                        }
                        else if (optionIndex > header.index && optionIndex < headers[headerIndex + 1].index) {
                            acc.push(option);
                        }
                    }
                    return acc;
                }, [])
            }));
            return headers;
        }), tap((headers) => headers.forEach(({ segmentedButtonHeaderItem, options }) => {
            segmentedButtonHeaderItem.setOptions(options.map((option) => option.segmentedButtonOption));
        })))
            .subscribe();
    }
    /** @hidden */
    ngOnDestroy() {
        this._destroyMobileComponent();
        this._destroyEventListeners();
        this._subscriptions.unsubscribe();
    }
    /** @hidden */
    set trigger(trigger) {
        this._externalTrigger = trigger;
        this._popoverService.initialise(this._externalTrigger);
        this._destroyEventListeners();
        this._listenOnTriggerRefClicks();
    }
    get trigger() {
        return this._externalTrigger;
    }
    /** Opens the menu */
    open() {
        if (this.mobile) {
            this.isOpen = true;
            this.isOpenChange.emit(this.isOpen);
        }
        else {
            this._popoverService.open();
        }
        this._changeDetectorRef.markForCheck();
    }
    /** Closes the menu */
    close() {
        if (this.mobile) {
            this.isOpen = false;
            this.isOpenChange.emit(this.isOpen);
        }
        else {
            this._popoverService.close();
        }
        this._cleanUpMenuAfterClose();
        this._focusTrigger();
        this._changeDetectorRef.markForCheck();
    }
    /** Toggles menu open/close state */
    toggle() {
        this.isOpen ? this.close() : this.open();
    }
    /** Method called to refresh position of opened popover */
    refreshPosition() {
        this._popoverService.refreshPosition();
    }
    /** @hidden */
    detectChanges() {
        this._changeDetectorRef.detectChanges();
    }
    /** @hidden */
    _cleanUpMenuAfterClose() {
        this._menuService.resetMenuState();
    }
    /** @hidden Select and instantiate menu view mode */
    _setupView() {
        if (this.mobile) {
            this._setupMobileMode();
        }
        else {
            this._setupPopoverService();
        }
        this.detectChanges();
    }
    /** @hidden */
    _setupPopoverService() {
        this._subscriptions.add(this._popoverService._onLoad.subscribe((elementRef) => this._menuService.addKeyboardSupport(elementRef)));
        this._popoverService.templateContent = this._menuRootTemplate;
        this._popoverService.initialise(this._externalTrigger, this._popoverConfig);
    }
    /** @hidden Open Menu in mobile mode */
    async _setupMobileMode() {
        const injector = Injector.create({
            providers: [{ provide: MENU_COMPONENT, useValue: this }],
            parent: this._injector
        });
        this._mobileModeComponentRef = this._dynamicComponentService.createDynamicComponent(this._menuRootTemplate, MenuMobileComponent, {
            containerRef: this._viewContainerRef
        }, { injector });
        this._listenOnTriggerRefClicks();
    }
    /** @hidden Listen on menu items change and rebuild menu */
    _listenOnMenuItemsChange() {
        this._subscriptions.add(this._menuItems.changes.subscribe(() => this._menuService.rebuildMenu()));
        // Whether menu have submenu or not.
        let isSubmenu = false;
        this._menuItems.forEach((menuItem) => {
            if (menuItem.submenu?.menuItems) {
                isSubmenu = true;
                this._subscriptions.add(menuItem.submenu._menuItemsChange$.subscribe(() => this._menuService.rebuildMenu()));
            }
        });
        if (!this.disableScrollbar && isSubmenu) {
            this.disableScrollbar = isSubmenu;
        }
    }
    /**
     * @hidden
     * This is going to be removed in feature, on dialog and dynamic service component refactor
     */
    _listenOnTriggerRefClicks() {
        this._destroyEventListeners();
        if (this.trigger && this.mobile) {
            this._clickEventListener = this._rendered.listen(this.trigger.nativeElement, 'click', () => this.toggle());
        }
    }
    /**
     * @hidden
     * This is going to be removed in feature, on dialog and dynamic service component refactor
     */
    _destroyEventListeners() {
        if (this._clickEventListener) {
            this._clickEventListener();
            this._clickEventListener = null;
        }
    }
    /** @hidden */
    _destroyMobileComponent() {
        if (this._mobileModeComponentRef) {
            this._mobileModeComponentRef.destroy();
        }
    }
    /** @hidden */
    _focusTrigger() {
        if (this.focusTrapped && this.trigger) {
            this.trigger.nativeElement.focus();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuComponent, deps: [{ token: i0.ElementRef }, { token: i1$1.DialogConfig, optional: true }, { token: i0.Renderer2 }, { token: MenuService }, { token: i0.ChangeDetectorRef }, { token: i3.PopoverService }, { token: i0.Injector }, { token: i0.ViewContainerRef }, { token: i2$1.DynamicComponentService, optional: true }, { token: i5.ContentDensityObserver }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "16.1.0", version: "20.0.2", type: MenuComponent, isStandalone: true, selector: "fd-menu", inputs: { mobile: ["mobile", "mobile", booleanAttribute], disabled: "disabled", focusTrapped: "focusTrapped", focusAutoCapture: "focusAutoCapture", openOnHoverTime: "openOnHoverTime", mobileConfig: "mobileConfig", ariaLabel: "ariaLabel", ariaLabelledby: "ariaLabelledby", id: "id" }, outputs: { activePath: "activePath" }, providers: [
            MenuService,
            PopoverService,
            DynamicComponentService,
            {
                provide: FD_MENU_COMPONENT,
                useExisting: forwardRef(() => MenuComponent)
            },
            contentDensityObserverProviders()
        ], queries: [{ propertyName: "_menuItems", predicate: FD_MENU_ITEM_COMPONENT }, { propertyName: "_segmentedButtonHeaderItems", predicate: SegmentedButtonHeaderDirective }, { propertyName: "_segmentedButtonOptions", predicate: SegmentedButtonOptionDirective }], viewQueries: [{ propertyName: "_menuRootTemplate", first: true, predicate: ["menuRootTemplate"], descendants: true }], usesInheritance: true, ngImport: i0, template: "<ng-container #viewContainer></ng-container>\n\n<ng-template #menuRootTemplate>\n    <div class=\"fd-popover__wrapper--visible\">\n        <nav\n            class=\"fd-menu\"\n            [id]=\"id\"\n            [attr.aria-labelledby]=\"ariaLabelledby\"\n            [attr.aria-label]=\"ariaLabel\"\n            [attr.role]=\"_navContainerRole\"\n            [class.fd-menu--mobile]=\"mobile\"\n            [class.fd-menu--icons]=\"hasAddons\"\n        >\n            <ul\n                [attr.role]=\"_menuListContainerRole\"\n                class=\"fd-menu__list fd-menu__list--no-shadow\"\n                [class.fd-menu--full-width]=\"mobile || false\"\n            >\n                <ng-content></ng-content>\n            </ul>\n        </nav>\n    </div>\n</ng-template>\n", styles: [".fd-dialog__body{--fdButton_Menu_Border_Radius:0}.fd-menu{--fdMenu_Icon_Width:2.25rem;--fdMenu_Link_Height:2.75rem;--fdMenu_Item_Spacing_Left:.75rem;--fdMenu_Item_Spacing_Right:.75rem;--fdMenu_Item_Border_Bottom_Color:transparent;--fdMenu_Shortcut_Padding_Left:1rem;--fdMenu_Shortcut_Padding_Right:.75rem;--fdMenu_Text_Spacing_Right:.75rem;--fdMenu_Icon_Color:var(--sapContent_NonInteractiveIconColor);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Regular);--fdMenu_Text_Color:var(--sapList_TextColor);--fdMenu_Item_Background_Color:var(--sapList_Background);--fdMenu_Active_Dot_Size:.75rem;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}.fd-menu:after,.fd-menu:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__list,.fd-menu__sublist{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;border-radius:var(--fdButton_Menu_Border_Radius);-webkit-box-shadow:var(--sapContent_Shadow1);box-shadow:var(--sapContent_Shadow1);-ms-flex-direction:column;flex-direction:column;-ms-flex-wrap:wrap;flex-wrap:wrap;list-style:none;max-width:20rem}.fd-menu__list:after,.fd-menu__list:before,.fd-menu__sublist:after,.fd-menu__sublist:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__list--no-shadow,.fd-menu__sublist--no-shadow{-webkit-box-shadow:none;box-shadow:none}.fd-menu__sublist{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;left:100%;line-height:normal;margin-block:0;margin-block:.25rem 0;margin-inline:0;margin-inline:-.25rem 0;min-width:100%;padding-block:0;padding-inline:0;position:absolute;top:0;z-index:2}.fd-menu__sublist:after,.fd-menu__sublist:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__sublist[dir=rtl],[dir=rtl] .fd-menu__sublist{left:auto;right:100%}.fd-menu__sublist[aria-hidden=true]{display:none}.fd-menu__list>.fd-menu__item{position:relative;width:100%}.fd-menu__list--overflow{-ms-flex-wrap:nowrap;flex-wrap:nowrap;overflow-y:scroll;scrollbar-color:var(--fdScrollbar_Thumb_Color) var(--fdScrollbar_Track_Color)}.fd-menu__list--overflow.is-focus,.fd-menu__list--overflow:focus{outline:none;z-index:5}.fd-menu__list--overflow::-webkit-scrollbar{height:var(--fdScrollbar_Dimension);width:var(--fdScrollbar_Dimension)}.fd-menu__list--overflow::-webkit-scrollbar-corner,.fd-menu__list--overflow::-webkit-scrollbar-track{background-color:var(--fdScrollbar_Track_Color)}.fd-menu__list--overflow::-webkit-scrollbar-thumb{background-color:transparent;border:var(--fdScrollbar_Thumb_Offset) solid transparent;border-radius:calc(var(--fdScrollbar_Thumb_Border_Radius) - var(--fdScrollbar_Thumb_Offset));-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color)}.fd-menu__list--overflow::-webkit-scrollbar-thumb:active,.fd-menu__list--overflow::-webkit-scrollbar-thumb:hover{-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color)}.fd-menu__list--overflow::-webkit-scrollbar-corner,.fd-menu__list--overflow::-webkit-scrollbar-track{border-radius:0 var(--fdScrollbar_Border_Radius) var(--fdScrollbar_Border_Radius) 0}.fd-menu__list--overflow[dir=rtl]::-webkit-scrollbar-corner,.fd-menu__list--overflow[dir=rtl]::-webkit-scrollbar-track,[dir=rtl] .fd-menu__list--overflow::-webkit-scrollbar-corner,[dir=rtl] .fd-menu__list--overflow::-webkit-scrollbar-track{border-radius:var(--fdScrollbar_Border_Radius) 0 0 var(--fdScrollbar_Border_Radius)}.fd-menu__separator{background-color:var(--sapGroup_ContentBorderColor);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:.0625rem;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%}.fd-menu__separator:after,.fd-menu__separator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__item{background-color:var(--sapList_Background);border:0;border-radius:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;padding-block:0;padding-inline:0;position:relative}.fd-menu__item:after,.fd-menu__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__item:first-child,.fd-menu__item:first-child .fd-menu__link:after{border-top-left-radius:var(--fdButton_Menu_Border_Radius);border-top-right-radius:var(--fdButton_Menu_Border_Radius)}.fd-menu__item:last-of-type,.fd-menu__item:last-of-type .fd-menu__link:after{border-bottom-left-radius:var(--fdButton_Menu_Border_Radius);border-bottom-right-radius:var(--fdButton_Menu_Border_Radius)}.fd-menu__item.has-separator{border-bottom:.0625rem solid var(--sapGroup_ContentBorderColor)}.fd-menu__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);cursor:pointer;display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdMenu_Item_Background_Color);border-bottom:.0625rem solid var(--fdMenu_Item_Border_Bottom_Color);border-radius:inherit;height:var(--fdMenu_Link_Height);outline:none;padding-inline:var(--fdMenu_Item_Spacing_Left) var(--fdMenu_Item_Spacing_Right);text-decoration:none;width:100%}.fd-menu__link:after,.fd-menu__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__link.is-focus:after,.fd-menu__link:focus:after{border-color:var(--sapContent_FocusColor);border-radius:0!important;border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:.125rem;pointer-events:none;position:absolute}.fd-menu__link.is-hover,.fd-menu__link:hover{--fdMenu_Item_Background_Color:var(--sapList_Hover_Background)}.fd-menu__link.is-selected,.fd-menu__link[aria-selected=true]{--fdMenu_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdMenu_Icon_Color:var(--sapContent_NonInteractiveIconColor);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Selected);--fdMenu_Text_Color:var(--sapList_TextColor);--fdMenu_Item_Border_Bottom_Color:var(--sapList_SelectionBorderColor)}.fd-menu__link.is-selected.is-hover:not(:active,.is-active),.fd-menu__link.is-selected:hover:not(:active,.is-active),.fd-menu__link[aria-selected=true].is-hover:not(:active,.is-active),.fd-menu__link[aria-selected=true]:hover:not(:active,.is-active){--fdMenu_Item_Background_Color:var(--sapList_Hover_SelectionBackground);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Selected_Hover)}.fd-menu__link.is-selected.is-focus,.fd-menu__link.is-selected:focus,.fd-menu__link[aria-selected=true].is-focus,.fd-menu__link[aria-selected=true]:focus{z-index:5}.fd-menu__link.is-selected.is-focus:after,.fd-menu__link.is-selected:focus:after,.fd-menu__link[aria-selected=true].is-focus:after,.fd-menu__link[aria-selected=true]:focus:after{bottom:.125rem}.fd-menu__link.is-active,.fd-menu__link:active{--fdMenu_Item_Background_Color:var(--sapList_Active_Background);--fdMenu_Icon_Color:var(--sapList_Active_TextColor);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Active);--fdMenu_Text_Color:var(--fdMenu_Text_Color_Active)}.fd-menu__link.is-active:after,.fd-menu__link:active:after{display:none}.fd-menu__link.is-active.is-focus,.fd-menu__link.is-active:focus,.fd-menu__link:active.is-focus,.fd-menu__link:active:focus{outline-color:var(--fdMenu_Active_State_Focus);z-index:5}.fd-menu__link.is-disabled,.fd-menu__link:disabled,.fd-menu__link[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-menu__link.is-disabled.is-focus,.fd-menu__link.is-disabled:focus,.fd-menu__link:disabled.is-focus,.fd-menu__link:disabled:focus,.fd-menu__link[aria-disabled=true].is-focus,.fd-menu__link[aria-disabled=true]:focus{z-index:5}.fd-menu__link.is-disabled.is-focus:after,.fd-menu__link.is-disabled:focus:after,.fd-menu__link:disabled.is-focus:after,.fd-menu__link:disabled:focus:after,.fd-menu__link[aria-disabled=true].is-focus:after,.fd-menu__link[aria-disabled=true]:focus:after{display:none}.fd-menu__link.has-child{--fdMenu_Item_Spacing_Right:0}.fd-menu__link.has-child.is-expanded:not(:active,.is-active),.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active){--fdMenu_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdMenu_Icon_Color:var(--sapContent_NonInteractiveIconColor);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Selected);--fdMenu_Text_Color:var(--sapList_TextColor);--fdMenu_Item_Border_Bottom_Color:var(--sapList_SelectionBorderColor)}.fd-menu__link.has-child.is-expanded:not(:active,.is-active).is-hover:not(:active,.is-active),.fd-menu__link.has-child.is-expanded:not(:active,.is-active):hover:not(:active,.is-active),.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active).is-hover:not(:active,.is-active),.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active):hover:not(:active,.is-active){--fdMenu_Item_Background_Color:var(--sapList_Hover_SelectionBackground);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Selected_Hover)}.fd-menu__link.has-child.is-expanded:not(:active,.is-active).is-focus,.fd-menu__link.has-child.is-expanded:not(:active,.is-active):focus,.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active).is-focus,.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active):focus{z-index:5}.fd-menu__link.has-child.is-expanded:not(:active,.is-active).is-focus:after,.fd-menu__link.has-child.is-expanded:not(:active,.is-active):focus:after,.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active).is-focus:after,.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active):focus:after{bottom:.125rem}.fd-menu__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdMenu_Text_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-align:left;text-overflow:ellipsis;text-shadow:var(--fdMenu_Text_Shadow);white-space:nowrap;width:100%}.fd-menu__title:after,.fd-menu__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__title[dir=rtl],[dir=rtl] .fd-menu__title{text-align:right}.fd-menu__title:has(+.fd-menu__input){min-width:-webkit-fit-content;min-width:-moz-fit-content;min-width:fit-content;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}.fd-menu__addon-after,.fd-menu__addon-before{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:transparent;color:var(--fdMenu_Icon_Color);font-size:var(--sapFontLargeSize);height:100%;max-width:var(--fdMenu_Icon_Width);min-width:var(--fdMenu_Icon_Width);text-shadow:var(--fdMenu_Text_Shadow);width:var(--fdMenu_Icon_Width)}.fd-menu__addon-after:after,.fd-menu__addon-after:before,.fd-menu__addon-before:after,.fd-menu__addon-before:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__addon-after [class*=sap-icon],.fd-menu__addon-after[class*=sap-icon],.fd-menu__addon-before [class*=sap-icon],.fd-menu__addon-before[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-menu__addon-after--submenu{font-size:var(--fdMenu_Affordance_Arrow_Size)}.fd-menu__addon-after--submenu:before{content:\"\\e066\"}.fd-menu__addon-after--submenu:before,.fd-menu__addon-after--submenu[dir=rtl]:before,[dir=rtl] .fd-menu__addon-after--submenu:before{font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-menu__addon-after--submenu[dir=rtl]:before,[dir=rtl] .fd-menu__addon-after--submenu:before{content:\"\\e067\"}.fd-menu__active-dot{background:var(--sapContent_Selected_ForegroundColor);border:0;border-radius:100%;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdMenu_Active_Dot_Size);line-height:normal;margin-block:0;margin-inline:0;min-width:var(--fdMenu_Active_Dot_Size);padding-block:0;padding-inline:0;width:var(--fdMenu_Active_Dot_Size)}.fd-menu__active-dot:after,.fd-menu__active-dot:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__checkmark [class*=sap-icon],.fd-menu__checkmark[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;color:var(--sapContent_Selected_ForegroundColor);font-size:inherit;font-size:1rem;line-height:1}.fd-menu__shortcut{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-ms-flex-negative:0;color:var(--fdMenu_Shortcut_Color);flex-shrink:0;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;-webkit-padding-start:var(--fdMenu_Shortcut_Padding_Left);padding-inline-start:var(--fdMenu_Shortcut_Padding_Left)}.fd-menu__shortcut:after,.fd-menu__shortcut:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__shortcut:last-child{padding-inline:var(--fdMenu_Shortcut_Padding_Left) var(--fdMenu_Shortcut_Padding_Right)}.fd-menu--overflow{border-radius:var(--fdButton_Menu_Border_Radius);-webkit-box-shadow:var(--sapContent_Shadow1);box-shadow:var(--sapContent_Shadow1);overflow-y:scroll;scrollbar-color:var(--fdScrollbar_Thumb_Color) var(--fdScrollbar_Track_Color)}.fd-menu--overflow.is-focus,.fd-menu--overflow:focus{outline:none;z-index:5}.fd-menu--overflow::-webkit-scrollbar{height:var(--fdScrollbar_Dimension);width:var(--fdScrollbar_Dimension)}.fd-menu--overflow::-webkit-scrollbar-corner,.fd-menu--overflow::-webkit-scrollbar-track{background-color:var(--fdScrollbar_Track_Color)}.fd-menu--overflow::-webkit-scrollbar-thumb{background-color:transparent;border:var(--fdScrollbar_Thumb_Offset) solid transparent;border-radius:calc(var(--fdScrollbar_Thumb_Border_Radius) - var(--fdScrollbar_Thumb_Offset));-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color)}.fd-menu--overflow::-webkit-scrollbar-thumb:active,.fd-menu--overflow::-webkit-scrollbar-thumb:hover{-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color)}.fd-menu--overflow::-webkit-scrollbar-corner,.fd-menu--overflow::-webkit-scrollbar-track{border-radius:0 var(--fdScrollbar_Border_Radius) var(--fdScrollbar_Border_Radius) 0}.fd-menu--overflow[dir=rtl]::-webkit-scrollbar-corner,.fd-menu--overflow[dir=rtl]::-webkit-scrollbar-track,[dir=rtl] .fd-menu--overflow::-webkit-scrollbar-corner,[dir=rtl] .fd-menu--overflow::-webkit-scrollbar-track{border-radius:var(--fdScrollbar_Border_Radius) 0 0 var(--fdScrollbar_Border_Radius)}.fd-menu--overflow .fd-menu__list{-webkit-box-shadow:none;box-shadow:none}.fd-menu--overflow .fd-menu__item:first-child{border-top-right-radius:0}.fd-menu--overflow .fd-menu__item:first-child[dir=rtl],[dir=rtl] .fd-menu--overflow .fd-menu__item:first-child{border-top-left-radius:0;border-top-right-radius:var(--fdButton_Menu_Border_Radius)}.fd-menu--overflow .fd-menu__item:last-of-type{border-bottom-right-radius:0}.fd-menu--overflow .fd-menu__item:last-of-type[dir=rtl],[dir=rtl] .fd-menu--overflow .fd-menu__item:last-of-type{border-bottom-left-radius:0;border-bottom-right-radius:var(--fdButton_Menu_Border_Radius)}.fd-menu--full-width{max-width:100%}.fd-menu--icons{--fdMenu_Item_Spacing_Left:0;--fdMenu_Item_Spacing_Right:0}.fd-menu--icons .fd-menu__title:first-child{-webkit-margin-start:var(--fdMenu_Icon_Width);margin-inline-start:var(--fdMenu_Icon_Width)}.fd-menu--icons .fd-menu__title:last-child{-webkit-margin-end:var(--fdMenu_Text_Spacing_Right);margin-inline-end:var(--fdMenu_Text_Spacing_Right)}.fd-menu--icons .fd-menu__title:only-child{margin-inline:var(--fdMenu_Icon_Width) var(--fdMenu_Text_Spacing_Right)}.fd-menu--icons .fd-menu__sublist{--fdMenu_Item_Spacing_Left:1rem;--fdMenu_Item_Spacing_Right:1rem}.fd-menu--icons .fd-menu__sublist .fd-menu__title:first-child{-webkit-margin-start:0;margin-inline-start:0}.fd-menu--icons .fd-menu__sublist .fd-menu__title:last-child{-webkit-margin-end:0;margin-inline-end:0}.fd-menu--icons .fd-menu__sublist .fd-menu__title:only-child{margin-inline:0}.fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons{--fdMenu_Item_Spacing_Left:0;--fdMenu_Item_Spacing_Right:0}.fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons .fd-menu__title:first-child{-webkit-margin-start:var(--fdMenu_Icon_Width);margin-inline-start:var(--fdMenu_Icon_Width)}.fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons .fd-menu__title:last-child{-webkit-margin-end:var(--fdMenu_Text_Spacing_Right);margin-inline-end:var(--fdMenu_Text_Spacing_Right)}.fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons .fd-menu__title:only-child{margin-inline:var(--fdMenu_Icon_Width) var(--fdMenu_Text_Spacing_Right)}.fd-menu--icons .fd-menu__input,.fd-menu--icons input{margin-inline:var(--fdMenu_Text_Spacing_Right) var(--fdMenu_Text_Spacing_Right)}.fd-menu--mobile{max-width:100%;width:100%;--fdMenu_Icon_Width:2.75rem;--fdMenu_Item_Spacing_Left:1rem;--fdMenu_Item_Spacing_Right:1rem;--fdMenu_Shortcut_Padding_Right:1rem;--fdMenu_Text_Spacing_Right:1rem}.fd-menu--mobile .fd-menu__list,.fd-menu--mobile .fd-menu__sublist{border-radius:0;-webkit-box-shadow:none;box-shadow:none;margin-block:0;margin-inline:0;position:static}.fd-menu--mobile .fd-menu__list .fd-menu__item,.fd-menu--mobile .fd-menu__sublist .fd-menu__item{border-radius:0}.fd-menu--mobile.fd-menu--icons{--fdMenu_Item_Spacing_Left:0;--fdMenu_Item_Spacing_Right:0}.fd-menu--mobile.fd-menu--icons .fd-menu__input,.fd-menu--mobile.fd-menu--icons input{margin-inline:1rem}.fd-menu[class*=-compact],.fd-menu[class*=-condensed],[class*=-compact] .fd-menu:not([class*=-cozy]),[class*=-condensed] .fd-menu:not([class*=-cozy]){--fdMenu_Icon_Width:2rem;--fdMenu_Link_Height:2rem;--fdMenu_Item_Spacing_Left:.5rem;--fdMenu_Item_Spacing_Right:.5rem;--fdMenu_Shortcut_Padding_Right:.5rem;--fdMenu_Text_Spacing_Right:.5rem}.fd-menu[class*=-compact].fd-menu--icons,.fd-menu[class*=-condensed].fd-menu--icons,[class*=-compact] .fd-menu:not([class*=-cozy]).fd-menu--icons,[class*=-condensed] .fd-menu:not([class*=-cozy]).fd-menu--icons{--fdMenu_Item_Spacing_Left:0;--fdMenu_Item_Spacing_Right:0}.fd-menu[class*=-compact].fd-menu--icons .fd-menu__input,.fd-menu[class*=-compact].fd-menu--icons input,.fd-menu[class*=-condensed].fd-menu--icons .fd-menu__input,.fd-menu[class*=-condensed].fd-menu--icons input,[class*=-compact] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__input,[class*=-compact] .fd-menu:not([class*=-cozy]).fd-menu--icons input,[class*=-condensed] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__input,[class*=-condensed] .fd-menu:not([class*=-cozy]).fd-menu--icons input{margin-inline:.5rem}.fd-menu[class*=-compact].fd-menu--icons .fd-menu__sublist,.fd-menu[class*=-condensed].fd-menu--icons .fd-menu__sublist,[class*=-compact] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__sublist,[class*=-condensed] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__sublist{--fdMenu_Item_Spacing_Left:.5rem;--fdMenu_Item_Spacing_Right:.5rem}.fd-menu[class*=-compact].fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons,.fd-menu[class*=-condensed].fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons,[class*=-compact] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons,[class*=-condensed] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons{--fdMenu_Item_Spacing_Left:0;--fdMenu_Item_Spacing_Right:0}:host{display:inline}fd-menu .fd-menu__list,fd-menu .fd-menu__sublist{flex-wrap:nowrap}\n/*! Bundled license information:\n\nfundamental-styles/dist/menu.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-menu', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        MenuService,
                        PopoverService,
                        DynamicComponentService,
                        {
                            provide: FD_MENU_COMPONENT,
                            useExisting: forwardRef(() => MenuComponent)
                        },
                        contentDensityObserverProviders()
                    ], standalone: true, template: "<ng-container #viewContainer></ng-container>\n\n<ng-template #menuRootTemplate>\n    <div class=\"fd-popover__wrapper--visible\">\n        <nav\n            class=\"fd-menu\"\n            [id]=\"id\"\n            [attr.aria-labelledby]=\"ariaLabelledby\"\n            [attr.aria-label]=\"ariaLabel\"\n            [attr.role]=\"_navContainerRole\"\n            [class.fd-menu--mobile]=\"mobile\"\n            [class.fd-menu--icons]=\"hasAddons\"\n        >\n            <ul\n                [attr.role]=\"_menuListContainerRole\"\n                class=\"fd-menu__list fd-menu__list--no-shadow\"\n                [class.fd-menu--full-width]=\"mobile || false\"\n            >\n                <ng-content></ng-content>\n            </ul>\n        </nav>\n    </div>\n</ng-template>\n", styles: [".fd-dialog__body{--fdButton_Menu_Border_Radius:0}.fd-menu{--fdMenu_Icon_Width:2.25rem;--fdMenu_Link_Height:2.75rem;--fdMenu_Item_Spacing_Left:.75rem;--fdMenu_Item_Spacing_Right:.75rem;--fdMenu_Item_Border_Bottom_Color:transparent;--fdMenu_Shortcut_Padding_Left:1rem;--fdMenu_Shortcut_Padding_Right:.75rem;--fdMenu_Text_Spacing_Right:.75rem;--fdMenu_Icon_Color:var(--sapContent_NonInteractiveIconColor);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Regular);--fdMenu_Text_Color:var(--sapList_TextColor);--fdMenu_Item_Background_Color:var(--sapList_Background);--fdMenu_Active_Dot_Size:.75rem;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}.fd-menu:after,.fd-menu:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__list,.fd-menu__sublist{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;border-radius:var(--fdButton_Menu_Border_Radius);-webkit-box-shadow:var(--sapContent_Shadow1);box-shadow:var(--sapContent_Shadow1);-ms-flex-direction:column;flex-direction:column;-ms-flex-wrap:wrap;flex-wrap:wrap;list-style:none;max-width:20rem}.fd-menu__list:after,.fd-menu__list:before,.fd-menu__sublist:after,.fd-menu__sublist:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__list--no-shadow,.fd-menu__sublist--no-shadow{-webkit-box-shadow:none;box-shadow:none}.fd-menu__sublist{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;left:100%;line-height:normal;margin-block:0;margin-block:.25rem 0;margin-inline:0;margin-inline:-.25rem 0;min-width:100%;padding-block:0;padding-inline:0;position:absolute;top:0;z-index:2}.fd-menu__sublist:after,.fd-menu__sublist:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__sublist[dir=rtl],[dir=rtl] .fd-menu__sublist{left:auto;right:100%}.fd-menu__sublist[aria-hidden=true]{display:none}.fd-menu__list>.fd-menu__item{position:relative;width:100%}.fd-menu__list--overflow{-ms-flex-wrap:nowrap;flex-wrap:nowrap;overflow-y:scroll;scrollbar-color:var(--fdScrollbar_Thumb_Color) var(--fdScrollbar_Track_Color)}.fd-menu__list--overflow.is-focus,.fd-menu__list--overflow:focus{outline:none;z-index:5}.fd-menu__list--overflow::-webkit-scrollbar{height:var(--fdScrollbar_Dimension);width:var(--fdScrollbar_Dimension)}.fd-menu__list--overflow::-webkit-scrollbar-corner,.fd-menu__list--overflow::-webkit-scrollbar-track{background-color:var(--fdScrollbar_Track_Color)}.fd-menu__list--overflow::-webkit-scrollbar-thumb{background-color:transparent;border:var(--fdScrollbar_Thumb_Offset) solid transparent;border-radius:calc(var(--fdScrollbar_Thumb_Border_Radius) - var(--fdScrollbar_Thumb_Offset));-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color)}.fd-menu__list--overflow::-webkit-scrollbar-thumb:active,.fd-menu__list--overflow::-webkit-scrollbar-thumb:hover{-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color)}.fd-menu__list--overflow::-webkit-scrollbar-corner,.fd-menu__list--overflow::-webkit-scrollbar-track{border-radius:0 var(--fdScrollbar_Border_Radius) var(--fdScrollbar_Border_Radius) 0}.fd-menu__list--overflow[dir=rtl]::-webkit-scrollbar-corner,.fd-menu__list--overflow[dir=rtl]::-webkit-scrollbar-track,[dir=rtl] .fd-menu__list--overflow::-webkit-scrollbar-corner,[dir=rtl] .fd-menu__list--overflow::-webkit-scrollbar-track{border-radius:var(--fdScrollbar_Border_Radius) 0 0 var(--fdScrollbar_Border_Radius)}.fd-menu__separator{background-color:var(--sapGroup_ContentBorderColor);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:.0625rem;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%}.fd-menu__separator:after,.fd-menu__separator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__item{background-color:var(--sapList_Background);border:0;border-radius:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;padding-block:0;padding-inline:0;position:relative}.fd-menu__item:after,.fd-menu__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__item:first-child,.fd-menu__item:first-child .fd-menu__link:after{border-top-left-radius:var(--fdButton_Menu_Border_Radius);border-top-right-radius:var(--fdButton_Menu_Border_Radius)}.fd-menu__item:last-of-type,.fd-menu__item:last-of-type .fd-menu__link:after{border-bottom-left-radius:var(--fdButton_Menu_Border_Radius);border-bottom-right-radius:var(--fdButton_Menu_Border_Radius)}.fd-menu__item.has-separator{border-bottom:.0625rem solid var(--sapGroup_ContentBorderColor)}.fd-menu__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);cursor:pointer;display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdMenu_Item_Background_Color);border-bottom:.0625rem solid var(--fdMenu_Item_Border_Bottom_Color);border-radius:inherit;height:var(--fdMenu_Link_Height);outline:none;padding-inline:var(--fdMenu_Item_Spacing_Left) var(--fdMenu_Item_Spacing_Right);text-decoration:none;width:100%}.fd-menu__link:after,.fd-menu__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__link.is-focus:after,.fd-menu__link:focus:after{border-color:var(--sapContent_FocusColor);border-radius:0!important;border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:.125rem;pointer-events:none;position:absolute}.fd-menu__link.is-hover,.fd-menu__link:hover{--fdMenu_Item_Background_Color:var(--sapList_Hover_Background)}.fd-menu__link.is-selected,.fd-menu__link[aria-selected=true]{--fdMenu_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdMenu_Icon_Color:var(--sapContent_NonInteractiveIconColor);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Selected);--fdMenu_Text_Color:var(--sapList_TextColor);--fdMenu_Item_Border_Bottom_Color:var(--sapList_SelectionBorderColor)}.fd-menu__link.is-selected.is-hover:not(:active,.is-active),.fd-menu__link.is-selected:hover:not(:active,.is-active),.fd-menu__link[aria-selected=true].is-hover:not(:active,.is-active),.fd-menu__link[aria-selected=true]:hover:not(:active,.is-active){--fdMenu_Item_Background_Color:var(--sapList_Hover_SelectionBackground);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Selected_Hover)}.fd-menu__link.is-selected.is-focus,.fd-menu__link.is-selected:focus,.fd-menu__link[aria-selected=true].is-focus,.fd-menu__link[aria-selected=true]:focus{z-index:5}.fd-menu__link.is-selected.is-focus:after,.fd-menu__link.is-selected:focus:after,.fd-menu__link[aria-selected=true].is-focus:after,.fd-menu__link[aria-selected=true]:focus:after{bottom:.125rem}.fd-menu__link.is-active,.fd-menu__link:active{--fdMenu_Item_Background_Color:var(--sapList_Active_Background);--fdMenu_Icon_Color:var(--sapList_Active_TextColor);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Active);--fdMenu_Text_Color:var(--fdMenu_Text_Color_Active)}.fd-menu__link.is-active:after,.fd-menu__link:active:after{display:none}.fd-menu__link.is-active.is-focus,.fd-menu__link.is-active:focus,.fd-menu__link:active.is-focus,.fd-menu__link:active:focus{outline-color:var(--fdMenu_Active_State_Focus);z-index:5}.fd-menu__link.is-disabled,.fd-menu__link:disabled,.fd-menu__link[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-menu__link.is-disabled.is-focus,.fd-menu__link.is-disabled:focus,.fd-menu__link:disabled.is-focus,.fd-menu__link:disabled:focus,.fd-menu__link[aria-disabled=true].is-focus,.fd-menu__link[aria-disabled=true]:focus{z-index:5}.fd-menu__link.is-disabled.is-focus:after,.fd-menu__link.is-disabled:focus:after,.fd-menu__link:disabled.is-focus:after,.fd-menu__link:disabled:focus:after,.fd-menu__link[aria-disabled=true].is-focus:after,.fd-menu__link[aria-disabled=true]:focus:after{display:none}.fd-menu__link.has-child{--fdMenu_Item_Spacing_Right:0}.fd-menu__link.has-child.is-expanded:not(:active,.is-active),.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active){--fdMenu_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdMenu_Icon_Color:var(--sapContent_NonInteractiveIconColor);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Selected);--fdMenu_Text_Color:var(--sapList_TextColor);--fdMenu_Item_Border_Bottom_Color:var(--sapList_SelectionBorderColor)}.fd-menu__link.has-child.is-expanded:not(:active,.is-active).is-hover:not(:active,.is-active),.fd-menu__link.has-child.is-expanded:not(:active,.is-active):hover:not(:active,.is-active),.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active).is-hover:not(:active,.is-active),.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active):hover:not(:active,.is-active){--fdMenu_Item_Background_Color:var(--sapList_Hover_SelectionBackground);--fdMenu_Shortcut_Color:var(--fdMenu_Shortcut_Color_Selected_Hover)}.fd-menu__link.has-child.is-expanded:not(:active,.is-active).is-focus,.fd-menu__link.has-child.is-expanded:not(:active,.is-active):focus,.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active).is-focus,.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active):focus{z-index:5}.fd-menu__link.has-child.is-expanded:not(:active,.is-active).is-focus:after,.fd-menu__link.has-child.is-expanded:not(:active,.is-active):focus:after,.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active).is-focus:after,.fd-menu__link.has-child[aria-expanded=true]:not(:active,.is-active):focus:after{bottom:.125rem}.fd-menu__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdMenu_Text_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-align:left;text-overflow:ellipsis;text-shadow:var(--fdMenu_Text_Shadow);white-space:nowrap;width:100%}.fd-menu__title:after,.fd-menu__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__title[dir=rtl],[dir=rtl] .fd-menu__title{text-align:right}.fd-menu__title:has(+.fd-menu__input){min-width:-webkit-fit-content;min-width:-moz-fit-content;min-width:fit-content;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}.fd-menu__addon-after,.fd-menu__addon-before{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:transparent;color:var(--fdMenu_Icon_Color);font-size:var(--sapFontLargeSize);height:100%;max-width:var(--fdMenu_Icon_Width);min-width:var(--fdMenu_Icon_Width);text-shadow:var(--fdMenu_Text_Shadow);width:var(--fdMenu_Icon_Width)}.fd-menu__addon-after:after,.fd-menu__addon-after:before,.fd-menu__addon-before:after,.fd-menu__addon-before:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__addon-after [class*=sap-icon],.fd-menu__addon-after[class*=sap-icon],.fd-menu__addon-before [class*=sap-icon],.fd-menu__addon-before[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-menu__addon-after--submenu{font-size:var(--fdMenu_Affordance_Arrow_Size)}.fd-menu__addon-after--submenu:before{content:\"\\e066\"}.fd-menu__addon-after--submenu:before,.fd-menu__addon-after--submenu[dir=rtl]:before,[dir=rtl] .fd-menu__addon-after--submenu:before{font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-menu__addon-after--submenu[dir=rtl]:before,[dir=rtl] .fd-menu__addon-after--submenu:before{content:\"\\e067\"}.fd-menu__active-dot{background:var(--sapContent_Selected_ForegroundColor);border:0;border-radius:100%;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdMenu_Active_Dot_Size);line-height:normal;margin-block:0;margin-inline:0;min-width:var(--fdMenu_Active_Dot_Size);padding-block:0;padding-inline:0;width:var(--fdMenu_Active_Dot_Size)}.fd-menu__active-dot:after,.fd-menu__active-dot:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__checkmark [class*=sap-icon],.fd-menu__checkmark[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;color:var(--sapContent_Selected_ForegroundColor);font-size:inherit;font-size:1rem;line-height:1}.fd-menu__shortcut{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-ms-flex-negative:0;color:var(--fdMenu_Shortcut_Color);flex-shrink:0;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;-webkit-padding-start:var(--fdMenu_Shortcut_Padding_Left);padding-inline-start:var(--fdMenu_Shortcut_Padding_Left)}.fd-menu__shortcut:after,.fd-menu__shortcut:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-menu__shortcut:last-child{padding-inline:var(--fdMenu_Shortcut_Padding_Left) var(--fdMenu_Shortcut_Padding_Right)}.fd-menu--overflow{border-radius:var(--fdButton_Menu_Border_Radius);-webkit-box-shadow:var(--sapContent_Shadow1);box-shadow:var(--sapContent_Shadow1);overflow-y:scroll;scrollbar-color:var(--fdScrollbar_Thumb_Color) var(--fdScrollbar_Track_Color)}.fd-menu--overflow.is-focus,.fd-menu--overflow:focus{outline:none;z-index:5}.fd-menu--overflow::-webkit-scrollbar{height:var(--fdScrollbar_Dimension);width:var(--fdScrollbar_Dimension)}.fd-menu--overflow::-webkit-scrollbar-corner,.fd-menu--overflow::-webkit-scrollbar-track{background-color:var(--fdScrollbar_Track_Color)}.fd-menu--overflow::-webkit-scrollbar-thumb{background-color:transparent;border:var(--fdScrollbar_Thumb_Offset) solid transparent;border-radius:calc(var(--fdScrollbar_Thumb_Border_Radius) - var(--fdScrollbar_Thumb_Offset));-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color)}.fd-menu--overflow::-webkit-scrollbar-thumb:active,.fd-menu--overflow::-webkit-scrollbar-thumb:hover{-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color)}.fd-menu--overflow::-webkit-scrollbar-corner,.fd-menu--overflow::-webkit-scrollbar-track{border-radius:0 var(--fdScrollbar_Border_Radius) var(--fdScrollbar_Border_Radius) 0}.fd-menu--overflow[dir=rtl]::-webkit-scrollbar-corner,.fd-menu--overflow[dir=rtl]::-webkit-scrollbar-track,[dir=rtl] .fd-menu--overflow::-webkit-scrollbar-corner,[dir=rtl] .fd-menu--overflow::-webkit-scrollbar-track{border-radius:var(--fdScrollbar_Border_Radius) 0 0 var(--fdScrollbar_Border_Radius)}.fd-menu--overflow .fd-menu__list{-webkit-box-shadow:none;box-shadow:none}.fd-menu--overflow .fd-menu__item:first-child{border-top-right-radius:0}.fd-menu--overflow .fd-menu__item:first-child[dir=rtl],[dir=rtl] .fd-menu--overflow .fd-menu__item:first-child{border-top-left-radius:0;border-top-right-radius:var(--fdButton_Menu_Border_Radius)}.fd-menu--overflow .fd-menu__item:last-of-type{border-bottom-right-radius:0}.fd-menu--overflow .fd-menu__item:last-of-type[dir=rtl],[dir=rtl] .fd-menu--overflow .fd-menu__item:last-of-type{border-bottom-left-radius:0;border-bottom-right-radius:var(--fdButton_Menu_Border_Radius)}.fd-menu--full-width{max-width:100%}.fd-menu--icons{--fdMenu_Item_Spacing_Left:0;--fdMenu_Item_Spacing_Right:0}.fd-menu--icons .fd-menu__title:first-child{-webkit-margin-start:var(--fdMenu_Icon_Width);margin-inline-start:var(--fdMenu_Icon_Width)}.fd-menu--icons .fd-menu__title:last-child{-webkit-margin-end:var(--fdMenu_Text_Spacing_Right);margin-inline-end:var(--fdMenu_Text_Spacing_Right)}.fd-menu--icons .fd-menu__title:only-child{margin-inline:var(--fdMenu_Icon_Width) var(--fdMenu_Text_Spacing_Right)}.fd-menu--icons .fd-menu__sublist{--fdMenu_Item_Spacing_Left:1rem;--fdMenu_Item_Spacing_Right:1rem}.fd-menu--icons .fd-menu__sublist .fd-menu__title:first-child{-webkit-margin-start:0;margin-inline-start:0}.fd-menu--icons .fd-menu__sublist .fd-menu__title:last-child{-webkit-margin-end:0;margin-inline-end:0}.fd-menu--icons .fd-menu__sublist .fd-menu__title:only-child{margin-inline:0}.fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons{--fdMenu_Item_Spacing_Left:0;--fdMenu_Item_Spacing_Right:0}.fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons .fd-menu__title:first-child{-webkit-margin-start:var(--fdMenu_Icon_Width);margin-inline-start:var(--fdMenu_Icon_Width)}.fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons .fd-menu__title:last-child{-webkit-margin-end:var(--fdMenu_Text_Spacing_Right);margin-inline-end:var(--fdMenu_Text_Spacing_Right)}.fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons .fd-menu__title:only-child{margin-inline:var(--fdMenu_Icon_Width) var(--fdMenu_Text_Spacing_Right)}.fd-menu--icons .fd-menu__input,.fd-menu--icons input{margin-inline:var(--fdMenu_Text_Spacing_Right) var(--fdMenu_Text_Spacing_Right)}.fd-menu--mobile{max-width:100%;width:100%;--fdMenu_Icon_Width:2.75rem;--fdMenu_Item_Spacing_Left:1rem;--fdMenu_Item_Spacing_Right:1rem;--fdMenu_Shortcut_Padding_Right:1rem;--fdMenu_Text_Spacing_Right:1rem}.fd-menu--mobile .fd-menu__list,.fd-menu--mobile .fd-menu__sublist{border-radius:0;-webkit-box-shadow:none;box-shadow:none;margin-block:0;margin-inline:0;position:static}.fd-menu--mobile .fd-menu__list .fd-menu__item,.fd-menu--mobile .fd-menu__sublist .fd-menu__item{border-radius:0}.fd-menu--mobile.fd-menu--icons{--fdMenu_Item_Spacing_Left:0;--fdMenu_Item_Spacing_Right:0}.fd-menu--mobile.fd-menu--icons .fd-menu__input,.fd-menu--mobile.fd-menu--icons input{margin-inline:1rem}.fd-menu[class*=-compact],.fd-menu[class*=-condensed],[class*=-compact] .fd-menu:not([class*=-cozy]),[class*=-condensed] .fd-menu:not([class*=-cozy]){--fdMenu_Icon_Width:2rem;--fdMenu_Link_Height:2rem;--fdMenu_Item_Spacing_Left:.5rem;--fdMenu_Item_Spacing_Right:.5rem;--fdMenu_Shortcut_Padding_Right:.5rem;--fdMenu_Text_Spacing_Right:.5rem}.fd-menu[class*=-compact].fd-menu--icons,.fd-menu[class*=-condensed].fd-menu--icons,[class*=-compact] .fd-menu:not([class*=-cozy]).fd-menu--icons,[class*=-condensed] .fd-menu:not([class*=-cozy]).fd-menu--icons{--fdMenu_Item_Spacing_Left:0;--fdMenu_Item_Spacing_Right:0}.fd-menu[class*=-compact].fd-menu--icons .fd-menu__input,.fd-menu[class*=-compact].fd-menu--icons input,.fd-menu[class*=-condensed].fd-menu--icons .fd-menu__input,.fd-menu[class*=-condensed].fd-menu--icons input,[class*=-compact] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__input,[class*=-compact] .fd-menu:not([class*=-cozy]).fd-menu--icons input,[class*=-condensed] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__input,[class*=-condensed] .fd-menu:not([class*=-cozy]).fd-menu--icons input{margin-inline:.5rem}.fd-menu[class*=-compact].fd-menu--icons .fd-menu__sublist,.fd-menu[class*=-condensed].fd-menu--icons .fd-menu__sublist,[class*=-compact] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__sublist,[class*=-condensed] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__sublist{--fdMenu_Item_Spacing_Left:.5rem;--fdMenu_Item_Spacing_Right:.5rem}.fd-menu[class*=-compact].fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons,.fd-menu[class*=-condensed].fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons,[class*=-compact] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons,[class*=-condensed] .fd-menu:not([class*=-cozy]).fd-menu--icons .fd-menu__sublist.fd-menu__sublist--icons{--fdMenu_Item_Spacing_Left:0;--fdMenu_Item_Spacing_Right:0}:host{display:inline}fd-menu .fd-menu__list,fd-menu .fd-menu__sublist{flex-wrap:nowrap}\n/*! Bundled license information:\n\nfundamental-styles/dist/menu.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i1$1.DialogConfig, decorators: [{
                    type: Optional
                }] }, { type: i0.Renderer2 }, { type: MenuService }, { type: i0.ChangeDetectorRef }, { type: i3.PopoverService }, { type: i0.Injector }, { type: i0.ViewContainerRef }, { type: i2$1.DynamicComponentService, decorators: [{
                    type: Optional
                }] }, { type: i5.ContentDensityObserver }], propDecorators: { mobile: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], disabled: [{
                type: Input
            }], focusTrapped: [{
                type: Input
            }], focusAutoCapture: [{
                type: Input
            }], openOnHoverTime: [{
                type: Input
            }], mobileConfig: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], ariaLabelledby: [{
                type: Input
            }], id: [{
                type: Input
            }], activePath: [{
                type: Output
            }], _menuRootTemplate: [{
                type: ViewChild,
                args: ['menuRootTemplate']
            }], _menuItems: [{
                type: ContentChildren,
                args: [FD_MENU_ITEM_COMPONENT]
            }], _segmentedButtonHeaderItems: [{
                type: ContentChildren,
                args: [SegmentedButtonHeaderDirective]
            }], _segmentedButtonOptions: [{
                type: ContentChildren,
                args: [SegmentedButtonOptionDirective]
            }] } });

class MenuModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: MenuModule, imports: [PopoverModule,
            InitialFocusModule,
            ContentDensityModule,
            GlyphMenuAddonDirective,
            PortalModule,
            MenuComponent,
            MenuItemComponent,
            MenuAddonDirective,
            MenuSeparatorDirective,
            MenuShortcutDirective,
            MenuInteractiveComponent,
            MenuTitleDirective,
            SubmenuComponent,
            MenuTriggerDirective,
            ToggleButtonDirective,
            SegmentedButtonHeaderDirective,
            SegmentedButtonOptionDirective,
            MenuItemInputDirective], exports: [MenuComponent,
            MenuItemComponent,
            SubmenuComponent,
            MenuSeparatorDirective,
            MenuShortcutDirective,
            MenuInteractiveComponent,
            MenuTitleDirective,
            MenuAddonDirective,
            MenuTriggerDirective,
            ContentDensityModule,
            GlyphMenuAddonDirective,
            ToggleButtonDirective,
            SegmentedButtonHeaderDirective,
            SegmentedButtonOptionDirective,
            MenuItemInputDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuModule, providers: [DynamicComponentService], imports: [PopoverModule,
            InitialFocusModule,
            ContentDensityModule,
            PortalModule,
            MenuAddonDirective,
            MenuInteractiveComponent, ContentDensityModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        PopoverModule,
                        InitialFocusModule,
                        ContentDensityModule,
                        GlyphMenuAddonDirective,
                        PortalModule,
                        MenuComponent,
                        MenuItemComponent,
                        MenuAddonDirective,
                        MenuSeparatorDirective,
                        MenuShortcutDirective,
                        MenuInteractiveComponent,
                        MenuTitleDirective,
                        SubmenuComponent,
                        MenuTriggerDirective,
                        ToggleButtonDirective,
                        SegmentedButtonHeaderDirective,
                        SegmentedButtonOptionDirective,
                        MenuItemInputDirective
                    ],
                    exports: [
                        MenuComponent,
                        MenuItemComponent,
                        SubmenuComponent,
                        MenuSeparatorDirective,
                        MenuShortcutDirective,
                        MenuInteractiveComponent,
                        MenuTitleDirective,
                        MenuAddonDirective,
                        MenuTriggerDirective,
                        ContentDensityModule,
                        GlyphMenuAddonDirective,
                        ToggleButtonDirective,
                        SegmentedButtonHeaderDirective,
                        SegmentedButtonOptionDirective,
                        MenuItemInputDirective
                    ],
                    providers: [DynamicComponentService]
                }]
        }] });

class MenuKeyboardService {
    constructor() {
        /** Event emitted when an item link is clicked.*/
        this.itemClicked = new Subject();
        /** Whether user wants to remove keyboard handling */
        this.disableKeydownHandling = false;
    }
    /** Function that should be called every time, keydown event is used on some menu item,
     * it provides whole functionality for handling
     * ArrowDown - focus, ArrowUp - focus, Space bar - simulate click, Enter key - simulate click.
     * @param event KeyboardEvent
     * @param index index of items starts from 0
     * @param menuItems array of menu item directives
     * */
    keyDownHandler(event, index, menuItems) {
        if (this.disableKeydownHandling) {
            return;
        }
        if (KeyUtil.isKeyCode(event, DOWN_ARROW)) {
            if (menuItems.length > index + 1) {
                menuItems[index + 1].focus();
            }
            else {
                if (this.focusEscapeAfterList) {
                    this.focusEscapeAfterList();
                }
                else {
                    menuItems[0].focus();
                }
            }
            event.preventDefault();
        }
        else if (KeyUtil.isKeyCode(event, UP_ARROW)) {
            if (index > 0) {
                menuItems[index - 1].focus();
            }
            else {
                if (this.focusEscapeBeforeList) {
                    this.focusEscapeBeforeList();
                }
                else {
                    menuItems[menuItems.length - 1].focus();
                }
            }
            event.preventDefault();
        }
        else if (KeyUtil.isKeyCode(event, [SPACE, ENTER])) {
            if (menuItems[index]) {
                menuItems[index].click();
                event.preventDefault();
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuKeyboardService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuKeyboardService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MenuKeyboardService, decorators: [{
            type: Injectable
        }], propDecorators: { itemClicked: [{
                type: Output
            }] } });

/**
 * Generated bundle index. Do not edit.
 */

export { DefaultMenuItem, GlyphMenuAddonDirective, MENU_COMPONENT, MenuAddonDirective, MenuComponent, MenuInteractiveComponent, MenuInteractiveComponent as MenuInteractiveDirective, MenuItemComponent, MenuItemInputDirective, MenuKeyboardService, MenuMobileComponent, MenuModule, MenuSeparatorDirective as MenuSeparatorComponent, MenuSeparatorDirective, MenuService, MenuShortcutDirective, MenuTitleDirective, MenuTriggerDirective, SUBMENU, SegmentedButtonHeaderDirective, SegmentedButtonOptionDirective, SubmenuComponent, ToggleButtonDirective };
//# sourceMappingURL=fundamental-ngx-core-menu.mjs.map
