import * as i0 from '@angular/core';
import { inject, HostListener, ContentChildren, Input, Directive, Injectable, ElementRef, ChangeDetectorRef, DestroyRef, InjectionToken, ViewChild, Inject, Component, ChangeDetectionStrategy, ViewEncapsulation, EventEmitter, Injector, Output, NgModule } from '@angular/core';
import { LiveAnnouncer } from '@angular/cdk/a11y';
import * as i1 from '@fundamental-ngx/cdk/utils';
import { KeyUtil, isJsObject, isFunction, isString, RangeSelector, coerceArraySafe, TemplateModule, TemplateDirective, resizeObservable, AutoCompleteDirective, SearchHighlightPipe, TruncatedTitleDirective, DynamicComponentService } from '@fundamental-ngx/cdk/utils';
import { TokenComponent, TokenizerComponent } from '@fundamental-ngx/core/token';
import { resolveTranslationSyncFn, FdTranslatePipe, FD_LANGUAGE, TranslationResolver } from '@fundamental-ngx/i18n';
import { BACKSPACE, ESCAPE, ENTER, CONTROL, TAB, SHIFT, UP_ARROW, RIGHT_ARROW, DOWN_ARROW, LEFT_ARROW, ALT, A, SPACE } from '@angular/cdk/keycodes';
import * as i3 from '@fundamental-ngx/cdk/data-source';
import { MatchingStrategy, DataSourceDirective, BaseDataSource, DataProvider, isDataSource, FD_DATA_SOURCE_TRANSFORMER } from '@fundamental-ngx/cdk/data-source';
import * as i2 from '@fundamental-ngx/cdk/forms';
import { isSelectItem, CvaControl, CvaDirective, isOptionItem, isSelectableOptionItem } from '@fundamental-ngx/cdk/forms';
import { ListFocusItem, ListComponent, ListGroupHeaderDirective, ListTitleDirective, ListItemComponent, ListSecondaryDirective, FD_LIST_COMPONENT } from '@fundamental-ngx/core/list';
import { ContentDensityObserver, contentDensityObserverProviders } from '@fundamental-ngx/core/content-density';
import equal from 'fast-deep-equal';
import { BehaviorSubject, Subscription, startWith, skip, timer, isObservable, Subject } from 'rxjs';
import { debounceTime } from 'rxjs/operators';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { NgTemplateOutlet, AsyncPipe, NgClass } from '@angular/common';
import { BarMiddleDirective, BarElementDirective, ButtonBarComponent } from '@fundamental-ngx/core/bar';
import { ButtonComponent } from '@fundamental-ngx/core/button';
import { DialogComponent, DialogHeaderComponent, DialogCloseButtonComponent, DialogBodyComponent, DialogFooterComponent } from '@fundamental-ngx/core/dialog';
import { MobileModeBase, MobileModeControl } from '@fundamental-ngx/core/mobile-mode';
import { TitleComponent } from '@fundamental-ngx/core/title';
import * as i4 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { CheckboxComponent } from '@fundamental-ngx/core/checkbox';
import { FormItemComponent, FormInputMessageGroupComponent, FormControlComponent, FormMessageComponent } from '@fundamental-ngx/core/form';
import { InputGroupComponent, InputGroupInputDirective } from '@fundamental-ngx/core/input-group';
import { PopoverComponent, PopoverControlComponent, PopoverBodyComponent } from '@fundamental-ngx/core/popover';
import { ToolbarComponent } from '@fundamental-ngx/core/toolbar';

class MultiAnnouncerDirective {
    constructor() {
        /** @hidden */
        this._noResultsAnnounced = false;
        /** @hidden */
        this._resultsAnnounced = false;
        /** @hidden */
        this._announcement = '';
        /** @hidden */
        this._liveAnnouncer = inject(LiveAnnouncer);
        /** @hidden */
        this._resolveTranslation = resolveTranslationSyncFn();
    }
    /** @hidden */
    _makeSearchTermChangeAnnouncements(event) {
        if (KeyUtil.isKeyType(event, 'alphabetical') || KeyUtil.isKeyType(event, 'numeric')) {
            this._liveAnnouncer.clear();
            const count = this.multiAnnouncerOptions?.length;
            if (!count && !this._noResultsAnnounced) {
                this._buildAnnouncement(this._resolveTranslation('coreMultiInput.noResults'));
                this._noResultsAnnounced = true;
                this._resultsAnnounced = false;
            }
            else if (count) {
                const trKey = count === 1 ? 'coreMultiInput.countListResultsSingular' : 'coreMultiInput.countListResultsPlural';
                this._buildAnnouncement(this._resolveTranslation(trKey, { count }));
                this._buildAnnouncement(this._resolveTranslation('coreMultiInput.navigateSelectionsWithArrows'));
                if (!this._resultsAnnounced) {
                    this._noResultsAnnounced = false;
                    this._resultsAnnounced = true;
                }
            }
            if (this._tokens?.length) {
                this._buildAnnouncement(this._resolveTranslation('coreMultiInput.escapeNavigateTokens'));
            }
            this._makeAnnouncement(this._announcement);
        }
    }
    /** @hidden */
    _buildAnnouncement(message) {
        this._announcement = this._announcement + message + ' ';
    }
    /** @hidden */
    async _makeAnnouncement(message) {
        await this._liveAnnouncer.announce(message, 'assertive').then(() => {
            this._announcement = '';
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MultiAnnouncerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: MultiAnnouncerDirective, isStandalone: true, selector: "[fdMultiAnnouncer]", inputs: { multiAnnouncerOptions: "multiAnnouncerOptions" }, host: { listeners: { "keyup": "_makeSearchTermChangeAnnouncements($event)" } }, queries: [{ propertyName: "_tokens", predicate: TokenComponent, descendants: true }], exportAs: ["fdMultiAnnouncer"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MultiAnnouncerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdMultiAnnouncer]',
                    exportAs: 'fdMultiAnnouncer',
                    standalone: true
                }]
        }], propDecorators: { multiAnnouncerOptions: [{
                type: Input
            }], _tokens: [{
                type: ContentChildren,
                args: [TokenComponent, { descendants: true }]
            }], _makeSearchTermChangeAnnouncements: [{
                type: HostListener,
                args: ['keyup', ['$event']]
            }] } });

/** @hidden */
function lookupValue(item, lookupKey) {
    if (isSelectItem(item)) {
        return lookupKey && item ? item.value[lookupKey] : item.value;
    }
    else {
        return lookupKey && item ? item[lookupKey] : item;
    }
}
/** @hidden */
function displayValue(item, displayKey) {
    if (isSelectItem(item)) {
        return item.label;
    }
    else if (isJsObject(item) && displayKey) {
        const currentItem = objectGet(item, displayKey);
        return isFunction(currentItem) ? currentItem() : currentItem;
    }
    else {
        return item;
    }
}
/** @hidden */
function objectGet(obj, is) {
    if (!isJsObject(obj)) {
        return obj;
    }
    else if (isString(is)) {
        return objectGet(obj, is.split('.'));
    }
    else if (!is?.length) {
        return obj;
    }
    else {
        return objectGet(obj[is[0]], is.slice(1));
    }
}
/** @hidden */
function getSelectItemByInputValue(suggestions, needleValue) {
    return suggestions.find((value) => value.label === needleValue);
}
/** @hidden
 *  Map grouped values to array. */
function flattenGroups(items) {
    return items.reduce((result, item) => result.concat(item.children ?? []), []);
}
/** @hidden */
function getTokenIndexByIdlOrValue(item, suggestions) {
    return suggestions.findIndex((token) => token.id === item.id || equal(token.value, item.value));
}

class MultiComboboxSelectionChangeEvent {
    /**
     * Multi Combobox selection change event
     * @param source Multi Combobox component
     * @param selectedItems Selected items
     */
    constructor(source, selectedItems // Contains selected items
    ) {
        this.source = source;
        this.selectedItems = selectedItems;
    }
}

// import { PlatformConfig } from '@fundamental-ngx/platform/shared';
/**
 * Default options for Multi-Combobox
 */
class MultiComboboxConfig {
    constructor() {
        /**
         * String matching strategy for typeahead list. Default: 'starts with per term'
         */
        this.matchingStrategy = MatchingStrategy.STARTS_WITH_PER_TERM;
        /**
         * Maps data providers
         */
        this.providers = new Map();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MultiComboboxConfig, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MultiComboboxConfig, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MultiComboboxConfig, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });

class BaseMultiCombobox {
    constructor() {
        // Injection section
        /** @hidden */
        this.cvaControl = inject(CvaControl);
        /** @hidden */
        this.dataSourceDirective = inject(DataSourceDirective);
        /** Control Value Accessor directive for forms support. */
        this._cva = inject((CvaDirective), {
            self: true
        });
        /** Multi combobox config. */
        this._multiComboboxConfig = inject(MultiComboboxConfig, {
            optional: true
        });
        /** Content Density Observer */
        this.contentDensityObserver = inject(ContentDensityObserver);
        /**
         * @hidden
         * List of selected suggestions
         */
        this._selectedSuggestions = [];
        /**
         * @hidden
         * Grouped suggestions mapped to array.
         */
        this._flatSuggestions = [];
        /** @hidden */
        this._fullFlatSuggestions = [];
        /** @hidden */
        this.selectedShown$ = new BehaviorSubject(false);
        /** @Hidden */
        this._elmRef = inject((ElementRef));
        /** @hidden */
        this._cd = inject(ChangeDetectorRef);
        /** @hidden */
        this._mapLimit = inject(FD_MAP_LIMIT);
        /** @Hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._matchingStrategy = this._multiComboboxConfig?.matchingStrategy ?? MatchingStrategy.CONTAINS;
        /** @hidden */
        this._dsSubscription = null;
        /** @hidden */
        this._element = this._elmRef.nativeElement;
        /**
         * @hidden
         * Keys, that won't trigger the popover's open state, when dispatched on search input.
         */
        this._nonOpeningKeys = [
            BACKSPACE,
            ESCAPE,
            ENTER,
            CONTROL,
            TAB,
            SHIFT,
            UP_ARROW,
            RIGHT_ARROW,
            DOWN_ARROW,
            LEFT_ARROW,
            ALT
        ];
        /** @hidden */
        this._rangeSelector = new RangeSelector();
        /** @hidden */
        this._dataSourceChanged = false;
        /** @hidden */
        this._displayFn = (value) => displayValue(value, this.displayKey);
        /** @hidden */
        this._secondaryFn = (value) => {
            if (isOptionItem(value)) {
                return value.secondaryText ?? '';
            }
            else if (isJsObject(value) && this.secondaryKey) {
                const currentItem = objectGet(value, this.secondaryKey);
                return isFunction(currentItem) ? currentItem() : currentItem;
            }
            else {
                return value;
            }
        };
    }
    /** @hidden */
    writeValue(value) {
        this.selectedItems = coerceArraySafe(value);
        this._cva.writeValue(this.selectedItems);
        this._setSelectedSuggestions();
        this._emitChangeEvent();
    }
    /**
     * Used to change the value of a control.
     * @param value the value to be applied
     * @param emitOnChange whether to emit "onChange" event.
     * Should be "false", if the change is made programmatically (internally) by the control, "true" otherwise
     */
    setValue(value, emitOnChange = true) {
        this.selectedItems = coerceArraySafe(value);
        this._cva.setValue(this.selectedItems, emitOnChange);
        this._setSelectedSuggestions();
        this._emitChangeEvent();
    }
    /**
     * @hidden
     * Method to emit change event
     */
    _emitChangeEvent() {
        const event = new MultiComboboxSelectionChangeEvent(this, this.selectedItems);
        this.selectionChange.emit(event);
    }
    /** @hidden */
    _setSelectedSuggestions() {
        this._selectedSuggestions = [];
        if (!this.selectedItems?.length) {
            return;
        }
        for (let i = 0; i <= this.selectedItems.length; i++) {
            const selectedItem = this.selectedItems[i];
            const idx = this._fullFlatSuggestions.findIndex((item) => item.label === selectedItem || item.value === selectedItem);
            if (idx !== -1) {
                this._selectedSuggestions.push(this._fullFlatSuggestions[idx]);
                this._fullFlatSuggestions[idx].selected = true;
            }
        }
        this._cd.detectChanges();
    }
    /**
     * Convert original data to SelectableOptionItems Interface
     * @hidden
     */
    _convertToOptionItems(items) {
        const item = items[0];
        const elementTypeIsOptionItem = isSelectableOptionItem(item);
        if (elementTypeIsOptionItem) {
            return items;
        }
        const elementTypeIsObject = isJsObject(item);
        if (elementTypeIsObject) {
            return this._convertObjectsToOptionItems(items);
        }
        const elementTypeIsString = isString(item);
        if (elementTypeIsString) {
            return this._convertPrimitiveToOptionItems(items);
        }
        return [];
    }
    /**
     * Convert data to SelectableOptionItems Interface
     * @hidden
     */
    _convertObjectsToOptionItems(items) {
        if (this.isGroup) {
            return this._convertObjectsToGroupOptionItems(items);
        }
        else if (this.showSecondaryText && this.secondaryKey) {
            return this._convertObjectsToSecondaryOptionItems(items);
        }
        else {
            return this._convertObjectsToDefaultOptionItems(items);
        }
    }
    /**
     * Convert object[] data to Group OptionItems Interface
     * @hidden
     */
    _convertObjectsToGroupOptionItems(items) {
        const group = {};
        for (let i = 0; i < items.length; i++) {
            const item = items[i];
            const keyValue = item[this.groupKey];
            if (!keyValue) {
                continue;
            }
            if (!group[keyValue]) {
                group[keyValue] = [];
            }
            group[keyValue].push(item);
        }
        return Object.keys(group).map((key) => {
            const selectItem = {
                label: key,
                value: null,
                isGroup: true
            };
            const currentGroup = group[key];
            if (this.showSecondaryText && this.secondaryKey) {
                selectItem.children = this._convertObjectsToSecondaryOptionItems(currentGroup);
            }
            else {
                selectItem.children = this._convertObjectsToDefaultOptionItems(currentGroup);
            }
            return selectItem;
        });
    }
    /**
     * Convert T[] data to Secondary SelectableOptionItems<T> Interface
     * @hidden
     */
    _convertObjectsToSecondaryOptionItems(items) {
        const selectItems = [];
        for (let i = 0; i < items.length; i++) {
            const value = items[i];
            selectItems.push({
                label: displayValue(value, this.displayKey),
                id: lookupValue(value, this.lookupKey),
                secondaryText: objectGet(value, this.secondaryKey),
                value,
                selected: this.selectedItems?.includes(value) || false
            });
        }
        return selectItems;
    }
    /**
     * Convert Primitive data(Boolean, String, Number) to SelectableOptionItems Interface
     * @hidden
     */
    _convertPrimitiveToOptionItems(items) {
        const selectItems = [];
        for (let i = 0; i < items.length; i++) {
            const value = items[i];
            selectItems.push({
                label: value,
                id: lookupValue(value, this.lookupKey),
                value,
                selected: this.selectedItems?.includes(value) || false
            });
        }
        return selectItems;
    }
    /**
     * Convert T[] to SelectableOptionItems<T> Interface (Default)
     * @hidden
     */
    _convertObjectsToDefaultOptionItems(items) {
        const selectItems = [];
        for (let i = 0; i < items.length; i++) {
            const value = items[i];
            selectItems.push({
                label: displayValue(value, this.displayKey),
                id: lookupValue(value, this.lookupKey),
                value,
                selected: this.selectedItems?.includes(value) || false
            });
        }
        return selectItems;
    }
    /** @hidden */
    _setInvalidEntry() {
        if (this._previousState || this._previousStateMessage) {
            return;
        }
        this._previousState = this._cva.state;
        this._cva.state = 'error';
        this._previousStateMessage = this._cva.stateMessage;
        this._cva.stateMessage = this.invalidEntryMessage;
        this._cd.markForCheck();
    }
    /** @hidden */
    _unsetInvalidEntry() {
        this._cva.state = this._previousState;
        this._previousState = undefined;
        this._cva.stateMessage = this._previousStateMessage;
        this._previousStateMessage = undefined;
        this._cd.markForCheck();
    }
    /** @hidden */
    _focusToSearchField() {
        this.searchInputElement?.nativeElement.focus();
    }
    /** @hidden */
    _mapAndUpdateModel() {
        const selectedItems = this._selectedSuggestions.map(({ value }) => value);
        const shouldEmitChangeEvent = !equal(this.selectedItems, selectedItems);
        if (!shouldEmitChangeEvent) {
            return;
        }
        this.writeValue(selectedItems);
        this._cva.onChange(selectedItems);
        this._emitChangeEvent();
    }
    /**
     * @hidden
     * Prepares the data stream and subscribes to it.
     */
    _openDataStream(matchingStrategy) {
        const dataSourceProvider = this.dataSourceDirective.dataSourceProvider;
        if (!dataSourceProvider) {
            throw new Error(`[dataSource] source did not match an array, Observable, or DataSource`);
        }
        dataSourceProvider.limitless = this.limitless;
        dataSourceProvider.dataProvider.setLookupKey(this.lookupKey);
        const matchingBy = {
            firstBy: this._displayFn
        };
        if (this.secondaryKey) {
            matchingBy.secondaryBy = this._secondaryFn;
        }
        dataSourceProvider.dataProvider.setMatchingBy(matchingBy);
        dataSourceProvider.dataProvider.setMatchingStrategy(matchingStrategy);
        // initial data fetch
        const map = new Map();
        map.set('query', '*');
        if (!this.limitless) {
            map.set('limit', this._mapLimit);
        }
        else {
            dataSourceProvider.dataProvider['defaultLimit'] = Number.MAX_SAFE_INTEGER;
        }
        dataSourceProvider.match(map);
        this._dsSubscription = new Subscription();
        this._dsSubscription.add(this.dataSourceDirective.dataSourceProvider?.dataRequested.subscribe(this.dataRequested));
        this._dsSubscription.add(this.dataSourceDirective.dataSourceProvider?.dataReceived.subscribe(this.dataReceived));
        this.dataSourceDirective.dataSourceChanged
            .pipe(startWith(true), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => {
            this._dataSourceChanged = true;
        });
        this.dataSourceDirective.dataChanged$.pipe(skip(0), takeUntilDestroyed(this._destroyRef)).subscribe((data) => {
            if (data.length === 0) {
                this._processingEmptyData();
                return;
            }
            this._previousInputText = this.inputText;
            this._parseDataSourceValue(data);
            this._cva.stateChanges.next('initDataSource.open().');
            this._cd.markForCheck();
        });
    }
    /**
     * Parses the data from the data stream and updates the model if needed.
     * @param data array of objects from the data stream.
     */
    _parseDataSourceValue(data) {
        this._convertDataSourceSuggestions(data);
        const selectedSuggestionsLength = this._selectedSuggestions.length;
        if (selectedSuggestionsLength > 0) {
            for (let i = 0; i < selectedSuggestionsLength; i++) {
                const selectedSuggestion = this._selectedSuggestions[i];
                const idx = this._suggestions.findIndex((item) => equal(item.value, selectedSuggestion.value));
                if (idx !== -1) {
                    this._suggestions[idx].selected = true;
                }
            }
        }
        if (this._dataSourceChanged) {
            this._flatSuggestions = this.isGroup ? flattenGroups(this._suggestions) : this._suggestions;
            this._fullFlatSuggestions = this._flatSuggestions;
            this._setSelectedSuggestions();
            this._mapAndUpdateModel();
            this._dataSourceChanged = false;
        }
    }
    /**
     * Transforms plain array into `SelectableOptionItem<T>`
     * @param data
     */
    _convertDataSourceSuggestions(data) {
        this._suggestions = this._convertToOptionItems(data).map((optionItem) => {
            const selectedElement = this._selectedSuggestions.find((selectedItem) => selectedItem.id === optionItem.id);
            if (selectedElement) {
                optionItem.selected = selectedElement.selected;
            }
            return optionItem;
        });
    }
    /** @hidden */
    _processingEmptyData() {
        if (this._cva.disabled) {
            return;
        }
        if (this._cva.controlInvalid && this._cva.ngControl?.hasError) {
            this._setInvalidEntry();
            if (this._timerSub$) {
                this._timerSub$.unsubscribe();
            }
        }
        this.inputText = this._previousInputText;
        this._timerSub$ = timer(this.invalidEntryDisplayTime).subscribe(() => this._unsetInvalidEntry());
        this._cd.detectChanges();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BaseMultiCombobox, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: BaseMultiCombobox, isStandalone: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BaseMultiCombobox, decorators: [{
            type: Directive
        }] });

const MULTI_COMBOBOX_COMPONENT = new InjectionToken('FdMultiComboboxInterface');

class MobileMultiComboboxComponent extends MobileModeBase {
    /** @hidden */
    constructor(multiComboboxComponent) {
        super(multiComboboxComponent, MobileModeControl.MULTI_COMBOBOX);
        /** @hidden
         * For internal usage
         * Control element, which will be rendered inside dialog.
         * List element, which will be rendered inside dialog.
         */
        this.childContent = null;
        /** @hidden */
        this.selectedShown$ = this._component.selectedShown$;
    }
    /** @hidden */
    ngOnInit() {
        this._listenOnMultiComboboxOpenChange();
    }
    /** @hidden */
    showSelected() {
        const isSelectedShown = this.selectedShown$.getValue();
        if (isSelectedShown) {
            this._component._searchTermChanged();
            this.selectedShown$.next(false);
            return;
        }
        this._component._moreClicked();
    }
    /** @hidden */
    handleDismiss() {
        this.dialogRef.dismiss();
        this._component._dialogDismiss(this._selectedBackup);
    }
    /** @hidden */
    handleApprove() {
        this.dialogRef.close();
        this._component._dialogApprove();
    }
    /** @hidden */
    _toggleDialog(open) {
        if (!open) {
            return;
        }
        this._selectedBackup = this._component._selectedSuggestions?.length
            ? [...this._component._selectedSuggestions]
            : [];
        if (!this._dialogService.hasOpenDialogs()) {
            this._open();
        }
    }
    /** @hidden */
    _listenOnMultiComboboxOpenChange() {
        this._component.openChange
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe((isOpen) => this._toggleDialog(isOpen));
    }
    /** @hidden */
    _open() {
        this.dialogRef = this._dialogService.open(this.dialogTemplate, {
            mobile: true,
            ...this.dialogConfig,
            backdropClickCloseable: false,
            escKeyCloseable: false,
            container: this._elementRef.nativeElement,
            disablePaddings: true
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MobileMultiComboboxComponent, deps: [{ token: MULTI_COMBOBOX_COMPONENT }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: MobileMultiComboboxComponent, isStandalone: true, selector: "fd-mobile-multi-combobox", viewQueries: [{ propertyName: "dialogTemplate", first: true, predicate: ["dialogTemplate"], descendants: true }], usesInheritance: true, ngImport: i0, template: "<ng-template [fdDialogTemplate] let-dialog let-dialogConfig=\"dialogConfig\" #dialogTemplate>\n    <fd-dialog [dialogConfig]=\"dialogConfig\" [dialogRef]=\"dialog\">\n        <fd-dialog-header>\n            @if (mobileConfig.title) {\n                <h1 fd-title fd-dialog-title>{{ mobileConfig.title }}</h1>\n            }\n            @if (mobileConfig.hasCloseButton) {\n                <button fd-dialog-close-button [mobile]=\"true\" (click)=\"handleDismiss()\"></button>\n            }\n            <ng-template fdkTemplate=\"subheader\">\n                <div fd-bar-middle>\n                    <fd-bar-element [fullWidth]=\"true\">\n                        <ng-template [ngTemplateOutlet]=\"childContent?.controlTemplate || null\"></ng-template>\n                        @if (selectedShown$ | async) {\n                            <button\n                                fd-button\n                                glyph=\"multiselect-all\"\n                                fdType=\"emphasized\"\n                                [title]=\"'platformMultiCombobox.mobileShowAllItemsButton' | fdTranslate\"\n                                [attr.aria-label]=\"'platformMultiCombobox.mobileShowAllItemsButton' | fdTranslate\"\n                                class=\"fd-margin-begin--tiny\"\n                                (click)=\"showSelected()\"\n                            ></button>\n                        }\n                        @if ((selectedShown$ | async) === false) {\n                            <button\n                                fd-button\n                                glyph=\"multiselect-all\"\n                                fdType=\"transparent\"\n                                [title]=\"'platformMultiCombobox.mobileShowSelectedItemsButton' | fdTranslate\"\n                                [attr.aria-label]=\"'platformMultiCombobox.mobileShowSelectedItemsButton' | fdTranslate\"\n                                class=\"fd-margin-begin--tiny\"\n                                (click)=\"showSelected()\"\n                            ></button>\n                        }\n                    </fd-bar-element>\n                </div>\n            </ng-template>\n        </fd-dialog-header>\n        <fd-dialog-body>\n            <ng-template [ngTemplateOutlet]=\"childContent?.listTemplate || null\"></ng-template>\n        </fd-dialog-body>\n        <fd-dialog-footer>\n            @if (mobileConfig.approveButtonText) {\n                <fd-button-bar fdType=\"emphasized\" [label]=\"mobileConfig.approveButtonText!\" (click)=\"handleApprove()\">\n                </fd-button-bar>\n            }\n            @if (mobileConfig.cancelButtonText) {\n                <fd-button-bar [label]=\"mobileConfig.cancelButtonText!\" (click)=\"handleDismiss()\"> </fd-button-bar>\n            }\n        </fd-dialog-footer>\n    </fd-dialog>\n</ng-template>\n", styles: [""], dependencies: [{ kind: "ngmodule", type: TemplateModule }, { kind: "directive", type: i1.TemplateDirective, selector: "[fdkTemplate]", inputs: ["fdkTemplate"] }, { kind: "directive", type: BarMiddleDirective, selector: "[fd-bar-middle]" }, { kind: "directive", type: BarElementDirective, selector: "fd-bar-element", inputs: ["fullWidth"] }, { kind: "component", type: ButtonBarComponent, selector: "fd-button-bar", inputs: ["fullWidth", "fdType", "title", "ariaLabelledby", "id"] }, { kind: "component", type: TitleComponent, selector: "[fd-title], [fdTitle]", inputs: ["headerSize", "wrap"], exportAs: ["fd-title"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }, { kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "component", type: DialogComponent, selector: "fd-dialog", inputs: ["class", "dialogRef", "dialogConfig"] }, { kind: "component", type: DialogHeaderComponent, selector: "fd-dialog-header" }, { kind: "component", type: DialogCloseButtonComponent, selector: "[fd-dialog-close-button]", inputs: ["mobile", "title", "ariaLabel"] }, { kind: "component", type: DialogBodyComponent, selector: "fd-dialog-body", inputs: ["disablePaddings"] }, { kind: "component", type: DialogFooterComponent, selector: "fd-dialog-footer" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MobileMultiComboboxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-mobile-multi-combobox', imports: [
                        TemplateModule,
                        BarMiddleDirective,
                        BarElementDirective,
                        ButtonBarComponent,
                        TitleComponent,
                        TitleComponent,
                        TemplateDirective,
                        BarMiddleDirective,
                        BarElementDirective,
                        NgTemplateOutlet,
                        ButtonComponent,
                        ButtonBarComponent,
                        FdTranslatePipe,
                        AsyncPipe,
                        DialogComponent,
                        DialogHeaderComponent,
                        DialogCloseButtonComponent,
                        DialogBodyComponent,
                        DialogFooterComponent
                    ], template: "<ng-template [fdDialogTemplate] let-dialog let-dialogConfig=\"dialogConfig\" #dialogTemplate>\n    <fd-dialog [dialogConfig]=\"dialogConfig\" [dialogRef]=\"dialog\">\n        <fd-dialog-header>\n            @if (mobileConfig.title) {\n                <h1 fd-title fd-dialog-title>{{ mobileConfig.title }}</h1>\n            }\n            @if (mobileConfig.hasCloseButton) {\n                <button fd-dialog-close-button [mobile]=\"true\" (click)=\"handleDismiss()\"></button>\n            }\n            <ng-template fdkTemplate=\"subheader\">\n                <div fd-bar-middle>\n                    <fd-bar-element [fullWidth]=\"true\">\n                        <ng-template [ngTemplateOutlet]=\"childContent?.controlTemplate || null\"></ng-template>\n                        @if (selectedShown$ | async) {\n                            <button\n                                fd-button\n                                glyph=\"multiselect-all\"\n                                fdType=\"emphasized\"\n                                [title]=\"'platformMultiCombobox.mobileShowAllItemsButton' | fdTranslate\"\n                                [attr.aria-label]=\"'platformMultiCombobox.mobileShowAllItemsButton' | fdTranslate\"\n                                class=\"fd-margin-begin--tiny\"\n                                (click)=\"showSelected()\"\n                            ></button>\n                        }\n                        @if ((selectedShown$ | async) === false) {\n                            <button\n                                fd-button\n                                glyph=\"multiselect-all\"\n                                fdType=\"transparent\"\n                                [title]=\"'platformMultiCombobox.mobileShowSelectedItemsButton' | fdTranslate\"\n                                [attr.aria-label]=\"'platformMultiCombobox.mobileShowSelectedItemsButton' | fdTranslate\"\n                                class=\"fd-margin-begin--tiny\"\n                                (click)=\"showSelected()\"\n                            ></button>\n                        }\n                    </fd-bar-element>\n                </div>\n            </ng-template>\n        </fd-dialog-header>\n        <fd-dialog-body>\n            <ng-template [ngTemplateOutlet]=\"childContent?.listTemplate || null\"></ng-template>\n        </fd-dialog-body>\n        <fd-dialog-footer>\n            @if (mobileConfig.approveButtonText) {\n                <fd-button-bar fdType=\"emphasized\" [label]=\"mobileConfig.approveButtonText!\" (click)=\"handleApprove()\">\n                </fd-button-bar>\n            }\n            @if (mobileConfig.cancelButtonText) {\n                <fd-button-bar [label]=\"mobileConfig.cancelButtonText!\" (click)=\"handleDismiss()\"> </fd-button-bar>\n            }\n        </fd-dialog-footer>\n    </fd-dialog>\n</ng-template>\n" }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MULTI_COMBOBOX_COMPONENT]
                }] }], propDecorators: { dialogTemplate: [{
                type: ViewChild,
                args: ['dialogTemplate']
            }] } });

class FdMultiComboBoxDataSource extends BaseDataSource {
    /** @hidden */
    constructor(dataProvider) {
        super(dataProvider);
        this.dataProvider = dataProvider;
        /** @hidden */
        this.limitless = false;
    }
}
class ArrayMultiComboBoxDataSource extends FdMultiComboBoxDataSource {
    /** @hidden */
    constructor(data) {
        super(new DataProvider(data));
    }
}
class ObservableMultiComboBoxDataSource extends FdMultiComboBoxDataSource {
    /** @hidden */
    constructor(data) {
        super(new DataProvider(data));
    }
}

class MultiComboboxDataSourceParser {
    /**
     * Transforms plain array or observable into DataSource class.
     * @param source
     */
    parse(source) {
        if (isDataSource(source)) {
            return source;
        }
        if (Array.isArray(source)) {
            return new ArrayMultiComboBoxDataSource(source);
        }
        if (isObservable(source)) {
            return new ObservableMultiComboBoxDataSource(source);
        }
        return undefined;
    }
}

class SelectAllTogglerComponent extends ListFocusItem {
    constructor() {
        super(...arguments);
        /** @hidden */
        this.selectedItems = [];
        /** @hidden */
        this.flatItems = [];
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this.changeDetector = inject(ChangeDetectorRef);
    }
    /** @hidden */
    get allAreSelected() {
        return this.selectedItems.length === this.flatItems.length;
    }
    /** @hidden */
    get someAreSelected() {
        return this.selectedItems.length > 0 && !this.allAreSelected;
    }
    /** @hidden */
    get checkboxValue() {
        if (this.allAreSelected) {
            return true;
        }
        if (this.someAreSelected) {
            return null;
        }
        return false;
    }
    /** @hidden */
    onKeyDown($event) {
        $event.preventDefault();
        this.change(!this.checkboxValue);
    }
    /** @hidden */
    onClick() {
        this.elementRef.nativeElement.focus();
        this.change(!this.checkboxValue);
    }
    /** @hidden */
    ngOnInit() {
        this.tabindex = 0;
        this.valueChanges.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this.changeDetector.detectChanges();
        });
    }
    /** @hidden */
    change(value) {
        this.selectAllHandler(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SelectAllTogglerComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: SelectAllTogglerComponent, isStandalone: true, selector: "fd-multi-combobox-select-all-toggler", inputs: { selectAllHandler: "selectAllHandler", valueChanges: "valueChanges", selectedItems: "selectedItems", flatItems: "flatItems" }, host: { listeners: { "keydown.enter": "onKeyDown($event)", "keydown.space": "onKeyDown($event)", "click": "onClick()" } }, providers: [
            {
                provide: ListFocusItem,
                useExisting: SelectAllTogglerComponent
            }
        ], usesInheritance: true, ngImport: i0, template: `
        <fd-toolbar>
            <div fd-form-item class="fd-multi-combobox-select-all__form-item">
                <fd-checkbox tabIndexValue="-1" [ngModel]="checkboxValue" [tristate]="true">
                    {{
                        'coreMultiComboBox.selectAllLabel'
                            | fdTranslate: { selectedItems: selectedItems.length, totalItems: flatItems.length }
                    }}
                </fd-checkbox>
            </div>
        </fd-toolbar>
    `, isInline: true, styles: ["fd-multi-combobox-select-all-toggler{display:block;background-color:var(--sapBackgroundColor);cursor:pointer;position:sticky;top:0;z-index:1}fd-multi-combobox-select-all-toggler:focus,fd-multi-combobox-select-all-toggler.is-focus{outline-offset:-.1875rem;outline-width:var(--sapContent_FocusWidth);outline-style:var(--sapContent_FocusStyle);outline-color:var(--sapContent_FocusColor)}fd-multi-combobox-select-all-toggler .fd-toolbar{padding-left:0;padding-right:0}fd-multi-combobox-select-all-toggler .fd-multi-combobox-select-all__form-item{display:flex;flex-direction:row;align-items:center;font-weight:700}fd-multi-combobox-select-all-toggler .fd-multi-combobox-select-all__form-item fd-checkbox{pointer-events:none}fd-multi-combobox-select-all-toggler .fd-multi-combobox-select-all__form-item fd-checkbox .fd-checkbox__checkmark{margin-inline-end:.5rem}fd-multi-combobox-select-all-toggler .fd-multi-combobox-select-all__form-item fd-checkbox .fd-checkbox__text{font-weight:700!important}\n"], dependencies: [{ kind: "component", type: ToolbarComponent, selector: "fd-toolbar", inputs: ["titleId", "class", "shouldOverflow", "fdType", "title", "active", "clearBorder", "forceOverflow", "tabindex", "headingLevel", "ariaLabel", "ariaLabelledBy"] }, { kind: "component", type: FormItemComponent, selector: "[fd-form-item]", inputs: ["isInline", "horizontal"] }, { kind: "component", type: CheckboxComponent, selector: "fd-checkbox", inputs: ["wrapLabel", "valignLabel", "ariaLabel", "role", "value", "ariaLabelledBy", "ariaDescribedBy", "title", "inputId", "state", "name", "label", "disabled", "readonly", "tristate", "tristateSelectable", "labelClass", "required", "displayOnly", "values", "standalone"], outputs: ["focusChange"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i4.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SelectAllTogglerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-multi-combobox-select-all-toggler', template: `
        <fd-toolbar>
            <div fd-form-item class="fd-multi-combobox-select-all__form-item">
                <fd-checkbox tabIndexValue="-1" [ngModel]="checkboxValue" [tristate]="true">
                    {{
                        'coreMultiComboBox.selectAllLabel'
                            | fdTranslate: { selectedItems: selectedItems.length, totalItems: flatItems.length }
                    }}
                </fd-checkbox>
            </div>
        </fd-toolbar>
    `, providers: [
                        {
                            provide: ListFocusItem,
                            useExisting: SelectAllTogglerComponent
                        }
                    ], encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, imports: [ToolbarComponent, FormItemComponent, CheckboxComponent, FormsModule, FdTranslatePipe], styles: ["fd-multi-combobox-select-all-toggler{display:block;background-color:var(--sapBackgroundColor);cursor:pointer;position:sticky;top:0;z-index:1}fd-multi-combobox-select-all-toggler:focus,fd-multi-combobox-select-all-toggler.is-focus{outline-offset:-.1875rem;outline-width:var(--sapContent_FocusWidth);outline-style:var(--sapContent_FocusStyle);outline-color:var(--sapContent_FocusColor)}fd-multi-combobox-select-all-toggler .fd-toolbar{padding-left:0;padding-right:0}fd-multi-combobox-select-all-toggler .fd-multi-combobox-select-all__form-item{display:flex;flex-direction:row;align-items:center;font-weight:700}fd-multi-combobox-select-all-toggler .fd-multi-combobox-select-all__form-item fd-checkbox{pointer-events:none}fd-multi-combobox-select-all-toggler .fd-multi-combobox-select-all__form-item fd-checkbox .fd-checkbox__checkmark{margin-inline-end:.5rem}fd-multi-combobox-select-all-toggler .fd-multi-combobox-select-all__form-item fd-checkbox .fd-checkbox__text{font-weight:700!important}\n"] }]
        }], propDecorators: { selectAllHandler: [{
                type: Input
            }], valueChanges: [{
                type: Input
            }], selectedItems: [{
                type: Input
            }], flatItems: [{
                type: Input
            }], onKeyDown: [{
                type: HostListener,
                args: ['keydown.enter', ['$event']]
            }, {
                type: HostListener,
                args: ['keydown.space', ['$event']]
            }], onClick: [{
                type: HostListener,
                args: ['click']
            }] } });

const FD_MAP_LIMIT = new InjectionToken('Map limit≥', { factory: () => 12 });
class MultiComboboxComponent extends BaseMultiCombobox {
    /** Provides selected items. */
    set selectedItems(value) {
        this._selectedItems = coerceArraySafe(value);
    }
    get selectedItems() {
        return this._selectedItems;
    }
    /** @hidden */
    get _popoverMaxWidth() {
        if (this.bodyMaxWidth === 'none') {
            return null;
        }
        if (typeof this.bodyMaxWidth === 'number') {
            return this.bodyMaxWidth;
        }
        return this._elementRef.nativeElement.getBoundingClientRect().width;
    }
    /** Value of the multi combobox */
    set value(value) {
        this.setValue(value, true);
    }
    get value() {
        return this._cva.value;
    }
    /** Set the input text of the input. */
    set inputText(value) {
        this._inputTextValue = value;
        this._cva.onTouched();
    }
    /** Get the input text of the input. */
    get inputText() {
        return this._inputTextValue || '';
    }
    /** Is empty search field. */
    get isEmptyValue() {
        return this.inputText.trim().length === 0;
    }
    /** @hidden */
    get isGroup() {
        return !!(this.group && this.groupKey);
    }
    /** @hidden */
    constructor(_elementRef, _injector, _viewContainerRef, _dynamicComponentService) {
        super();
        this._elementRef = _elementRef;
        this._injector = _injector;
        this._viewContainerRef = _viewContainerRef;
        this._dynamicComponentService = _dynamicComponentService;
        /**
         * Show select all checkbox
         */
        this.showSelectAll = false;
        /** Provides maximum height for the optionPanel. */
        this.maxHeight = '250px';
        /**
         * Whether AddOn Button should be focusable
         * @default false
         */
        this.buttonFocusable = false;
        /** Whether the autocomplete should be enabled; Enabled by default. */
        this.autoComplete = true;
        /** Whether list item options should be rendered as byline. */
        this.byline = false;
        /**
         * Max width of multi combobox dropdown body.
         * `none` will not limit width of the dropdown.
         * `container` will limit width of the dropdown to the width of the multi-input itself.
         * `number` will limit width of the dropdown by provided number in pixels.
         */
        this.bodyMaxWidth = 'none';
        /** Whether the multi-combobox should be built on mobile mode. */
        this.mobile = false;
        /** Tells the multi-combobox if we need to group items. */
        this.group = false;
        /** Show the second column (applicable for two columns layout). */
        this.showSecondaryText = false;
        /** Horizontally align text inside the second column (applicable for two columns layout). */
        this.secondaryTextAlignment = 'right';
        /** Turns on/off Adjustable Width feature. */
        this.autoResize = true;
        /** Whether to open the dropdown when the addon button is clicked. */
        this.openDropdownOnAddOnClicked = true;
        /**
         * Preset options for the Select body width, whatever is chosen, the body has a 600px limit.
         * * `at-least` will apply a minimum width to the body equivalent to the width of the control. - Default
         * * `equal` will apply a width to the body equivalent to the width of the control.
         * * 'fit-content' will apply width needed to properly display items inside, independent of control.
         */
        this.fillControlMode = 'at-least';
        /** Time in ms for how long message of invalid entry should be displayed. */
        this.invalidEntryDisplayTime = 3000;
        /**
         * String matching strategy for typeahead list.
         * Available options: 'starts with per term', 'starts with', 'contains'
         * Default: 'starts with per term' */
        this.matchingStrategy = MatchingStrategy.STARTS_WITH_PER_TERM;
        /** Event emitted when item is selected. */
        this.selectionChange = new EventEmitter();
        /** @hidden Emits event when the menu is opened/closed. */
        this.isOpenChange = new EventEmitter();
        /** Emits event when the addon button is clicked. */
        this.addOnButtonClicked = new EventEmitter();
        /** Event emitted when data loading is started. */
        this.dataRequested = new EventEmitter();
        /** Event emitted when data loading is finished. */
        this.dataReceived = new EventEmitter();
        /** @hidden */
        this._contentDensity = this._multiComboboxConfig?.contentDensity ?? 'cozy';
        /** Whether the Multi Input is opened. */
        this.isOpen = false;
        /**
         * @hidden
         * Need for opening mobile version
         */
        this.openChange = new Subject();
        /** @hidden */
        this._selectedItems = [];
        /** @hidden */
        this._lang$ = inject(FD_LANGUAGE);
        /** @hidden */
        this._translationResolver = new TranslationResolver();
        /**
         * @hidden
         * Method that selects all possible options.
         * *select* attribute – if *true* select all, if *false* unselect all
         * */
        this._handleSelectAllItems = (select) => {
            this._flatSuggestions.forEach((item) => (item.selected = select));
            this._onEveryItem(this._suggestions, (item) => (item.selected = select));
            this._selectedSuggestions = select ? [...this._flatSuggestions] : [];
            this._rangeSelector.reset();
            this.inputText = '';
            this._propagateChange();
        };
        this.contentDensityObserver.subscribe();
    }
    /** @hidden */
    ngOnInit() {
        this.cvaControl.listenToChanges();
        this._openDataStream(this.matchingStrategy);
        this._lang$.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((lang) => {
            this.invalidEntryMessage = this._translationResolver.resolve(lang, 'platformMultiCombobox.invalidEntryError');
        });
    }
    /** @hidden */
    async ngAfterViewInit() {
        if (this.mobile) {
            await this._setUpMobileMode();
        }
        this._assignCustomTemplates();
        this._initWindowResize();
    }
    /** @hidden */
    _toggleSelection(item, fromTokenCloseClick = false) {
        const idx = getTokenIndexByIdlOrValue(item, this._selectedSuggestions);
        if (idx === -1) {
            this._selectedSuggestions.push(item);
        }
        else {
            this._selectedSuggestions.splice(idx, 1);
        }
        item.selected = !item.selected;
        this._propagateChange(fromTokenCloseClick);
        if (!this._selectedSuggestions.length) {
            this._focusToSearchField();
        }
        this._cd.detectChanges();
    }
    /** @hidden */
    _onOptionCheckboxClicked(event, index) {
        event.stopPropagation();
        this._onListElementClicked(event, index);
        this.inputText = '';
        this._searchTermChanged('');
    }
    /** @hidden */
    _onCompleteTerm(event) {
        if (event.forceClose) {
            this._toggleSelectionByInputText(event.term);
            this.close();
        }
    }
    /** @hidden */
    _navigateByTokens(event) {
        if (KeyUtil.isKeyCode(event, [DOWN_ARROW, UP_ARROW]) && this.isOpen) {
            this.listComponent.items?.first.focus();
        }
    }
    /** @hidden */
    _removeToken(token, event) {
        if (event) {
            event.preventDefault();
        }
        const optionItem = this._flatSuggestions.find((s) => s.value === token.value);
        if (optionItem) {
            this._toggleSelection(optionItem, true);
            this._rangeSelector.reset();
        }
    }
    /** @hidden */
    _moreClicked() {
        this._suggestions = this.isGroup
            ? this._convertObjectsToGroupOptionItems(this._selectedSuggestions.map(({ value }) => value))
            : this._suggestions.filter((value) => this._selectedSuggestions.some((item) => equal(item.value, value.value)));
        this._showList(true);
        this.selectedShown$.next(true);
        this._cd.markForCheck();
    }
    /** @hidden */
    _onBlur(event) {
        const target = event.relatedTarget;
        if (target) {
            const isList = !!target.closest('.fd-multi-combobox__list-container');
            if (isList) {
                return;
            }
            if (this._suggestions?.length === 1 &&
                this._suggestions[0].label === this.inputText &&
                !this._suggestions[0].selected) {
                this._toggleSelection(this._suggestions[0]);
            }
            this._showList(false);
            this.inputText = '';
        }
        this._cva.onTouched();
    }
    /** @hidden */
    _onItemKeyDownHandler(event) {
        if (KeyUtil.isKeyCode(event, ESCAPE)) {
            this._focusToSearchField();
        }
        else if ((event.ctrlKey || event.metaKey) && event.shiftKey && KeyUtil.isKeyCode(event, A)) {
            event.preventDefault();
            this._handleSelectAllItems(false);
        }
        else if ((event.ctrlKey || event.metaKey) && KeyUtil.isKeyCode(event, A)) {
            event.preventDefault();
            this._handleSelectAllItems(true);
        }
        else if (KeyUtil.isKeyCode(event, ENTER)) {
            if (!this.mobile) {
                this.close();
            }
            this._rangeSelector.reset();
        }
        else if (KeyUtil.isKeyCode(event, SPACE)) {
            this._rangeSelector.reset();
        }
    }
    /** @hidden */
    _onOptionClicked(event, index) {
        this._onListElementClicked(event, index);
        this.close();
    }
    /**
     * @hidden
     * Handle dialog dismissing, closes popover and sets backup data.
     */
    _dialogDismiss(backup) {
        this._selectedSuggestions = [...backup];
        this.inputText = '';
        this._showList(false);
        this.selectedShown$.next(false);
    }
    /**
     * @hidden
     * Handle dialog approval, closes popover and propagates data changes.
     */
    _dialogApprove() {
        this.inputText = '';
        this._showList(false);
        this._propagateChange(true);
    }
    /** @hidden */
    _popoverOpenChangeHandle(isOpen) {
        this.isOpen = isOpen;
        this._rangeSelector.reset();
        if (!isOpen) {
            this._cva.onTouched();
        }
    }
    /** Opens the select popover body. */
    open() {
        this.isOpen = true;
        this.isOpenChange.emit(this.isOpen);
        this._cd.markForCheck();
    }
    /** Closes the select popover body. */
    close() {
        this._focusToSearchField();
        this._rangeSelector.reset();
        this.selectedShown$.next(false);
        this.inputText = '';
        this.isOpen = false;
        this.isOpenChange.emit(this.isOpen);
        this._cva.onTouched();
        this._cd.markForCheck();
    }
    /** @hidden */
    _showList(isOpen) {
        if (this.isOpen !== isOpen) {
            this.isOpen = isOpen;
            this._cva.onTouched();
            this.openChange.next(isOpen);
        }
        if (!this.isOpen) {
            this._searchTermChanged('');
        }
        this._cd.markForCheck();
    }
    /** @hidden */
    _searchTermChanged(text = this.inputText) {
        const map = new Map();
        map.set('query', text);
        if (!this.limitless) {
            map.set('limit', this._mapLimit);
        }
        else {
            map.set('limit', Number.MAX_SAFE_INTEGER);
        }
        this.dataSourceDirective.dataSourceProvider?.match(map);
        if (text) {
            this.open();
        }
        this._cd.markForCheck();
    }
    /**
     * Handle Click on Button
     * @hidden
     */
    _onPrimaryButtonClick(isOpen) {
        if (!isOpen) {
            this._searchTermChanged('');
        }
        if (this.openDropdownOnAddOnClicked) {
            this._showList(!isOpen);
        }
        else if (this.isOpen) {
            this._showList(false);
        }
        if (this.isOpen) {
            this.searchInputElement?.nativeElement.focus();
        }
    }
    /**
     * Handle Keydown on Input
     * @hidden
     */
    _onInputKeydownHandler(event) {
        if (this._cva.readonly) {
            return;
        }
        if (KeyUtil.isKeyCode(event, DOWN_ARROW)) {
            event.preventDefault();
            if (event.altKey) {
                this._showList(true);
            }
            if (this.isOpen && this.listComponent) {
                this.listComponent.setItemActive(0);
            }
            else if (!this.isOpen) {
                this._chooseOtherItem(1);
            }
        }
        else if (KeyUtil.isKeyCode(event, UP_ARROW)) {
            event.preventDefault();
            this._chooseOtherItem(-1);
        }
        else if (KeyUtil.isKeyCode(event, ENTER)) {
            this._toggleSelectionByInputText();
        }
        else if (!KeyUtil.isKeyCode(event, [...this._nonOpeningKeys, CONTROL])) {
            this._showList(true);
            const acceptedKeys = !KeyUtil.isKeyType(event, 'alphabetical') &&
                !KeyUtil.isKeyType(event, 'numeric') &&
                !KeyUtil.isKeyType(event, 'ime');
            if (acceptedKeys) {
                // SetTimeout is needed for input to receive new value.
                setTimeout(() => {
                    if (this.isEmptyValue) {
                        this.listComponent?.setItemActive(0);
                    }
                });
            }
        }
    }
    /**
     * @hidden
     * Method passed to list component.
     */
    _handleListFocusEscape(direction) {
        if (direction === 'up') {
            this._focusToSearchField();
        }
    }
    /**
     * @hidden
     */
    _addOnClicked($event) {
        this.addOnButtonClicked.emit($event);
        if (!this.mobile) {
            this._onPrimaryButtonClick(this.isOpen);
        }
    }
    /** @hidden */
    _setLimitless(limitless) {
        this.limitless = limitless;
    }
    /** @hidden */
    _getMapLimit() {
        return this.limitless ? this.dataSourceDirective.dataSource.length : this._mapLimit;
    }
    /**
     * @hidden
     * Iterate over every item and perform callback
     */
    _onEveryItem(items, callback) {
        items.forEach((item) => {
            callback(item);
            if (item.children && item.children.length > 0) {
                this._onEveryItem(item.children, callback);
            }
        });
    }
    /** @hidden */
    _toggleSelectionByInputText(text = this.inputText) {
        const item = getSelectItemByInputValue(this._fullFlatSuggestions, text);
        if (item) {
            this._toggleSelection(item);
            this.inputText = '';
        }
        this._searchTermChanged();
    }
    /**
     * @hidden
     * Method to set input text as item label.
     */
    _setInputTextFromOptionItem(item) {
        this.inputText = item.label;
        if (this.mobile) {
            return;
        }
        this._showList(false);
    }
    /**
     * @hidden
     * applying range selection. Note, that this function will be invoked after combobox item's value has been changed
     */
    _onListElementClicked(event, index) {
        // value has been changed at this point, so it can be safely used
        const selectionState = this._flatSuggestions[index].selected;
        this._rangeSelector.onRangeElementToggled(index, event);
        const toRemoveSet = new Set();
        this._rangeSelector.applyValueToEachInRange((idx) => {
            const current = this._flatSuggestions[idx];
            if (current.selected !== selectionState) {
                if (current.selected) {
                    // removing from "_selectedSuggestions" list
                    toRemoveSet.add(current.value);
                }
                else {
                    // adding current item to "_selectedSuggestions"
                    this._selectedSuggestions.push(current);
                }
                current.selected = selectionState;
            }
        });
        this._selectedSuggestions = this._selectedSuggestions.filter((s) => !toRemoveSet.has(s.value));
        this._propagateChange();
        this._tokenizer.onResize();
        this._tokenizer.tokenizerInnerEl.nativeElement.scrollLeft =
            this._tokenizer.tokenizerInnerEl.nativeElement.scrollWidth;
    }
    /** @hidden */
    _propagateChange(emitInMobile) {
        if (!this.mobile || emitInMobile) {
            this._mapAndUpdateModel();
        }
    }
    /** @hidden */
    async _setUpMobileMode() {
        const injector = Injector.create({
            providers: [{ provide: MULTI_COMBOBOX_COMPONENT, useValue: this }],
            parent: this._injector
        });
        this._dynamicComponentService.createDynamicComponent({ listTemplate: this.listTemplate, controlTemplate: this.mobileControlTemplate }, MobileMultiComboboxComponent, {
            containerRef: this._viewContainerRef
        }, { injector });
    }
    /**
     * @hidden
     * Method that picks other value moved from current one by offset, called only when Multi Combobox is closed.
     */
    _chooseOtherItem(offset) {
        if (this._selectedSuggestions?.length === this._flatSuggestions.length) {
            this.inputText = '';
            return;
        }
        const activeValue = getSelectItemByInputValue(this._fullFlatSuggestions, this.inputText);
        const index = this._flatSuggestions.findIndex((value) => value === activeValue);
        const position = !this.inputText && offset === -1 ? this._flatSuggestions.length - 1 : index + offset;
        const item = this._flatSuggestions[position];
        if (item) {
            this._setInputTextFromOptionItem(item);
        }
        const selectedIndex = this._selectedSuggestions.findIndex((value) => value.label === item?.label);
        if (selectedIndex !== -1) {
            this._chooseOtherItem(offset);
        }
    }
    /** @hidden */
    _initWindowResize() {
        this._getOptionsListWidth();
        if (!this.autoResize) {
            return;
        }
        resizeObservable(this._inputGroup.nativeElement)
            .pipe(debounceTime(30), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => this._getOptionsListWidth());
    }
    /** @hidden */
    _getOptionsListWidth() {
        const body = document.body;
        const rect = this._inputGroup.nativeElement.getBoundingClientRect();
        const scrollBarWidth = body.offsetWidth - body.clientWidth;
        this.maxWidth = this.autoResize ? window.innerWidth - scrollBarWidth - rect.left : this.minWidth;
        this.minWidth = rect.width - 2;
        this._cd.detectChanges();
    }
    /**
     * @hidden
     * Assign custom templates
     */
    _assignCustomTemplates() {
        this.customTemplates.forEach((template) => {
            switch (template.name) {
                case 'optionItemTemplate':
                    this.optionItemTemplate = template.templateRef;
                    break;
                case 'groupItemTemplate':
                    this.groupItemTemplate = template.templateRef;
                    break;
                case 'secondaryItemTemplate':
                    this.secondaryItemTemplate = template.templateRef;
                    break;
                case 'selectedItemTemplate':
                    this.selectedItemTemplate = template.templateRef;
                    break;
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MultiComboboxComponent, deps: [{ token: i0.ElementRef }, { token: i0.Injector }, { token: i0.ViewContainerRef }, { token: i1.DynamicComponentService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: MultiComboboxComponent, isStandalone: true, selector: "fd-multi-combobox", inputs: { showSelectAll: "showSelectAll", selectedItems: "selectedItems", maxHeight: "maxHeight", buttonFocusable: "buttonFocusable", autoComplete: "autoComplete", byline: "byline", bodyMaxWidth: "bodyMaxWidth", entityClass: "entityClass", mobile: "mobile", mobileConfig: "mobileConfig", group: "group", groupKey: "groupKey", secondaryKey: "secondaryKey", showSecondaryText: "showSecondaryText", secondaryTextAlignment: "secondaryTextAlignment", autoResize: "autoResize", openDropdownOnAddOnClicked: "openDropdownOnAddOnClicked", value: "value", fillControlMode: "fillControlMode", addonIconTitle: "addonIconTitle", invalidEntryMessage: "invalidEntryMessage", limitless: "limitless", lookupKey: "lookupKey", displayKey: "displayKey", list: "list", invalidEntryDisplayTime: "invalidEntryDisplayTime", matchingStrategy: "matchingStrategy" }, outputs: { selectionChange: "selectionChange", isOpenChange: "isOpenChange", addOnButtonClicked: "addOnButtonClicked", dataRequested: "dataRequested", dataReceived: "dataReceived" }, providers: [
            CvaControl,
            DynamicComponentService,
            contentDensityObserverProviders(),
            {
                provide: FD_DATA_SOURCE_TRANSFORMER,
                useClass: MultiComboboxDataSourceParser
            },
            {
                provide: MULTI_COMBOBOX_COMPONENT,
                useExisting: MultiComboboxComponent
            }
        ], queries: [{ propertyName: "customTemplates", predicate: TemplateDirective }], viewQueries: [{ propertyName: "searchInputElement", first: true, predicate: ["searchInputElement"], descendants: true, read: ElementRef }, { propertyName: "listComponent", first: true, predicate: FD_LIST_COMPONENT, descendants: true }, { propertyName: "mobileControlTemplate", first: true, predicate: ["mobileControlTemplate"], descendants: true }, { propertyName: "listTemplate", first: true, predicate: ["listTemplate"], descendants: true }, { propertyName: "_tokenizer", first: true, predicate: TokenizerComponent, descendants: true }, { propertyName: "_inputGroup", first: true, predicate: ["inputGroup"], descendants: true, read: ElementRef }], usesInheritance: true, hostDirectives: [{ directive: i2.CvaDirective, inputs: ["id", "inputId", "placeholder", "placeholder", "state", "state", "stateMessage", "stateMessage", "disabled", "disabled", "readonly", "readonly", "name", "name"] }, { directive: i3.DataSourceDirective, inputs: ["dataSource", "dataSource"], outputs: ["dataChanged", "dataChanged"] }], ngImport: i0, template: "<div class=\"fd-multi-combobox\">\n    @if (mobile) {\n        <ng-template [ngTemplateOutlet]=\"controlTemplate\"></ng-template>\n    } @else {\n        <fd-popover\n            additionalBodyClass=\"fd-popover-custom-list fd-multi-combobox__list-container\"\n            (isOpenChange)=\"_popoverOpenChangeHandle($event)\"\n            [isOpen]=\"isOpen\"\n            [triggers]=\"[]\"\n            [disabled]=\"_cva.disabled\"\n            [maxWidth]=\"_popoverMaxWidth\"\n            [fillControlMode]=\"fillControlMode\"\n        >\n            <fd-popover-control>\n                <ng-template [ngTemplateOutlet]=\"controlTemplate\"></ng-template>\n            </fd-popover-control>\n            <fd-popover-body [style.width.%]=\"!autoResize && 100\">\n                <ng-template [ngTemplateOutlet]=\"listTemplate\"></ng-template>\n                <ng-content></ng-content>\n            </fd-popover-body>\n        </fd-popover>\n    }\n</div>\n<ng-template #controlTemplate>\n    <fd-form-input-message-group>\n        <fd-input-group\n            #inputGroup\n            [id]=\"_cva.id + '-input-group-container'\"\n            [state]=\"_cva.state\"\n            [buttonFocusable]=\"buttonFocusable\"\n            [button]=\"!_cva.readonly\"\n            [glyph]=\"!_cva.readonly ? 'navigation-down-arrow' : ' '\"\n            [isControl]=\"true\"\n            [disabled]=\"_cva.disabled || _cva.readonly\"\n            [isExpanded]=\"!mobile && isOpen && _suggestions.length > 0\"\n            [attr.aria-disabled]=\"_cva.disabled || _cva.readonly\"\n            [attr.aria-readonly]=\"_cva.readonly\"\n            [glyphAriaLabel]=\"_cva.ariaLabel || ('platformMultiCombobox.inputGlyphAriaLabel' | fdTranslate)\"\n            [iconTitle]=\"addonIconTitle || ('platformMultiCombobox.inputGlyphAriaLabel' | fdTranslate)\"\n            (addOnButtonClicked)=\"_addOnClicked($event)\"\n            (click)=\"mobile && !isOpen && _onPrimaryButtonClick(false)\"\n            (keydown)=\"_navigateByTokens($event)\"\n        >\n            <fd-tokenizer\n                [tokenizerFocusable]=\"false\"\n                [compactCollapse]=\"true\"\n                [showOverflowPopover]=\"false\"\n                #tokenizer\n                class=\"fd-multi-combobox-tokenizer-custom\"\n                (moreClickedEvent)=\"_moreClicked()\"\n                fdMultiAnnouncer\n                [multiAnnouncerOptions]=\"_suggestions\"\n            >\n                @for (token of _selectedSuggestions; track token) {\n                    <fd-token [readOnly]=\"_cva.disabled\" (onCloseClick)=\"_removeToken(token, $event)\">\n                        {{ token.label }}\n                    </fd-token>\n                }\n                <input\n                    #searchInputElement\n                    fdkAutoComplete\n                    (onComplete)=\"_onCompleteTerm($event)\"\n                    [options]=\"_suggestions\"\n                    [inputText]=\"inputText\"\n                    type=\"text\"\n                    role=\"combobox\"\n                    autocomplete=\"off\"\n                    [ariaLabel]=\"'coreMultiComboBox.multiComboBoxAriaLabel' | fdTranslate\"\n                    [attr.aria-labelledby]=\"_cva.ariaLabelledBy\"\n                    [attr.aria-autocomplete]=\"autoComplete && !mobile ? 'list' : null\"\n                    [attr.aria-owns]=\"autoComplete && !mobile ? _cva.id + '-result' : null\"\n                    [attr.aria-haspopup]=\"autoComplete && !mobile\"\n                    fd-form-control\n                    fd-input-group-input\n                    tabindex=\"0\"\n                    [id]=\"_cva.id\"\n                    [name]=\"_cva.name\"\n                    (keydown)=\"_onInputKeydownHandler($event)\"\n                    [disabled]=\"_cva.disabled\"\n                    [(ngModel)]=\"inputText\"\n                    (ngModelChange)=\"_searchTermChanged()\"\n                    [attr.placeholder]=\"_selectedSuggestions.length ? null : _cva.placeholder\"\n                    (focus)=\"tokenizer._showAllTokens()\"\n                    (blur)=\"!mobile && _onBlur($event); tokenizer._hideTokens()\"\n                    [attr.aria-expanded]=\"isOpen\"\n                    [readonly]=\"_cva.readonly\"\n                    [attr.aria-readonly]=\"_cva.readonly\"\n                    [attr.aria-required]=\"_cva.required\"\n                    [displayFn]=\"_displayFn\"\n                    class=\"fd-tokenizer__input fd-input-group__input\"\n                />\n            </fd-tokenizer>\n        </fd-input-group>\n        @if (mobile && isOpen ? false : !!_cva.stateMessage) {\n            <fd-form-message [type]=\"_cva.state\" [innerHtml]=\"_cva.stateMessage\"></fd-form-message>\n        }\n    </fd-form-input-message-group>\n</ng-template>\n<ng-template #mobileControlTemplate>\n    <fd-input-group\n        [id]=\"_cva.id + '-input-group-container'\"\n        class=\"fd-multi-combobox-input-group-custom\"\n        [state]=\"_cva.state\"\n        [buttonFocusable]=\"false\"\n        [isControl]=\"true\"\n        [disabled]=\"_cva.disabled || _cva.readonly\"\n        [isExpanded]=\"!mobile && isOpen && _suggestions.length > 0\"\n        [attr.aria-disabled]=\"_cva.disabled || _cva.readonly\"\n        [attr.aria-readonly]=\"_cva.readonly\"\n        [glyphAriaLabel]=\"_cva.ariaLabel\"\n    >\n        <input\n            fdkAutoComplete\n            (onComplete)=\"_onCompleteTerm($event)\"\n            [options]=\"_suggestions\"\n            [inputText]=\"inputText\"\n            type=\"text\"\n            role=\"combobox\"\n            autocomplete=\"off\"\n            [ariaLabel]=\"'coreMultiComboBox.multiComboBoxAriaLabel' | fdTranslate\"\n            [attr.aria-labelledby]=\"_cva.ariaLabelledBy\"\n            [attr.aria-autocomplete]=\"autoComplete && !mobile ? 'list' : null\"\n            [attr.aria-owns]=\"autoComplete && !mobile ? _cva.id + '-result' : null\"\n            [attr.aria-haspopup]=\"autoComplete && !mobile\"\n            fd-form-control\n            fd-input-group-input\n            tabindex=\"0\"\n            [id]=\"_cva.id\"\n            [name]=\"_cva.name\"\n            (keydown)=\"_onInputKeydownHandler($event)\"\n            [disabled]=\"_cva.disabled\"\n            [(ngModel)]=\"inputText\"\n            (ngModelChange)=\"_searchTermChanged()\"\n            [placeholder]=\"_cva.placeholder\"\n            (focus)=\"_cva.onTouched()\"\n            (blur)=\"!mobile && _onBlur($event)\"\n            [attr.aria-expanded]=\"isOpen\"\n            [readonly]=\"_cva.readonly\"\n            [attr.aria-readonly]=\"_cva.readonly\"\n            [displayFn]=\"_displayFn\"\n        />\n    </fd-input-group>\n</ng-template>\n<ng-template #listTemplate>\n    <ul\n        fd-list\n        [byline]=\"byline\"\n        [selection]=\"byline\"\n        (focusEscapeList)=\"_handleListFocusEscape($event)\"\n        class=\"fd-multi-combobox__list fd-list--multi-input\"\n        [id]=\"_cva.id + '-result'\"\n        role=\"listbox\"\n        [style.max-height]=\"!mobile && maxHeight\"\n        [style.min-width.px]=\"!mobile && minWidth\"\n        [style.max-width.px]=\"autoResize && maxWidth\"\n        [attr.aria-labelledby]=\"_cva.id + '-search'\"\n        aria-multiselectable=\"true\"\n        (keydown.tab)=\"close()\"\n        (keydown.shift.tab)=\"close()\"\n        (keydown.escape)=\"close()\"\n    >\n        @if (!!_cva.stateMessage) {\n            <fd-form-message [type]=\"_cva.state\" [innerHtml]=\"_cva.stateMessage\"></fd-form-message>\n        }\n        @if (showSelectAll) {\n            <fd-multi-combobox-select-all-toggler\n                [selectAllHandler]=\"_handleSelectAllItems\"\n                [valueChanges]=\"selectionChange\"\n                [selectedItems]=\"_selectedSuggestions\"\n                [flatItems]=\"_flatSuggestions\"\n            ></fd-multi-combobox-select-all-toggler>\n        }\n        <ng-content></ng-content>\n        @if (isGroup) {\n            @for (group of _suggestions; track group) {\n                @if (!groupItemTemplate) {\n                    <label fd-list-group-header role=\"group\">\n                        <span fd-list-title>{{ group.label }}</span>\n                    </label>\n                } @else {\n                    <ng-template\n                        [ngTemplateOutlet]=\"groupItemTemplate\"\n                        [ngTemplateOutletContext]=\"{ $implicit: { label: group.label } }\"\n                    ></ng-template>\n                }\n                @for (optionItem of group.children; track optionItem; let i = $index) {\n                    <li\n                        fd-list-item\n                        role=\"option\"\n                        [tabindex]=\"0\"\n                        (click)=\"!mobile && _onOptionClicked($event, i)\"\n                        (keydown)=\"_onItemKeyDownHandler($event)\"\n                        [selected]=\"!!optionItem.selected\"\n                    >\n                        <fd-checkbox\n                            (click)=\"_onOptionCheckboxClicked($event, i)\"\n                            (ngModelChange)=\"_toggleSelection(optionItem)\"\n                            [ngModel]=\"optionItem.selected\"\n                        >\n                        </fd-checkbox>\n                        <ng-template\n                            [ngTemplateOutlet]=\"listItem\"\n                            [ngTemplateOutletContext]=\"{ optionItem: optionItem, index: i }\"\n                        ></ng-template>\n                    </li>\n                }\n            }\n        } @else {\n            @for (optionItem of _suggestions; track optionItem; let i = $index) {\n                <li\n                    fd-list-item\n                    role=\"option\"\n                    [tabindex]=\"0\"\n                    (click)=\"!mobile && _onOptionClicked($event, i)\"\n                    (keydown)=\"_onItemKeyDownHandler($event)\"\n                    [selected]=\"!!optionItem.selected\"\n                >\n                    <fd-checkbox\n                        (click)=\"_onOptionCheckboxClicked($event, i)\"\n                        (ngModelChange)=\"_toggleSelection(optionItem)\"\n                        [ngModel]=\"optionItem.selected\"\n                    >\n                    </fd-checkbox>\n                    <ng-template\n                        [ngTemplateOutlet]=\"listItem\"\n                        [ngTemplateOutletContext]=\"{ optionItem: optionItem, index: i }\"\n                    ></ng-template>\n                </li>\n            }\n        }\n    </ul>\n</ng-template>\n<ng-template let-optionItem=\"optionItem\" let-index=\"index\" #listItem>\n    @if (optionItem.selected && !!selectedItemTemplate) {\n        <ng-template\n            [ngTemplateOutlet]=\"selectedItemTemplate\"\n            [ngTemplateOutletContext]=\"{ $implicit: optionItem.value, index: index }\"\n        ></ng-template>\n    }\n    @if (!(optionItem.selected && selectedItemTemplate)) {\n        <ng-template\n            [ngTemplateOutlet]=\"optionItemSource\"\n            [ngTemplateOutletContext]=\"{ optionItem: optionItem, index: index }\"\n        ></ng-template>\n        <ng-template\n            [ngTemplateOutlet]=\"secondaryTextSource\"\n            [ngTemplateOutletContext]=\"{ optionItem: optionItem }\"\n        ></ng-template>\n    }\n</ng-template>\n<ng-template let-optionItem=\"optionItem\" let-index=\"index\" #optionItemSource>\n    @if (!optionItemTemplate) {\n        <span\n            fd-list-title\n            [attr.title]=\"optionItem.label\"\n            [innerHTML]=\"optionItem.label | highlight: inputText\"\n            fdTruncatedTitle\n        ></span>\n    } @else {\n        <ng-template\n            [ngTemplateOutlet]=\"optionItemTemplate\"\n            [ngTemplateOutletContext]=\"{ $implicit: optionItem.value, index: index }\"\n        ></ng-template>\n    }\n</ng-template>\n<ng-template let-optionItem=\"optionItem\" #secondaryTextSource>\n    @if (showSecondaryText) {\n        @if (!secondaryItemTemplate) {\n            <span\n                [style.text-align]=\"secondaryTextAlignment\"\n                fd-list-secondary\n                [attr.title]=\"optionItem.secondaryText\"\n                [innerHTML]=\"optionItem.secondaryText | highlight: inputText\"\n            ></span>\n        } @else {\n            <ng-template\n                [ngTemplateOutlet]=\"secondaryItemTemplate\"\n                [ngTemplateOutletContext]=\"{ $implicit: optionItem.value }\"\n            ></ng-template>\n        }\n    }\n</ng-template>\n", styles: [".fd-margin--tiny{margin-block:.5rem;margin-inline:.5rem}.fd-margin--sm{margin-block:1rem;margin-inline:1rem}.fd-margin--md{margin-block:2rem;margin-inline:2rem}.fd-margin--lg{margin-block:3rem;margin-inline:3rem}.fd-margin--none{margin-block:0;margin-inline:0}.fd-margin-top--tiny{-webkit-margin-before:.5rem;margin-block-start:.5rem}.fd-margin-top--sm{-webkit-margin-before:1rem;margin-block-start:1rem}.fd-margin-top--md{-webkit-margin-before:2rem;margin-block-start:2rem}.fd-margin-top--lg{-webkit-margin-before:3rem;margin-block-start:3rem}.fd-margin-top--none{-webkit-margin-before:0;margin-block-start:0}.fd-margin-end--tiny{-webkit-margin-end:.5rem;margin-inline-end:.5rem}.fd-margin-end--sm{-webkit-margin-end:1rem;margin-inline-end:1rem}.fd-margin-end--md{-webkit-margin-end:2rem;margin-inline-end:2rem}.fd-margin-end--lg{-webkit-margin-end:3rem;margin-inline-end:3rem}.fd-margin-end--none{-webkit-margin-end:0;margin-inline-end:0}.fd-margin-bottom--tiny{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-margin-bottom--sm{-webkit-margin-after:1rem;margin-block-end:1rem}.fd-margin-bottom--md{-webkit-margin-after:2rem;margin-block-end:2rem}.fd-margin-bottom--lg{-webkit-margin-after:3rem;margin-block-end:3rem}.fd-margin-bottom--none{-webkit-margin-after:0;margin-block-end:0}.fd-margin-begin--tiny{-webkit-margin-start:.5rem;margin-inline-start:.5rem}.fd-margin-begin--sm{-webkit-margin-start:1rem;margin-inline-start:1rem}.fd-margin-begin--md{-webkit-margin-start:2rem;margin-inline-start:2rem}.fd-margin-begin--lg{-webkit-margin-start:3rem;margin-inline-start:3rem}.fd-margin-begin--none{-webkit-margin-start:0;margin-inline-start:0}.fd-margin-top-bottom--tiny{margin-block:.5rem}.fd-margin-top-bottom--sm{margin-block:1rem}.fd-margin-top-bottom--md{margin-block:2rem}.fd-margin-top-bottom--lg{margin-block:3rem}.fd-margin-begin-end--tiny{margin-inline:.5rem}.fd-margin-begin-end--sm{margin-inline:1rem}.fd-margin-begin-end--md{margin-inline:2rem}.fd-margin-begin-end--lg{margin-inline:3rem}.fd-margin-responsive--sm{margin-block:0 1rem;margin-inline:0}.fd-margin-responsive--md{margin-block:1rem;margin-inline:1rem}.fd-margin-responsive--lg{margin-block:1rem;margin-inline:2rem}.fd-margin-responsive--xl{margin-block:1rem;margin-inline:3rem}.fd-margin-negative-begin-end--tiny{margin-block:0;margin-inline:-.5rem}.fd-margin-negative-begin-end--sm{margin-block:0;margin-inline:-1rem}.fd-margin-negative-begin-end--md{margin-block:0;margin-inline:-2rem}.fd-margin-negative-begin-end--lg{margin-block:0;margin-inline:-3rem}.fd-multi-combobox-tokenizer-custom{width:calc(100% - 2.25rem)}[class*=--compact] .fd-multi-combobox-tokenizer-custom:not([class*=--cozy]):not([class*=--condensed]),.is-compact .fd-multi-combobox-tokenizer-custom:not(.is-cozy):not(.is-condensed),.fd-multi-combobox-tokenizer-custom[class*=--compact],.fd-multi-combobox-tokenizer-custom.is-compact{width:calc(100% - 2rem)}.fd-multi-combobox-input-group-custom{display:inline-block}.fd-multi-combobox .fd-popover-custom{display:block}.fd-multi-combobox__list-container .fd-list .fd-list__item.fd-list__group-header{padding:0 1rem}.fd-multi-combobox__list-container .fd-list .fd-list__item .fd-list__title{max-width:inherit}.fd-multi-combobox__list-container .fd-list.fd-list--compact .fd-list__item.fd-list__group-header{padding:0 .5rem}.fd-multi-combobox__list-container fd-form-message{max-width:100%;border-radius:0!important}.fd-dialog__body fd-form-message{max-width:100%;border-radius:0!important}\n/*! Bundled license information:\n\nfundamental-styles/dist/margins.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: PopoverComponent, selector: "fd-popover", inputs: ["title", "trigger", "fixedPosition", "id", "mobile", "mobileConfig", "preventSpaceKeyScroll"] }, { kind: "component", type: PopoverControlComponent, selector: "fd-popover-control, [fdPopoverControl]" }, { kind: "component", type: PopoverBodyComponent, selector: "fd-popover-body", inputs: ["minWidth", "maxWidth", "minHeight", "maxHeight"] }, { kind: "component", type: FormInputMessageGroupComponent, selector: "fd-form-input-message-group", inputs: ["triggers", "closeOnOutsideClick", "fillControlMode", "noArrow", "closeOnEscapeKey", "placement", "placementContainer", "isOpen", "preventSpaceKeyScroll"], outputs: ["isOpenChange"] }, { kind: "component", type: InputGroupComponent, selector: "fd-input-group", inputs: ["placement", "required", "inline", "addOnText", "buttonFocusable", "type", "glyph", "glyphFont", "button", "isControl", "showFocus", "isExpanded", "glyphAriaLabel", "addonButtonAriaHidden", "iconTitle", "ariaLabelledBy", "ariaLabel"], outputs: ["addOnButtonClicked", "search"] }, { kind: "component", type: TokenizerComponent, selector: "fd-tokenizer", inputs: ["class", "disableKeyboardDeletion", "compactCollapse", "tokenizerFocusable", "inputValue", "glyph", "glyphFont", "moreTerm", "open", "showOverflowPopover"], outputs: ["moreClickedEvent"] }, { kind: "component", type: TokenComponent, selector: "fd-token", inputs: ["disabled", "selected", "readOnly"], outputs: ["onCloseClick", "onRemove", "onTokenClick", "onTokenKeydown", "elementFocused"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i4.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i4.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: AutoCompleteDirective, selector: "[fdkAutoComplete]", inputs: ["options", "inputText", "enable", "displayFn", "matcher"], outputs: ["onComplete"] }, { kind: "component", type: FormControlComponent, selector: "input[fd-form-control], textarea[fd-form-control]", inputs: ["state", "type", "class", "ariaLabel", "ariaLabelledBy"] }, { kind: "directive", type: InputGroupInputDirective, selector: "[fdInputGroupInput], [fd-input-group-input]", inputs: ["class"] }, { kind: "component", type: FormMessageComponent, selector: "fd-form-message", inputs: ["type", "static", "embedded", "class"] }, { kind: "component", type: ListComponent, selector: "[fd-list], [fdList]", inputs: ["dropdownMode", "multiInputMode", "mobileMode", "hasMessage", "noBorder", "navigationIndicator", "selection", "keyboardSupport", "byline", "subline", "unreadIndicator", "role", "settingsList", "settingsListFooter"], outputs: ["focusEscapeList"] }, { kind: "component", type: SelectAllTogglerComponent, selector: "fd-multi-combobox-select-all-toggler", inputs: ["selectAllHandler", "valueChanges", "selectedItems", "flatItems"] }, { kind: "directive", type: ListGroupHeaderDirective, selector: "[fdListGroupHeader], [fd-list-group-header]", inputs: ["nativeElementId"], outputs: ["keyDown"] }, { kind: "directive", type: ListTitleDirective, selector: "[fd-list-title], [fdListTitle]", inputs: ["wrap"] }, { kind: "component", type: ListItemComponent, selector: "[fdListItem] ,[fd-list-item]", inputs: ["selected", "noData", "action", "interactive", "growing", "counter", "active", "unread", "byline", "ariaRole", "id", "preventClick", "settingsListTpl"], outputs: ["keyDown"] }, { kind: "component", type: CheckboxComponent, selector: "fd-checkbox", inputs: ["wrapLabel", "valignLabel", "ariaLabel", "role", "value", "ariaLabelledBy", "ariaDescribedBy", "title", "inputId", "state", "name", "label", "disabled", "readonly", "tristate", "tristateSelectable", "labelClass", "required", "displayOnly", "values", "standalone"], outputs: ["focusChange"] }, { kind: "directive", type: ListSecondaryDirective, selector: "[fd-list-secondary], [fdListSecondary]", inputs: ["type"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }, { kind: "pipe", type: SearchHighlightPipe, name: "highlight" }, { kind: "directive", type: MultiAnnouncerDirective, selector: "[fdMultiAnnouncer]", inputs: ["multiAnnouncerOptions"], exportAs: ["fdMultiAnnouncer"] }, { kind: "directive", type: TruncatedTitleDirective, selector: "[fdkTruncatedTitle], [fdTruncatedTitle], [fd-truncate-title]" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MultiComboboxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-multi-combobox', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, hostDirectives: [
                        {
                            directive: CvaDirective,
                            inputs: ['id:inputId', 'placeholder', 'state', 'stateMessage', 'disabled', 'readonly', 'name']
                        },
                        {
                            directive: DataSourceDirective,
                            inputs: ['dataSource'],
                            outputs: ['dataChanged']
                        }
                    ], providers: [
                        CvaControl,
                        DynamicComponentService,
                        contentDensityObserverProviders(),
                        {
                            provide: FD_DATA_SOURCE_TRANSFORMER,
                            useClass: MultiComboboxDataSourceParser
                        },
                        {
                            provide: MULTI_COMBOBOX_COMPONENT,
                            useExisting: MultiComboboxComponent
                        }
                    ], imports: [
                        NgTemplateOutlet,
                        PopoverComponent,
                        PopoverControlComponent,
                        PopoverBodyComponent,
                        FormInputMessageGroupComponent,
                        InputGroupComponent,
                        TokenizerComponent,
                        TokenComponent,
                        FormsModule,
                        AutoCompleteDirective,
                        FormControlComponent,
                        InputGroupInputDirective,
                        FormMessageComponent,
                        ListComponent,
                        SelectAllTogglerComponent,
                        ListGroupHeaderDirective,
                        ListTitleDirective,
                        ListItemComponent,
                        CheckboxComponent,
                        NgClass,
                        ListSecondaryDirective,
                        FdTranslatePipe,
                        SearchHighlightPipe,
                        MultiAnnouncerDirective,
                        TruncatedTitleDirective
                    ], template: "<div class=\"fd-multi-combobox\">\n    @if (mobile) {\n        <ng-template [ngTemplateOutlet]=\"controlTemplate\"></ng-template>\n    } @else {\n        <fd-popover\n            additionalBodyClass=\"fd-popover-custom-list fd-multi-combobox__list-container\"\n            (isOpenChange)=\"_popoverOpenChangeHandle($event)\"\n            [isOpen]=\"isOpen\"\n            [triggers]=\"[]\"\n            [disabled]=\"_cva.disabled\"\n            [maxWidth]=\"_popoverMaxWidth\"\n            [fillControlMode]=\"fillControlMode\"\n        >\n            <fd-popover-control>\n                <ng-template [ngTemplateOutlet]=\"controlTemplate\"></ng-template>\n            </fd-popover-control>\n            <fd-popover-body [style.width.%]=\"!autoResize && 100\">\n                <ng-template [ngTemplateOutlet]=\"listTemplate\"></ng-template>\n                <ng-content></ng-content>\n            </fd-popover-body>\n        </fd-popover>\n    }\n</div>\n<ng-template #controlTemplate>\n    <fd-form-input-message-group>\n        <fd-input-group\n            #inputGroup\n            [id]=\"_cva.id + '-input-group-container'\"\n            [state]=\"_cva.state\"\n            [buttonFocusable]=\"buttonFocusable\"\n            [button]=\"!_cva.readonly\"\n            [glyph]=\"!_cva.readonly ? 'navigation-down-arrow' : ' '\"\n            [isControl]=\"true\"\n            [disabled]=\"_cva.disabled || _cva.readonly\"\n            [isExpanded]=\"!mobile && isOpen && _suggestions.length > 0\"\n            [attr.aria-disabled]=\"_cva.disabled || _cva.readonly\"\n            [attr.aria-readonly]=\"_cva.readonly\"\n            [glyphAriaLabel]=\"_cva.ariaLabel || ('platformMultiCombobox.inputGlyphAriaLabel' | fdTranslate)\"\n            [iconTitle]=\"addonIconTitle || ('platformMultiCombobox.inputGlyphAriaLabel' | fdTranslate)\"\n            (addOnButtonClicked)=\"_addOnClicked($event)\"\n            (click)=\"mobile && !isOpen && _onPrimaryButtonClick(false)\"\n            (keydown)=\"_navigateByTokens($event)\"\n        >\n            <fd-tokenizer\n                [tokenizerFocusable]=\"false\"\n                [compactCollapse]=\"true\"\n                [showOverflowPopover]=\"false\"\n                #tokenizer\n                class=\"fd-multi-combobox-tokenizer-custom\"\n                (moreClickedEvent)=\"_moreClicked()\"\n                fdMultiAnnouncer\n                [multiAnnouncerOptions]=\"_suggestions\"\n            >\n                @for (token of _selectedSuggestions; track token) {\n                    <fd-token [readOnly]=\"_cva.disabled\" (onCloseClick)=\"_removeToken(token, $event)\">\n                        {{ token.label }}\n                    </fd-token>\n                }\n                <input\n                    #searchInputElement\n                    fdkAutoComplete\n                    (onComplete)=\"_onCompleteTerm($event)\"\n                    [options]=\"_suggestions\"\n                    [inputText]=\"inputText\"\n                    type=\"text\"\n                    role=\"combobox\"\n                    autocomplete=\"off\"\n                    [ariaLabel]=\"'coreMultiComboBox.multiComboBoxAriaLabel' | fdTranslate\"\n                    [attr.aria-labelledby]=\"_cva.ariaLabelledBy\"\n                    [attr.aria-autocomplete]=\"autoComplete && !mobile ? 'list' : null\"\n                    [attr.aria-owns]=\"autoComplete && !mobile ? _cva.id + '-result' : null\"\n                    [attr.aria-haspopup]=\"autoComplete && !mobile\"\n                    fd-form-control\n                    fd-input-group-input\n                    tabindex=\"0\"\n                    [id]=\"_cva.id\"\n                    [name]=\"_cva.name\"\n                    (keydown)=\"_onInputKeydownHandler($event)\"\n                    [disabled]=\"_cva.disabled\"\n                    [(ngModel)]=\"inputText\"\n                    (ngModelChange)=\"_searchTermChanged()\"\n                    [attr.placeholder]=\"_selectedSuggestions.length ? null : _cva.placeholder\"\n                    (focus)=\"tokenizer._showAllTokens()\"\n                    (blur)=\"!mobile && _onBlur($event); tokenizer._hideTokens()\"\n                    [attr.aria-expanded]=\"isOpen\"\n                    [readonly]=\"_cva.readonly\"\n                    [attr.aria-readonly]=\"_cva.readonly\"\n                    [attr.aria-required]=\"_cva.required\"\n                    [displayFn]=\"_displayFn\"\n                    class=\"fd-tokenizer__input fd-input-group__input\"\n                />\n            </fd-tokenizer>\n        </fd-input-group>\n        @if (mobile && isOpen ? false : !!_cva.stateMessage) {\n            <fd-form-message [type]=\"_cva.state\" [innerHtml]=\"_cva.stateMessage\"></fd-form-message>\n        }\n    </fd-form-input-message-group>\n</ng-template>\n<ng-template #mobileControlTemplate>\n    <fd-input-group\n        [id]=\"_cva.id + '-input-group-container'\"\n        class=\"fd-multi-combobox-input-group-custom\"\n        [state]=\"_cva.state\"\n        [buttonFocusable]=\"false\"\n        [isControl]=\"true\"\n        [disabled]=\"_cva.disabled || _cva.readonly\"\n        [isExpanded]=\"!mobile && isOpen && _suggestions.length > 0\"\n        [attr.aria-disabled]=\"_cva.disabled || _cva.readonly\"\n        [attr.aria-readonly]=\"_cva.readonly\"\n        [glyphAriaLabel]=\"_cva.ariaLabel\"\n    >\n        <input\n            fdkAutoComplete\n            (onComplete)=\"_onCompleteTerm($event)\"\n            [options]=\"_suggestions\"\n            [inputText]=\"inputText\"\n            type=\"text\"\n            role=\"combobox\"\n            autocomplete=\"off\"\n            [ariaLabel]=\"'coreMultiComboBox.multiComboBoxAriaLabel' | fdTranslate\"\n            [attr.aria-labelledby]=\"_cva.ariaLabelledBy\"\n            [attr.aria-autocomplete]=\"autoComplete && !mobile ? 'list' : null\"\n            [attr.aria-owns]=\"autoComplete && !mobile ? _cva.id + '-result' : null\"\n            [attr.aria-haspopup]=\"autoComplete && !mobile\"\n            fd-form-control\n            fd-input-group-input\n            tabindex=\"0\"\n            [id]=\"_cva.id\"\n            [name]=\"_cva.name\"\n            (keydown)=\"_onInputKeydownHandler($event)\"\n            [disabled]=\"_cva.disabled\"\n            [(ngModel)]=\"inputText\"\n            (ngModelChange)=\"_searchTermChanged()\"\n            [placeholder]=\"_cva.placeholder\"\n            (focus)=\"_cva.onTouched()\"\n            (blur)=\"!mobile && _onBlur($event)\"\n            [attr.aria-expanded]=\"isOpen\"\n            [readonly]=\"_cva.readonly\"\n            [attr.aria-readonly]=\"_cva.readonly\"\n            [displayFn]=\"_displayFn\"\n        />\n    </fd-input-group>\n</ng-template>\n<ng-template #listTemplate>\n    <ul\n        fd-list\n        [byline]=\"byline\"\n        [selection]=\"byline\"\n        (focusEscapeList)=\"_handleListFocusEscape($event)\"\n        class=\"fd-multi-combobox__list fd-list--multi-input\"\n        [id]=\"_cva.id + '-result'\"\n        role=\"listbox\"\n        [style.max-height]=\"!mobile && maxHeight\"\n        [style.min-width.px]=\"!mobile && minWidth\"\n        [style.max-width.px]=\"autoResize && maxWidth\"\n        [attr.aria-labelledby]=\"_cva.id + '-search'\"\n        aria-multiselectable=\"true\"\n        (keydown.tab)=\"close()\"\n        (keydown.shift.tab)=\"close()\"\n        (keydown.escape)=\"close()\"\n    >\n        @if (!!_cva.stateMessage) {\n            <fd-form-message [type]=\"_cva.state\" [innerHtml]=\"_cva.stateMessage\"></fd-form-message>\n        }\n        @if (showSelectAll) {\n            <fd-multi-combobox-select-all-toggler\n                [selectAllHandler]=\"_handleSelectAllItems\"\n                [valueChanges]=\"selectionChange\"\n                [selectedItems]=\"_selectedSuggestions\"\n                [flatItems]=\"_flatSuggestions\"\n            ></fd-multi-combobox-select-all-toggler>\n        }\n        <ng-content></ng-content>\n        @if (isGroup) {\n            @for (group of _suggestions; track group) {\n                @if (!groupItemTemplate) {\n                    <label fd-list-group-header role=\"group\">\n                        <span fd-list-title>{{ group.label }}</span>\n                    </label>\n                } @else {\n                    <ng-template\n                        [ngTemplateOutlet]=\"groupItemTemplate\"\n                        [ngTemplateOutletContext]=\"{ $implicit: { label: group.label } }\"\n                    ></ng-template>\n                }\n                @for (optionItem of group.children; track optionItem; let i = $index) {\n                    <li\n                        fd-list-item\n                        role=\"option\"\n                        [tabindex]=\"0\"\n                        (click)=\"!mobile && _onOptionClicked($event, i)\"\n                        (keydown)=\"_onItemKeyDownHandler($event)\"\n                        [selected]=\"!!optionItem.selected\"\n                    >\n                        <fd-checkbox\n                            (click)=\"_onOptionCheckboxClicked($event, i)\"\n                            (ngModelChange)=\"_toggleSelection(optionItem)\"\n                            [ngModel]=\"optionItem.selected\"\n                        >\n                        </fd-checkbox>\n                        <ng-template\n                            [ngTemplateOutlet]=\"listItem\"\n                            [ngTemplateOutletContext]=\"{ optionItem: optionItem, index: i }\"\n                        ></ng-template>\n                    </li>\n                }\n            }\n        } @else {\n            @for (optionItem of _suggestions; track optionItem; let i = $index) {\n                <li\n                    fd-list-item\n                    role=\"option\"\n                    [tabindex]=\"0\"\n                    (click)=\"!mobile && _onOptionClicked($event, i)\"\n                    (keydown)=\"_onItemKeyDownHandler($event)\"\n                    [selected]=\"!!optionItem.selected\"\n                >\n                    <fd-checkbox\n                        (click)=\"_onOptionCheckboxClicked($event, i)\"\n                        (ngModelChange)=\"_toggleSelection(optionItem)\"\n                        [ngModel]=\"optionItem.selected\"\n                    >\n                    </fd-checkbox>\n                    <ng-template\n                        [ngTemplateOutlet]=\"listItem\"\n                        [ngTemplateOutletContext]=\"{ optionItem: optionItem, index: i }\"\n                    ></ng-template>\n                </li>\n            }\n        }\n    </ul>\n</ng-template>\n<ng-template let-optionItem=\"optionItem\" let-index=\"index\" #listItem>\n    @if (optionItem.selected && !!selectedItemTemplate) {\n        <ng-template\n            [ngTemplateOutlet]=\"selectedItemTemplate\"\n            [ngTemplateOutletContext]=\"{ $implicit: optionItem.value, index: index }\"\n        ></ng-template>\n    }\n    @if (!(optionItem.selected && selectedItemTemplate)) {\n        <ng-template\n            [ngTemplateOutlet]=\"optionItemSource\"\n            [ngTemplateOutletContext]=\"{ optionItem: optionItem, index: index }\"\n        ></ng-template>\n        <ng-template\n            [ngTemplateOutlet]=\"secondaryTextSource\"\n            [ngTemplateOutletContext]=\"{ optionItem: optionItem }\"\n        ></ng-template>\n    }\n</ng-template>\n<ng-template let-optionItem=\"optionItem\" let-index=\"index\" #optionItemSource>\n    @if (!optionItemTemplate) {\n        <span\n            fd-list-title\n            [attr.title]=\"optionItem.label\"\n            [innerHTML]=\"optionItem.label | highlight: inputText\"\n            fdTruncatedTitle\n        ></span>\n    } @else {\n        <ng-template\n            [ngTemplateOutlet]=\"optionItemTemplate\"\n            [ngTemplateOutletContext]=\"{ $implicit: optionItem.value, index: index }\"\n        ></ng-template>\n    }\n</ng-template>\n<ng-template let-optionItem=\"optionItem\" #secondaryTextSource>\n    @if (showSecondaryText) {\n        @if (!secondaryItemTemplate) {\n            <span\n                [style.text-align]=\"secondaryTextAlignment\"\n                fd-list-secondary\n                [attr.title]=\"optionItem.secondaryText\"\n                [innerHTML]=\"optionItem.secondaryText | highlight: inputText\"\n            ></span>\n        } @else {\n            <ng-template\n                [ngTemplateOutlet]=\"secondaryItemTemplate\"\n                [ngTemplateOutletContext]=\"{ $implicit: optionItem.value }\"\n            ></ng-template>\n        }\n    }\n</ng-template>\n", styles: [".fd-margin--tiny{margin-block:.5rem;margin-inline:.5rem}.fd-margin--sm{margin-block:1rem;margin-inline:1rem}.fd-margin--md{margin-block:2rem;margin-inline:2rem}.fd-margin--lg{margin-block:3rem;margin-inline:3rem}.fd-margin--none{margin-block:0;margin-inline:0}.fd-margin-top--tiny{-webkit-margin-before:.5rem;margin-block-start:.5rem}.fd-margin-top--sm{-webkit-margin-before:1rem;margin-block-start:1rem}.fd-margin-top--md{-webkit-margin-before:2rem;margin-block-start:2rem}.fd-margin-top--lg{-webkit-margin-before:3rem;margin-block-start:3rem}.fd-margin-top--none{-webkit-margin-before:0;margin-block-start:0}.fd-margin-end--tiny{-webkit-margin-end:.5rem;margin-inline-end:.5rem}.fd-margin-end--sm{-webkit-margin-end:1rem;margin-inline-end:1rem}.fd-margin-end--md{-webkit-margin-end:2rem;margin-inline-end:2rem}.fd-margin-end--lg{-webkit-margin-end:3rem;margin-inline-end:3rem}.fd-margin-end--none{-webkit-margin-end:0;margin-inline-end:0}.fd-margin-bottom--tiny{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-margin-bottom--sm{-webkit-margin-after:1rem;margin-block-end:1rem}.fd-margin-bottom--md{-webkit-margin-after:2rem;margin-block-end:2rem}.fd-margin-bottom--lg{-webkit-margin-after:3rem;margin-block-end:3rem}.fd-margin-bottom--none{-webkit-margin-after:0;margin-block-end:0}.fd-margin-begin--tiny{-webkit-margin-start:.5rem;margin-inline-start:.5rem}.fd-margin-begin--sm{-webkit-margin-start:1rem;margin-inline-start:1rem}.fd-margin-begin--md{-webkit-margin-start:2rem;margin-inline-start:2rem}.fd-margin-begin--lg{-webkit-margin-start:3rem;margin-inline-start:3rem}.fd-margin-begin--none{-webkit-margin-start:0;margin-inline-start:0}.fd-margin-top-bottom--tiny{margin-block:.5rem}.fd-margin-top-bottom--sm{margin-block:1rem}.fd-margin-top-bottom--md{margin-block:2rem}.fd-margin-top-bottom--lg{margin-block:3rem}.fd-margin-begin-end--tiny{margin-inline:.5rem}.fd-margin-begin-end--sm{margin-inline:1rem}.fd-margin-begin-end--md{margin-inline:2rem}.fd-margin-begin-end--lg{margin-inline:3rem}.fd-margin-responsive--sm{margin-block:0 1rem;margin-inline:0}.fd-margin-responsive--md{margin-block:1rem;margin-inline:1rem}.fd-margin-responsive--lg{margin-block:1rem;margin-inline:2rem}.fd-margin-responsive--xl{margin-block:1rem;margin-inline:3rem}.fd-margin-negative-begin-end--tiny{margin-block:0;margin-inline:-.5rem}.fd-margin-negative-begin-end--sm{margin-block:0;margin-inline:-1rem}.fd-margin-negative-begin-end--md{margin-block:0;margin-inline:-2rem}.fd-margin-negative-begin-end--lg{margin-block:0;margin-inline:-3rem}.fd-multi-combobox-tokenizer-custom{width:calc(100% - 2.25rem)}[class*=--compact] .fd-multi-combobox-tokenizer-custom:not([class*=--cozy]):not([class*=--condensed]),.is-compact .fd-multi-combobox-tokenizer-custom:not(.is-cozy):not(.is-condensed),.fd-multi-combobox-tokenizer-custom[class*=--compact],.fd-multi-combobox-tokenizer-custom.is-compact{width:calc(100% - 2rem)}.fd-multi-combobox-input-group-custom{display:inline-block}.fd-multi-combobox .fd-popover-custom{display:block}.fd-multi-combobox__list-container .fd-list .fd-list__item.fd-list__group-header{padding:0 1rem}.fd-multi-combobox__list-container .fd-list .fd-list__item .fd-list__title{max-width:inherit}.fd-multi-combobox__list-container .fd-list.fd-list--compact .fd-list__item.fd-list__group-header{padding:0 .5rem}.fd-multi-combobox__list-container fd-form-message{max-width:100%;border-radius:0!important}.fd-dialog__body fd-form-message{max-width:100%;border-radius:0!important}\n/*! Bundled license information:\n\nfundamental-styles/dist/margins.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Injector }, { type: i0.ViewContainerRef }, { type: i1.DynamicComponentService }], propDecorators: { showSelectAll: [{
                type: Input
            }], selectedItems: [{
                type: Input
            }], maxHeight: [{
                type: Input
            }], buttonFocusable: [{
                type: Input
            }], autoComplete: [{
                type: Input
            }], byline: [{
                type: Input
            }], bodyMaxWidth: [{
                type: Input
            }], entityClass: [{
                type: Input
            }], mobile: [{
                type: Input
            }], mobileConfig: [{
                type: Input
            }], group: [{
                type: Input
            }], groupKey: [{
                type: Input
            }], secondaryKey: [{
                type: Input
            }], showSecondaryText: [{
                type: Input
            }], secondaryTextAlignment: [{
                type: Input
            }], autoResize: [{
                type: Input
            }], openDropdownOnAddOnClicked: [{
                type: Input
            }], value: [{
                type: Input
            }], fillControlMode: [{
                type: Input
            }], addonIconTitle: [{
                type: Input
            }], invalidEntryMessage: [{
                type: Input
            }], limitless: [{
                type: Input
            }], lookupKey: [{
                type: Input
            }], displayKey: [{
                type: Input
            }], list: [{
                type: Input
            }], invalidEntryDisplayTime: [{
                type: Input
            }], matchingStrategy: [{
                type: Input
            }], selectionChange: [{
                type: Output
            }], isOpenChange: [{
                type: Output
            }], addOnButtonClicked: [{
                type: Output
            }], dataRequested: [{
                type: Output
            }], dataReceived: [{
                type: Output
            }], searchInputElement: [{
                type: ViewChild,
                args: ['searchInputElement', { read: ElementRef }]
            }], listComponent: [{
                type: ViewChild,
                args: [FD_LIST_COMPONENT]
            }], customTemplates: [{
                type: ContentChildren,
                args: [TemplateDirective]
            }], mobileControlTemplate: [{
                type: ViewChild,
                args: ['mobileControlTemplate']
            }], listTemplate: [{
                type: ViewChild,
                args: ['listTemplate']
            }], _tokenizer: [{
                type: ViewChild,
                args: [TokenizerComponent]
            }], _inputGroup: [{
                type: ViewChild,
                args: ['inputGroup', { read: ElementRef }]
            }] } });

class MultiComboboxModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MultiComboboxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: MultiComboboxModule, imports: [MultiComboboxComponent, SelectAllTogglerComponent, MultiAnnouncerDirective], exports: [MultiComboboxComponent, SelectAllTogglerComponent, MultiAnnouncerDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MultiComboboxModule, imports: [MultiComboboxComponent, SelectAllTogglerComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: MultiComboboxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [MultiComboboxComponent, SelectAllTogglerComponent, MultiAnnouncerDirective],
                    exports: [MultiComboboxComponent, SelectAllTogglerComponent, MultiAnnouncerDirective]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ArrayMultiComboBoxDataSource, BaseMultiCombobox, FD_MAP_LIMIT, FdMultiComboBoxDataSource, MULTI_COMBOBOX_COMPONENT, MobileMultiComboboxComponent, MultiAnnouncerDirective, MultiComboboxComponent, MultiComboboxConfig, MultiComboboxDataSourceParser, MultiComboboxModule, MultiComboboxSelectionChangeEvent, ObservableMultiComboBoxDataSource, SelectAllTogglerComponent, displayValue, flattenGroups, getSelectItemByInputValue, getTokenIndexByIdlOrValue, lookupValue, objectGet };
//# sourceMappingURL=fundamental-ngx-core-multi-combobox.mjs.map
