import * as i0 from '@angular/core';
import { EventEmitter, Output, Input, HostBinding, Directive, inject, TemplateRef, HostListener, ViewChild, ChangeDetectionStrategy, ViewEncapsulation, Component, DestroyRef, InjectionToken, Inject, NgModule, ElementRef, Optional, Injectable, Injector, ViewContainerRef, ContentChild } from '@angular/core';
import * as i2 from '@angular/cdk/a11y';
import { A11yModule, CdkTrapFocus } from '@angular/cdk/a11y';
import { ESCAPE, DOWN_ARROW } from '@angular/cdk/keycodes';
import * as i1$1 from '@angular/cdk/overlay';
import { CdkScrollable, OverlayConfig, CdkOverlayOrigin } from '@angular/cdk/overlay';
import { Subject, Subscription, merge } from 'rxjs';
import { NgTemplateOutlet } from '@angular/common';
import * as i2$1 from '@fundamental-ngx/cdk/utils';
import { KeyUtil, ResizeHandleDirective, ResizeDirective, resizeObservable, TemplateModule, DynamicComponentService, destroyObservable, isOdd } from '@fundamental-ngx/cdk/utils';
import * as i1 from '@fundamental-ngx/core/content-density';
import { contentDensityObserverProviders } from '@fundamental-ngx/core/content-density';
import { ScrollbarDirective } from '@fundamental-ngx/core/scrollbar';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { DialogComponent, DialogBodyComponent, DialogHeaderComponent, DialogFooterComponent, DialogModule } from '@fundamental-ngx/core/dialog';
import { MobileModeBase, MobileModeControl } from '@fundamental-ngx/core/mobile-mode';
import { TitleComponent } from '@fundamental-ngx/core/title';
import { ButtonComponent } from '@fundamental-ngx/core/button';
import { TemplatePortal, ComponentPortal } from '@angular/cdk/portal';
import { takeUntil, startWith, filter, distinctUntilChanged } from 'rxjs/operators';
import { GetDefaultPosition, PopoverPosition } from '@fundamental-ngx/core/shared';
import equal from 'fast-deep-equal';

class BasePopoverClass {
    constructor() {
        /** Whether to close the popover on router navigation start. */
        this.closeOnNavigation = true;
        /** Whether the popover is disabled. */
        this.disabled = false;
        /** Maximum width of popover body in px, prevents from overextending body by `fillControlMode`  */
        this.maxWidth = null;
        /** Whether the popover should have an arrow. */
        this.noArrow = true;
        /** Whether the popover container needs an extra class for styling. */
        this.additionalBodyClass = null;
        /** Classes that should be applied to fd-popover-body component directly. */
        this.additionalBodyComponentClasses = null;
        /** Whether the popover container needs an extra class for styling. */
        this.additionalTriggerClass = null;
        /** Whether the popover should close when the escape key is pressed. */
        this.closeOnEscapeKey = true;
        /** Whether to wrap content with fd-scrollbar directive. */
        this.disableScrollbar = false;
        /**
         * The placement of the popover.
         * It can be one of:
         * top, top-start, top-end, bottom, bottom-start, bottom-end,
         * right, right-start, right-end, left, left-start, left-end.
         */
        this.placement = null;
        /**
         * The trigger events that will open/close the popover.
         * Accepts any [HTML DOM Events](https://www.w3schools.com/jsref/dom_obj_event.asp) or a config object for the corresponding event.
         * Using the config object allows to specify whether an event should apply both for open and close actions or only some of them.
         *
         * If array of triggers consists only of one event, it will be treated at a toggle event (open and close)
         * If array of trigger consists of more than one event, each odd event will be treated as an open event for the popover,
         * and each even event will be treated as closing event for the popover.
         *
         * Consider the following value for `triggers`:
         * ```
         * [
         *  'click' // basically it's an alias for "{ trigger: 'click', openAction: true, closeAction: true }"
         * ]
         * ```
         * ```
         * [
         *  'mouseenter' // Shortcut for "{ trigger: 'mouseenter', openAction: true, closeAction: false }", and will only open the popover.
         *  'mouseleave' // Shortcut for "{ trigger: 'mouseleave', openAction: false, closeAction: true }" and will only close the popover.
         * ]
         * ```
         * ```
         * [
         *  { trigger: 'mouseenter', openAction: true, closeAction: true }, // "mouseenter" will toggle the popover.
         *  { trigger: 'mouseleave', openAction: true, closeAction: true } // "mouseleave" will toggle the popover.
         * ]
         * ```
         *
         * @default ['click']
         */
        this.triggers = ['click'];
        /** Whether the popover is open. Can be used through two-way binding. */
        this.isOpen = false;
        /** Whether the popover should close when a click is made outside its boundaries. */
        this.closeOnOutsideClick = true;
        /** Wether to apply a background overlay */
        this.applyOverlay = false;
        /** Whether the popover should be focusTrapped. */
        this.focusTrapped = false;
        /**
         * Whether the popover should automatically move focus into the trapped region upon
         * initialization and return focus to the previous activeElement upon destruction.
         */
        this.focusAutoCapture = false;
        /**
         * Whether to move the focus after popover is closed to the last focused element before popover was opened.
         */
        this.restoreFocusOnClose = true;
        /**
         * Scroll strategy, there are 4 accepted
         * - CloseScrollStrategy
         * - NoopScrollStrategy
         * - BlockScrollStrategy
         * - RepositionScrollStrategy ( default )
         */
        this.scrollStrategy = null;
        /**
         * List of positions options for overlay defined by angular CDK.
         * Positions will be taken in order, same like on array. If first position provided doesn't fit to window,
         * another will be used
         * More information can be found in https://material.angular.io/cdk/overlay/api
         */
        this.cdkPositions = null;
        /**
         * Preset options for the popover body width.
         * * `at-least` will apply a minimum width to the body equivalent to the width of the control.
         * * `equal` will apply a width to the body equivalent to the width of the control.
         * * Leave blank for no effect.
         */
        this.fillControlMode = null;
        /** The element to which  the overlay is attached. By default it is body */
        this.appendTo = null;
        /** Whether position shouldn't change, when popover approach the corner of page */
        this.fixedPosition = false;
        /** Whether the popover body is resizable. */
        this.resizable = false;
        /** Event emitted when the state of the isOpen property changes. */
        this.isOpenChange = new EventEmitter();
        /** Event emitted right before the popover is being opened.
         * Useful for cases when component inside popover body needs to be initialized right BEFORE the opening of the popover. */
        this.beforeOpen = new EventEmitter();
        /** @hidden Aria role for the popover body. */
        this._bodyRole = 'dialog';
        /** @hidden ID for the popover body. */
        this._bodyId = null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BasePopoverClass, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: BasePopoverClass, isStandalone: true, inputs: { closeOnNavigation: "closeOnNavigation", disabled: "disabled", maxWidth: "maxWidth", noArrow: "noArrow", additionalBodyClass: "additionalBodyClass", additionalBodyComponentClasses: "additionalBodyComponentClasses", additionalTriggerClass: "additionalTriggerClass", closeOnEscapeKey: "closeOnEscapeKey", disableScrollbar: "disableScrollbar", placement: "placement", triggers: "triggers", isOpen: "isOpen", closeOnOutsideClick: "closeOnOutsideClick", applyOverlay: "applyOverlay", focusTrapped: "focusTrapped", focusAutoCapture: "focusAutoCapture", restoreFocusOnClose: "restoreFocusOnClose", scrollStrategy: "scrollStrategy", cdkPositions: "cdkPositions", fillControlMode: "fillControlMode", appendTo: "appendTo", placementContainer: "placementContainer", fixedPosition: "fixedPosition", resizable: "resizable" }, outputs: { isOpenChange: "isOpenChange", beforeOpen: "beforeOpen" }, host: { properties: { "class.fd-popover-custom--disabled": "this.disabled" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BasePopoverClass, decorators: [{
            type: Directive
        }], propDecorators: { closeOnNavigation: [{
                type: Input
            }], disabled: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.fd-popover-custom--disabled']
            }], maxWidth: [{
                type: Input
            }], noArrow: [{
                type: Input
            }], additionalBodyClass: [{
                type: Input
            }], additionalBodyComponentClasses: [{
                type: Input
            }], additionalTriggerClass: [{
                type: Input
            }], closeOnEscapeKey: [{
                type: Input
            }], disableScrollbar: [{
                type: Input
            }], placement: [{
                type: Input
            }], triggers: [{
                type: Input
            }], isOpen: [{
                type: Input
            }], closeOnOutsideClick: [{
                type: Input
            }], applyOverlay: [{
                type: Input
            }], focusTrapped: [{
                type: Input
            }], focusAutoCapture: [{
                type: Input
            }], restoreFocusOnClose: [{
                type: Input
            }], scrollStrategy: [{
                type: Input
            }], cdkPositions: [{
                type: Input
            }], fillControlMode: [{
                type: Input
            }], appendTo: [{
                type: Input
            }], placementContainer: [{
                type: Input
            }], fixedPosition: [{
                type: Input
            }], resizable: [{
                type: Input
            }], isOpenChange: [{
                type: Output
            }], beforeOpen: [{
                type: Output
            }] } });

class PopoverBodyDirective {
    constructor() {
        /**
         * The template to be used as the popover's body.
         **/
        this.templateRef = inject(TemplateRef);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverBodyDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: PopoverBodyDirective, isStandalone: true, selector: "[fdPopoverBody]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverBodyDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdPopoverBody]',
                    standalone: true
                }]
        }] });

class PopoverBodyFooterDirective {
    constructor() {
        /** @hidden */
        this.fdPopoverBodyFooterClass = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverBodyFooterDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: PopoverBodyFooterDirective, isStandalone: true, selector: "[fdPopoverBodyFooter], [fd-popover-body-footer]", host: { properties: { "class.fd-popover__body-footer": "this.fdPopoverBodyFooterClass" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverBodyFooterDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdPopoverBodyFooter], [fd-popover-body-footer]',
                    standalone: true
                }]
        }], propDecorators: { fdPopoverBodyFooterClass: [{
                type: HostBinding,
                args: ['class.fd-popover__body-footer']
            }] } });

class PopoverBodyHeaderDirective {
    constructor() {
        /** @hidden */
        this.fdPopoverBodyHeaderClass = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverBodyHeaderDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: PopoverBodyHeaderDirective, isStandalone: true, selector: "[fdPopoverBodyHeader], [fd-popover-body-header]", host: { properties: { "class.fd-popover__body-header": "this.fdPopoverBodyHeaderClass" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverBodyHeaderDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdPopoverBodyHeader], [fd-popover-body-header]',
                    standalone: true
                }]
        }], propDecorators: { fdPopoverBodyHeaderClass: [{
                type: HostBinding,
                args: ['class.fd-popover__body-header']
            }] } });

/**
 * A component used to enforce a certain layout for the popover.
 * ```html
 * <fd-popover>
 *     <fd-popover-control>Control Element</fd-popover-control>
 *     <fd-popover-body>Popover Body</fd-popover-body>
 * </fd-popover>
 * ```
 */
class PopoverBodyComponent {
    /** @hidden */
    constructor(_elementRef, _changeDetectorRef, _renderer, _contentDensityObserver) {
        this._elementRef = _elementRef;
        this._changeDetectorRef = _changeDetectorRef;
        this._renderer = _renderer;
        this._contentDensityObserver = _contentDensityObserver;
        /** Whether to wrap content with fd-scrollbar directive. */
        this._disableScrollbar = false;
        /** Whether the popover should have an arrow. */
        this._noArrow = true;
        /** Whether the popover should be focusTrapped. */
        this._focusTrapped = false;
        /**
         * Whether the popover should automatically move focus into the trapped region upon
         * initialization and return focus to the previous activeElement upon destruction.
         */
        this._focusAutoCapture = false;
        /** @hidden Property bind to popover's body. */
        this._closeOnEscapeKey = false;
        /** @hidden Aria role for the popover body. */
        this._bodyRole = 'dialog';
        /** @hidden Aria role for the popover body. */
        this._bodyId = null;
        /** Classes added to arrow element. */
        this._arrowClasses = '';
        /** @hidden text rendered inside popover's body. */
        this.text = null;
        /** @hidden Whether the popover body is resizable. */
        this._resizable = false;
        /** @hidden */
        this._resizeHandleLocation = 'bottom-right';
        /** Close event from popover body */
        this.onClose = new Subject();
        /** @hidden */
        this._bodyComponentClasses = null;
    }
    /** Handler escape keydown */
    bodyKeyupHandler(event) {
        if (KeyUtil.isKeyCode(event, ESCAPE) && this._closeOnEscapeKey) {
            // In case if popover belongs to the element inside dialog
            event.stopPropagation();
            this.onClose.next();
        }
    }
    /** @hidden */
    ngAfterViewInit() {
        if (this._scrollbar) {
            this._scrollbar._inPopover = true;
        }
    }
    /** @hidden */
    _setBodyComponentClasses(classes) {
        this._bodyComponentClasses?.split(' ').forEach((klass) => {
            this._renderer.removeClass(this._elementRef.nativeElement, klass);
        });
        this._bodyComponentClasses = classes;
        if (!this._bodyComponentClasses) {
            return;
        }
        this._bodyComponentClasses.split(' ').forEach((klass) => {
            this._renderer.addClass(this._elementRef.nativeElement, klass);
        });
    }
    /** @hidden */
    _setArrowStyles(position, rtl) {
        this._resizeHandleLocation = `${position.overlayY === 'top' ? 'bottom' : 'top'}-${position.overlayX === 'start' ? 'right' : 'left'}`;
        if (this._noArrow) {
            this._arrowClasses = '';
            return;
        }
        let arrowClasses = [];
        if (position.overlayY !== position.originY &&
            position.originY !== 'center' &&
            position.overlayY !== 'center' &&
            position.overlayX === position.originX) {
            arrowClasses = [
                `fd-popover__body--${position.overlayY === 'top' ? 'below' : 'above'}`,
                `fd-popover__body--${position.overlayX === 'start' ? 'left' : 'right'}`,
                `fd-popover__body--arrow-${position.overlayY}`,
                `fd-popover__body--arrow-x-${position.originX}`
            ];
        }
        else if (position.overlayX !== position.originX &&
            position.overlayX !== 'center' &&
            position.originX !== 'center' &&
            position.originY === position.overlayY) {
            let overlayX = position.overlayX;
            if (rtl === 'rtl') {
                overlayX = position.overlayX === 'end' ? 'start' : 'end';
            }
            arrowClasses = [
                `fd-popover__body--${overlayX === 'start' ? 'after' : 'before'}`,
                `fd-popover__body--${overlayX === 'start' ? 'left' : 'right'}`,
                `fd-popover__body--${position.overlayY === 'center' ? 'middle' : position.overlayY}`,
                `fd-popover__body--arrow-${overlayX === 'start' ? 'left' : 'right'}`,
                `fd-popover__body--arrow-y-${position.originY} `
            ];
        }
        else {
            arrowClasses = ['fd-popover__body--no-arrow'];
        }
        this._arrowClasses = arrowClasses.join(' ');
        this.detectChanges();
    }
    /** @hidden */
    detectChanges() {
        if (!this._changeDetectorRef['destroyed']) {
            this._changeDetectorRef.detectChanges();
        }
    }
    /** @hidden */
    _focusFirstTabbableElement(forced = false) {
        if (forced || this._focusAutoCapture) {
            this._cdkTrapFocus.focusTrap.focusFirstTabbableElement();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverBodyComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: i0.Renderer2 }, { token: i1.ContentDensityObserver }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: PopoverBodyComponent, isStandalone: true, selector: "fd-popover-body", inputs: { minWidth: "minWidth", maxWidth: "maxWidth", minHeight: "minHeight", maxHeight: "maxHeight" }, host: { listeners: { "keyup": "bodyKeyupHandler($event)" } }, providers: [contentDensityObserverProviders({ alwaysAddModifiers: true })], viewQueries: [{ propertyName: "_cdkTrapFocus", first: true, predicate: CdkTrapFocus, descendants: true }, { propertyName: "_scrollbar", first: true, predicate: ScrollbarDirective, descendants: true }], ngImport: i0, template: "<div\n    class=\"fd-popover__body fd-popover__body--static\"\n    [class.fd-popover__body--no-arrow]=\"_noArrow\"\n    [class.fd-popover__body--resizable]=\"_resizable\"\n    [class]=\"_arrowClasses + ' ' + (_additionalBodyClass || '')\"\n    [cdkTrapFocus]=\"_focusTrapped\"\n    [style.min-width]=\"_popoverBodyMinWidth ? null : minWidth\"\n    [style.max-width]=\"_maxWidth ? null : maxWidth\"\n    [style.min-height]=\"minHeight\"\n    [style.max-height]=\"maxHeight\"\n    [style.max-width.px]=\"_maxWidth\"\n    [style.min-width.px]=\"_popoverBodyMinWidth\"\n    [style.width.px]=\"_popoverBodyWidth\"\n    [attr.role]=\"_bodyRole\"\n    [attr.id]=\"_bodyId\"\n    fdkResize\n    [fdkResizeDisabled]=\"!_resizable\"\n    [fdkResizeClass]=\"'fd-popover__body--disable-transitions'\"\n    [fdkResizeHandleLocation]=\"_resizeHandleLocation\"\n>\n    @if (!_disableScrollbar) {\n        <div fd-scrollbar class=\"fd-popover__wrapper\">\n            <ng-template [ngTemplateOutlet]=\"renderer\"></ng-template>\n        </div>\n    } @else {\n        <ng-template [ngTemplateOutlet]=\"renderer\"></ng-template>\n    }\n    @if (_resizable) {\n        <span fdkResizeHandle class=\"fd-popover__resize-handle\" role=\"presentation\" aria-hidden=\"true\"></span>\n    }\n</div>\n<ng-template #renderer>\n    <ng-content select=\"[fd-popover-body-header]\"></ng-content>\n    <ng-content select=\"[fd-popover-body-subheader]\"></ng-content>\n    <ng-content></ng-content>\n    {{ text }}\n    <ng-template [ngTemplateOutlet]=\"_templateToDisplay\"></ng-template>\n    <ng-content select=\"[fd-popover-body-footer]\"></ng-content>\n</ng-template>\n", styles: ["body.fd-overlay-active:before{background:var(--fdModal_BackgroundColor);content:\"\";height:100vh;left:0;pointer-events:all;position:fixed;top:0;width:100vw;z-index:999}.fd-popover{--fdPopover_Display:inline-block;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:var(--fdPopover_Display);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;padding-block:0;padding-inline:0;position:relative}.fd-popover:after,.fd-popover:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover__modal{position:relative;z-index:1000}.fd-popover__control{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);cursor:pointer;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-popover__control:after,.fd-popover__control:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover__control:focus-visible{outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor)}.fd-popover__control.is-expanded>*,.fd-popover__control[aria-expanded=true]>*{-webkit-margin-after:0;margin-block-end:0}.fd-popover__control.is-expanded+.fd-popover__body--input-message-group,.fd-popover__control[aria-expanded=true]+.fd-popover__body--input-message-group{margin-top:0}.fd-popover__control.is-disabled,.fd-popover__control:disabled,.fd-popover__control[aria-disabled=true]{pointer-events:none}.fd-popover__wrapper{border-radius:var(--fdPopover_Body_Border_Radius);overflow:auto;position:relative;scrollbar-color:var(--fdScrollbar_Thumb_Color) var(--fdScrollbar_Track_Color)}.fd-popover__wrapper.is-focus,.fd-popover__wrapper:focus{outline:none;z-index:5}.fd-popover__wrapper::-webkit-scrollbar{height:var(--fdScrollbar_Dimension);width:var(--fdScrollbar_Dimension)}.fd-popover__wrapper::-webkit-scrollbar-corner,.fd-popover__wrapper::-webkit-scrollbar-track{background-color:var(--fdScrollbar_Track_Color)}.fd-popover__wrapper::-webkit-scrollbar-thumb{background-color:transparent;border:var(--fdScrollbar_Thumb_Offset) solid transparent;border-radius:calc(var(--fdScrollbar_Thumb_Border_Radius) - var(--fdScrollbar_Thumb_Offset));-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color)}.fd-popover__wrapper::-webkit-scrollbar-thumb:active,.fd-popover__wrapper::-webkit-scrollbar-thumb:hover{-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color)}.fd-popover__wrapper::-webkit-scrollbar-corner,.fd-popover__wrapper::-webkit-scrollbar-track{border-radius:0 var(--fdScrollbar_Border_Radius) var(--fdScrollbar_Border_Radius) 0}.fd-popover__wrapper[dir=rtl]::-webkit-scrollbar-corner,.fd-popover__wrapper[dir=rtl]::-webkit-scrollbar-track,[dir=rtl] .fd-popover__wrapper::-webkit-scrollbar-corner,[dir=rtl] .fd-popover__wrapper::-webkit-scrollbar-track{border-radius:var(--fdScrollbar_Border_Radius) 0 0 var(--fdScrollbar_Border_Radius)}.fd-popover__wrapper--visible{overflow:visible!important}.fd-popover__body{--fdPopover_Offset:100%;--fdPopover_Center_Offset:50%;--fdPopover_Arrow_Size:.5rem;--fdPopover_Body_Border_Radius:var(--fdPopover_Border_Radius);--fdPopover_Body_Box_Shadow:var(--sapContent_Shadow2);--fdPopover_Body_Box_Shadow_No_Arrow:var(--sapContent_Shadow1);--fdIcon_Button_Height:2.25rem;--fdIcon_Button_Width:2.25rem;--fdPopover_Resize_Handle_Offset:-.5rem;--fdPopover_Resize_Handle_Position_Top:auto;--fdPopover_Resize_Handle_Position_Right:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Bottom:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Rotate_Angle:0;--fdPopover_Resize_Handle_Cursor:se-resize;--fdPopover_Resize_Handle_Justify:center;--fdPopover_Resize_Handle_Transform_Scale:1;background:var(--sapGroup_ContentBackground);border:0;border-radius:var(--fdPopover_Body_Border_Radius);-webkit-box-shadow:var(--fdPopover_Body_Box_Shadow);box-shadow:var(--fdPopover_Body_Box_Shadow);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;opacity:1;padding-block:0;padding-inline:0;position:absolute;top:calc(var(--fdPopover_Offset) + var(--fdPopover_Arrow_Size));-webkit-transition:all .125s;transition:all .125s;visibility:visible;white-space:nowrap;z-index:1000}.fd-popover__body:after,.fd-popover__body:before{-webkit-box-sizing:inherit;box-sizing:inherit;content:\"\";font-size:inherit;position:absolute}.fd-popover__body:before{border-bottom:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid var(--sapGroup_ContentBackground);border-left:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;border-right:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;top:calc(var(--fdPopover_Arrow_Size) * -1 + var(--fdPopover_Border_Width));z-index:1002}.fd-popover__body:after,.fd-popover__body:before{border-top:none;display:inline-block;height:0;width:0}.fd-popover__body:after{border-bottom:var(--fdPopover_Arrow_Size) solid var(--fdPopover_Border_Color);border-left:var(--fdPopover_Arrow_Size) solid transparent;border-right:var(--fdPopover_Arrow_Size) solid transparent;top:calc(var(--fdPopover_Arrow_Size) * -1);z-index:1001}.fd-popover__body>:not(.fd-popover__wrapper){overflow:hidden}.fd-popover__body-header>:first-child,.fd-popover__body>:first-child{border-top-left-radius:var(--fdPopover_Border_Radius);border-top-right-radius:var(--fdPopover_Border_Radius)}.fd-popover__body-footer>:last-child,.fd-popover__body>:last-child:not(.fd-popover__resize-handle){border-bottom-left-radius:var(--fdPopover_Border_Radius);border-bottom-right-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-menu{width:100%}.fd-popover__body[class*=-compact],.fd-popover__body[class*=-condensed],[class*=-compact] .fd-popover__body:not([class*=-cozy]),[class*=-condensed] .fd-popover__body:not([class*=-cozy]){--fdIcon_Button_Height:1.625rem;--fdIcon_Button_Width:2rem}.fd-popover__body--no-arrow{-webkit-box-shadow:var(--fdPopover_Body_Box_Shadow_No_Arrow);box-shadow:var(--fdPopover_Body_Box_Shadow_No_Arrow);top:var(--fdPopover_Offset)}.fd-popover__body--no-arrow:after,.fd-popover__body--no-arrow:before{display:none}.fd-popover__body,.fd-popover__body--left{left:0}.fd-popover__body--left[dir=rtl],.fd-popover__body[dir=rtl],[dir=rtl] .fd-popover__body,[dir=rtl] .fd-popover__body--left{left:auto;right:0}.fd-popover__body--left:before,.fd-popover__body:before{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--left:after,.fd-popover__body:after{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--left[dir=rtl]:before,.fd-popover__body[dir=rtl]:before,[dir=rtl] .fd-popover__body--left:before,[dir=rtl] .fd-popover__body:before{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--left[dir=rtl]:after,.fd-popover__body[dir=rtl]:after,[dir=rtl] .fd-popover__body--left:after,[dir=rtl] .fd-popover__body:after{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--center{left:var(--fdPopover_Center_Offset);-webkit-transform:translateX(calc(var(--fdPopover_Center_Offset) * -1));transform:translate(calc(var(--fdPopover_Center_Offset) * -1))}.fd-popover__body--center[dir=rtl],[dir=rtl] .fd-popover__body--center{left:auto;right:var(--fdPopover_Center_Offset);-webkit-transform:translateX(var(--fdPopover_Center_Offset));transform:translate(var(--fdPopover_Center_Offset))}.fd-popover__body--right{left:auto;right:0}.fd-popover__body--right[dir=rtl],[dir=rtl] .fd-popover__body--right{left:0;right:auto}.fd-popover__body--right:before{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--right:after{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--right[dir=rtl]:before,[dir=rtl] .fd-popover__body--right:before{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width));right:auto}.fd-popover__body--right[dir=rtl]:after,[dir=rtl] .fd-popover__body--right:after{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width));right:auto}.fd-popover__body--before{left:auto!important;right:var(--fdPopover_Offset)!important;top:0}.fd-popover__body--after{left:var(--fdPopover_Offset)!important;right:auto!important;top:0}.fd-popover__body--middle{top:var(--fdPopover_Center_Offset);-webkit-transform:translateY(calc(var(--fdPopover_Center_Offset) * -1));transform:translateY(calc(var(--fdPopover_Center_Offset) * -1))}.fd-popover__body--bottom{bottom:0;top:auto}.fd-popover__body--above{bottom:var(--fdPopover_Offset);top:auto}.fd-popover__body--arrow-bottom{bottom:calc(var(--fdPopover_Offset) + var(--fdPopover_Arrow_Size))!important}.fd-popover__body--arrow-bottom:before{border-bottom:none;border-left:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;border-right:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;border-top:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid var(--sapGroup_ContentBackground);display:inline-block;height:0;top:100%;width:0}.fd-popover__body--arrow-bottom:after{border-bottom:none;border-left:var(--fdPopover_Arrow_Size) solid transparent;border-right:var(--fdPopover_Arrow_Size) solid transparent;border-top:var(--fdPopover_Arrow_Size) solid var(--fdPopover_Border_Color);display:inline-block;height:0;top:100%;width:0}.fd-popover__body--arrow-left{left:calc(var(--fdPopover_Offset) + var(--fdPopover_Arrow_Size))!important}.fd-popover__body--arrow-left:before{border-bottom:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;border-right:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid var(--sapGroup_ContentBackground);border-top:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;top:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--arrow-left:after,.fd-popover__body--arrow-left:before{border-left:none;display:inline-block;height:0;left:auto!important;right:100%!important;width:0}.fd-popover__body--arrow-left:after{border-bottom:var(--fdPopover_Arrow_Size) solid transparent;border-right:var(--fdPopover_Arrow_Size) solid var(--fdPopover_Border_Color);border-top:var(--fdPopover_Arrow_Size) solid transparent;top:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--arrow-right{right:calc(var(--fdPopover_Offset) + var(--fdPopover_Arrow_Size))!important}.fd-popover__body--arrow-right:before{border-bottom:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;border-left:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid var(--sapGroup_ContentBackground);border-top:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;top:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--arrow-right:after,.fd-popover__body--arrow-right:before{border-right:none;display:inline-block;height:0;left:100%!important;right:auto!important;width:0}.fd-popover__body--arrow-right:after{border-bottom:var(--fdPopover_Arrow_Size) solid transparent;border-left:var(--fdPopover_Arrow_Size) solid var(--fdPopover_Border_Color);border-top:var(--fdPopover_Arrow_Size) solid transparent;top:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--arrow-x-center:after,.fd-popover__body--arrow-x-center:before{left:50%;-webkit-transform:translateX(-50%);transform:translate(-50%)}.fd-popover__body--arrow-x-center[dir=rtl]:after,.fd-popover__body--arrow-x-center[dir=rtl]:before,[dir=rtl] .fd-popover__body--arrow-x-center:after,[dir=rtl] .fd-popover__body--arrow-x-center:before{left:auto;right:50%;-webkit-transform:translateX(50%);transform:translate(50%)}.fd-popover__body--arrow-x-end:before{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--arrow-x-end:after{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--arrow-x-end[dir=rtl]:before,[dir=rtl] .fd-popover__body--arrow-x-end:before{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width));right:auto}.fd-popover__body--arrow-x-end[dir=rtl]:after,[dir=rtl] .fd-popover__body--arrow-x-end:after{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width));right:auto}.fd-popover__body--arrow-y-center:after,.fd-popover__body--arrow-y-center:before{top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.fd-popover__body--arrow-y-bottom:before,.fd-popover__body--arrow-y-end:before{bottom:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width));top:auto}.fd-popover__body--arrow-y-bottom:after,.fd-popover__body--arrow-y-end:after{bottom:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width));top:auto}.fd-popover__body--dropdown{width:-webkit-max-content;width:-moz-max-content;width:max-content}.fd-popover__body--dropdown-fill{display:block;max-width:40rem;width:calc(100% - var(--sapGroup_BorderWidth) * 2)}.fd-popover__body--static{position:relative;--fdPopover_Offset:0%;--fdPopover_Center_Offset:0%}.fd-popover__body.is-hidden,.fd-popover__body[aria-hidden=true]{opacity:0;visibility:hidden;z-index:-1}.fd-popover__body .fd-popover__body--hidden{display:none}.fd-popover__body--input-message-group{border:none;-webkit-box-shadow:none;box-shadow:none}.fd-popover__body--inline-help{font-size:var(--sapFontSmallSize);padding-block:.75rem;padding-inline:.75rem}.fd-popover__body--inline-help-icon{--fdIcon_Button_Height:1.375rem;--fdIcon_Button_Width:1.375rem}.fd-popover__body.fd-popover__body--resizable[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable{--fdPopover_Resize_Handle_Position_Right:auto;--fdPopover_Resize_Handle_Position_Left:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Cursor:sw-resize;--fdPopover_Resize_Handle_Transform_Scale:-1}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--right{--fdPopover_Resize_Handle_Position_Left:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Right:auto;--fdPopover_Resize_Handle_Cursor:sw-resize;--fdPopover_Resize_Handle_Transform_Scale:-1;--fdPopover_Resize_Handle_Container_Justify:flex-end}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--right[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--right{--fdPopover_Resize_Handle_Position_Right:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Cursor:se-resize;--fdPopover_Resize_Handle_Transform_Scale:1}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--above{--fdPopover_Resize_Handle_Position_Top:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Bottom:auto;--fdPopover_Resize_Handle_Position_Right:-.5rem;--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Cursor:ne-resize;--fdPopover_Resize_Handle_Rotate_Angle:-90deg;--fdPopover_Resize_Handle_Transform_Scale:1}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--above[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--above{--fdPopover_Resize_Handle_Position_Right:auto;--fdPopover_Resize_Handle_Position_Left:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Cursor:nw-resize;--fdPopover_Resize_Handle_Transform_Scale:1;--fdPopover_Resize_Handle_Rotate_Angle:180deg;--fdPopover_Resize_Handle_Container_Justify:flex-end}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--above.fd-popover__body--right{--fdPopover_Resize_Handle_Position_Right:auto;--fdPopover_Resize_Handle_Position_Left:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Rotate_Angle:180deg;--fdPopover_Resize_Handle_Cursor:nw-resize;--fdPopover_Resize_Handle_Transform_Scale:1;--fdPopover_Resize_Handle_Container_Justify:flex-start}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--above.fd-popover__body--right[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--above.fd-popover__body--right{--fdPopover_Resize_Handle_Position_Right:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Rotate_Angle:-90deg;--fdPopover_Resize_Handle_Cursor:ne-resize;--fdPopover_Resize_Handle_Container_Justify:flex-end}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--after{--fdPopover_Resize_Handle_Position_Top:auto;--fdPopover_Resize_Handle_Position_Bottom:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Right:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Cursor:se-resize}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--after[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--after{--fdPopover_Resize_Handle_Rotate_Angle:-90deg}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--after.fd-popover__body--bottom{--fdPopover_Resize_Handle_Position_Top:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Bottom:auto;--fdPopover_Resize_Handle_Position_Right:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Cursor:ne-resize;--fdPopover_Resize_Handle_Rotate_Angle:-90deg;--fdPopover_Resize_Handle_Transform_Scale:1}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--after.fd-popover__body--bottom[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--after.fd-popover__body--bottom{--fdPopover_Resize_Handle_Container_Justify:flex-end}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--before{--fdPopover_Resize_Handle_Position_Top:auto;--fdPopover_Resize_Handle_Position_Bottom:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Right:auto;--fdPopover_Resize_Handle_Position_Left:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Cursor:sw-resize;--fdPopover_Resize_Handle_Rotate_Angle:0;--fdPopover_Resize_Handle_Transform_Scale:-1;--fdPopover_Resize_Handle_Container_Justify:flex-end}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--before[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--before{--fdPopover_Resize_Handle_Container_Justify:flex-start}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--before.fd-popover__body--bottom,.fd-popover__body.fd-popover__body--resizable.fd-popover__body--before.fd-popover__body--middle{--fdPopover_Resize_Handle_Position_Top:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Bottom:auto;--fdPopover_Resize_Handle_Rotate_Angle:90deg;--fdPopover_Resize_Handle_Cursor:nw-resize}.fd-popover__resize-handle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:1.5rem;line-height:normal;margin-block:0;margin-inline:0;min-width:1.5rem;padding-block:0;padding-inline:0;width:1.5rem;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start;-webkit-box-pack:var(--fdPopover_Resize_Handle_Container_Justify, flex-start);-ms-flex-pack:var(--fdPopover_Resize_Handle_Container_Justify, flex-start);color:var(--sapButton_Lite_TextColor);cursor:var(--fdPopover_Resize_Handle_Cursor);font-size:1rem;inset:var(--fdPopover_Resize_Handle_Position_Top) var(--fdPopover_Resize_Handle_Position_Right) var(--fdPopover_Resize_Handle_Position_Bottom) var(--fdPopover_Resize_Handle_Position_Left);justify-content:var(--fdPopover_Resize_Handle_Container_Justify, flex-start);line-height:1rem;overflow:hidden;position:absolute;-webkit-transform:rotate(var(--fdPopover_Resize_Handle_Rotate_Angle));transform:rotate(var(--fdPopover_Resize_Handle_Rotate_Angle))}.fd-popover__resize-handle:after,.fd-popover__resize-handle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover__resize-handle:after{content:\"\\e24f\";display:-webkit-box;display:-ms-flexbox;display:flex;font-family:SAP-icons;height:1rem;min-width:1rem;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none;width:1rem;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:var(--fdPopover_Resize_Handle_Justify);-ms-flex-pack:var(--fdPopover_Resize_Handle_Justify);color:inherit;justify-content:var(--fdPopover_Resize_Handle_Justify);-webkit-transform:scaleX(var(--fdPopover_Resize_Handle_Transform_Scale));transform:scaleX(var(--fdPopover_Resize_Handle_Transform_Scale))}.fd-popover--slider{--fdPopover_Display:block}.fd-popover--input-message-group .fd-popover__body,.fd-popover--input-message-group .fd-popover__body--no-arrow{border:none;-webkit-box-shadow:none;box-shadow:none}.fd-popover--full-width{width:100%}.fd-popover--btp .fd-popover__body{--fdPopover_Arrow_Size:.375rem;--fdPopover_Body_Border_Radius:.75rem;--fdPopover_Body_Box_Shadow:var(--sapMenu_Shadow2);border:none;top:calc(var(--fdPopover_Offset) + var(--fdPopover_Arrow_Size) - .1875rem)}.fd-popover--btp .fd-popover__body--padding{padding-block:.75rem;padding-inline:.75rem}.fd-popover--btp .fd-popover__body-header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-popover--btp .fd-popover__body-header:after,.fd-popover--btp .fd-popover__body-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover--btp .fd-popover__body-content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-block:.75rem;margin-inline:0;padding-block:0;padding-inline:0}.fd-popover--btp .fd-popover__body-content:after,.fd-popover--btp .fd-popover__body-content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover--btp .fd-popover__body-content:only-child{margin-block:0;margin-inline:0}.fd-popover--btp .fd-popover__body-footer{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.1875rem;-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;padding-block:.375rem;padding-inline:0}.fd-popover--btp .fd-popover__body-footer:after,.fd-popover--btp .fd-popover__body-footer:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover--btp .fd-popover__body-footer--center{-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.cdk-overlay-container,.cdk-global-overlay-wrapper{pointer-events:none;top:0;left:0;height:100%;width:100%}.cdk-overlay-container{position:fixed;z-index:1000}.cdk-overlay-container:empty{display:none}.cdk-global-overlay-wrapper{display:flex;position:absolute;z-index:1000}.cdk-overlay-pane{position:absolute;pointer-events:auto;box-sizing:border-box;display:flex;max-width:100%;max-height:100%;z-index:1000}.cdk-overlay-backdrop{position:absolute;inset:0;pointer-events:auto;-webkit-tap-highlight-color:rgba(0,0,0,0);opacity:0;touch-action:manipulation;z-index:1000;transition:opacity .4s cubic-bezier(.25,.8,.25,1)}@media (prefers-reduced-motion){.cdk-overlay-backdrop{transition-duration:1ms}}.cdk-overlay-backdrop-showing{opacity:1}@media (forced-colors: active){.cdk-overlay-backdrop-showing{opacity:.6}}.cdk-overlay-dark-backdrop{background:#00000052}.cdk-overlay-transparent-backdrop{transition:visibility 1ms linear,opacity 1ms linear;visibility:hidden;opacity:1}.cdk-overlay-transparent-backdrop.cdk-overlay-backdrop-showing,.cdk-high-contrast-active .cdk-overlay-transparent-backdrop{opacity:0;visibility:visible}.cdk-overlay-backdrop-noop-animation{transition:none}.cdk-overlay-connected-position-bounding-box{position:absolute;display:flex;flex-direction:column;min-width:1px;min-height:1px;z-index:1000}.cdk-global-scrollblock{position:fixed;width:100%;overflow-y:scroll}fd-popover-body{max-width:100%;max-height:100%}.fd-popover-custom{display:inline-block;max-width:100%}.fd-popover-custom--disabled .fd-popover__control{cursor:auto}.fd-popover__body{max-height:100%;max-width:100%;display:flex}.fd-popover__body .fd-popover__body-footer,.fd-popover__body .fd-popover__body-header{position:sticky;z-index:6}.fd-popover__body .fd-popover__body-footer{bottom:0}.fd-popover__body--hidden{display:none!important}.fd-popover__body--disable-transitions{transition:none!important;-webkit-transition:none!important}.fd-popover__body--inline-help.fd-inline-help__content{white-space:initial}.fd-popover__body--inline-help.fd-inline-help__content>.fd-scrollbar{border-radius:0}.fd-popover__body.fd-form-message:before{width:auto;height:auto;position:relative;inset:0;border:none}.fd-popover__body>.fd-scrollbar{max-height:100%;max-width:100%;width:100%;border-radius:inherit}.fd-popover__body .fd-list{border-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-list__item:first-child,.fd-popover__body .fd-list__item:first-of-type{border-top-right-radius:var(--fdPopover_Border_Radius);border-top-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-list__item:last-child,.fd-popover__body .fd-list__item:last-of-type{border-bottom-right-radius:var(--fdPopover_Border_Radius);border-bottom-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-nested-list{border-bottom:none}.fd-popover__body .fd-nested-list__item:first-child .fd-nested-list__content{border-top-right-radius:var(--fdPopover_Border_Radius);border-top-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-nested-list__item:last-child .fd-nested-list__item:last-child .fd-nested-list__link{border-bottom-right-radius:var(--fdPopover_Border_Radius);border-bottom-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-nested-list__item:last-child .fd-nested-list__content{border-bottom-right-radius:var(--fdPopover_Border_Radius);border-bottom-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-nested-list__item:last-child .fd-nested-list__content.is-selected{border-bottom-right-radius:0;border-bottom-left-radius:0}.fd-popover__body .fd-side-nav,.fd-popover__body .fd-nested-list__item{border-right:none}.fd-popover__body .fd-side-nav:first-child,.fd-popover__body .fd-nested-list__item:first-child{border-top-right-radius:var(--fdPopover_Border_Radius);border-top-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-side-nav:last-child,.fd-popover__body .fd-nested-list__item:last-child{border-bottom-right-radius:var(--fdPopover_Border_Radius);border-bottom-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__resize-handle{-webkit-user-select:none;user-select:none}.cdk-overlay-container{z-index:1002}.cdk-overlay-pane{max-width:100%;max-height:100%}\n/*!\n * Fundamental Library Styles v0.40.1\n * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n */\n"], dependencies: [{ kind: "ngmodule", type: A11yModule }, { kind: "directive", type: i2.CdkTrapFocus, selector: "[cdkTrapFocus]", inputs: ["cdkTrapFocus", "cdkTrapFocusAutoCapture"], exportAs: ["cdkTrapFocus"] }, { kind: "directive", type: ScrollbarDirective, selector: "[fdScrollbar], [fd-scrollbar]", inputs: ["noHorizontalScroll", "noVerticalScroll", "alwaysVisible"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: ResizeHandleDirective, selector: "[fdkResizeHandle]" }, { kind: "directive", type: ResizeDirective, selector: "[fdkResize]", inputs: ["fdkResizeBoundary", "fdkResizeDisabled", "fdkResizeClass", "fdkResizeHandleLocation", "fdkResizeResizeHandleRef"], outputs: ["onResizeStart", "onResizeEnd"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverBodyComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-popover-body', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [contentDensityObserverProviders({ alwaysAddModifiers: true })], imports: [A11yModule, CdkScrollable, ScrollbarDirective, NgTemplateOutlet, ResizeHandleDirective, ResizeDirective], standalone: true, template: "<div\n    class=\"fd-popover__body fd-popover__body--static\"\n    [class.fd-popover__body--no-arrow]=\"_noArrow\"\n    [class.fd-popover__body--resizable]=\"_resizable\"\n    [class]=\"_arrowClasses + ' ' + (_additionalBodyClass || '')\"\n    [cdkTrapFocus]=\"_focusTrapped\"\n    [style.min-width]=\"_popoverBodyMinWidth ? null : minWidth\"\n    [style.max-width]=\"_maxWidth ? null : maxWidth\"\n    [style.min-height]=\"minHeight\"\n    [style.max-height]=\"maxHeight\"\n    [style.max-width.px]=\"_maxWidth\"\n    [style.min-width.px]=\"_popoverBodyMinWidth\"\n    [style.width.px]=\"_popoverBodyWidth\"\n    [attr.role]=\"_bodyRole\"\n    [attr.id]=\"_bodyId\"\n    fdkResize\n    [fdkResizeDisabled]=\"!_resizable\"\n    [fdkResizeClass]=\"'fd-popover__body--disable-transitions'\"\n    [fdkResizeHandleLocation]=\"_resizeHandleLocation\"\n>\n    @if (!_disableScrollbar) {\n        <div fd-scrollbar class=\"fd-popover__wrapper\">\n            <ng-template [ngTemplateOutlet]=\"renderer\"></ng-template>\n        </div>\n    } @else {\n        <ng-template [ngTemplateOutlet]=\"renderer\"></ng-template>\n    }\n    @if (_resizable) {\n        <span fdkResizeHandle class=\"fd-popover__resize-handle\" role=\"presentation\" aria-hidden=\"true\"></span>\n    }\n</div>\n<ng-template #renderer>\n    <ng-content select=\"[fd-popover-body-header]\"></ng-content>\n    <ng-content select=\"[fd-popover-body-subheader]\"></ng-content>\n    <ng-content></ng-content>\n    {{ text }}\n    <ng-template [ngTemplateOutlet]=\"_templateToDisplay\"></ng-template>\n    <ng-content select=\"[fd-popover-body-footer]\"></ng-content>\n</ng-template>\n", styles: ["body.fd-overlay-active:before{background:var(--fdModal_BackgroundColor);content:\"\";height:100vh;left:0;pointer-events:all;position:fixed;top:0;width:100vw;z-index:999}.fd-popover{--fdPopover_Display:inline-block;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:var(--fdPopover_Display);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;padding-block:0;padding-inline:0;position:relative}.fd-popover:after,.fd-popover:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover__modal{position:relative;z-index:1000}.fd-popover__control{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);cursor:pointer;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-popover__control:after,.fd-popover__control:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover__control:focus-visible{outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor)}.fd-popover__control.is-expanded>*,.fd-popover__control[aria-expanded=true]>*{-webkit-margin-after:0;margin-block-end:0}.fd-popover__control.is-expanded+.fd-popover__body--input-message-group,.fd-popover__control[aria-expanded=true]+.fd-popover__body--input-message-group{margin-top:0}.fd-popover__control.is-disabled,.fd-popover__control:disabled,.fd-popover__control[aria-disabled=true]{pointer-events:none}.fd-popover__wrapper{border-radius:var(--fdPopover_Body_Border_Radius);overflow:auto;position:relative;scrollbar-color:var(--fdScrollbar_Thumb_Color) var(--fdScrollbar_Track_Color)}.fd-popover__wrapper.is-focus,.fd-popover__wrapper:focus{outline:none;z-index:5}.fd-popover__wrapper::-webkit-scrollbar{height:var(--fdScrollbar_Dimension);width:var(--fdScrollbar_Dimension)}.fd-popover__wrapper::-webkit-scrollbar-corner,.fd-popover__wrapper::-webkit-scrollbar-track{background-color:var(--fdScrollbar_Track_Color)}.fd-popover__wrapper::-webkit-scrollbar-thumb{background-color:transparent;border:var(--fdScrollbar_Thumb_Offset) solid transparent;border-radius:calc(var(--fdScrollbar_Thumb_Border_Radius) - var(--fdScrollbar_Thumb_Offset));-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color)}.fd-popover__wrapper::-webkit-scrollbar-thumb:active,.fd-popover__wrapper::-webkit-scrollbar-thumb:hover{-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color)}.fd-popover__wrapper::-webkit-scrollbar-corner,.fd-popover__wrapper::-webkit-scrollbar-track{border-radius:0 var(--fdScrollbar_Border_Radius) var(--fdScrollbar_Border_Radius) 0}.fd-popover__wrapper[dir=rtl]::-webkit-scrollbar-corner,.fd-popover__wrapper[dir=rtl]::-webkit-scrollbar-track,[dir=rtl] .fd-popover__wrapper::-webkit-scrollbar-corner,[dir=rtl] .fd-popover__wrapper::-webkit-scrollbar-track{border-radius:var(--fdScrollbar_Border_Radius) 0 0 var(--fdScrollbar_Border_Radius)}.fd-popover__wrapper--visible{overflow:visible!important}.fd-popover__body{--fdPopover_Offset:100%;--fdPopover_Center_Offset:50%;--fdPopover_Arrow_Size:.5rem;--fdPopover_Body_Border_Radius:var(--fdPopover_Border_Radius);--fdPopover_Body_Box_Shadow:var(--sapContent_Shadow2);--fdPopover_Body_Box_Shadow_No_Arrow:var(--sapContent_Shadow1);--fdIcon_Button_Height:2.25rem;--fdIcon_Button_Width:2.25rem;--fdPopover_Resize_Handle_Offset:-.5rem;--fdPopover_Resize_Handle_Position_Top:auto;--fdPopover_Resize_Handle_Position_Right:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Bottom:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Rotate_Angle:0;--fdPopover_Resize_Handle_Cursor:se-resize;--fdPopover_Resize_Handle_Justify:center;--fdPopover_Resize_Handle_Transform_Scale:1;background:var(--sapGroup_ContentBackground);border:0;border-radius:var(--fdPopover_Body_Border_Radius);-webkit-box-shadow:var(--fdPopover_Body_Box_Shadow);box-shadow:var(--fdPopover_Body_Box_Shadow);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;opacity:1;padding-block:0;padding-inline:0;position:absolute;top:calc(var(--fdPopover_Offset) + var(--fdPopover_Arrow_Size));-webkit-transition:all .125s;transition:all .125s;visibility:visible;white-space:nowrap;z-index:1000}.fd-popover__body:after,.fd-popover__body:before{-webkit-box-sizing:inherit;box-sizing:inherit;content:\"\";font-size:inherit;position:absolute}.fd-popover__body:before{border-bottom:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid var(--sapGroup_ContentBackground);border-left:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;border-right:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;top:calc(var(--fdPopover_Arrow_Size) * -1 + var(--fdPopover_Border_Width));z-index:1002}.fd-popover__body:after,.fd-popover__body:before{border-top:none;display:inline-block;height:0;width:0}.fd-popover__body:after{border-bottom:var(--fdPopover_Arrow_Size) solid var(--fdPopover_Border_Color);border-left:var(--fdPopover_Arrow_Size) solid transparent;border-right:var(--fdPopover_Arrow_Size) solid transparent;top:calc(var(--fdPopover_Arrow_Size) * -1);z-index:1001}.fd-popover__body>:not(.fd-popover__wrapper){overflow:hidden}.fd-popover__body-header>:first-child,.fd-popover__body>:first-child{border-top-left-radius:var(--fdPopover_Border_Radius);border-top-right-radius:var(--fdPopover_Border_Radius)}.fd-popover__body-footer>:last-child,.fd-popover__body>:last-child:not(.fd-popover__resize-handle){border-bottom-left-radius:var(--fdPopover_Border_Radius);border-bottom-right-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-menu{width:100%}.fd-popover__body[class*=-compact],.fd-popover__body[class*=-condensed],[class*=-compact] .fd-popover__body:not([class*=-cozy]),[class*=-condensed] .fd-popover__body:not([class*=-cozy]){--fdIcon_Button_Height:1.625rem;--fdIcon_Button_Width:2rem}.fd-popover__body--no-arrow{-webkit-box-shadow:var(--fdPopover_Body_Box_Shadow_No_Arrow);box-shadow:var(--fdPopover_Body_Box_Shadow_No_Arrow);top:var(--fdPopover_Offset)}.fd-popover__body--no-arrow:after,.fd-popover__body--no-arrow:before{display:none}.fd-popover__body,.fd-popover__body--left{left:0}.fd-popover__body--left[dir=rtl],.fd-popover__body[dir=rtl],[dir=rtl] .fd-popover__body,[dir=rtl] .fd-popover__body--left{left:auto;right:0}.fd-popover__body--left:before,.fd-popover__body:before{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--left:after,.fd-popover__body:after{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--left[dir=rtl]:before,.fd-popover__body[dir=rtl]:before,[dir=rtl] .fd-popover__body--left:before,[dir=rtl] .fd-popover__body:before{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--left[dir=rtl]:after,.fd-popover__body[dir=rtl]:after,[dir=rtl] .fd-popover__body--left:after,[dir=rtl] .fd-popover__body:after{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--center{left:var(--fdPopover_Center_Offset);-webkit-transform:translateX(calc(var(--fdPopover_Center_Offset) * -1));transform:translate(calc(var(--fdPopover_Center_Offset) * -1))}.fd-popover__body--center[dir=rtl],[dir=rtl] .fd-popover__body--center{left:auto;right:var(--fdPopover_Center_Offset);-webkit-transform:translateX(var(--fdPopover_Center_Offset));transform:translate(var(--fdPopover_Center_Offset))}.fd-popover__body--right{left:auto;right:0}.fd-popover__body--right[dir=rtl],[dir=rtl] .fd-popover__body--right{left:0;right:auto}.fd-popover__body--right:before{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--right:after{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--right[dir=rtl]:before,[dir=rtl] .fd-popover__body--right:before{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width));right:auto}.fd-popover__body--right[dir=rtl]:after,[dir=rtl] .fd-popover__body--right:after{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width));right:auto}.fd-popover__body--before{left:auto!important;right:var(--fdPopover_Offset)!important;top:0}.fd-popover__body--after{left:var(--fdPopover_Offset)!important;right:auto!important;top:0}.fd-popover__body--middle{top:var(--fdPopover_Center_Offset);-webkit-transform:translateY(calc(var(--fdPopover_Center_Offset) * -1));transform:translateY(calc(var(--fdPopover_Center_Offset) * -1))}.fd-popover__body--bottom{bottom:0;top:auto}.fd-popover__body--above{bottom:var(--fdPopover_Offset);top:auto}.fd-popover__body--arrow-bottom{bottom:calc(var(--fdPopover_Offset) + var(--fdPopover_Arrow_Size))!important}.fd-popover__body--arrow-bottom:before{border-bottom:none;border-left:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;border-right:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;border-top:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid var(--sapGroup_ContentBackground);display:inline-block;height:0;top:100%;width:0}.fd-popover__body--arrow-bottom:after{border-bottom:none;border-left:var(--fdPopover_Arrow_Size) solid transparent;border-right:var(--fdPopover_Arrow_Size) solid transparent;border-top:var(--fdPopover_Arrow_Size) solid var(--fdPopover_Border_Color);display:inline-block;height:0;top:100%;width:0}.fd-popover__body--arrow-left{left:calc(var(--fdPopover_Offset) + var(--fdPopover_Arrow_Size))!important}.fd-popover__body--arrow-left:before{border-bottom:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;border-right:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid var(--sapGroup_ContentBackground);border-top:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;top:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--arrow-left:after,.fd-popover__body--arrow-left:before{border-left:none;display:inline-block;height:0;left:auto!important;right:100%!important;width:0}.fd-popover__body--arrow-left:after{border-bottom:var(--fdPopover_Arrow_Size) solid transparent;border-right:var(--fdPopover_Arrow_Size) solid var(--fdPopover_Border_Color);border-top:var(--fdPopover_Arrow_Size) solid transparent;top:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--arrow-right{right:calc(var(--fdPopover_Offset) + var(--fdPopover_Arrow_Size))!important}.fd-popover__body--arrow-right:before{border-bottom:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;border-left:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid var(--sapGroup_ContentBackground);border-top:calc(var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width)) solid transparent;top:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--arrow-right:after,.fd-popover__body--arrow-right:before{border-right:none;display:inline-block;height:0;left:100%!important;right:auto!important;width:0}.fd-popover__body--arrow-right:after{border-bottom:var(--fdPopover_Arrow_Size) solid transparent;border-left:var(--fdPopover_Arrow_Size) solid var(--fdPopover_Border_Color);border-top:var(--fdPopover_Arrow_Size) solid transparent;top:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--arrow-x-center:after,.fd-popover__body--arrow-x-center:before{left:50%;-webkit-transform:translateX(-50%);transform:translate(-50%)}.fd-popover__body--arrow-x-center[dir=rtl]:after,.fd-popover__body--arrow-x-center[dir=rtl]:before,[dir=rtl] .fd-popover__body--arrow-x-center:after,[dir=rtl] .fd-popover__body--arrow-x-center:before{left:auto;right:50%;-webkit-transform:translateX(50%);transform:translate(50%)}.fd-popover__body--arrow-x-end:before{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width))}.fd-popover__body--arrow-x-end:after{left:auto;right:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width))}.fd-popover__body--arrow-x-end[dir=rtl]:before,[dir=rtl] .fd-popover__body--arrow-x-end:before{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width));right:auto}.fd-popover__body--arrow-x-end[dir=rtl]:after,[dir=rtl] .fd-popover__body--arrow-x-end:after{left:calc(var(--fdIcon_Button_Width) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width));right:auto}.fd-popover__body--arrow-y-center:after,.fd-popover__body--arrow-y-center:before{top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.fd-popover__body--arrow-y-bottom:before,.fd-popover__body--arrow-y-end:before{bottom:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width) + var(--fdPopover_Border_Width));top:auto}.fd-popover__body--arrow-y-bottom:after,.fd-popover__body--arrow-y-end:after{bottom:calc(var(--fdIcon_Button_Height) * .5 - var(--fdPopover_Arrow_Size) - var(--fdPopover_Border_Width));top:auto}.fd-popover__body--dropdown{width:-webkit-max-content;width:-moz-max-content;width:max-content}.fd-popover__body--dropdown-fill{display:block;max-width:40rem;width:calc(100% - var(--sapGroup_BorderWidth) * 2)}.fd-popover__body--static{position:relative;--fdPopover_Offset:0%;--fdPopover_Center_Offset:0%}.fd-popover__body.is-hidden,.fd-popover__body[aria-hidden=true]{opacity:0;visibility:hidden;z-index:-1}.fd-popover__body .fd-popover__body--hidden{display:none}.fd-popover__body--input-message-group{border:none;-webkit-box-shadow:none;box-shadow:none}.fd-popover__body--inline-help{font-size:var(--sapFontSmallSize);padding-block:.75rem;padding-inline:.75rem}.fd-popover__body--inline-help-icon{--fdIcon_Button_Height:1.375rem;--fdIcon_Button_Width:1.375rem}.fd-popover__body.fd-popover__body--resizable[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable{--fdPopover_Resize_Handle_Position_Right:auto;--fdPopover_Resize_Handle_Position_Left:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Cursor:sw-resize;--fdPopover_Resize_Handle_Transform_Scale:-1}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--right{--fdPopover_Resize_Handle_Position_Left:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Right:auto;--fdPopover_Resize_Handle_Cursor:sw-resize;--fdPopover_Resize_Handle_Transform_Scale:-1;--fdPopover_Resize_Handle_Container_Justify:flex-end}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--right[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--right{--fdPopover_Resize_Handle_Position_Right:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Cursor:se-resize;--fdPopover_Resize_Handle_Transform_Scale:1}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--above{--fdPopover_Resize_Handle_Position_Top:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Bottom:auto;--fdPopover_Resize_Handle_Position_Right:-.5rem;--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Cursor:ne-resize;--fdPopover_Resize_Handle_Rotate_Angle:-90deg;--fdPopover_Resize_Handle_Transform_Scale:1}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--above[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--above{--fdPopover_Resize_Handle_Position_Right:auto;--fdPopover_Resize_Handle_Position_Left:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Cursor:nw-resize;--fdPopover_Resize_Handle_Transform_Scale:1;--fdPopover_Resize_Handle_Rotate_Angle:180deg;--fdPopover_Resize_Handle_Container_Justify:flex-end}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--above.fd-popover__body--right{--fdPopover_Resize_Handle_Position_Right:auto;--fdPopover_Resize_Handle_Position_Left:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Rotate_Angle:180deg;--fdPopover_Resize_Handle_Cursor:nw-resize;--fdPopover_Resize_Handle_Transform_Scale:1;--fdPopover_Resize_Handle_Container_Justify:flex-start}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--above.fd-popover__body--right[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--above.fd-popover__body--right{--fdPopover_Resize_Handle_Position_Right:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Rotate_Angle:-90deg;--fdPopover_Resize_Handle_Cursor:ne-resize;--fdPopover_Resize_Handle_Container_Justify:flex-end}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--after{--fdPopover_Resize_Handle_Position_Top:auto;--fdPopover_Resize_Handle_Position_Bottom:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Right:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Cursor:se-resize}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--after[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--after{--fdPopover_Resize_Handle_Rotate_Angle:-90deg}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--after.fd-popover__body--bottom{--fdPopover_Resize_Handle_Position_Top:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Bottom:auto;--fdPopover_Resize_Handle_Position_Right:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Left:auto;--fdPopover_Resize_Handle_Cursor:ne-resize;--fdPopover_Resize_Handle_Rotate_Angle:-90deg;--fdPopover_Resize_Handle_Transform_Scale:1}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--after.fd-popover__body--bottom[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--after.fd-popover__body--bottom{--fdPopover_Resize_Handle_Container_Justify:flex-end}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--before{--fdPopover_Resize_Handle_Position_Top:auto;--fdPopover_Resize_Handle_Position_Bottom:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Right:auto;--fdPopover_Resize_Handle_Position_Left:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Cursor:sw-resize;--fdPopover_Resize_Handle_Rotate_Angle:0;--fdPopover_Resize_Handle_Transform_Scale:-1;--fdPopover_Resize_Handle_Container_Justify:flex-end}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--before[dir=rtl],[dir=rtl] .fd-popover__body.fd-popover__body--resizable.fd-popover__body--before{--fdPopover_Resize_Handle_Container_Justify:flex-start}.fd-popover__body.fd-popover__body--resizable.fd-popover__body--before.fd-popover__body--bottom,.fd-popover__body.fd-popover__body--resizable.fd-popover__body--before.fd-popover__body--middle{--fdPopover_Resize_Handle_Position_Top:var(--fdPopover_Resize_Handle_Offset);--fdPopover_Resize_Handle_Position_Bottom:auto;--fdPopover_Resize_Handle_Rotate_Angle:90deg;--fdPopover_Resize_Handle_Cursor:nw-resize}.fd-popover__resize-handle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:1.5rem;line-height:normal;margin-block:0;margin-inline:0;min-width:1.5rem;padding-block:0;padding-inline:0;width:1.5rem;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start;-webkit-box-pack:var(--fdPopover_Resize_Handle_Container_Justify, flex-start);-ms-flex-pack:var(--fdPopover_Resize_Handle_Container_Justify, flex-start);color:var(--sapButton_Lite_TextColor);cursor:var(--fdPopover_Resize_Handle_Cursor);font-size:1rem;inset:var(--fdPopover_Resize_Handle_Position_Top) var(--fdPopover_Resize_Handle_Position_Right) var(--fdPopover_Resize_Handle_Position_Bottom) var(--fdPopover_Resize_Handle_Position_Left);justify-content:var(--fdPopover_Resize_Handle_Container_Justify, flex-start);line-height:1rem;overflow:hidden;position:absolute;-webkit-transform:rotate(var(--fdPopover_Resize_Handle_Rotate_Angle));transform:rotate(var(--fdPopover_Resize_Handle_Rotate_Angle))}.fd-popover__resize-handle:after,.fd-popover__resize-handle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover__resize-handle:after{content:\"\\e24f\";display:-webkit-box;display:-ms-flexbox;display:flex;font-family:SAP-icons;height:1rem;min-width:1rem;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none;width:1rem;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:var(--fdPopover_Resize_Handle_Justify);-ms-flex-pack:var(--fdPopover_Resize_Handle_Justify);color:inherit;justify-content:var(--fdPopover_Resize_Handle_Justify);-webkit-transform:scaleX(var(--fdPopover_Resize_Handle_Transform_Scale));transform:scaleX(var(--fdPopover_Resize_Handle_Transform_Scale))}.fd-popover--slider{--fdPopover_Display:block}.fd-popover--input-message-group .fd-popover__body,.fd-popover--input-message-group .fd-popover__body--no-arrow{border:none;-webkit-box-shadow:none;box-shadow:none}.fd-popover--full-width{width:100%}.fd-popover--btp .fd-popover__body{--fdPopover_Arrow_Size:.375rem;--fdPopover_Body_Border_Radius:.75rem;--fdPopover_Body_Box_Shadow:var(--sapMenu_Shadow2);border:none;top:calc(var(--fdPopover_Offset) + var(--fdPopover_Arrow_Size) - .1875rem)}.fd-popover--btp .fd-popover__body--padding{padding-block:.75rem;padding-inline:.75rem}.fd-popover--btp .fd-popover__body-header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-popover--btp .fd-popover__body-header:after,.fd-popover--btp .fd-popover__body-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover--btp .fd-popover__body-content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-block:.75rem;margin-inline:0;padding-block:0;padding-inline:0}.fd-popover--btp .fd-popover__body-content:after,.fd-popover--btp .fd-popover__body-content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover--btp .fd-popover__body-content:only-child{margin-block:0;margin-inline:0}.fd-popover--btp .fd-popover__body-footer{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.1875rem;-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;padding-block:.375rem;padding-inline:0}.fd-popover--btp .fd-popover__body-footer:after,.fd-popover--btp .fd-popover__body-footer:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-popover--btp .fd-popover__body-footer--center{-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.cdk-overlay-container,.cdk-global-overlay-wrapper{pointer-events:none;top:0;left:0;height:100%;width:100%}.cdk-overlay-container{position:fixed;z-index:1000}.cdk-overlay-container:empty{display:none}.cdk-global-overlay-wrapper{display:flex;position:absolute;z-index:1000}.cdk-overlay-pane{position:absolute;pointer-events:auto;box-sizing:border-box;display:flex;max-width:100%;max-height:100%;z-index:1000}.cdk-overlay-backdrop{position:absolute;inset:0;pointer-events:auto;-webkit-tap-highlight-color:rgba(0,0,0,0);opacity:0;touch-action:manipulation;z-index:1000;transition:opacity .4s cubic-bezier(.25,.8,.25,1)}@media (prefers-reduced-motion){.cdk-overlay-backdrop{transition-duration:1ms}}.cdk-overlay-backdrop-showing{opacity:1}@media (forced-colors: active){.cdk-overlay-backdrop-showing{opacity:.6}}.cdk-overlay-dark-backdrop{background:#00000052}.cdk-overlay-transparent-backdrop{transition:visibility 1ms linear,opacity 1ms linear;visibility:hidden;opacity:1}.cdk-overlay-transparent-backdrop.cdk-overlay-backdrop-showing,.cdk-high-contrast-active .cdk-overlay-transparent-backdrop{opacity:0;visibility:visible}.cdk-overlay-backdrop-noop-animation{transition:none}.cdk-overlay-connected-position-bounding-box{position:absolute;display:flex;flex-direction:column;min-width:1px;min-height:1px;z-index:1000}.cdk-global-scrollblock{position:fixed;width:100%;overflow-y:scroll}fd-popover-body{max-width:100%;max-height:100%}.fd-popover-custom{display:inline-block;max-width:100%}.fd-popover-custom--disabled .fd-popover__control{cursor:auto}.fd-popover__body{max-height:100%;max-width:100%;display:flex}.fd-popover__body .fd-popover__body-footer,.fd-popover__body .fd-popover__body-header{position:sticky;z-index:6}.fd-popover__body .fd-popover__body-footer{bottom:0}.fd-popover__body--hidden{display:none!important}.fd-popover__body--disable-transitions{transition:none!important;-webkit-transition:none!important}.fd-popover__body--inline-help.fd-inline-help__content{white-space:initial}.fd-popover__body--inline-help.fd-inline-help__content>.fd-scrollbar{border-radius:0}.fd-popover__body.fd-form-message:before{width:auto;height:auto;position:relative;inset:0;border:none}.fd-popover__body>.fd-scrollbar{max-height:100%;max-width:100%;width:100%;border-radius:inherit}.fd-popover__body .fd-list{border-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-list__item:first-child,.fd-popover__body .fd-list__item:first-of-type{border-top-right-radius:var(--fdPopover_Border_Radius);border-top-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-list__item:last-child,.fd-popover__body .fd-list__item:last-of-type{border-bottom-right-radius:var(--fdPopover_Border_Radius);border-bottom-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-nested-list{border-bottom:none}.fd-popover__body .fd-nested-list__item:first-child .fd-nested-list__content{border-top-right-radius:var(--fdPopover_Border_Radius);border-top-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-nested-list__item:last-child .fd-nested-list__item:last-child .fd-nested-list__link{border-bottom-right-radius:var(--fdPopover_Border_Radius);border-bottom-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-nested-list__item:last-child .fd-nested-list__content{border-bottom-right-radius:var(--fdPopover_Border_Radius);border-bottom-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-nested-list__item:last-child .fd-nested-list__content.is-selected{border-bottom-right-radius:0;border-bottom-left-radius:0}.fd-popover__body .fd-side-nav,.fd-popover__body .fd-nested-list__item{border-right:none}.fd-popover__body .fd-side-nav:first-child,.fd-popover__body .fd-nested-list__item:first-child{border-top-right-radius:var(--fdPopover_Border_Radius);border-top-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__body .fd-side-nav:last-child,.fd-popover__body .fd-nested-list__item:last-child{border-bottom-right-radius:var(--fdPopover_Border_Radius);border-bottom-left-radius:var(--fdPopover_Border_Radius)}.fd-popover__resize-handle{-webkit-user-select:none;user-select:none}.cdk-overlay-container{z-index:1002}.cdk-overlay-pane{max-width:100%;max-height:100%}\n/*!\n * Fundamental Library Styles v0.40.1\n * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n */\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i0.Renderer2 }, { type: i1.ContentDensityObserver }], propDecorators: { minWidth: [{
                type: Input
            }], maxWidth: [{
                type: Input
            }], minHeight: [{
                type: Input
            }], maxHeight: [{
                type: Input
            }], _cdkTrapFocus: [{
                type: ViewChild,
                args: [CdkTrapFocus]
            }], _scrollbar: [{
                type: ViewChild,
                args: [ScrollbarDirective]
            }], bodyKeyupHandler: [{
                type: HostListener,
                args: ['keyup', ['$event']]
            }] } });

class PopoverContainerDirective {
    /** @hidden */
    constructor(_elmRef) {
        this._elmRef = _elmRef;
        /** Subject which emits when popover position refresh is required. */
        this.refreshPosition$ = new Subject();
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
    }
    /** @hidden */
    ngOnInit() {
        resizeObservable(this._elmRef.nativeElement)
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe(() => {
            this.refreshPosition$.next();
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverContainerDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: PopoverContainerDirective, isStandalone: true, selector: "[fdPopoverContainer]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverContainerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdPopoverContainer]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }] });

/**
 * A component used to enforce a certain layout for the popover.
 * ```html
 * <fd-popover>
 *     <fd-popover-control>Control Element</fd-popover-control>
 *     <fd-popover-body>Popover Body</fd-popover-body>
 * </fd-popover>
 * ```
 */
class PopoverControlComponent {
    /** @hidden */
    constructor(elRef) {
        this.elRef = elRef;
        /** @hidden */
        this._tabbable = false;
    }
    /** @hidden */
    ngAfterContentChecked() {
        if (this._tabbable) {
            this.makeTabbable();
        }
    }
    /** @hidden */
    makeTabbable() {
        const elemChild = this.elRef.nativeElement.children[0];
        if (elemChild && elemChild.getAttribute('tabindex') !== '-1') {
            elemChild.tabIndex = '0';
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverControlComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: PopoverControlComponent, isStandalone: true, selector: "fd-popover-control, [fdPopoverControl]", ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverControlComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-popover-control, [fdPopoverControl]',
                    template: `<ng-content></ng-content>`,
                    encapsulation: ViewEncapsulation.None,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }] });

const POPOVER_COMPONENT = new InjectionToken('PopoverInterface');

let mobilePopoverUniqueId = 0;
class PopoverMobileComponent extends MobileModeBase {
    /** @hidden */
    get titleId() {
        return this.id + '-title';
    }
    /** @hidden */
    constructor(_changeDetectorref, _popoverComponent) {
        super(_popoverComponent, MobileModeControl.POPOVER);
        this._changeDetectorref = _changeDetectorref;
        /** @hidden
         * from mobile class can not prefix _,
         * to avoid build issues
         */
        this.childContent = undefined;
        /** @hidden */
        this.id = 'fd-popover-mobile-' + mobilePopoverUniqueId++;
        /** @hidden */
        this._subscriptions = new Subscription();
    }
    /** @hidden */
    ngOnInit() {
        this._listenOnPopoverOpenChange();
        this.title = this.mobileConfig.title || '';
        this.viewBody = this.childContent?.popoverBodyContentTemplate ?? null;
        this.viewFooter = this.childContent?.popoverFooterContentTemplate ?? null;
        this._changeDetectorref.markForCheck();
    }
    /** @hidden */
    ngOnDestroy() {
        this.dialogRef?.close();
        this._subscriptions.unsubscribe();
    }
    /** Closes the Dialog and Popover component */
    close() {
        this.dialogRef.close();
        this._component.close();
    }
    /** @hidden Opens/closes the Dialog based on Popover isOpenChange events */
    _listenOnPopoverOpenChange() {
        this._subscriptions.add(this._component.isOpenChange.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((isOpen) => {
            if (isOpen) {
                this._openDialog();
            }
            else {
                this.dialogRef.hide(true);
            }
        }));
    }
    /** @hidden Opens the Dialog */
    _openDialog() {
        this.dialogRef = this._dialogService.open(this._dialogTemplate, {
            verticalPadding: true,
            horizontalPadding: true,
            ...this.dialogConfig,
            mobile: true,
            focusTrapped: true,
            escKeyCloseable: false,
            backdropClickCloseable: false,
            container: this._elementRef.nativeElement,
            responsivePadding: true,
            ariaLabelledBy: this.titleId
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverMobileComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: POPOVER_COMPONENT }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: PopoverMobileComponent, isStandalone: true, selector: "fd-popover-mobile", viewQueries: [{ propertyName: "_dialogTemplate", first: true, predicate: ["dialogTemplate"], descendants: true }], usesInheritance: true, ngImport: i0, template: "<ng-template [fdDialogTemplate] let-dialog let-dialogConfig=\"dialogConfig\" #dialogTemplate>\n    <fd-dialog [dialogConfig]=\"dialogConfig\" [dialogRef]=\"dialog\" data-mobile-popover>\n        <fd-dialog-header>\n            <h1 fd-title [id]=\"titleId\">{{ title }}</h1>\n            @if (this.mobileConfig.hasCloseButton) {\n                <button fd-dialog-close-button (click)=\"close()\"></button>\n            }\n        </fd-dialog-header>\n        <fd-dialog-body>\n            <ng-template [ngTemplateOutlet]=\"viewBody\"></ng-template>\n        </fd-dialog-body>\n        @if (viewFooter) {\n            <fd-dialog-footer>\n                <ng-template [ngTemplateOutlet]=\"viewFooter\"></ng-template>\n            </fd-dialog-footer>\n        }\n    </fd-dialog>\n</ng-template>\n", dependencies: [{ kind: "ngmodule", type: TemplateModule }, { kind: "component", type: TitleComponent, selector: "[fd-title], [fdTitle]", inputs: ["headerSize", "wrap"], exportAs: ["fd-title"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: DialogComponent, selector: "fd-dialog", inputs: ["class", "dialogRef", "dialogConfig"] }, { kind: "component", type: DialogBodyComponent, selector: "fd-dialog-body", inputs: ["disablePaddings"] }, { kind: "component", type: DialogHeaderComponent, selector: "fd-dialog-header" }, { kind: "component", type: DialogFooterComponent, selector: "fd-dialog-footer" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverMobileComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-popover-mobile', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, imports: [
                        TemplateModule,
                        TitleComponent,
                        TitleComponent,
                        NgTemplateOutlet,
                        DialogComponent,
                        DialogBodyComponent,
                        DialogHeaderComponent,
                        DialogFooterComponent
                    ], template: "<ng-template [fdDialogTemplate] let-dialog let-dialogConfig=\"dialogConfig\" #dialogTemplate>\n    <fd-dialog [dialogConfig]=\"dialogConfig\" [dialogRef]=\"dialog\" data-mobile-popover>\n        <fd-dialog-header>\n            <h1 fd-title [id]=\"titleId\">{{ title }}</h1>\n            @if (this.mobileConfig.hasCloseButton) {\n                <button fd-dialog-close-button (click)=\"close()\"></button>\n            }\n        </fd-dialog-header>\n        <fd-dialog-body>\n            <ng-template [ngTemplateOutlet]=\"viewBody\"></ng-template>\n        </fd-dialog-body>\n        @if (viewFooter) {\n            <fd-dialog-footer>\n                <ng-template [ngTemplateOutlet]=\"viewFooter\"></ng-template>\n            </fd-dialog-footer>\n        }\n    </fd-dialog>\n</ng-template>\n" }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [POPOVER_COMPONENT]
                }] }], propDecorators: { _dialogTemplate: [{
                type: ViewChild,
                args: ['dialogTemplate']
            }] } });

class PopoverMobileModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverMobileModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: PopoverMobileModule, imports: [DialogModule, ButtonComponent, PopoverMobileComponent], exports: [PopoverMobileComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverMobileModule, providers: [DynamicComponentService], imports: [DialogModule, ButtonComponent, PopoverMobileComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverMobileModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [DialogModule, ButtonComponent, PopoverMobileComponent],
                    exports: [PopoverMobileComponent],
                    providers: [DynamicComponentService]
                }]
        }] });

const MAX_BODY_SIZE = 99999999;
class PopoverService extends BasePopoverClass {
    /** @hidden */
    get _triggerHtmlElement() {
        return this._triggerElement instanceof ElementRef ? this._triggerElement.nativeElement : this._triggerElement;
    }
    /** @hidden */
    constructor(_overlay, _renderer, _viewportRuler, _injector, _rtlService, _popoverContainer) {
        super();
        this._overlay = _overlay;
        this._renderer = _renderer;
        this._viewportRuler = _viewportRuler;
        this._injector = _injector;
        this._rtlService = _rtlService;
        this._popoverContainer = _popoverContainer;
        /** @hidden */
        this._onLoad = new Subject();
        /** @hidden */
        this._mobile = false;
        /** @hidden */
        this._eventRef = [];
        /** @hidden */
        this._stopCloseListening$ = new Subject();
        /** @hidden */
        this._placementRefresh$ = new Subject();
        /** @hidden */
        this._ignoreTriggers = false;
        /** @hidden */
        this._modalBodyClass = 'fd-overlay-active';
        /** @hidden */
        this._modalTriggerClass = 'fd-popover__modal';
        /** @hidden */
        this._isModal = false;
        /** An RxJS Subject that will kill the data stream upon component’s destruction (for unsubscribing)  */
        this._destroyRef = inject(DestroyRef);
        /** Merge observables - close or destroy */
        this._refresh$ = merge(this.isOpenChange, destroyObservable(this._destroyRef));
        this._destroyRef.onDestroy(() => {
            this._removeTriggerListeners();
            if (this._overlayRef) {
                this._overlayRef.detach();
                this._overlayRef.dispose();
            }
            if (this._isModal) {
                this._removeOverlay(this._modalBodyClass, this._modalTriggerClass);
            }
        });
    }
    /**
     * Method initialising the popover service - should be called, after view is initialised, params:
     * - triggerElement - element, which is equivalent for cdkOverlayOrigin, or fd-popover-control,
     *   by default to this element the popover body will lbe appended and events on this element will trigger
     *   popover's  toggle
     * - config - configuration object - in this case the intention is to use inheritance of BasePopoverClass in component
     * - templateData - in case of having already PopoverBodyComponent, there is way to pass container, template containing
     *   PopoverComponent and PopoverComponent instance
     */
    initialise(triggerElement, config, templateData) {
        if (templateData instanceof TemplateRef) {
            this.templateContent = templateData;
        }
        else {
            this._templateData = templateData;
        }
        this._triggerElement = triggerElement;
        if (config) {
            this.refreshConfiguration(config);
        }
        this._refreshTriggerListeners();
        if (this.isOpen) {
            this.open();
        }
        // If wrapper container height changes outside, refresh popover position.
        this._popoverContainer?.refreshPosition$.pipe(takeUntil(this._refresh$)).subscribe(() => {
            this.refreshPosition();
        });
    }
    /** Closes the popover. */
    close(focusActiveElement = true) {
        if (this._overlayRef) {
            this._overlayRef.dispose();
        }
        const prevState = this.isOpen;
        this.isOpen = false;
        if (prevState !== this.isOpen) {
            this.isOpenChange.emit(this.isOpen);
        }
        this.checkModalBackground();
        this._focusLastActiveElementBeforeOpen(focusActiveElement);
    }
    /** Opens the popover. */
    open() {
        if ((!this._overlayRef || !this._overlayRef.hasAttached()) && !this.disabled && this._triggerElement) {
            this.beforeOpen.emit();
            const position = this._getPositionStrategy();
            this._overlayRef = this._overlay.create(this._getOverlayConfig(position));
            if (this._placementContainer) {
                const placementElement = this._placementContainer instanceof ElementRef
                    ? this._placementContainer.nativeElement
                    : this._placementContainer;
                placementElement.append(this._overlayRef.hostElement);
            }
            if (this._templateData) {
                this._attachTemplate();
            }
            else {
                this._attachBodyComponent();
            }
            this._stopCloseListening$.next();
            this._listenForPositionChange(position.positionChanges);
            if (this.fillControlMode) {
                this._listenOnResize();
            }
            const prevState = this.isOpen;
            this.isOpen = true;
            if (prevState !== this.isOpen) {
                this.isOpenChange.emit(this.isOpen);
            }
            this._detectChanges();
            this._listenOnClose();
            this._focusFirstTabbableElement();
            this._onLoad.next(this._getPopoverBody()._elementRef);
            this._overlayRef.updatePosition();
        }
    }
    /** method updating template or text inside rendered PopoverBody */
    updateContent(stringContent, templateContent) {
        templateContent = !templateContent
            ? typeof stringContent === 'string'
                ? null
                : stringContent
            : templateContent;
        stringContent = typeof stringContent === 'string' ? stringContent : null;
        this.stringContent = stringContent;
        this.templateContent = templateContent;
        if (this._getPopoverBody()) {
            this._passVariablesToBody();
        }
    }
    /** Changes background theming when modal */
    /** @hidden */
    checkModalBackground() {
        const isClosingConditions = (!this.closeOnOutsideClick || !this.closeOnEscapeKey) && this.applyOverlay;
        if (isClosingConditions && this.isOpen) {
            this._addModalOverlay(this._modalBodyClass, this._modalTriggerClass);
        }
        else if (isClosingConditions && !this.isOpen) {
            this._removeOverlay(this._modalBodyClass, this._modalTriggerClass);
        }
    }
    /** Toggles the popover open state */
    toggle(openAction = true, closeAction = true) {
        if (this.isOpen) {
            closeAction && this.close();
        }
        else {
            openAction && this.open();
            this.checkModalBackground();
        }
    }
    /**
     * Method called to change position of popover,
     * recommended to be used only when popover is opened, otherwise change position or cdkPlacement
     */
    applyNewPosition(positions) {
        const refPosition = this._getPositionStrategy(positions);
        this._listenForPositionChange(refPosition.positionChanges);
        this._overlayRef.updatePositionStrategy(refPosition);
    }
    /** Method called to refresh position of opened popover */
    refreshPosition() {
        this._overlayRef?.updatePosition();
    }
    /** Temporary sets the ignoring of the event triggers. */
    setIgnoreTriggers(ignore) {
        this._ignoreTriggers = ignore;
    }
    /**
     * Method that sets configuration/options, it detects if there is something changed and overwrites them
     */
    refreshConfiguration(config) {
        this._placementContainer = config.placementContainer;
        const onlyChanged = Object.keys(new BasePopoverClass()).filter((key) => this[key] !== config[key]);
        if (onlyChanged.includes('isOpen')) {
            if (config.isOpen) {
                this.open();
            }
            else {
                this.close();
            }
        }
        if (onlyChanged.includes('placementContainer')) {
            this._placementContainer = config.placementContainer;
        }
        /** TODO
         * This overriding is dangerous thing and leads to unexpected behavior
         * We have to avoid this.
         */
        onlyChanged.forEach((key) => (this[key] = config[key]));
        if (onlyChanged.includes('triggers')) {
            this._refreshTriggerListeners();
        }
    }
    /**
     * This method is intended to be called in order
     * to postpone the main functionality but be able
     * to enable it back in the future by initialise()
     */
    deactivate() {
        this._removeTriggerListeners();
    }
    /** Refresh listeners on trigger element events */
    _refreshTriggerListeners() {
        if (!this._triggerElement) {
            return;
        }
        this._removeTriggerListeners();
        if (this.triggers?.length) {
            this._normalizeTriggers().forEach((trigger) => {
                this._eventRef.push(this._renderer.listen(this._triggerHtmlElement, trigger.trigger, (event) => {
                    if (this._ignoreTriggers) {
                        return;
                    }
                    const closeAction = !!trigger.closeAction;
                    const openAction = !!trigger.openAction;
                    this.toggle(openAction, closeAction);
                    if (trigger.stopPropagation) {
                        event.stopImmediatePropagation();
                    }
                }));
            });
        }
    }
    /**
     * Updates trigger element and refreshes the listeners.
     * @param trigger Trigger element ref.
     */
    updateTriggerElement(trigger) {
        this._triggerElement = trigger;
        this._refreshTriggerListeners();
    }
    /** @hidden */
    _normalizeTriggers() {
        return this.triggers.map((trigger, index) => {
            if (typeof trigger === 'object' && trigger.trigger) {
                return trigger;
            }
            const oddNumber = isOdd(index + 1);
            return {
                trigger,
                openAction: this.triggers.length === 1 || oddNumber,
                closeAction: this.triggers.length === 1 || !oddNumber,
                stopPropagation: false
            };
        });
    }
    /** @hidden */
    _getOverlayConfig(position) {
        const direction = this._getDirection();
        return new OverlayConfig({
            direction,
            disposeOnNavigation: this.closeOnNavigation,
            positionStrategy: position,
            scrollStrategy: this.scrollStrategy || this._overlay.scrollStrategies.reposition()
        });
    }
    /** @hidden */
    _listenOnResize() {
        this._viewportRuler
            .change(15)
            .pipe(takeUntil(this._refresh$), startWith(1))
            .subscribe(() => this._applyWidthOverlay());
    }
    /** @hidden */
    _getDirection() {
        if (!this._rtlService) {
            return 'ltr';
        }
        return this._rtlService.rtl.getValue() ? 'rtl' : 'ltr';
    }
    /** @hidden */
    _getPositionStrategy(forcedPositions) {
        let resultPosition = forcedPositions ? forcedPositions : this._getPositions();
        if (!this.fixedPosition) {
            resultPosition = resultPosition.concat(GetDefaultPosition(resultPosition));
        }
        return this._overlay
            .position()
            .flexibleConnectedTo(this.appendTo || this._triggerElement)
            .withPositions(resultPosition)
            .withPush(false)
            .withGrowAfterOpen(true);
    }
    /** remove listeners from trigger element events */
    _removeTriggerListeners() {
        this._eventRef.forEach((event) => event());
        this._eventRef = [];
    }
    _addModalOverlay(bodyClass, triggerClass) {
        this._renderer.addClass(document.body, bodyClass);
        this._renderer.addClass(this._triggerElement.nativeElement, triggerClass);
        this._isModal = true;
    }
    _removeOverlay(bodyClass, triggerClass) {
        this._renderer.removeClass(document.body, bodyClass);
        this._renderer.removeClass(this._triggerElement.nativeElement, triggerClass);
        this._isModal = false;
    }
    /** Attach template containing popover body to overlay */
    _attachTemplate() {
        this._passVariablesToBody();
        if (this._templateData) {
            this._overlayRef.attach(new TemplatePortal(this._templateData.template, this._templateData.container));
        }
    }
    /** Create PopoverBodyComponent and attach it into overlay */
    _attachBodyComponent() {
        const overlay = this._overlayRef.attach(new ComponentPortal(PopoverBodyComponent, null, this._injector));
        this._popoverBody = overlay.instance;
        this._passVariablesToBody();
    }
    /** @hidden */
    _listenForPositionChange(positionChange) {
        this._placementRefresh$.next();
        positionChange
            .pipe(filter(() => !this.noArrow && !!this._getPopoverBody()), distinctUntilChanged((previous, current) => previous.connectionPair === current.connectionPair), takeUntil(this._placementRefresh$), takeUntilDestroyed(this._destroyRef))
            .subscribe((event) => this._getPopoverBody()._setArrowStyles(event.connectionPair, this._getDirection()));
    }
    /** Subscribe to close events from CDK Overlay, to throw proper events, change values */
    _listenOnClose() {
        const closeEvents$ = merge(this._overlayRef.detachments(), this._getPopoverBody().onClose, this._outsideClicks$());
        const finalizer$ = merge(this._stopCloseListening$, this._refresh$);
        closeEvents$.pipe(takeUntil(finalizer$)).subscribe(() => this.close());
    }
    /** Listener for click events */
    _outsideClicks$() {
        return merge(this._overlayRef.backdropClick(), this._overlayRef._outsidePointerEvents).pipe(filter((event) => this._shouldClose(event)));
    }
    /** @hidden */
    _shouldClose(event) {
        return (this.isOpen &&
            this.closeOnOutsideClick &&
            !this._triggerContainsTarget(event) &&
            !this._targetIsPopoverMobileDialog(event));
    }
    /** @hidden */
    _targetIsPopoverMobileDialog(event) {
        if (this._mobile) {
            let el = event.target.parentElement;
            while (el) {
                if (el.hasAttribute('data-mobile-popover')) {
                    return true;
                }
                else {
                    el = el.parentElement;
                }
            }
        }
        return false;
    }
    /** @hidden */
    _getEventTarget(event) {
        return event.composedPath ? event.composedPath()[0] : event.target;
    }
    /** @hidden */
    _triggerContainsTarget(event) {
        return this._triggerHtmlElement.contains(this._getEventTarget(event));
    }
    /** @hidden */
    _getPositions() {
        if (this.cdkPositions) {
            return this.cdkPositions;
        }
        if (this.placement) {
            return [PopoverPosition.getCdkPlacement(this.placement, this._getDirection())];
        }
        return [];
    }
    /** @hidden */
    _applyWidthOverlay() {
        const maxWidthLimit = this.maxWidth ? this.maxWidth : MAX_BODY_SIZE;
        const width = Math.min(this._getTriggerWidth(), maxWidthLimit);
        if (this.fillControlMode === 'at-least') {
            this._getPopoverBody()._popoverBodyMinWidth = width;
        }
        else if (this.fillControlMode === 'equal') {
            this._getPopoverBody()._popoverBodyWidth = width;
        }
        this._detectChanges();
    }
    /** @hidden */
    _passVariablesToBody() {
        const body = this._getPopoverBody();
        body.text = this.stringContent;
        body._additionalBodyClass = this.additionalBodyClass;
        body._focusTrapped = this.focusTrapped;
        body._maxWidth = this.maxWidth;
        body._noArrow = this.noArrow;
        body._focusAutoCapture = this.focusAutoCapture;
        body._disableScrollbar = this.disableScrollbar;
        body._templateToDisplay = this.templateContent;
        body._closeOnEscapeKey = this.closeOnEscapeKey;
        body._bodyRole = this._bodyRole;
        body._bodyId = this._bodyId;
        body._resizable = this.resizable;
        body._setBodyComponentClasses(this.additionalBodyComponentClasses);
        this._detectChanges();
    }
    /** @hidden */
    _getTriggerWidth() {
        return this._triggerHtmlElement.offsetWidth;
    }
    /** @hidden */
    _getPopoverBody() {
        return this._templateData?.popoverBody || this._popoverBody;
    }
    /** @hidden */
    _detectChanges() {
        if (this._getPopoverBody()) {
            this._getPopoverBody().detectChanges();
        }
    }
    /** @hidden */
    _focusFirstTabbableElement(focusLastElement = true) {
        if (focusLastElement && this.focusAutoCapture) {
            this._lastActiveElement = document.activeElement;
            this._getPopoverBody()?._focusFirstTabbableElement();
        }
    }
    /** @hidden */
    _focusLastActiveElementBeforeOpen(focusLastElement = true) {
        if (focusLastElement && this.restoreFocusOnClose && this.focusAutoCapture && this._lastActiveElement) {
            this._lastActiveElement.focus();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverService, deps: [{ token: i1$1.Overlay }, { token: i0.Renderer2 }, { token: i1$1.ViewportRuler }, { token: i0.Injector }, { token: i2$1.RtlService, optional: true }, { token: PopoverContainerDirective, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1$1.Overlay }, { type: i0.Renderer2 }, { type: i1$1.ViewportRuler }, { type: i0.Injector }, { type: i2$1.RtlService, decorators: [{
                    type: Optional
                }] }, { type: PopoverContainerDirective, decorators: [{
                    type: Optional
                }] }] });

class PopoverTriggerDirective {
    /** Set reference to Popover Component */
    set popover(popover) {
        if (popover) {
            popover.trigger = this._elementRef;
            this._listenOnExpanded(popover);
        }
        this._setAriaAttributes(popover);
    }
    /** @hidden */
    constructor(_elementRef) {
        this._elementRef = _elementRef;
    }
    /** @hidden */
    ngOnDestroy() {
        this._unsubscribeExpandedListener();
    }
    /** @hidden */
    _listenOnExpanded(popover) {
        this._unsubscribeExpandedListener();
        if (popover) {
            this._isExpandedSubscription = popover.isOpenChange
                .pipe(startWith(popover.isOpen))
                .subscribe((isOpen) => (this.ariaExpanded = isOpen));
        }
    }
    /** @hidden */
    _setAriaAttributes(popover) {
        this.ariaHasPopup = !!popover;
        this.ariaControls = popover ? popover.id : null;
    }
    /** @hidden */
    _unsubscribeExpandedListener() {
        if (this._isExpandedSubscription) {
            this._isExpandedSubscription.unsubscribe();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverTriggerDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: PopoverTriggerDirective, isStandalone: true, selector: "[fdPopoverTrigger], [fd-popover-trigger]", inputs: { popover: ["fdPopoverTrigger", "popover"] }, host: { properties: { "attr.aria-haspopup": "this.ariaHasPopup", "attr.aria-controls": "this.ariaControls", "attr.aria-expanded": "this.ariaExpanded" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverTriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdPopoverTrigger], [fd-popover-trigger]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { popover: [{
                type: Input,
                args: ['fdPopoverTrigger']
            }], ariaHasPopup: [{
                type: HostBinding,
                args: ['attr.aria-haspopup']
            }], ariaControls: [{
                type: HostBinding,
                args: ['attr.aria-controls']
            }], ariaExpanded: [{
                type: HostBinding,
                args: ['attr.aria-expanded']
            }] } });

const FD_POPOVER_COMPONENT = new InjectionToken('FdPopoverComponent');

const SELECT_CLASS_NAMES = {
    selectControl: 'fd-select__control'
};
let cdkPopoverUniqueId = 0;
/**
 * The popover is a wrapping component that accepts a *control* as well as a *body*.
 * The control is what will trigger the opening of the actual popover, which is called the body.
 * By default, popovers are triggered by click. This can be customized through the *triggers* input.
 */
class PopoverComponent extends BasePopoverClass {
    /** Reference to popover trigger element */
    set trigger(trigger) {
        if (equal(trigger, this._trigger)) {
            return;
        }
        this._trigger = trigger;
        this._popoverService.updateTriggerElement(this._trigger);
    }
    get trigger() {
        return this._trigger;
    }
    /** @hidden */
    get _triggerElement() {
        return this._trigger instanceof ElementRef ? this._trigger.nativeElement : this._trigger;
    }
    /** @hidden */
    constructor(_popoverService, _cdr, _rendered, _viewContainerRef, _injector, _dynamicComponentService) {
        super();
        this._popoverService = _popoverService;
        this._cdr = _cdr;
        this._rendered = _rendered;
        this._viewContainerRef = _viewContainerRef;
        this._injector = _injector;
        this._dynamicComponentService = _dynamicComponentService;
        /** Whether position shouldn't change, when popover approach the corner of page */
        this.fixedPosition = false;
        /** Id of the popover. If none is provided, one will be generated. */
        this.id = 'fd-popover-' + cdkPopoverUniqueId++;
        /** Whether the popover component should be displayed in mobile mode. */
        this.mobile = false;
        /** Config for the popover in mobile mode */
        this.mobileConfig = { hasCloseButton: true };
        /**
         * Whether the popover should prevent page scrolling when space key is pressed.
         **/
        this.preventSpaceKeyScroll = true;
    }
    /** Handler escape keydown */
    escapeKeydownHandler(event) {
        if (this.closeOnEscapeKey && this.isOpen) {
            // In case if popover belongs to the element inside dialog
            event.preventDefault();
            event.stopImmediatePropagation();
            this.popoverBody.onClose.next();
        }
    }
    /** @hidden */
    onKeyDown(event) {
        if (!this.preventSpaceKeyScroll) {
            return;
        }
        const activeElement = document.activeElement;
        if (
        // popoverControl will be undefined when popover is used from "fdPopoverTrigger"
        this.popoverControl?.elRef.nativeElement.children[0] === activeElement &&
            activeElement?.tagName !== 'INPUT' &&
            activeElement?.tagName !== 'TEXTAREA' &&
            !activeElement?.classList.contains(SELECT_CLASS_NAMES.selectControl)) {
            // prevent page scrolling on Space keydown
            event.preventDefault();
            this._popoverService.toggle();
        }
    }
    /** @hidden */
    ngAfterViewInit() {
        this._setupView();
    }
    /** @hidden */
    ngAfterContentInit() {
        if (this.popoverControl && this.triggers.includes('click')) {
            this.popoverControl._tabbable = true;
        }
    }
    /** @hidden */
    ngOnChanges(changes) {
        this._popoverService.refreshConfiguration(this);
        if (changes.disableScrollbar && this.popoverBody && this.popoverBody._scrollbar) {
            this.popoverBody._scrollbar._inPopover = changes.disableScrollbar.currentValue;
        }
    }
    /** @hidden */
    ngOnDestroy() {
        this._destroyMobileComponent();
        this._destroyEventListeners();
    }
    /** Toggles menu open/close state */
    toggle() {
        if (this.isOpen) {
            this.close();
        }
        else {
            this.open();
        }
    }
    /** Opens the popover. */
    open() {
        this._popoverService.open();
        this._cdr.markForCheck();
    }
    /** Closes the popover. */
    close(focusActiveElement = true) {
        this._popoverService.close(focusActiveElement);
        this._cdr.markForCheck();
    }
    /** Temporary sets the ignoring of the event triggers. */
    setIgnoreTriggers(ignore) {
        this._popoverService.setIgnoreTriggers(ignore);
    }
    /**
     * Method called to change position of popover,
     * recommended to be used only when popover is opened, otherwise change position or cdkPlacement
     */
    applyNewPosition(positions) {
        this._popoverService.applyNewPosition(positions);
    }
    /** Method called to refresh position of opened popover */
    refreshPosition() {
        this._popoverService.refreshPosition();
    }
    /** Handler for alt + arrow down keydown */
    triggerKeyDownHandler(event) {
        if (KeyUtil.isKeyCode(event, DOWN_ARROW) && event.altKey && !this.disabled) {
            this.open();
            event.preventDefault();
            event.stopPropagation();
        }
    }
    /** @hidden Select and instantiate popover view mode */
    _setupView() {
        if (!this.mobile) {
            this._popoverService._mobile = false;
            if (!this.popoverBody) {
                this._popoverService.templateContent = this.templateRef;
            }
            this._popoverService.initialise(this._triggerElement || this.triggerOrigin.elementRef, this, this._getPopoverBodyContent());
        }
        else {
            this._setupMobileMode();
        }
        this._cdr.detectChanges();
    }
    /**
     * Depending on a used popover body type, returns a popover body content
     **/
    _getPopoverBodyContent() {
        if (this.popoverBody) {
            return {
                template: this.templateRef,
                container: this.container,
                popoverBody: this.popoverBody
            };
        }
        if (this.popoverBodyDirective) {
            return this.popoverBodyDirective.templateRef;
        }
        return null;
    }
    /** @hidden Open Popover in mobile mode */
    async _setupMobileMode() {
        const injector = Injector.create({
            providers: [{ provide: POPOVER_COMPONENT, useValue: this }],
            parent: this._injector
        });
        this._popoverService._mobile = true;
        this._mobileModeComponentRef = this._dynamicComponentService.createDynamicComponent({
            popoverBodyContentTemplate: this.popoverBodyContentTemplate,
            popoverFooterContentTemplate: this.popoverFooterContentTemplate
        }, PopoverMobileComponent, {
            containerRef: this._viewContainerRef
        }, { injector });
        this._listenOnTriggerRefClicks();
    }
    /** @hidden - Listen on popover trigger ref clicks */
    _listenOnTriggerRefClicks() {
        this._destroyEventListeners();
        if (this.trigger && this.mobile) {
            this._clickEventListener = this._rendered.listen(this._triggerElement, 'click', () => this.toggle());
        }
    }
    /**
     * @hidden
     * This is going to be removed in feature, on dialog and dynamic service component refactor
     */
    _destroyEventListeners() {
        if (this._clickEventListener) {
            this._clickEventListener();
            this._clickEventListener = null;
        }
    }
    /** @hidden */
    _destroyMobileComponent() {
        if (this._mobileModeComponentRef) {
            this._mobileModeComponentRef.destroy();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverComponent, deps: [{ token: PopoverService }, { token: i0.ChangeDetectorRef }, { token: i0.Renderer2 }, { token: i0.ViewContainerRef }, { token: i0.Injector }, { token: i2$1.DynamicComponentService, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: PopoverComponent, isStandalone: true, selector: "fd-popover", inputs: { title: "title", trigger: "trigger", fixedPosition: "fixedPosition", id: "id", mobile: "mobile", mobileConfig: "mobileConfig", preventSpaceKeyScroll: "preventSpaceKeyScroll" }, host: { listeners: { "keydown.escape": "escapeKeydownHandler($event)", "keydown.space": "onKeyDown($event)", "keydown.enter": "onKeyDown($event)" }, properties: { "class.fd-popover-custom--mobile": "mobile", "attr.id": "id" }, classAttribute: "fd-popover-custom" }, providers: [
            PopoverService,
            {
                provide: FD_POPOVER_COMPONENT,
                useExisting: PopoverComponent
            },
            contentDensityObserverProviders()
        ], queries: [{ propertyName: "popoverBody", first: true, predicate: PopoverBodyComponent, descendants: true }, { propertyName: "popoverBodyDirective", first: true, predicate: PopoverBodyDirective, descendants: true }, { propertyName: "popoverControl", first: true, predicate: PopoverControlComponent, descendants: true }, { propertyName: "popoverBodyContentTemplate", first: true, predicate: ["popoverBodyContent"], descendants: true }, { propertyName: "popoverFooterContentTemplate", first: true, predicate: ["popoverFooterContent"], descendants: true }], viewQueries: [{ propertyName: "templateRef", first: true, predicate: ["templateRef"], descendants: true, read: TemplateRef }, { propertyName: "container", first: true, predicate: ["container"], descendants: true, read: ViewContainerRef }, { propertyName: "triggerOrigin", first: true, predicate: CdkOverlayOrigin, descendants: true }], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "@if (!trigger) {\n    <div\n        cdkOverlayOrigin\n        class=\"fd-popover__control\"\n        [class]=\"additionalTriggerClass\"\n        (keydown)=\"triggerKeyDownHandler($event)\"\n    >\n        <ng-content select=\"fd-popover-control, [fdPopoverControl]\"></ng-content>\n    </div>\n}\n<ng-template #templateRef>\n    <ng-content select=\"fd-popover-body\"></ng-content>\n    <ng-content></ng-content>\n</ng-template>\n<ng-container #container></ng-container>\n", dependencies: [{ kind: "directive", type: CdkOverlayOrigin, selector: "[cdk-overlay-origin], [overlay-origin], [cdkOverlayOrigin]", exportAs: ["cdkOverlayOrigin"] }, { kind: "ngmodule", type: A11yModule }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-popover', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, providers: [
                        PopoverService,
                        {
                            provide: FD_POPOVER_COMPONENT,
                            useExisting: PopoverComponent
                        },
                        contentDensityObserverProviders()
                    ], host: {
                        class: 'fd-popover-custom',
                        '[class.fd-popover-custom--mobile]': 'mobile',
                        '[attr.id]': 'id'
                    }, imports: [CdkOverlayOrigin, A11yModule], template: "@if (!trigger) {\n    <div\n        cdkOverlayOrigin\n        class=\"fd-popover__control\"\n        [class]=\"additionalTriggerClass\"\n        (keydown)=\"triggerKeyDownHandler($event)\"\n    >\n        <ng-content select=\"fd-popover-control, [fdPopoverControl]\"></ng-content>\n    </div>\n}\n<ng-template #templateRef>\n    <ng-content select=\"fd-popover-body\"></ng-content>\n    <ng-content></ng-content>\n</ng-template>\n<ng-container #container></ng-container>\n" }]
        }], ctorParameters: () => [{ type: PopoverService }, { type: i0.ChangeDetectorRef }, { type: i0.Renderer2 }, { type: i0.ViewContainerRef }, { type: i0.Injector }, { type: i2$1.DynamicComponentService, decorators: [{
                    type: Optional
                }] }], propDecorators: { title: [{
                type: Input
            }], trigger: [{
                type: Input
            }], fixedPosition: [{
                type: Input
            }], id: [{
                type: Input
            }], mobile: [{
                type: Input
            }], mobileConfig: [{
                type: Input
            }], preventSpaceKeyScroll: [{
                type: Input
            }], templateRef: [{
                type: ViewChild,
                args: ['templateRef', { read: TemplateRef }]
            }], container: [{
                type: ViewChild,
                args: ['container', { read: ViewContainerRef }]
            }], triggerOrigin: [{
                type: ViewChild,
                args: [CdkOverlayOrigin]
            }], popoverBody: [{
                type: ContentChild,
                args: [PopoverBodyComponent]
            }], popoverBodyDirective: [{
                type: ContentChild,
                args: [PopoverBodyDirective]
            }], popoverControl: [{
                type: ContentChild,
                args: [PopoverControlComponent]
            }], popoverBodyContentTemplate: [{
                type: ContentChild,
                args: ['popoverBodyContent']
            }], popoverFooterContentTemplate: [{
                type: ContentChild,
                args: ['popoverFooterContent']
            }], escapeKeydownHandler: [{
                type: HostListener,
                args: ['keydown.escape', ['$event']]
            }], onKeyDown: [{
                type: HostListener,
                args: ['keydown.space', ['$event']]
            }, {
                type: HostListener,
                args: ['keydown.enter', ['$event']]
            }] } });

class PopoverModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: PopoverModule, imports: [PopoverControlComponent,
            PopoverBodyComponent,
            PopoverBodyHeaderDirective,
            PopoverBodyFooterDirective,
            PopoverComponent,
            PopoverTriggerDirective,
            PopoverContainerDirective,
            PopoverBodyDirective], exports: [PopoverControlComponent,
            PopoverBodyComponent,
            PopoverBodyHeaderDirective,
            PopoverBodyFooterDirective,
            PopoverComponent,
            PopoverTriggerDirective,
            PopoverContainerDirective,
            PopoverBodyDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverModule, imports: [PopoverBodyComponent,
            PopoverComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: PopoverModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        PopoverControlComponent,
                        PopoverBodyComponent,
                        PopoverBodyHeaderDirective,
                        PopoverBodyFooterDirective,
                        PopoverComponent,
                        PopoverTriggerDirective,
                        PopoverContainerDirective,
                        PopoverBodyDirective
                    ],
                    exports: [
                        PopoverControlComponent,
                        PopoverBodyComponent,
                        PopoverBodyHeaderDirective,
                        PopoverBodyFooterDirective,
                        PopoverComponent,
                        PopoverTriggerDirective,
                        PopoverContainerDirective,
                        PopoverBodyDirective
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BasePopoverClass, FD_POPOVER_COMPONENT, POPOVER_COMPONENT, PopoverBodyComponent, PopoverBodyDirective, PopoverBodyFooterDirective, PopoverBodyHeaderDirective, PopoverComponent, PopoverContainerDirective, PopoverControlComponent, PopoverMobileComponent, PopoverMobileModule, PopoverModule, PopoverService, PopoverTriggerDirective, SELECT_CLASS_NAMES };
//# sourceMappingURL=fundamental-ngx-core-popover.mjs.map
