import * as i0 from '@angular/core';
import { HostBinding, ContentChild, Directive, HostListener, ViewChildren, Input, ViewEncapsulation, Component, NgModule } from '@angular/core';
import * as i1 from '@fundamental-ngx/core/nested-list';
import { NestedListDirective, PreparedNestedListComponent, NestedListKeyboardService, NestedListStateService } from '@fundamental-ngx/core/nested-list';
import { warnOnce } from '@fundamental-ngx/cdk/utils';
import { MenuKeyboardService } from '@fundamental-ngx/core/menu';

class SideNavigationMainDirective {
    constructor() {
        /** @hidden */
        this.classSideNavMainNavigation = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SideNavigationMainDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: SideNavigationMainDirective, isStandalone: true, selector: "[fdSideNavigationMain], [fd-side-nav-main]", host: { properties: { "class.fd-side-nav__main-navigation": "this.classSideNavMainNavigation" } }, queries: [{ propertyName: "list", first: true, predicate: NestedListDirective, descendants: true }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SideNavigationMainDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdSideNavigationMain], [fd-side-nav-main]',
                    standalone: true
                }]
        }], propDecorators: { list: [{
                type: ContentChild,
                args: [NestedListDirective]
            }], classSideNavMainNavigation: [{
                type: HostBinding,
                args: ['class.fd-side-nav__main-navigation']
            }] } });

class SideNavigationUtilityDirective {
    constructor() {
        /** @hidden */
        this.classSideNavUtility = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SideNavigationUtilityDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: SideNavigationUtilityDirective, isStandalone: true, selector: "[fdSideNavigationUtility], [fd-side-nav-utility]", host: { properties: { "class.fd-side-nav__utility": "this.classSideNavUtility" } }, queries: [{ propertyName: "list", first: true, predicate: NestedListDirective, descendants: true }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SideNavigationUtilityDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdSideNavigationUtility], [fd-side-nav-utility]',
                    standalone: true
                }]
        }], propDecorators: { list: [{
                type: ContentChild,
                args: [NestedListDirective]
            }], classSideNavUtility: [{
                type: HostBinding,
                args: ['class.fd-side-nav__utility']
            }] } });

/**
 * @deprecated use the vertical navigation component instead.
 * The side-navigation is a wrapping component representing
 * a left navigation that can always display or expand/collapse using the menu icon within the global navigation.
 */
class SideNavigationComponent {
    /** Whether clicking on elements should change selected state of items */
    set selectable(selectable) {
        this.nestedListState.selectable = selectable;
    }
    /** @hidden */
    constructor(keyboardService, nestedListState) {
        this.keyboardService = keyboardService;
        this.nestedListState = nestedListState;
        /** Whether condensed mode is included */
        this.condensed = false;
        /** @hidden */
        this.additionalShellbarCssClass = 'fd-shellbar--side-nav';
        this.keyboardService.refresh$.subscribe(() => {
            /** Refresh list of elements, that are being supported by keyboard */
            this.keyboardService.refreshItems(this.getLists());
        });
        warnOnce(`
            SideNavigationComponent is deprecated since version 0.40.0 and will be removed in future release.
            Use the vertical navigation component instead.
            For more information check the documentation.
        `);
    }
    /** @hidden */
    onResize() {
        if (this.collapseWidth) {
            this.condensed = window.innerWidth <= this.collapseWidth;
        }
    }
    /** @hidden */
    ngOnInit() {
        /** Set up condensed state */
        this.nestedListState.condensed =
            this.condensed || !!(this.sideNavigationConfiguration && this.sideNavigationConfiguration.condensed);
        if (this.collapseWidth) {
            this.onResize();
        }
    }
    /** @hidden */
    ngAfterContentInit() {
        if (!this.sideNavigationConfiguration) {
            this.keyboardService.refreshItems(this.getLists());
        }
    }
    /** @hidden */
    ngAfterViewInit() {
        if (this.sideNavigationConfiguration) {
            this.keyboardService.refreshItems(this.getLists());
        }
    }
    /**
     * @hidden
     * Method that returns 1 deep level of lists.
     */
    getLists() {
        const lists = [];
        if (this.sideNavMain) {
            lists.push(this.sideNavMain.list);
        }
        if (this.sideNavUtility) {
            lists.push(this.sideNavUtility.list);
        }
        if (this.preparedNestedList) {
            lists.push(...this.preparedNestedList.map((preparedNested) => preparedNested.nestedListDirective));
        }
        return lists;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SideNavigationComponent, deps: [{ token: i1.NestedListKeyboardService }, { token: i1.NestedListStateService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: SideNavigationComponent, isStandalone: true, selector: "fd-side-nav", inputs: { sideNavigationConfiguration: "sideNavigationConfiguration", condensed: "condensed", collapseWidth: "collapseWidth", selectable: "selectable" }, host: { listeners: { "window:resize": "onResize()" }, properties: { "class.fd-side-nav--condensed": "this.condensed" } }, providers: [MenuKeyboardService, NestedListKeyboardService, NestedListStateService], queries: [{ propertyName: "sideNavUtility", first: true, predicate: SideNavigationUtilityDirective, descendants: true }, { propertyName: "sideNavMain", first: true, predicate: SideNavigationMainDirective, descendants: true }], viewQueries: [{ propertyName: "preparedNestedList", predicate: PreparedNestedListComponent, descendants: true }], ngImport: i0, template: "<nav class=\"fd-side-nav\" [class.fd-side-nav--condensed]=\"condensed || sideNavigationConfiguration?.condensed\">\n    @if (!sideNavigationConfiguration) {\n        <ng-content></ng-content>\n    } @else {\n        @if (sideNavigationConfiguration.mainNavigation) {\n            <div fd-side-nav-main>\n                <fd-prepared-nested-list\n                    [condensed]=\"condensed || !!sideNavigationConfiguration.condensed\"\n                    [first]=\"true\"\n                    [list]=\"sideNavigationConfiguration.mainNavigation\"\n                >\n                </fd-prepared-nested-list>\n            </div>\n        }\n        @if (sideNavigationConfiguration.utilityNavigation) {\n            <div fd-side-nav-utility>\n                <fd-prepared-nested-list\n                    [condensed]=\"condensed || !!sideNavigationConfiguration.condensed\"\n                    [first]=\"true\"\n                    [list]=\"sideNavigationConfiguration.utilityNavigation\"\n                >\n                </fd-prepared-nested-list>\n            </div>\n        }\n    }\n</nav>\n", styles: [".fd-nested-list{--fdNestedList_Link_Height:2.75rem;--fdNestedList_Title_Font_Size:var(--sapFontLargeSize);--fdNestedList_Icon_Font_Size:var(--sapFontHeader4Size);--fdNestedList_Item_Padding_Left:0;--fdNestedList_Item_Padding_Right:0;border:0;border-bottom:var(--sapList_BorderWidth) solid var(--sapList_BorderColor);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;list-style:none;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%}.fd-nested-list:after,.fd-nested-list:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-nested-list [class*=level]{border-bottom:none}.fd-nested-list [class*=level] .fd-nested-list__content,.fd-nested-list [class*=level] .fd-nested-list__link{border-top:none}.fd-nested-list .fd-nested-list__content,.fd-nested-list .fd-nested-list__link{border-bottom:none;padding-inline:var(--fdNestedList_Item_Padding_Left) var(--fdNestedList_Item_Padding_Right)}.fd-nested-list .fd-nested-list__content.is-selected,.fd-nested-list .fd-nested-list__content[aria-selected=true],.fd-nested-list .fd-nested-list__link.is-selected,.fd-nested-list .fd-nested-list__link[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-nested-list .fd-nested-list__content.has-child,.fd-nested-list .fd-nested-list__link.has-child{padding-inline:0}.fd-nested-list .fd-nested-list__content.has-child>.fd-nested-list__title{padding-inline:var(--fdNestedList_Item_Padding_Left) var(--fdNestedList_Item_Padding_Right)}.fd-nested-list .level-2{--fdNestedList_Item_Padding_Left:2.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-3{--fdNestedList_Item_Padding_Left:3.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-4{--fdNestedList_Item_Padding_Left:4.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-5{--fdNestedList_Item_Padding_Left:5.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-6{--fdNestedList_Item_Padding_Left:6.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-7{--fdNestedList_Item_Padding_Left:7.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-8{--fdNestedList_Item_Padding_Left:8.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-9{--fdNestedList_Item_Padding_Left:9.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-10{--fdNestedList_Item_Padding_Left:10.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list[aria-hidden=true]{display:none}.fd-nested-list--popover{border-bottom:none}.fd-nested-list--popover .fd-nested-list__group-header{border-bottom:none;border-top-left-radius:var(--fdNested_List_Border_Corner_Radius);border-top-right-radius:var(--fdNested_List_Border_Corner_Radius)}.fd-nested-list--popover .fd-nested-list__item:first-child,.fd-nested-list--popover .fd-nested-list__item:first-child .fd-nested-list__content,.fd-nested-list--popover .fd-nested-list__item:first-child .fd-nested-list__link{border-top-left-radius:var(--fdNested_List_Border_Corner_Radius);border-top-right-radius:var(--fdNested_List_Border_Corner_Radius)}.fd-nested-list--popover .fd-nested-list__item:last-child,.fd-nested-list--popover .fd-nested-list__item:last-child .fd-nested-list__content,.fd-nested-list--popover .fd-nested-list__item:last-child .fd-nested-list__link{border-bottom-left-radius:var(--fdNested_List_Border_Corner_Radius);border-bottom-right-radius:var(--fdNested_List_Border_Corner_Radius)}.fd-nested-list__item{background:var(--sapList_Background);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-shadow:var(--fdVerticalNav_Text_Shadow)}.fd-nested-list__item:after,.fd-nested-list__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-nested-list__item:first-child .fd-nested-list__content,.fd-nested-list__item:first-child .fd-nested-list__link{border-top:none}.fd-nested-list__content,.fd-nested-list__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdNestedList_Link_Height);line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-decoration:none;width:100%;-webkit-box-align:center;-ms-flex-align:center;align-items:center;border-top:var(--sapList_BorderWidth) solid var(--sapList_BorderColor)}.fd-nested-list__content:after,.fd-nested-list__content:before,.fd-nested-list__link:after,.fd-nested-list__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-nested-list__content.is-hover,.fd-nested-list__content.is-hover .fd-nested-list__button,.fd-nested-list__content:hover,.fd-nested-list__content:hover .fd-nested-list__button,.fd-nested-list__link.is-hover,.fd-nested-list__link.is-hover .fd-nested-list__button,.fd-nested-list__link:hover,.fd-nested-list__link:hover .fd-nested-list__button{background:var(--sapList_Hover_Background)}.fd-nested-list__content.is-focus,.fd-nested-list__content:focus,.fd-nested-list__link.is-focus,.fd-nested-list__link:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.1875rem}.fd-nested-list__content.is-selected,.fd-nested-list__content[aria-selected=true],.fd-nested-list__link.is-selected,.fd-nested-list__link[aria-selected=true]{background:var(--sapList_SelectionBackgroundColor);border-bottom:var(--sapList_BorderWidth) solid;border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-nested-list__content.is-selected .fd-nested-list__button,.fd-nested-list__content[aria-selected=true] .fd-nested-list__button,.fd-nested-list__link.is-selected .fd-nested-list__button,.fd-nested-list__link[aria-selected=true] .fd-nested-list__button{background:var(--sapList_SelectionBackgroundColor)}.fd-nested-list__content.is-selected.is-hover,.fd-nested-list__content.is-selected.is-hover .fd-nested-list__button,.fd-nested-list__content.is-selected:hover,.fd-nested-list__content.is-selected:hover .fd-nested-list__button,.fd-nested-list__content[aria-selected=true].is-hover,.fd-nested-list__content[aria-selected=true].is-hover .fd-nested-list__button,.fd-nested-list__content[aria-selected=true]:hover,.fd-nested-list__content[aria-selected=true]:hover .fd-nested-list__button,.fd-nested-list__link.is-selected.is-hover,.fd-nested-list__link.is-selected.is-hover .fd-nested-list__button,.fd-nested-list__link.is-selected:hover,.fd-nested-list__link.is-selected:hover .fd-nested-list__button,.fd-nested-list__link[aria-selected=true].is-hover,.fd-nested-list__link[aria-selected=true].is-hover .fd-nested-list__button,.fd-nested-list__link[aria-selected=true]:hover,.fd-nested-list__link[aria-selected=true]:hover .fd-nested-list__button{background:var(--sapList_Hover_SelectionBackground)}.fd-nested-list__content.is-active,.fd-nested-list__content.is-active .fd-nested-list__button,.fd-nested-list__content.is-active.is-selected,.fd-nested-list__content.is-active.is-selected .fd-nested-list__button,.fd-nested-list__content.is-active[aria-selected=true],.fd-nested-list__content.is-active[aria-selected=true] .fd-nested-list__button,.fd-nested-list__content:active,.fd-nested-list__content:active .fd-nested-list__button,.fd-nested-list__content:active.is-selected,.fd-nested-list__content:active.is-selected .fd-nested-list__button,.fd-nested-list__content:active[aria-selected=true],.fd-nested-list__content:active[aria-selected=true] .fd-nested-list__button,.fd-nested-list__link.is-active,.fd-nested-list__link.is-active .fd-nested-list__button,.fd-nested-list__link.is-active.is-selected,.fd-nested-list__link.is-active.is-selected .fd-nested-list__button,.fd-nested-list__link.is-active[aria-selected=true],.fd-nested-list__link.is-active[aria-selected=true] .fd-nested-list__button,.fd-nested-list__link:active,.fd-nested-list__link:active .fd-nested-list__button,.fd-nested-list__link:active.is-selected,.fd-nested-list__link:active.is-selected .fd-nested-list__button,.fd-nested-list__link:active[aria-selected=true],.fd-nested-list__link:active[aria-selected=true] .fd-nested-list__button{background:var(--sapList_Active_Background)}.fd-nested-list__content.is-active .fd-nested-list__button,.fd-nested-list__content.is-active .fd-nested-list__icon,.fd-nested-list__content.is-active .fd-nested-list__title,.fd-nested-list__content:active .fd-nested-list__button,.fd-nested-list__content:active .fd-nested-list__icon,.fd-nested-list__content:active .fd-nested-list__title,.fd-nested-list__link.is-active .fd-nested-list__button,.fd-nested-list__link.is-active .fd-nested-list__icon,.fd-nested-list__link.is-active .fd-nested-list__title,.fd-nested-list__link:active .fd-nested-list__button,.fd-nested-list__link:active .fd-nested-list__icon,.fd-nested-list__link:active .fd-nested-list__title{color:var(--sapList_Active_TextColor)}.fd-nested-list__content.has-child,.fd-nested-list__link.has-child{-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;padding-block:0;padding-inline:0}.fd-nested-list__content.has-child>.fd-nested-list__item,.fd-nested-list__content.has-child>.fd-nested-list__link,.fd-nested-list__link.has-child>.fd-nested-list__item,.fd-nested-list__link.has-child>.fd-nested-list__link{border:none}.fd-nested-list__content.has-child>.fd-nested-list__link,.fd-nested-list__link.has-child>.fd-nested-list__link{background:transparent;border:none;height:100%}.fd-nested-list__content.has-child>.fd-nested-list__link.is-focus,.fd-nested-list__content.has-child>.fd-nested-list__link:focus,.fd-nested-list__link.has-child>.fd-nested-list__link.is-focus,.fd-nested-list__link.has-child>.fd-nested-list__link:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.1875rem}.fd-nested-list__content.has-child>.fd-nested-list__link>.fd-nested-list__title,.fd-nested-list__link.has-child>.fd-nested-list__link>.fd-nested-list__title{-webkit-padding-end:0;padding-inline-end:0}.fd-nested-list__link{cursor:pointer}.fd-nested-list__button.fd-button{background:none;border:none;color:var(--sapContent_IconColor);height:100%;max-height:100%;min-height:100%;min-width:2.5rem;outline:none;text-decoration:none}.fd-nested-list__button.fd-button [class*=sap-icon],.fd-nested-list__button.fd-button[class*=sap-icon]{font-size:var(--sapFontLargeSize)}.fd-nested-list__icon [class*=sap-icon],.fd-nested-list__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;color:var(--sapList_TextColor);font-size:var(--fdNestedList_Icon_Font_Size);justify-content:center;min-width:2.75rem}.fd-nested-list__icon [class*=sap-icon],.fd-nested-list__icon[class*=sap-icon],.fd-nested-list__title{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:100%}.fd-nested-list__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapList_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdNestedList_Title_Font_Size);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:100%;-webkit-padding-end:1rem;padding-inline-end:1rem;text-align:start}.fd-nested-list__title:after,.fd-nested-list__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-nested-list__title:first-child{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-nested-list__group-header{background:var(--sapList_GroupHeaderBackground);border:0;border-bottom:var(--sapList_BorderWidth) solid var(--sapList_GroupHeaderBorderColor);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapList_GroupHeaderTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-weight:400;forced-color-adjust:none;height:2.75rem;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end;font-size:var(--sapFontSize);font-weight:700;line-height:2rem;overflow:hidden;padding-inline:1rem;text-overflow:ellipsis;white-space:nowrap}.fd-nested-list__group-header:after,.fd-nested-list__group-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-nested-list--no-border .fd-nested-list__group-header,.fd-nested-list--no-border .fd-nested-list__item,.fd-nested-list--no-border .fd-nested-list__link{border-top:none}.fd-nested-list--text-only{--fdNestedList_Item_Padding_Left:1rem}.fd-nested-list--text-only .fd-nested-list__content.has-child,.fd-nested-list--text-only .fd-nested-list__link.has-child{padding-block:0;padding-inline:0}.fd-nested-list--text-only .fd-nested-list__title:first-child{-webkit-padding-start:0;padding-inline-start:0}.fd-nested-list--text-only .level-2{--fdNestedList_Item_Padding_Left:2rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-2{--fdNestedList_Item_Padding_Left:2.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-3{--fdNestedList_Item_Padding_Left:3rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-3{--fdNestedList_Item_Padding_Left:3.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-4{--fdNestedList_Item_Padding_Left:4rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-4{--fdNestedList_Item_Padding_Left:4.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-5{--fdNestedList_Item_Padding_Left:5rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-5{--fdNestedList_Item_Padding_Left:5.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-6{--fdNestedList_Item_Padding_Left:6rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-6{--fdNestedList_Item_Padding_Left:6.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-7{--fdNestedList_Item_Padding_Left:7rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-7{--fdNestedList_Item_Padding_Left:7.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-8{--fdNestedList_Item_Padding_Left:8rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-8{--fdNestedList_Item_Padding_Left:8.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-9{--fdNestedList_Item_Padding_Left:9rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-9{--fdNestedList_Item_Padding_Left:9.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-10{--fdNestedList_Item_Padding_Left:10rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-10{--fdNestedList_Item_Padding_Left:10.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list[class*=-compact],[class*=-compact] .fd-nested-list:not([class*=-cozy]){--fdNestedList_Link_Height:2rem;--fdNestedList_Title_Font_Size:var(--sapFontSize);--fdNestedList_Icon_Font_Size:var(--sapFontLargeSize)}.fd-side-nav{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;background:var(--sapList_Background);-ms-flex-direction:column;flex-direction:column;height:100%;max-height:100%;width:var(--fdSideNav_Width,100%)}.fd-side-nav:after,.fd-side-nav:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-side-nav__container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;padding-inline:.5rem}.fd-side-nav__container:after,.fd-side-nav__container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-side-nav__container--top{-webkit-box-flex:1;-ms-flex:1;flex:1;height:100%;overflow-y:var(--fdSideNav_Overflow,scroll);position:relative;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-side-nav__container--bottom{-webkit-padding-after:.5rem;padding-block-end:.5rem}.fd-side-nav__separator{background:var(--sapToolbar_SeparatorColor);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:.0625rem;line-height:normal;margin-block:0;margin-block:.25rem;margin-inline:0;margin-inline:.5rem;min-height:.0625rem;padding-block:0;padding-inline:0}.fd-side-nav__separator:after,.fd-side-nav__separator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-side-nav__group-header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-side-nav__group-header:after,.fd-side-nav__group-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-side-nav[class*=-collapsed],[class*=-collapsed]{--fdSideNav_Width:4rem;--fdSideNav_Overflow:visible}.fd-nested-list__item{display:block}.fd-nested-list__item .fd-nested-list__link{cursor:pointer}.fd-nested-list__item .fd-nested-list__content .fd-nested-list__button.fd-button{background:none}\n/*! Bundled license information:\n\nfundamental-styles/dist/side-nav.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "directive", type: SideNavigationMainDirective, selector: "[fdSideNavigationMain], [fd-side-nav-main]" }, { kind: "component", type: PreparedNestedListComponent, selector: "fd-prepared-nested-list", inputs: ["first", "condensed", "list"] }, { kind: "directive", type: SideNavigationUtilityDirective, selector: "[fdSideNavigationUtility], [fd-side-nav-utility]" }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SideNavigationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-side-nav', encapsulation: ViewEncapsulation.None, providers: [MenuKeyboardService, NestedListKeyboardService, NestedListStateService], imports: [SideNavigationMainDirective, PreparedNestedListComponent, SideNavigationUtilityDirective], template: "<nav class=\"fd-side-nav\" [class.fd-side-nav--condensed]=\"condensed || sideNavigationConfiguration?.condensed\">\n    @if (!sideNavigationConfiguration) {\n        <ng-content></ng-content>\n    } @else {\n        @if (sideNavigationConfiguration.mainNavigation) {\n            <div fd-side-nav-main>\n                <fd-prepared-nested-list\n                    [condensed]=\"condensed || !!sideNavigationConfiguration.condensed\"\n                    [first]=\"true\"\n                    [list]=\"sideNavigationConfiguration.mainNavigation\"\n                >\n                </fd-prepared-nested-list>\n            </div>\n        }\n        @if (sideNavigationConfiguration.utilityNavigation) {\n            <div fd-side-nav-utility>\n                <fd-prepared-nested-list\n                    [condensed]=\"condensed || !!sideNavigationConfiguration.condensed\"\n                    [first]=\"true\"\n                    [list]=\"sideNavigationConfiguration.utilityNavigation\"\n                >\n                </fd-prepared-nested-list>\n            </div>\n        }\n    }\n</nav>\n", styles: [".fd-nested-list{--fdNestedList_Link_Height:2.75rem;--fdNestedList_Title_Font_Size:var(--sapFontLargeSize);--fdNestedList_Icon_Font_Size:var(--sapFontHeader4Size);--fdNestedList_Item_Padding_Left:0;--fdNestedList_Item_Padding_Right:0;border:0;border-bottom:var(--sapList_BorderWidth) solid var(--sapList_BorderColor);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;list-style:none;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%}.fd-nested-list:after,.fd-nested-list:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-nested-list [class*=level]{border-bottom:none}.fd-nested-list [class*=level] .fd-nested-list__content,.fd-nested-list [class*=level] .fd-nested-list__link{border-top:none}.fd-nested-list .fd-nested-list__content,.fd-nested-list .fd-nested-list__link{border-bottom:none;padding-inline:var(--fdNestedList_Item_Padding_Left) var(--fdNestedList_Item_Padding_Right)}.fd-nested-list .fd-nested-list__content.is-selected,.fd-nested-list .fd-nested-list__content[aria-selected=true],.fd-nested-list .fd-nested-list__link.is-selected,.fd-nested-list .fd-nested-list__link[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-nested-list .fd-nested-list__content.has-child,.fd-nested-list .fd-nested-list__link.has-child{padding-inline:0}.fd-nested-list .fd-nested-list__content.has-child>.fd-nested-list__title{padding-inline:var(--fdNestedList_Item_Padding_Left) var(--fdNestedList_Item_Padding_Right)}.fd-nested-list .level-2{--fdNestedList_Item_Padding_Left:2.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-3{--fdNestedList_Item_Padding_Left:3.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-4{--fdNestedList_Item_Padding_Left:4.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-5{--fdNestedList_Item_Padding_Left:5.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-6{--fdNestedList_Item_Padding_Left:6.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-7{--fdNestedList_Item_Padding_Left:7.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-8{--fdNestedList_Item_Padding_Left:8.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-9{--fdNestedList_Item_Padding_Left:9.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list .level-10{--fdNestedList_Item_Padding_Left:10.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list[aria-hidden=true]{display:none}.fd-nested-list--popover{border-bottom:none}.fd-nested-list--popover .fd-nested-list__group-header{border-bottom:none;border-top-left-radius:var(--fdNested_List_Border_Corner_Radius);border-top-right-radius:var(--fdNested_List_Border_Corner_Radius)}.fd-nested-list--popover .fd-nested-list__item:first-child,.fd-nested-list--popover .fd-nested-list__item:first-child .fd-nested-list__content,.fd-nested-list--popover .fd-nested-list__item:first-child .fd-nested-list__link{border-top-left-radius:var(--fdNested_List_Border_Corner_Radius);border-top-right-radius:var(--fdNested_List_Border_Corner_Radius)}.fd-nested-list--popover .fd-nested-list__item:last-child,.fd-nested-list--popover .fd-nested-list__item:last-child .fd-nested-list__content,.fd-nested-list--popover .fd-nested-list__item:last-child .fd-nested-list__link{border-bottom-left-radius:var(--fdNested_List_Border_Corner_Radius);border-bottom-right-radius:var(--fdNested_List_Border_Corner_Radius)}.fd-nested-list__item{background:var(--sapList_Background);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-shadow:var(--fdVerticalNav_Text_Shadow)}.fd-nested-list__item:after,.fd-nested-list__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-nested-list__item:first-child .fd-nested-list__content,.fd-nested-list__item:first-child .fd-nested-list__link{border-top:none}.fd-nested-list__content,.fd-nested-list__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdNestedList_Link_Height);line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-decoration:none;width:100%;-webkit-box-align:center;-ms-flex-align:center;align-items:center;border-top:var(--sapList_BorderWidth) solid var(--sapList_BorderColor)}.fd-nested-list__content:after,.fd-nested-list__content:before,.fd-nested-list__link:after,.fd-nested-list__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-nested-list__content.is-hover,.fd-nested-list__content.is-hover .fd-nested-list__button,.fd-nested-list__content:hover,.fd-nested-list__content:hover .fd-nested-list__button,.fd-nested-list__link.is-hover,.fd-nested-list__link.is-hover .fd-nested-list__button,.fd-nested-list__link:hover,.fd-nested-list__link:hover .fd-nested-list__button{background:var(--sapList_Hover_Background)}.fd-nested-list__content.is-focus,.fd-nested-list__content:focus,.fd-nested-list__link.is-focus,.fd-nested-list__link:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.1875rem}.fd-nested-list__content.is-selected,.fd-nested-list__content[aria-selected=true],.fd-nested-list__link.is-selected,.fd-nested-list__link[aria-selected=true]{background:var(--sapList_SelectionBackgroundColor);border-bottom:var(--sapList_BorderWidth) solid;border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-nested-list__content.is-selected .fd-nested-list__button,.fd-nested-list__content[aria-selected=true] .fd-nested-list__button,.fd-nested-list__link.is-selected .fd-nested-list__button,.fd-nested-list__link[aria-selected=true] .fd-nested-list__button{background:var(--sapList_SelectionBackgroundColor)}.fd-nested-list__content.is-selected.is-hover,.fd-nested-list__content.is-selected.is-hover .fd-nested-list__button,.fd-nested-list__content.is-selected:hover,.fd-nested-list__content.is-selected:hover .fd-nested-list__button,.fd-nested-list__content[aria-selected=true].is-hover,.fd-nested-list__content[aria-selected=true].is-hover .fd-nested-list__button,.fd-nested-list__content[aria-selected=true]:hover,.fd-nested-list__content[aria-selected=true]:hover .fd-nested-list__button,.fd-nested-list__link.is-selected.is-hover,.fd-nested-list__link.is-selected.is-hover .fd-nested-list__button,.fd-nested-list__link.is-selected:hover,.fd-nested-list__link.is-selected:hover .fd-nested-list__button,.fd-nested-list__link[aria-selected=true].is-hover,.fd-nested-list__link[aria-selected=true].is-hover .fd-nested-list__button,.fd-nested-list__link[aria-selected=true]:hover,.fd-nested-list__link[aria-selected=true]:hover .fd-nested-list__button{background:var(--sapList_Hover_SelectionBackground)}.fd-nested-list__content.is-active,.fd-nested-list__content.is-active .fd-nested-list__button,.fd-nested-list__content.is-active.is-selected,.fd-nested-list__content.is-active.is-selected .fd-nested-list__button,.fd-nested-list__content.is-active[aria-selected=true],.fd-nested-list__content.is-active[aria-selected=true] .fd-nested-list__button,.fd-nested-list__content:active,.fd-nested-list__content:active .fd-nested-list__button,.fd-nested-list__content:active.is-selected,.fd-nested-list__content:active.is-selected .fd-nested-list__button,.fd-nested-list__content:active[aria-selected=true],.fd-nested-list__content:active[aria-selected=true] .fd-nested-list__button,.fd-nested-list__link.is-active,.fd-nested-list__link.is-active .fd-nested-list__button,.fd-nested-list__link.is-active.is-selected,.fd-nested-list__link.is-active.is-selected .fd-nested-list__button,.fd-nested-list__link.is-active[aria-selected=true],.fd-nested-list__link.is-active[aria-selected=true] .fd-nested-list__button,.fd-nested-list__link:active,.fd-nested-list__link:active .fd-nested-list__button,.fd-nested-list__link:active.is-selected,.fd-nested-list__link:active.is-selected .fd-nested-list__button,.fd-nested-list__link:active[aria-selected=true],.fd-nested-list__link:active[aria-selected=true] .fd-nested-list__button{background:var(--sapList_Active_Background)}.fd-nested-list__content.is-active .fd-nested-list__button,.fd-nested-list__content.is-active .fd-nested-list__icon,.fd-nested-list__content.is-active .fd-nested-list__title,.fd-nested-list__content:active .fd-nested-list__button,.fd-nested-list__content:active .fd-nested-list__icon,.fd-nested-list__content:active .fd-nested-list__title,.fd-nested-list__link.is-active .fd-nested-list__button,.fd-nested-list__link.is-active .fd-nested-list__icon,.fd-nested-list__link.is-active .fd-nested-list__title,.fd-nested-list__link:active .fd-nested-list__button,.fd-nested-list__link:active .fd-nested-list__icon,.fd-nested-list__link:active .fd-nested-list__title{color:var(--sapList_Active_TextColor)}.fd-nested-list__content.has-child,.fd-nested-list__link.has-child{-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;padding-block:0;padding-inline:0}.fd-nested-list__content.has-child>.fd-nested-list__item,.fd-nested-list__content.has-child>.fd-nested-list__link,.fd-nested-list__link.has-child>.fd-nested-list__item,.fd-nested-list__link.has-child>.fd-nested-list__link{border:none}.fd-nested-list__content.has-child>.fd-nested-list__link,.fd-nested-list__link.has-child>.fd-nested-list__link{background:transparent;border:none;height:100%}.fd-nested-list__content.has-child>.fd-nested-list__link.is-focus,.fd-nested-list__content.has-child>.fd-nested-list__link:focus,.fd-nested-list__link.has-child>.fd-nested-list__link.is-focus,.fd-nested-list__link.has-child>.fd-nested-list__link:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.1875rem}.fd-nested-list__content.has-child>.fd-nested-list__link>.fd-nested-list__title,.fd-nested-list__link.has-child>.fd-nested-list__link>.fd-nested-list__title{-webkit-padding-end:0;padding-inline-end:0}.fd-nested-list__link{cursor:pointer}.fd-nested-list__button.fd-button{background:none;border:none;color:var(--sapContent_IconColor);height:100%;max-height:100%;min-height:100%;min-width:2.5rem;outline:none;text-decoration:none}.fd-nested-list__button.fd-button [class*=sap-icon],.fd-nested-list__button.fd-button[class*=sap-icon]{font-size:var(--sapFontLargeSize)}.fd-nested-list__icon [class*=sap-icon],.fd-nested-list__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;color:var(--sapList_TextColor);font-size:var(--fdNestedList_Icon_Font_Size);justify-content:center;min-width:2.75rem}.fd-nested-list__icon [class*=sap-icon],.fd-nested-list__icon[class*=sap-icon],.fd-nested-list__title{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:100%}.fd-nested-list__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapList_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdNestedList_Title_Font_Size);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:100%;-webkit-padding-end:1rem;padding-inline-end:1rem;text-align:start}.fd-nested-list__title:after,.fd-nested-list__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-nested-list__title:first-child{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-nested-list__group-header{background:var(--sapList_GroupHeaderBackground);border:0;border-bottom:var(--sapList_BorderWidth) solid var(--sapList_GroupHeaderBorderColor);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapList_GroupHeaderTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-weight:400;forced-color-adjust:none;height:2.75rem;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end;font-size:var(--sapFontSize);font-weight:700;line-height:2rem;overflow:hidden;padding-inline:1rem;text-overflow:ellipsis;white-space:nowrap}.fd-nested-list__group-header:after,.fd-nested-list__group-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-nested-list--no-border .fd-nested-list__group-header,.fd-nested-list--no-border .fd-nested-list__item,.fd-nested-list--no-border .fd-nested-list__link{border-top:none}.fd-nested-list--text-only{--fdNestedList_Item_Padding_Left:1rem}.fd-nested-list--text-only .fd-nested-list__content.has-child,.fd-nested-list--text-only .fd-nested-list__link.has-child{padding-block:0;padding-inline:0}.fd-nested-list--text-only .fd-nested-list__title:first-child{-webkit-padding-start:0;padding-inline-start:0}.fd-nested-list--text-only .level-2{--fdNestedList_Item_Padding_Left:2rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-2{--fdNestedList_Item_Padding_Left:2.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-3{--fdNestedList_Item_Padding_Left:3rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-3{--fdNestedList_Item_Padding_Left:3.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-4{--fdNestedList_Item_Padding_Left:4rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-4{--fdNestedList_Item_Padding_Left:4.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-5{--fdNestedList_Item_Padding_Left:5rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-5{--fdNestedList_Item_Padding_Left:5.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-6{--fdNestedList_Item_Padding_Left:6rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-6{--fdNestedList_Item_Padding_Left:6.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-7{--fdNestedList_Item_Padding_Left:7rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-7{--fdNestedList_Item_Padding_Left:7.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-8{--fdNestedList_Item_Padding_Left:8rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-8{--fdNestedList_Item_Padding_Left:8.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-9{--fdNestedList_Item_Padding_Left:9rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-9{--fdNestedList_Item_Padding_Left:9.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only .level-10{--fdNestedList_Item_Padding_Left:10rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list--text-only.level-10{--fdNestedList_Item_Padding_Left:10.75rem;--fdNestedList_Item_Padding_Right:0}.fd-nested-list[class*=-compact],[class*=-compact] .fd-nested-list:not([class*=-cozy]){--fdNestedList_Link_Height:2rem;--fdNestedList_Title_Font_Size:var(--sapFontSize);--fdNestedList_Icon_Font_Size:var(--sapFontLargeSize)}.fd-side-nav{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;background:var(--sapList_Background);-ms-flex-direction:column;flex-direction:column;height:100%;max-height:100%;width:var(--fdSideNav_Width,100%)}.fd-side-nav:after,.fd-side-nav:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-side-nav__container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;padding-inline:.5rem}.fd-side-nav__container:after,.fd-side-nav__container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-side-nav__container--top{-webkit-box-flex:1;-ms-flex:1;flex:1;height:100%;overflow-y:var(--fdSideNav_Overflow,scroll);position:relative;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-side-nav__container--bottom{-webkit-padding-after:.5rem;padding-block-end:.5rem}.fd-side-nav__separator{background:var(--sapToolbar_SeparatorColor);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:.0625rem;line-height:normal;margin-block:0;margin-block:.25rem;margin-inline:0;margin-inline:.5rem;min-height:.0625rem;padding-block:0;padding-inline:0}.fd-side-nav__separator:after,.fd-side-nav__separator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-side-nav__group-header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-side-nav__group-header:after,.fd-side-nav__group-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-side-nav[class*=-collapsed],[class*=-collapsed]{--fdSideNav_Width:4rem;--fdSideNav_Overflow:visible}.fd-nested-list__item{display:block}.fd-nested-list__item .fd-nested-list__link{cursor:pointer}.fd-nested-list__item .fd-nested-list__content .fd-nested-list__button.fd-button{background:none}\n/*! Bundled license information:\n\nfundamental-styles/dist/side-nav.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i1.NestedListKeyboardService }, { type: i1.NestedListStateService }], propDecorators: { sideNavigationConfiguration: [{
                type: Input
            }], condensed: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.fd-side-nav--condensed']
            }], collapseWidth: [{
                type: Input
            }], selectable: [{
                type: Input
            }], sideNavUtility: [{
                type: ContentChild,
                args: [SideNavigationUtilityDirective]
            }], sideNavMain: [{
                type: ContentChild,
                args: [SideNavigationMainDirective]
            }], preparedNestedList: [{
                type: ViewChildren,
                args: [PreparedNestedListComponent]
            }], onResize: [{
                type: HostListener,
                args: ['window:resize']
            }] } });

/**
 * @deprecated
 */
class SideNavigationModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SideNavigationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: SideNavigationModule, imports: [SideNavigationComponent, SideNavigationMainDirective, SideNavigationUtilityDirective], exports: [SideNavigationComponent, SideNavigationMainDirective, SideNavigationUtilityDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SideNavigationModule, providers: [MenuKeyboardService, NestedListKeyboardService, NestedListStateService], imports: [SideNavigationComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SideNavigationModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [SideNavigationComponent, SideNavigationMainDirective, SideNavigationUtilityDirective],
                    exports: [SideNavigationComponent, SideNavigationMainDirective, SideNavigationUtilityDirective],
                    providers: [MenuKeyboardService, NestedListKeyboardService, NestedListStateService]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { SideNavigationComponent, SideNavigationMainDirective, SideNavigationModule, SideNavigationUtilityDirective };
//# sourceMappingURL=fundamental-ngx-core-side-navigation.mjs.map
