import * as i0 from '@angular/core';
import { computed, effect, Input, Optional, Directive, forwardRef, inject, DestroyRef, ElementRef, HostBinding, ViewChildren, ViewChild, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import * as i1 from '@fundamental-ngx/cdk/utils';
import { KeyUtil, OnlyDigitsDirective, applyCssClass, OnlyDigitsModule } from '@fundamental-ngx/cdk/utils';
import { __decorate, __metadata } from 'tslib';
import * as i2 from '@angular/cdk/a11y';
import { coerceNumberProperty } from '@angular/cdk/coercion';
import { LEFT_ARROW, RIGHT_ARROW, UP_ARROW, DOWN_ARROW, ENTER, SPACE } from '@angular/cdk/keycodes';
import * as i1$1 from '@angular/cdk/platform';
import * as i5 from '@angular/forms';
import { NG_VALUE_ACCESSOR, FormsModule } from '@angular/forms';
import { BehaviorSubject, fromEvent, combineLatest, of } from 'rxjs';
import { debounceTime, skip, map, switchMap, distinctUntilChanged, mapTo, take, startWith } from 'rxjs/operators';
import { NgTemplateOutlet } from '@angular/common';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import * as i4 from '@fundamental-ngx/core/content-density';
import { contentDensityObserverProviders, ContentDensityMode, ContentDensityModule } from '@fundamental-ngx/core/content-density';
import { registerFormItemControl } from '@fundamental-ngx/core/form';
import { PopoverComponent, PopoverTriggerDirective, PopoverModule } from '@fundamental-ngx/core/popover';
import { FdTranslatePipe, I18nModule } from '@fundamental-ngx/i18n';

class SliderPositionDirective {
    /** @hidden */
    constructor(_elementRef, _renderer, _rtlService) {
        this._elementRef = _elementRef;
        this._renderer = _renderer;
        this._rtlService = _rtlService;
        /** Whether the slider is rendered vertically. */
        this.vertical = false;
        this._rtl$ = computed(() => !!this._rtlService?.rtlSignal());
        effect(() => {
            this._setPosition(this._rtl$());
        });
    }
    /** @hidden */
    ngOnChanges() {
        this._setPosition();
    }
    /** @hidden */
    _setPosition(rtl = this._rtl$()) {
        if (this.vertical) {
            this._renderer.setStyle(this._elementRef.nativeElement, 'bottom', `${this.position}%`);
            return;
        }
        this._renderer.setStyle(this._elementRef.nativeElement, 'left', !rtl ? `${this.position}%` : 'unset');
        this._renderer.setStyle(this._elementRef.nativeElement, 'right', rtl ? `${this.position}%` : 'unset');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SliderPositionDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i1.RtlService, optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: SliderPositionDirective, isStandalone: true, selector: "[fd-slider-position]", inputs: { position: "position", vertical: "vertical" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SliderPositionDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-slider-position]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i1.RtlService, decorators: [{
                    type: Optional
                }] }], propDecorators: { position: [{
                type: Input
            }], vertical: [{
                type: Input
            }] } });

const MIN_DISTANCE_BETWEEN_TICKS = 8;

var SliderValueTargets;
(function (SliderValueTargets) {
    SliderValueTargets[SliderValueTargets["SINGLE_SLIDER"] = 0] = "SINGLE_SLIDER";
    SliderValueTargets[SliderValueTargets["RANGE_SLIDER1"] = 1] = "RANGE_SLIDER1";
    SliderValueTargets[SliderValueTargets["RANGE_SLIDER2"] = 2] = "RANGE_SLIDER2";
})(SliderValueTargets || (SliderValueTargets = {}));
var SliderRangeHandles;
(function (SliderRangeHandles) {
    SliderRangeHandles[SliderRangeHandles["First"] = 0] = "First";
    SliderRangeHandles[SliderRangeHandles["Second"] = 1] = "Second";
    SliderRangeHandles[SliderRangeHandles["Both"] = 2] = "Both";
})(SliderRangeHandles || (SliderRangeHandles = {}));

const SLIDER_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => SliderComponent),
    multi: true
};
let sliderId = 0;
class SliderComponent {
    /** Minimum value. */
    set min(value) {
        const newValue = coerceNumberProperty(value, this._min);
        if (((this.max - newValue) / this.step) % 1 !== 0) {
            return;
        }
        this._min = value;
    }
    get min() {
        return this._min;
    }
    /** Maximum value. */
    set max(value) {
        const newValue = coerceNumberProperty(value, this._max);
        if (((newValue - this.min) / this.step) % 1 !== 0) {
            return;
        }
        this._max = value;
    }
    get max() {
        return this._max;
    }
    /** Step value. */
    set step(value) {
        const newValue = coerceNumberProperty(value, this._step);
        if (((this.max - this.min) / newValue) % 1 !== 0) {
            return;
        }
        this._step = value;
    }
    get step() {
        return this._step;
    }
    /** Jump value. */
    set jump(value) {
        this._jump = coerceNumberProperty(value, this._jump);
    }
    get jump() {
        return this._jump;
    }
    /** Put a label on every N-th tickmark. */
    set tickmarksBetweenLabels(value) {
        this._tickmarksBetweenLabels = coerceNumberProperty(value, this._tickmarksBetweenLabels);
    }
    get tickmarksBetweenLabels() {
        return this._tickmarksBetweenLabels;
    }
    /** Control value */
    set value(value) {
        this._setValue(value);
    }
    get value() {
        return this._value;
    }
    /** @hidden */
    get _popoverValueRef() {
        return [this._position, this._handle1Value, this._handle2Value];
    }
    /** @hidden */
    constructor(elementRef, _cdr, _renderer, _platform, _liveAnnouncer, _rtlService, _contentDensityObserver) {
        this.elementRef = elementRef;
        this._cdr = _cdr;
        this._renderer = _renderer;
        this._platform = _platform;
        this._liveAnnouncer = _liveAnnouncer;
        this._rtlService = _rtlService;
        this._contentDensityObserver = _contentDensityObserver;
        /** Slider id, it has some default value if not set,  */
        this.id = 'fd-slider-id-' + sliderId++;
        /**
         * Slider mode.
         * Options include: 'single' | 'range'
         * The default is set to 'single'
         */
        this.mode = 'single';
        /** Toggles the visibility of tick marks. */
        this.showTicks = false;
        /** Toggles the visibility of tick mark labels. Must be used in conjunction with 'showTicks' */
        this.showTicksLabels = false;
        /** Array of custom values to use for Slider. */
        this.customValues = [];
        /** Hides display of colored progress bar. */
        this.hideProgressBar = false;
        /** Whether the control is disabled. */
        this.disabled = false;
        /**
         * Whether slider should have vertical alignment.
         */
        this.vertical = false;
        /** @hidden */
        this._position = 0;
        /** @hidden */
        this._value = 0;
        /** @hidden */
        this._progress = 0;
        /** @hidden */
        this._isRange = false;
        /** @hidden */
        this._handle1Position = 0;
        /** @hidden */
        this._handle2Position = 0;
        /** @hidden */
        this._handle1Value = 0;
        /** @hidden */
        this._handle2Value = 0;
        /** @hidden */
        this._rangeProgress = 0;
        /** @hidden */
        this._tickMarks = [];
        /** @hidden */
        this._sliderValueTargets = SliderValueTargets;
        /** @hidden */
        this._popoverInputFieldClass = `fd-slider-popover-input-${sliderId}`;
        /**
         * @hidden
         * whether to use value with a prefix for announcing
         */
        this._useSliderValuePrefix = true;
        /** @hidden */
        this._handles = SliderRangeHandles;
        /** @hidden */
        this._min = 0;
        /** @hidden */
        this._max = 100;
        /** @hidden */
        this._step = 1;
        /** @hidden */
        this._jump = 10;
        /** @hidden */
        this._tickmarksBetweenLabels = 1;
        /** @hidden */
        this._valuesBySteps = [];
        /**
         * @hidden
         * An RxJS Subject that will kill the data stream upon component’s destruction (for unsubscribing)
         */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._componentHovered$ = new BehaviorSubject(false);
        /** @hidden */
        this._handleFocused$ = new BehaviorSubject(false);
        /** @hidden */
        this._rangeHandle1Focused$ = new BehaviorSubject(false);
        /** @hidden */
        this._rangeHandle2Focused$ = new BehaviorSubject(false);
        /** @hidden */
        this._popoverInputFieldFocused$ = new BehaviorSubject(false);
        /** @hidden */
        this._popoverInputFieldHovered$ = new BehaviorSubject(false);
        /** @hidden */
        this._rtl$ = computed(() => !!this._rtlService?.rtlSignal());
        /** @hidden */
        this.onChange = () => { };
        /** @hidden */
        this.onTouched = () => { };
        _contentDensityObserver.subscribe();
    }
    /**
     * @hidden
     * CssClassBuilder interface implementation
     * function must return single string
     * function is responsible for order which css classes are applied
     */
    buildComponentCssClass() {
        return [
            'fd-slider',
            this.disabled ? 'is-disabled' : '',
            this._isRange ? 'fd-slider--range' : '',
            this.showTicks && this.showTicksLabels ? 'fd-slider--with-labels' : '',
            this.vertical ? 'fd-slider--vertical' : '',
            this.class,
            this._platform.EDGE || this._platform.TRIDENT ? 'fd-slider__alternative-tick-width' : ''
        ];
    }
    /** @hidden */
    ngOnInit() {
        this._attachResizeListener();
        this._onResize();
        if (this._valuesBySteps.length === 0) {
            this._constructValuesBySteps();
        }
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
        this._checkIsInRangeMode();
        this._constructTickMarks();
        this._constructValuesBySteps();
        this._recalcHandlePositions();
    }
    /** @hidden */
    ngAfterViewInit() {
        this._listenToInteractionChanges();
    }
    /** @hidden */
    getValuenow(position, sliderValueTarget) {
        return this.customValues.length > 0
            ? this.customValues[position].label
            : this._popoverValueRef[sliderValueTarget];
    }
    /** @hidden */
    get minValue() {
        return this.customValues.length > 0 ? this.customValues[this.min].label : this.min;
    }
    /** @hidden */
    get maxValue() {
        return this.customValues.length > 0 ? this.customValues[this.max].label : this.max;
    }
    /** @hidden */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /** @hidden */
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    /** @hidden */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    /** @hidden */
    writeValue(value) {
        this._setValue(value, false);
    }
    /** @hidden */
    onTrackClick(event) {
        if (this.disabled || this._isRange) {
            return;
        }
        this._setValue(this._calculateValueFromPointerPosition(event));
        this._updatePopoversPosition();
        this.handle.nativeElement.focus();
    }
    /** @hidden */
    onHandleClick(event, group = false) {
        if (this.disabled) {
            return;
        }
        let firstHandleCoords;
        let rangeSliderStartCoords;
        if (group) {
            rangeSliderStartCoords = {
                x: event.clientX,
                y: event.clientY
            };
            const firstHandleRect = this.rangeHandle1.nativeElement.getBoundingClientRect();
            firstHandleCoords = {
                x: firstHandleRect.x + firstHandleRect.width / 2,
                y: firstHandleRect.y + firstHandleRect.height / 2
            };
        }
        const unsubscribeFromMousemove = this._renderer.listen('document', 'mousemove', (moveEvent) => {
            this._updatePopoversPosition();
            if (!this._isRange) {
                this._setValue(this._calculateValueFromPointerPosition(moveEvent));
                return;
            }
            let coords = {
                clientX: moveEvent.clientX,
                clientY: moveEvent.clientY
            };
            let handleIndex;
            if (group) {
                handleIndex = SliderRangeHandles.Both;
                // Mimic dragging first handle to calculate the difference between old and new values.
                coords = {
                    clientX: firstHandleCoords.x + (moveEvent.clientX - rangeSliderStartCoords.x),
                    clientY: firstHandleCoords.y + (moveEvent.clientY - rangeSliderStartCoords.y)
                };
            }
            else if (event.target === this.rangeHandle1.nativeElement) {
                handleIndex = SliderRangeHandles.First;
            }
            else if (event.target === this.rangeHandle2.nativeElement) {
                handleIndex = SliderRangeHandles.Second;
            }
            else {
                return;
            }
            const value = this._calculateValueFromPointerPosition(coords, false);
            this._setRangeHandleValueAndPosition(handleIndex, value);
            this._setValue(this._constructRangeModelValue());
        });
        const unsubscribeFromMouseup = this._renderer.listen('document', 'mouseup', () => {
            unsubscribeFromMousemove();
            unsubscribeFromMouseup();
        });
    }
    /** @hidden */
    onKeyDown(event, handle) {
        if (this.disabled) {
            return;
        }
        const allowedKeys = [LEFT_ARROW, RIGHT_ARROW, UP_ARROW, DOWN_ARROW, ENTER, SPACE];
        if (!KeyUtil.isKeyCode(event, allowedKeys)) {
            return;
        }
        event.preventDefault();
        const upActionKey = KeyUtil.isKeyCode(event, [UP_ARROW, this._rtl$() ? LEFT_ARROW : RIGHT_ARROW]);
        const downActionKey = KeyUtil.isKeyCode(event, [DOWN_ARROW, this._rtl$() ? RIGHT_ARROW : LEFT_ARROW]);
        if (!upActionKey && !downActionKey) {
            return;
        }
        const diff = event.shiftKey ? this.jump : this.step;
        let newValue = null;
        if (!this._isRange) {
            newValue = this._position + diff * (upActionKey ? 1 : -1);
            if (newValue === null) {
                return;
            }
            newValue = this._processNewValue(newValue, !this._isRange);
            this._setValue(newValue);
            this._updatePopoversPosition();
            return;
        }
        this._handleRangeKeydown(handle === SliderRangeHandles.Both ? [SliderRangeHandles.First, SliderRangeHandles.Second] : handle, diff, upActionKey);
        this._updatePopoversPosition();
    }
    /** @hidden */
    _updateValueFromInput(value, target) {
        const newValue = this._processNewValue(+value);
        if (!this._isRange && target === SliderValueTargets.SINGLE_SLIDER) {
            this._setValue(newValue);
            this.handle.nativeElement.focus();
            this._updatePopoversPosition();
            return;
        }
        if (target === SliderValueTargets.RANGE_SLIDER1) {
            this._setRangeHandleValueAndPosition(SliderRangeHandles.First, newValue);
            this.rangeHandle1.nativeElement.focus();
        }
        if (target === SliderValueTargets.RANGE_SLIDER2) {
            this._setRangeHandleValueAndPosition(SliderRangeHandles.Second, newValue);
            this.rangeHandle2.nativeElement.focus();
        }
        this._setValue(this._constructRangeModelValue());
        this._updatePopoversPosition();
    }
    /** @hidden */
    _handleRangeKeydown(handles, diff, up) {
        handles = Array.isArray(handles) ? handles : [handles];
        const valueMap = new Map();
        handles.forEach((handle) => {
            const prevValue = handle === SliderRangeHandles.First ? this._handle1Value : this._handle2Value;
            let newValue = prevValue + diff * (up ? 1 : -1);
            if (newValue === null) {
                return;
            }
            newValue = this._processNewValue(newValue, !this._isRange);
            valueMap.set(handle, { prev: prevValue, current: newValue });
        });
        if (Array.from(valueMap.values()).some((entry) => entry.current === entry.prev)) {
            return;
        }
        valueMap.forEach((entry, handle) => {
            this._setRangeHandleValueAndPosition(handle, entry.current);
        });
        this._setValue(this._constructRangeModelValue());
    }
    /** @hidden */
    _setValue(value, emitEvent = true) {
        if (this._isRange) {
            this._initRangeMode((value ?? [0.0]));
        }
        else {
            this._initSingeMode((value ?? 0));
        }
        this._value = value;
        if (emitEvent) {
            this.onChange(value);
        }
        this._cdr.markForCheck();
    }
    /** @hidden */
    _updatePopoversPosition() {
        this._cdr.detectChanges();
        this._popovers.forEach((popover) => popover.refreshPosition());
    }
    /** @hidden */
    _calculateValueFromPointerPosition(coords, takeCustomValue = true) {
        const { left, width, bottom, height } = this.trackEl.nativeElement.getBoundingClientRect();
        let percentage = this.vertical ? (bottom - coords.clientY) / height : (coords.clientX - left) / width;
        if (this._rtl$()) {
            percentage = 1 - percentage;
        }
        const newValue = this.min + percentage * (this.max - this.min);
        return this._processNewValue(newValue, takeCustomValue);
    }
    /** @hidden */
    _processNewValue(newValue, takeCustomValue = true) {
        if (newValue > this.max) {
            newValue = this.max;
        }
        if (newValue < this.min) {
            newValue = this.min;
        }
        this._useSliderValuePrefix = false;
        this._cdr.markForCheck();
        const stepDiffArray = this._valuesBySteps
            .map((stepValue) => ({
            diff: Math.abs(stepValue - newValue),
            value: stepValue
        }))
            .sort((a, b) => a.diff - b.diff);
        let value = stepDiffArray[0].value;
        if (takeCustomValue && this.customValues.length > 0) {
            value = this.customValues[value];
        }
        return value;
    }
    /** @hidden */
    _setRangeHandleValueAndPosition(handleIndex, value) {
        const position = this._calcProgress(value, true);
        if (handleIndex === SliderRangeHandles.First) {
            this._handle1Value = value;
            this._handle1Position = position;
        }
        else if (handleIndex === SliderRangeHandles.Second) {
            this._handle2Value = value;
            this._handle2Position = position;
        }
        else if (handleIndex === SliderRangeHandles.Both) {
            // Calculate how much steps being skipped.
            const oldValueIndex = this._valuesBySteps.indexOf(this._handle1Value);
            const newValueIndex = this._valuesBySteps.indexOf(value);
            const diff = oldValueIndex - newValueIndex;
            const handle2ValueIndex = this._valuesBySteps.indexOf(this._handle2Value);
            if (diff === 0 || this._valuesBySteps.length <= handle2ValueIndex - diff) {
                return;
            }
            const positionShift = position - this._handle1Position;
            this._handle1Position = position;
            this._handle2Position = this._handle2Position + positionShift;
            this._handle1Value = value;
            this._handle2Value = this._valuesBySteps[handle2ValueIndex - diff];
        }
        this._rangeProgress = Math.abs(this._handle2Position - this._handle1Position);
    }
    /** @hidden */
    _constructRangeModelValue() {
        let rangeLowerValue;
        let rangeHigherValue;
        let rangeValue = [
            Math.min(this._handle1Value, this._handle2Value),
            Math.max(this._handle1Value, this._handle2Value)
        ];
        rangeLowerValue = rangeValue[0];
        rangeHigherValue = rangeValue[1];
        if (this.customValues.length > 0) {
            const min = this.customValues[rangeValue[0]] || this.customValues[0];
            const max = this.customValues[rangeValue[1]] || this.customValues[this.customValues.length - 1];
            rangeValue = [min, max];
            rangeLowerValue = rangeValue[0].label;
            rangeHigherValue = rangeValue[1].label;
        }
        this._liveAnnouncer.announce('range value between ' + rangeLowerValue + ' and ' + rangeHigherValue, 'polite');
        return rangeValue;
    }
    /** @hidden */
    _attachResizeListener() {
        fromEvent(window, 'resize')
            .pipe(debounceTime(500), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => this._onResize());
    }
    /** @hidden */
    _onResize() {
        this._constructTickMarks();
        this._cdr.markForCheck();
    }
    /** @hidden */
    _constructValuesBySteps() {
        try {
            this._valuesBySteps = Array.from({
                length: (this.max - this.min) / this.step + 1
            }, (_, i) => Number((this.min + i * this.step).toFixed(2)));
        }
        catch { }
    }
    /** @hidden */
    _constructTickMarks() {
        if (!this.showTicks) {
            this._tickMarks = [];
            return;
        }
        if (this.customValues.length) {
            this.min = 0;
            this.max = this.customValues.length - 1;
            this.step = 1;
            const customValuesLength = this.customValues.length - 1;
            this._tickMarks = this.customValues.map((item, i) => ({
                ...item,
                position: (100 / customValuesLength) * i
            }));
        }
        else {
            const total = this.max - this.min;
            const tickMarksCount = total / this.step + 1;
            if (this._maxTickMarksNumber !== undefined && tickMarksCount > this._maxTickMarksNumber) {
                this._tickMarks = [
                    {
                        position: 0,
                        value: 0,
                        label: `${this.min}`
                    },
                    {
                        position: 100,
                        value: total,
                        label: `${this.max}`
                    }
                ];
                return;
            }
            if (tickMarksCount % 1 === 0) {
                this._tickMarks = Array.from({
                    length: tickMarksCount
                }, (_, i) => {
                    const value = Math.round(i * this.step * 100) / 100;
                    const position = (value / (this.max - this.min)) * 100;
                    return {
                        value,
                        position,
                        label: `${this.min + value}`
                    };
                });
            }
        }
    }
    /** @hidden */
    get _maxTickMarksNumber() {
        if (!this.trackEl || !this.trackEl.nativeElement) {
            return;
        }
        const { width, height } = this.trackEl.nativeElement.getBoundingClientRect();
        return Math.floor((this.vertical ? height : width) / MIN_DISTANCE_BETWEEN_TICKS);
    }
    /** @hidden */
    _calcProgress(value, skipRtl = false) {
        let progress = ((value - this.min) / (this.max - this.min)) * 100;
        if (!skipRtl && this._rtl$()) {
            progress = 100 - progress;
        }
        if (progress > 100) {
            return 100;
        }
        if (progress < 0) {
            return 0;
        }
        return progress;
    }
    /** @hidden */
    _recalcHandlePositions() {
        if (this._isRange) {
            this._handle1Position = this._calcProgress(this._handle1Value);
            this._handle2Position = this._calcProgress(this._handle2Value);
            this._rangeProgress = Math.abs(this._handle2Position - this._handle1Position);
        }
        this._progress = this._calcProgress(this._position, true);
    }
    /** @hidden */
    _checkIsInRangeMode() {
        this._isRange = this.mode === 'range';
    }
    /** @hidden */
    _initSingeMode(value) {
        if (this.customValues.length > 0) {
            this._initSingeModeWithCustomValue(value);
            return;
        }
        this._initSingeModeDefault(coerceNumberProperty(value, this.min));
    }
    /** @hidden */
    _initSingeModeDefault(value) {
        this._position = value;
        this._progress = this._calcProgress(value, true);
    }
    /** @hidden */
    _initSingeModeWithCustomValue(sliderTickMark) {
        const value = this._getCustomValuesPosition(sliderTickMark) || this.min;
        this._initSingeModeDefault(value);
    }
    /** @hidden */
    _initRangeMode(value) {
        if (this.customValues.length > 0) {
            this._initRangeModeWithCustomValues(value);
            return;
        }
        const firstHandle = coerceNumberProperty(value[0], this.min);
        const secondHandle = coerceNumberProperty(value[1], this.max);
        this._initRangeModeDefault([firstHandle, secondHandle]);
    }
    /** @hidden */
    _initRangeModeDefault([firstHandle, secondHandle]) {
        this._position = [firstHandle, secondHandle];
        this._setRangeHandleValueAndPosition(SliderRangeHandles.First, firstHandle);
        this._setRangeHandleValueAndPosition(SliderRangeHandles.Second, secondHandle);
    }
    /** @hidden */
    _initRangeModeWithCustomValues([firstHandle, secondHandle]) {
        const value = this._getCustomValuesPosition([firstHandle, secondHandle]) || [this.min, this.max];
        this._initRangeModeDefault(value);
    }
    /** @hidden */
    _getCustomValuesPosition(value) {
        this.min = 0;
        this.max = this.customValues.length - 1;
        this.step = 1;
        return this._getCustomValuesPositions(value);
    }
    /** @hidden */
    _getCustomValuesPositions(value) {
        if (!value || value.length === 0) {
            return this._isRange ? [0, this.customValues.length - 1] : 0;
        }
        if (Array.isArray(value)) {
            let [firstHandle, secondHandle] = value;
            if (!this._instanceOfCustomValue(firstHandle)) {
                firstHandle = this.customValues[0];
            }
            if (!this._instanceOfCustomValue(secondHandle)) {
                secondHandle = this.customValues[this.customValues.length - 1];
            }
            const firstHandlePosition = this.customValues.findIndex((item) => item.value === firstHandle.value);
            const secondHandlePosition = this.customValues.findIndex((item) => item.value === secondHandle.value);
            const indexes = [
                firstHandlePosition >= 0 ? firstHandlePosition : 0,
                secondHandlePosition >= 0 ? secondHandlePosition : this.customValues.length - 1
            ];
            return indexes;
        }
        else {
            let firstHandle = value;
            if (!this._instanceOfCustomValue(firstHandle)) {
                firstHandle = this.customValues[0];
            }
            return this.customValues.findIndex((item) => item.value === firstHandle.value) || 0;
        }
    }
    /** @hidden */
    _instanceOfCustomValue(object) {
        return !!object && 'value' in object && 'label' in object;
    }
    /** @hidden */
    _listenToInteractionChanges() {
        combineLatest([
            this._handleFocused$,
            this._rangeHandle1Focused$,
            this._rangeHandle2Focused$,
            this._popoverInputFieldFocused$,
            this._componentHovered$,
            this._popoverInputFieldHovered$
        ])
            .pipe(skip(1), map((states) => states.some(Boolean)), switchMap((focused) => {
            if (focused) {
                return of(true);
            }
            // If not focused, check for the edge case,
            // when hover is on the fd-popover-body, that is a parent for the tooltip.
            // This will return true, when hovering the gap between handle and the tooltip.
            return this._isPopoverHovered();
        }), debounceTime(10), distinctUntilChanged(), takeUntilDestroyed(this._destroyRef))
            .subscribe((focused) => {
            if (focused) {
                this._popovers.forEach((popover) => popover.open());
            }
            else {
                this._resetPrefix();
                this._popovers.forEach((popover) => popover.close());
            }
        });
    }
    /** @hidden reset default prefix on leaving the slider */
    _resetPrefix() {
        // reset prefix string for slider current value that need to be announced
        this._useSliderValuePrefix = true;
        this._cdr.markForCheck();
    }
    /**
     * @hidden
     * Checks whether input popover element is hovered.
     * Will also return true, when hovering the gap between handle and the tooltip.
     * If yes, returns "true" instantly and "false" once it's not hovered anymore.
     */
    _isPopoverHovered() {
        const popoverBody = this._sliderTooltipWrappers.first?.nativeElement.closest('fd-popover-body');
        if (popoverBody?.matches(':hover')) {
            return fromEvent(popoverBody, 'mouseleave').pipe(mapTo(false), take(1), startWith(true));
        }
        return of(false);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SliderComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: i0.Renderer2 }, { token: i1$1.Platform }, { token: i2.LiveAnnouncer }, { token: i1.RtlService, optional: true }, { token: i4.ContentDensityObserver }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: SliderComponent, isStandalone: true, selector: "fd-slider", inputs: { id: "id", class: "class", ariaLabelledBy: "ariaLabelledBy", ariaLabel: "ariaLabel", min: "min", max: "max", step: "step", jump: "jump", tickmarksBetweenLabels: "tickmarksBetweenLabels", mode: "mode", showTicks: "showTicks", showTicksLabels: "showTicksLabels", customValues: "customValues", tooltipMode: "tooltipMode", hideProgressBar: "hideProgressBar", disabled: "disabled", vertical: "vertical", value: "value" }, host: { listeners: { "mouseenter": "this._componentHovered$.next(true)", "mouseleave": "this._componentHovered$.next(false)", "focusout": "onTouched()" }, properties: { "attr.id": "this.id", "class.fd-slider--range": "this._isRange" } }, providers: [
            SLIDER_VALUE_ACCESSOR,
            registerFormItemControl(SliderComponent),
            contentDensityObserverProviders({
                defaultContentDensity: ContentDensityMode.COMPACT,
                modifiers: {
                    [ContentDensityMode.COZY]: 'fd-slider--lg'
                }
            })
        ], viewQueries: [{ propertyName: "trackEl", first: true, predicate: ["track"], descendants: true, read: ElementRef, static: true }, { propertyName: "handle", first: true, predicate: ["handle"], descendants: true, read: ElementRef }, { propertyName: "rangeHandle1", first: true, predicate: ["rangeHandle1"], descendants: true, read: ElementRef }, { propertyName: "rangeHandle2", first: true, predicate: ["rangeHandle2"], descendants: true, read: ElementRef }, { propertyName: "_rangeGroupHandle", first: true, predicate: ["rangeGroupHandle"], descendants: true, read: ElementRef }, { propertyName: "_popovers", predicate: PopoverComponent, descendants: true }, { propertyName: "_sliderTooltipWrappers", predicate: ["sliderTooltipWrapper"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div class=\"fd-slider__inner\">\n    <ng-template [ngTemplateOutlet]=\"_isRange ? rangeMode : singleMode\"></ng-template>\n    <div class=\"fd-slider__track\" (click)=\"onTrackClick($event)\" #track>\n        <ng-template [ngTemplateOutlet]=\"_isRange ? rangeModeTrack : singleModeTrack\"></ng-template>\n    </div>\n    <div class=\"fd-slider__tick-wrapper\">\n        <div class=\"fd-slider__ticks\" (click)=\"onTrackClick($event)\">\n            @if (showTicks) {\n                @for (tick of _tickMarks; track tick; let i = $index) {\n                    <div\n                        class=\"fd-slider__tick\"\n                        fd-slider-position\n                        [vertical]=\"vertical\"\n                        [position]=\"tick.position || 0\"\n                        [class.fd-slider__tick--in-range]=\"\n                            !hideProgressBar &&\n                            (_isRange\n                                ? tick.value >= _position[0] && tick.value <= _position[1]\n                                : tick.value <= _position)\n                        \"\n                    ></div>\n                }\n            }\n        </div>\n        @if (showTicks && showTicksLabels) {\n            <div class=\"fd-slider__labels\">\n                @for (tick of _tickMarks; track tick; let i = $index; let last = $last; let first = $first) {\n                    @if (first || last || i % tickmarksBetweenLabels === 0) {\n                        <div\n                            class=\"fd-slider__label\"\n                            fd-slider-position\n                            [vertical]=\"vertical\"\n                            [position]=\"tick.position || 0\"\n                        >\n                            {{ tick.label }}\n                        </div>\n                    }\n                }\n            </div>\n        }\n    </div>\n</div>\n<ng-template #singleModeTrack>\n    @if (!hideProgressBar) {\n        <div\n            class=\"fd-slider__track-range\"\n            [style.height.%]=\"vertical ? _progress : null\"\n            [style.width.%]=\"vertical ? null : _progress\"\n        ></div>\n    }\n</ng-template>\n<ng-template #rangeModeTrack>\n    @if (!hideProgressBar) {\n        <div\n            class=\"fd-slider__track-range\"\n            [style.height.%]=\"vertical ? _rangeProgress : null\"\n            [style.width.%]=\"vertical ? null : _rangeProgress\"\n            fd-slider-position\n            [vertical]=\"vertical\"\n            [position]=\"_handle1Position < _handle2Position ? _handle1Position : _handle2Position\"\n        >\n            <div\n                class=\"fd-slider__track-focus-range\"\n                (mousedown)=\"onHandleClick($event, true)\"\n                (keydown)=\"onKeyDown($event, _handles.Both)\"\n                tabindex=\"0\"\n                #rangeGroupHandle\n            ></div>\n        </div>\n    }\n</ng-template>\n<ng-template #singleMode>\n    <div\n        #handle\n        class=\"fd-slider__handle\"\n        [class.fd-slider__handle--lg]=\"_contentDensityObserver.isCozySignal()\"\n        [attr.tabindex]=\"disabled ? -1 : 0\"\n        role=\"slider\"\n        [attr.aria-label]=\"\n            ariaLabel || ('coreSlider.singleMinMaxDetails' | fdTranslate: { min: minValue, max: maxValue })\n        \"\n        [attr.aria-labelledby]=\"ariaLabelledBy\"\n        [fdPopoverTrigger]=\"tooltipMode ? singleSliderPopover : null\"\n        [attr.aria-valuemin]=\"'coreSlider.singleValueminDetails' | fdTranslate: { value: minValue }\"\n        [attr.aria-valuemax]=\"'coreSlider.singleValuemaxDetails' | fdTranslate: { value: maxValue }\"\n        [attr.aria-valuenow]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.singleValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_position, _sliderValueTargets.SINGLE_SLIDER) })\n                : getValuenow(_position, _sliderValueTargets.SINGLE_SLIDER)\n        \"\n        [attr.aria-valuetext]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.singleValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_position, _sliderValueTargets.SINGLE_SLIDER) })\n                : getValuenow(_position, _sliderValueTargets.SINGLE_SLIDER)\n        \"\n        fd-slider-position\n        [vertical]=\"vertical\"\n        [position]=\"_progress\"\n        (mousedown)=\"onHandleClick($event); $event.stopPropagation()\"\n        (focus)=\"_handleFocused$.next(true)\"\n        (blur)=\"_handleFocused$.next(false)\"\n        (keydown)=\"onKeyDown($event)\"\n    ></div>\n    <fd-popover\n        #singleSliderPopover\n        [triggers]=\"[]\"\n        [closeOnOutsideClick]=\"false\"\n        [appendTo]=\"handle\"\n        [disabled]=\"!tooltipMode\"\n        class=\"fd-popover--slider\"\n        additionalBodyClass=\"fd-slider-tooltip-popover\"\n        placement=\"top\"\n    >\n        <ng-template\n            [ngTemplateOutlet]=\"popoverInner\"\n            [ngTemplateOutletContext]=\"{ target: _sliderValueTargets.SINGLE_SLIDER, position: _position }\"\n        ></ng-template>\n    </fd-popover>\n</ng-template>\n<ng-template #rangeMode>\n    <div\n        #rangeHandle1\n        class=\"fd-slider__handle\"\n        [class.fd-slider__handle--lg]=\"_contentDensityObserver.isCozySignal()\"\n        [attr.tabindex]=\"disabled ? -1 : 0\"\n        role=\"slider\"\n        [attr.aria-label]=\"\n            ariaLabel || ('coreSlider.multipleHandle1MinMaxDetails' | fdTranslate: { min: minValue, max: maxValue })\n        \"\n        [attr.aria-labelledby]=\"ariaLabelledBy\"\n        [fdPopoverTrigger]=\"tooltipMode ? rangeSliderPopover1 : null\"\n        [attr.aria-valuemin]=\"'coreSlider.multipleHandle1ValueminDetails' | fdTranslate: { value: minValue }\"\n        [attr.aria-valuemax]=\"'coreSlider.multipleHandle1ValuemaxDetails' | fdTranslate: { value: maxValue }\"\n        [attr.aria-valuenow]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.multipleHandle1ValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_handle1Value, _sliderValueTargets.RANGE_SLIDER1) })\n                : getValuenow(_handle1Value, _sliderValueTargets.RANGE_SLIDER1)\n        \"\n        [attr.aria-valuetext]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.multipleHandle1ValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_handle1Value, _sliderValueTargets.RANGE_SLIDER1) })\n                : getValuenow(_handle1Value, _sliderValueTargets.RANGE_SLIDER1)\n        \"\n        fd-slider-position\n        [vertical]=\"vertical\"\n        [position]=\"_handle1Position\"\n        (mousedown)=\"onHandleClick($event); $event.stopPropagation()\"\n        (keydown)=\"onKeyDown($event, _handles.First)\"\n        (focus)=\"_rangeHandle1Focused$.next(true)\"\n        (blur)=\"_rangeHandle1Focused$.next(false)\"\n    ></div>\n    <div\n        #rangeHandle2\n        class=\"fd-slider__handle\"\n        [class.fd-slider__handle--lg]=\"_contentDensityObserver.isCozySignal()\"\n        [attr.tabindex]=\"disabled ? -1 : 0\"\n        role=\"slider\"\n        [attr.aria-label]=\"\n            ariaLabel || ('coreSlider.multipleHandle2MinMaxDetails' | fdTranslate: { min: minValue, max: maxValue })\n        \"\n        [attr.aria-labelledby]=\"ariaLabelledBy\"\n        [fdPopoverTrigger]=\"tooltipMode ? rangeSliderPopover2 : null\"\n        [attr.aria-valuemin]=\"'coreSlider.multipleHandle2ValueminDetails' | fdTranslate: { value: minValue }\"\n        [attr.aria-valuemax]=\"'coreSlider.multipleHandle2ValuemaxDetails' | fdTranslate: { value: maxValue }\"\n        [attr.aria-valuenow]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.multipleHandle2ValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_handle2Value, _sliderValueTargets.RANGE_SLIDER2) })\n                : getValuenow(_handle2Value, _sliderValueTargets.RANGE_SLIDER2)\n        \"\n        [attr.aria-valuetext]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.multipleHandle2ValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_handle2Value, _sliderValueTargets.RANGE_SLIDER2) })\n                : getValuenow(_handle2Value, _sliderValueTargets.RANGE_SLIDER2)\n        \"\n        fd-slider-position\n        [vertical]=\"vertical\"\n        [position]=\"_handle2Position\"\n        (mousedown)=\"onHandleClick($event); $event.stopPropagation()\"\n        (keydown)=\"onKeyDown($event, _handles.Second)\"\n        (focus)=\"_rangeHandle2Focused$.next(true)\"\n        (blur)=\"_rangeHandle2Focused$.next(false)\"\n    ></div>\n    <fd-popover\n        #rangeSliderPopover1\n        [triggers]=\"[]\"\n        [closeOnOutsideClick]=\"false\"\n        [appendTo]=\"rangeHandle1\"\n        [disabled]=\"!tooltipMode\"\n        additionalBodyClass=\"fd-slider-tooltip-popover\"\n        class=\"fd-popover--slider\"\n        placement=\"top\"\n    >\n        <ng-template\n            [ngTemplateOutlet]=\"popoverInner\"\n            [ngTemplateOutletContext]=\"{ target: _sliderValueTargets.RANGE_SLIDER1, position: _handle1Value }\"\n        ></ng-template>\n    </fd-popover>\n    <fd-popover\n        #rangeSliderPopover2\n        [triggers]=\"[]\"\n        [closeOnOutsideClick]=\"false\"\n        [appendTo]=\"rangeHandle2\"\n        [disabled]=\"!tooltipMode\"\n        additionalBodyClass=\"fd-slider-tooltip-popover\"\n        class=\"fd-popover--slider\"\n        placement=\"top\"\n    >\n        <ng-template\n            [ngTemplateOutlet]=\"popoverInner\"\n            [ngTemplateOutletContext]=\"{ target: _sliderValueTargets.RANGE_SLIDER2, position: _handle2Value }\"\n        ></ng-template>\n    </fd-popover>\n</ng-template>\n<ng-template #popoverInner let-target=\"target\" let-position=\"position\">\n    <div\n        #sliderTooltipWrapper\n        class=\"fd-slider-tooltip-wrapper\"\n        (click)=\"$event.stopPropagation()\"\n        (keydown)=\"$event.stopPropagation()\"\n        (mouseenter)=\"_popoverInputFieldHovered$.next(true)\"\n        (mouseleave)=\"_popoverInputFieldHovered$.next(false)\"\n    >\n        @if ((customValues && customValues.length > 0) || tooltipMode === 'readonly') {\n            <div class=\"fd-slider-tooltip\">\n                {{ customValues && customValues.length > 0 ? customValues[position].label : _popoverValueRef[target] }}\n            </div>\n        }\n        @if (customValues.length === 0 && tooltipMode === 'editable') {\n            <input\n                #popoverInputField\n                tabindex=\"-1\"\n                type=\"text\"\n                [disabled]=\"disabled\"\n                fdkOnlyDigits\n                [decimal]=\"true\"\n                [style.width.ch]=\"('' + _popoverValueRef[target]).length + 2\"\n                class=\"fd-input fd-slider-tooltip {{ _popoverInputFieldClass }}\"\n                [(ngModel)]=\"_popoverValueRef[target]\"\n                (blur)=\"_updateValueFromInput(popoverInputField.value, target)\"\n                (keydown.enter)=\"_updateValueFromInput(popoverInputField.value, target)\"\n                (focus)=\"_popoverInputFieldFocused$.next(true)\"\n                (blur)=\"_popoverInputFieldFocused$.next(false)\"\n            />\n        }\n    </div>\n</ng-template>\n", styles: [".fd-slider{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;min-width:4rem;padding-block:0;padding-block:1rem;padding-inline:0;padding-inline:calc(var(--fdSlider_Handle_Width)*.5 + .125rem);position:relative}.fd-slider:after,.fd-slider:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider.is-disabled,.fd-slider:disabled,.fd-slider[aria-disabled=true]{cursor:not-allowed}.fd-slider--lg{--fdSlider_Handle_Width:var(--fdSlider_Mobile_Handle_Width);--fdSlider_Handle_Height:var(--fdSlider_Mobile_Handle_Height);--fdSlider_Handle_Active_Width:var(--fdSlider_Mobile_Handle_Active_Size);--fdSlider_Handle_Active_Height:var(--fdSlider_Mobile_Handle_Active_Size);padding-inline:calc(var(--fdSlider_Mobile_Handle_Width)*.5 + .125rem)}.fd-slider__inner{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-slider__inner:after,.fd-slider__inner:before{background-color:var(--fdSlider_Endpoint_Active_Background);border:0;border:var(--fdSlider_Endpoint_Active_Border);border-radius:50%;-webkit-box-sizing:inherit;box-sizing:inherit;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);content:\"\";font-family:var(--sapFontFamily);font-size:inherit;font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdSlider_Endpoint_Size);left:-.7rem;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:absolute;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%);width:var(--fdSlider_Endpoint_Size)}.fd-slider__inner:after:after,.fd-slider__inner:after:before,.fd-slider__inner:before:after,.fd-slider__inner:before:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__inner:after{left:auto;right:-.7rem}.fd-slider:not(.fd-slider--vertical,.fd-slider--range) .fd-slider__inner[dir=rtl]:before,.fd-slider__inner:after,[dir=rtl] .fd-slider:not(.fd-slider--vertical,.fd-slider--range) .fd-slider__inner:before{background-color:var(--fdSlider_Endpoint_Background);border:var(--fdSlider_Endpoint_Border)}.fd-slider:not(.fd-slider--vertical,.fd-slider--range) .fd-slider__inner[dir=rtl]:after,[dir=rtl] .fd-slider:not(.fd-slider--vertical,.fd-slider--range) .fd-slider__inner:after{background-color:var(--fdSlider_Endpoint_Active_Background);border:var(--fdSlider_Endpoint_Active_Border)}.fd-slider__track{background-color:var(--fdSlider_Track_Background);border:0;border-radius:var(--fdSlider_Track_BorderRadius);-webkit-box-shadow:inset 0 0 0 var(--fdSlider_Track_Border_Width) var(--fdSlider_Track_Border_Color);box-shadow:inset 0 0 0 var(--fdSlider_Track_Border_Width) var(--fdSlider_Track_Border_Color);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdSlider_Track_Height);line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative;width:100%;z-index:1}.fd-slider__track:after,.fd-slider__track:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__track .fd-slider__handle.is-focus,.fd-slider__track .fd-slider__handle:focus{z-index:5;z-index:2;-webkit-touch-callout:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.fd-slider__track-range{background-color:var(--fdSlider_Track_Active_Background);border:0;border:.0625rem solid var(--fdSlider_Track_Active_Border);border-radius:.25rem;-webkit-box-shadow:var(--fdSlider_Track_Active_Box_Shadow);box-shadow:var(--fdSlider_Track_Active_Box_Shadow);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:100%;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-slider__track-range:after,.fd-slider__track-range:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__tick-wrapper{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:absolute;top:calc((var(--fdSlider_Track_Height) - var(--fdSlider_Tick_Height))/2);width:100%;z-index:2}.fd-slider__tick-wrapper:after,.fd-slider__tick-wrapper:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__ticks{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-ms-flex-pack:justify;height:var(--fdSlider_Tick_Height);justify-content:space-between}.fd-slider__ticks:after,.fd-slider__ticks:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__labels{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-ms-flex-pack:justify;height:1rem;justify-content:space-between;position:relative;top:.5rem}.fd-slider__labels:after,.fd-slider__labels:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__tick{border:0;border-left:.0625rem solid var(--fdSlider_Tick_Background);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdSlider_Tick_Height);line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-slider__tick:after,.fd-slider__tick:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__tick--in-range{border-color:var(--fdSlider_Active_Tick_Background)}.fd-slider__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_LabelColor);font-size:var(--sapFontSmallSize);position:relative;width:0}.fd-slider__label:after,.fd-slider__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__handle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:var(--fdSlider_Handle_Background);border:var(--fdSlider_Handle_Border);border-radius:var(--fdSlider_Handle_Border_Radius);cursor:pointer;height:var(--fdSlider_Handle_Height);position:absolute;top:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);width:var(--fdSlider_Handle_Width);z-index:3}.fd-slider__handle:after,.fd-slider__handle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__handle:before{content:\"\";height:var(--fdSlider_Handle_Active_Height);left:50%;position:absolute;top:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);width:var(--fdSlider_Handle_Active_Width)}.fd-slider__handle:after{color:var(--sapContent_Selected_ForegroundColor);content:\"\\e29c\";display:var(--fdSlider_Handle_Icon_Display);font-family:SAP-icons;font-size:.875rem;line-height:1}.fd-slider__handle.is-focus,.fd-slider__handle:focus{background-color:var(--fdSlider_Focus_Handle_Background);border:var(--fdSlider_Focus_Handle_Border);outline:none;z-index:5}.fd-slider__handle.is-focus:after,.fd-slider__handle:focus:after{display:none}.fd-slider__handle.is-hover,.fd-slider__handle:hover{background-color:var(--fdSlider_Hover_Handle_Background);border:var(--fdSlider_Hover_Handle_Border);border-color:var(--fdSlider_Handle_Border_Hover_Color)}.fd-slider__handle.is-hover.is-focus,.fd-slider__handle.is-hover:focus,.fd-slider__handle:hover.is-focus,.fd-slider__handle:hover:focus{background-color:var(--fdSlider_Focus_Handle_Background);border:var(--fdSlider_Focus_Handle_Border);outline:none;z-index:5}.fd-slider__handle.is-hover.is-focus:after,.fd-slider__handle.is-hover:focus:after,.fd-slider__handle:hover.is-focus:after,.fd-slider__handle:hover:focus:after{display:none}.fd-slider__handle.is-active,.fd-slider__handle:active{background-color:var(--fdSlider_Active_Handle_Background);border:var(--fdSlider_Active_Handle_Border)}.fd-slider__handle.is-active.is-focus,.fd-slider__handle.is-active:focus,.fd-slider__handle:active.is-focus,.fd-slider__handle:active:focus{background-color:var(--fdSlider_Focus_Handle_Background);border:var(--fdSlider_Focus_Handle_Border);outline:none;z-index:5}.fd-slider__handle.is-active.is-focus:after,.fd-slider__handle.is-active:focus:after,.fd-slider__handle:active.is-focus:after,.fd-slider__handle:active:focus:after{display:none}.fd-slider__track-focus-range{border:0;border-radius:var(--fdSlider_Range_Track_Border_Radius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:calc(var(--fdSlider_Handle_Height) + .5rem);left:0;line-height:normal;margin-block:0;margin-inline:0;margin-inline:calc(var(--fdSlider_Handle_Height)*-1/1.1);padding-block:0;padding-inline:0;position:absolute;right:0;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.fd-slider__track-focus-range:after,.fd-slider__track-focus-range:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__track-focus-range.is-focus,.fd-slider__track-focus-range:focus{outline:var(--fdSlider_Focus_Range_Outline);z-index:5}.fd-slider--range .fd-slider__inner:after,.fd-slider--range .fd-slider__inner:before{background-color:var(--fdSlider_Endpoint_Background);border:var(--fdSlider_Endpoint_Border)}.fd-slider--range .fd-slider__inner .fd-slider__handle{background-color:var(--fdSlider_Range_Handle_Background);border:var(--fdSlider_Range_Handle_Border)}.fd-slider--range .fd-slider__inner .fd-slider__handle.is-hover,.fd-slider--range .fd-slider__inner .fd-slider__handle:hover{background-color:var(--fdSlider_Range_Hover_Handle_Background);border-color:var(--fdSlider_Range_Hover_Handle_Border_Color)}.fd-slider--range .fd-slider__inner .fd-slider__handle.is-active,.fd-slider--range .fd-slider__inner .fd-slider__handle:active{background-color:var(--fdSlider_Range_Active_Handle_Background);border-color:var(--fdSlider_Range_Active_Handle_Border_Color)}.fd-slider--range .fd-slider__inner .fd-slider__handle.is-active:after,.fd-slider--range .fd-slider__inner .fd-slider__handle:active:after{display:var(--fdSlider_Focus_Handle_Display)}.fd-slider--range .fd-slider__inner .fd-slider__handle.is-focus,.fd-slider--range .fd-slider__inner .fd-slider__handle:focus{background-color:var(--fdSlider_Range_Focus_Handle_Background);border:var(--fdSlider_Range_Focus_Handle_Border);z-index:5}.fd-slider--range .fd-slider__inner .fd-slider__handle.is-focus:after,.fd-slider--range .fd-slider__inner .fd-slider__handle:focus:after{display:var(--fdSlider_Focus_Handle_Display)}.fd-slider--vertical{height:100%}.fd-slider--vertical .fd-slider__inner{height:100%;width:var(--fdSlider_Track_Height)}.fd-slider--vertical .fd-slider__inner:after,.fd-slider--vertical .fd-slider__inner:before{left:50%;right:auto;top:auto;-webkit-transform:translateX(-50%);transform:translate(-50%)}.fd-slider--vertical .fd-slider__inner:before{bottom:-.7rem}.fd-slider--vertical .fd-slider__inner:after{top:-.7rem}.fd-slider--vertical .fd-slider__track{height:100%;width:var(--fdSlider_Track_Height)}.fd-slider--vertical .fd-slider__track-range{bottom:0;position:absolute;width:100%}.fd-slider--vertical .fd-slider__handle{bottom:0;height:var(--fdSlider_Handle_Width);left:50%;top:auto;-webkit-transform:translate(-50%,50%);transform:translate(-50%,50%);width:var(--fdSlider_Handle_Height)}.fd-slider--vertical .fd-slider__handle:after{-webkit-transform:rotate(90deg);transform:rotate(90deg)}.fd-slider--vertical .fd-slider__tick-wrapper{height:100%;left:calc((var(--fdSlider_Track_Height) - var(--fdSlider_Tick_Height))/2);right:calc((var(--fdSlider_Track_Height) - var(--fdSlider_Tick_Height))/2);top:0}.fd-slider--vertical .fd-slider__ticks{-webkit-box-orient:vertical;-webkit-box-direction:reverse;-ms-flex-direction:column-reverse;flex-direction:column-reverse;height:100%}.fd-slider--vertical .fd-slider__tick{border-left:none;border-top-style:solid;border-top-width:.0625rem;height:0;width:var(--fdSlider_Tick_Height)}.fd-slider--vertical .fd-slider__labels{height:100%;position:absolute;top:-.55rem;-webkit-box-orient:vertical;-webkit-box-direction:reverse;-ms-flex-direction:column-reverse;flex-direction:column-reverse;left:calc(var(--fdSlider_Handle_Width)*.5 + .125rem)}.fd-slider--vertical .fd-slider__labels[dir=rtl],[dir=rtl] .fd-slider--vertical .fd-slider__labels{left:auto;right:calc(var(--fdSlider_Handle_Width)*.5 + .125rem)}.fd-slider--vertical .fd-slider__label{height:.0625rem;width:auto}.fd-slider--vertical.fd-slider--range .fd-slider__track-range{left:0}.fd-slider--vertical.fd-slider--range .fd-slider__track-focus-range{height:auto;inset:0 auto 0 50%;margin-block:calc(var(--fdSlider_Handle_Height)*-1/1.1);margin-inline:0;-webkit-transform:translateX(-50%);transform:translate(-50%);width:calc(var(--fdSlider_Handle_Height) + .5rem)}.fd-slider-tooltip-popover.fd-popover__body{background:var(--sapBackgroundColor);border:none;border-radius:.0625rem;-webkit-box-shadow:var(--sapContent_Shadow1);box-shadow:var(--sapContent_Shadow1);height:1rem;overflow:hidden;padding-block:0;padding-inline:.5rem;top:-.4375rem!important}.fd-slider-tooltip-popover.fd-popover__body .fd-slider-tooltip{color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSmallSize);line-height:1rem;text-align:center}.fd-slider-tooltip-popover.fd-popover__body:has(input){-webkit-box-shadow:none;box-shadow:none;height:auto;padding-inline:0;width:auto}.fd-input{-webkit-appearance:none;-moz-appearance:none;appearance:none;background:var(--sapField_BackgroundStyle,var(--sapField_BackgroundStyle));background-color:var(--sapField_Background,var(--sapField_Background));border:0;border:var(--sapField_BorderWidth) var(--sapField_BorderStyle) var(--sapField_BorderColor);border-radius:var(--sapField_BorderCornerRadius);-webkit-box-shadow:var(--sapField_Shadow);box-shadow:var(--sapField_Shadow);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapField_TextColor);cursor:text;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdInput_Height,var(--sapElement_Height));line-height:normal;margin-block:0;margin-block:var(--fdInput_Field_Margin_Block,.25rem);margin-inline:0;min-height:var(--fdInput_Height,var(--sapElement_Height));min-width:2.75rem;outline:none;overflow:hidden;padding-block:0;padding-inline:0;padding-inline:var(--fdInput_Field_Padding_Inline,.625rem);text-overflow:ellipsis;text-shadow:var(--fdInput_Text_Shadow);white-space:nowrap;width:100%;z-index:1}.fd-input:after,.fd-input:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-input::-webkit-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:var(--fdPlaceholder_Font_Style)}.fd-input::-moz-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:var(--fdPlaceholder_Font_Style)}.fd-input:-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:var(--fdPlaceholder_Font_Style)}.fd-input::-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:var(--fdPlaceholder_Font_Style)}.fd-input::placeholder{color:var(--sapField_PlaceholderTextColor);font-style:var(--fdPlaceholder_Font_Style)}.fd-input[dir=rtl]::-webkit-input-placeholder,[dir=rtl] .fd-input::-webkit-input-placeholder{text-indent:.125rem}.fd-input[dir=rtl]::-moz-placeholder,[dir=rtl] .fd-input::-moz-placeholder{text-indent:.125rem}.fd-input[dir=rtl]:-ms-input-placeholder,[dir=rtl] .fd-input:-ms-input-placeholder{text-indent:.125rem}.fd-input[dir=rtl]::-ms-input-placeholder,[dir=rtl] .fd-input::-ms-input-placeholder{text-indent:.125rem}.fd-input[dir=rtl]::placeholder,[dir=rtl] .fd-input::placeholder{text-indent:.125rem}.fd-input::-moz-selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-input::selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-input::-ms-clear{display:none}.fd-input.is-hover,.fd-input:hover{background:var(--sapField_Hover_BackgroundStyle,var(--sapField_Hover_BackgroundStyle));background-color:var(--sapField_Hover_Background,var(--sapField_Hover_Background));border-color:var(--sapField_Hover_BorderColor);-webkit-box-shadow:var(--fdInput_Box_Shadow_Hover);box-shadow:var(--fdInput_Box_Shadow_Hover)}.fd-input.is-focus,.fd-input:focus{background:var(--sapField_Focus_Background,var(--sapField_Focus_Background));-webkit-box-shadow:none;box-shadow:none;outline:var(--fdInput_Outline_Color) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:var(--fdInput_Outline_Offset);z-index:5}.fd-input[type=search]::-webkit-search-cancel-button,.fd-input[type=search]::-webkit-search-decoration,.fd-input[type=search]::-webkit-search-results-button,.fd-input[type=search]::-webkit-search-results-decoration{-webkit-appearance:none;appearance:none}.fd-input[aria-expanded=false]{z-index:0}.fd-input.is-expanded,.fd-input[aria-expanded=true]{z-index:4}.fd-input[class*=-compact],.fd-input[class*=-condensed],[class*=-compact] .fd-input:not([class*=-cozy]),[class*=-condensed] .fd-input:not([class*=-cozy]){-webkit-box-sizing:border-box;box-sizing:border-box;height:var(--fdInput_Compact_Height,var(--sapElement_Compact_Height));margin-block:var(--fdInput_Field_Compact_Margin_Block,.1875rem);margin-inline:0;min-height:var(--fdInput_Compact_Height,var(--sapElement_Compact_Height));min-width:var(--fdInput_Field_Compact_Min_Width,2rem);padding-block:0;padding-inline:var(--fdInput_Field_Compact_Padding,.5rem)}.fd-input--no-number-spinner{-webkit-appearance:textfield;-moz-appearance:textfield;appearance:textfield}.fd-input--no-number-spinner::-webkit-inner-spin-button,.fd-input--no-number-spinner::-webkit-outer-spin-button{-webkit-appearance:none;appearance:none;margin-block:0;margin-inline:0}.fd-input.right-align{text-align:right}.fd-input.is-success{background:var(--sapField_SuccessBackgroundStyle);background-color:var(--sapField_SuccessBackground);border:var(--sapField_SuccessColor) var(--sapField_SuccessBorderWidth) var(--sapField_SuccessBorderStyle);-webkit-box-shadow:var(--sapField_SuccessShadow);box-shadow:var(--sapField_SuccessShadow)}.fd-input.is-success.is-hover,.fd-input.is-success:hover{background-color:var(--fdInput_Success_Background_Color_Hover);border-color:var(--sapField_SuccessColor);-webkit-box-shadow:var(--fdInput_Success_Box_Shadow_Hover);box-shadow:var(--fdInput_Success_Box_Shadow_Hover)}.fd-input.is-success.is-focus,.fd-input.is-success:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Success_Outline_Color);z-index:5}.fd-input.is-success.is-focus.is-hover,.fd-input.is-success.is-focus:hover,.fd-input.is-success:focus.is-hover,.fd-input.is-success:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-input.is-success.is-expanded,.fd-input.is-success[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Success_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-input.is-error{background:var(--sapField_InvalidBackgroundStyle);background-color:var(--sapField_InvalidBackground);border:var(--sapField_InvalidColor) var(--sapField_InvalidBorderWidth) var(--sapField_InvalidBorderStyle);-webkit-box-shadow:var(--sapField_InvalidShadow);box-shadow:var(--sapField_InvalidShadow)}.fd-input.is-error.is-hover,.fd-input.is-error:hover{background-color:var(--fdInput_Error_Background_Color_Hover);border-color:var(--sapField_InvalidColor);-webkit-box-shadow:var(--fdInput_Error_Box_Shadow_Hover);box-shadow:var(--fdInput_Error_Box_Shadow_Hover)}.fd-input.is-error.is-focus,.fd-input.is-error:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Error_Outline_Color);z-index:5}.fd-input.is-error.is-focus.is-hover,.fd-input.is-error.is-focus:hover,.fd-input.is-error:focus.is-hover,.fd-input.is-error:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-input.is-error.is-expanded,.fd-input.is-error[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Error_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-input.is-warning{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle);-webkit-box-shadow:var(--sapField_WarningShadow);box-shadow:var(--sapField_WarningShadow)}.fd-input.is-warning.is-hover,.fd-input.is-warning:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-input.is-warning.is-focus,.fd-input.is-warning:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-input.is-warning.is-focus.is-hover,.fd-input.is-warning.is-focus:hover,.fd-input.is-warning:focus.is-hover,.fd-input.is-warning:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-input.is-warning.is-expanded,.fd-input.is-warning[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-input.is-alert{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle)}.fd-input.is-alert.is-hover,.fd-input.is-alert:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-input.is-alert.is-focus,.fd-input.is-alert:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-input.is-alert.is-focus.is-hover,.fd-input.is-alert.is-focus:hover,.fd-input.is-alert:focus.is-hover,.fd-input.is-alert:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-input.is-alert.is-expanded,.fd-input.is-alert[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-input.is-information{background:var(--sapField_InformationBackgroundStyle);background-color:var(--sapField_InformationBackground);border:var(--sapField_InformationColor) var(--sapField_InformationBorderWidth) var(--sapField_InformationBorderStyle);-webkit-box-shadow:var(--sapField_InformationShadow);box-shadow:var(--sapField_InformationShadow)}.fd-input.is-information.is-hover,.fd-input.is-information:hover{background-color:var(--fdInput_Information_Background_Color_Hover);border-color:var(--sapField_InformationColor);-webkit-box-shadow:var(--fdInput_Information_Box_Shadow_Hover);box-shadow:var(--fdInput_Information_Box_Shadow_Hover)}.fd-input.is-information.is-focus,.fd-input.is-information:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Information_Outline_Color);z-index:5}.fd-input.is-information.is-focus.is-hover,.fd-input.is-information.is-focus:hover,.fd-input.is-information:focus.is-hover,.fd-input.is-information:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-input.is-information.is-expanded,.fd-input.is-information[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Information_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-input.is-alert,.fd-input.is-error,.fd-input.is-warning{font-style:var(--fdInput_State_Text_Style);font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert::-webkit-input-placeholder,.fd-input.is-error::-webkit-input-placeholder,.fd-input.is-warning::-webkit-input-placeholder{font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert::-moz-placeholder,.fd-input.is-error::-moz-placeholder,.fd-input.is-warning::-moz-placeholder{font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert:-ms-input-placeholder,.fd-input.is-error:-ms-input-placeholder,.fd-input.is-warning:-ms-input-placeholder{font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert::-ms-input-placeholder,.fd-input.is-error::-ms-input-placeholder,.fd-input.is-warning::-ms-input-placeholder{font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert::placeholder,.fd-input.is-error::placeholder,.fd-input.is-warning::placeholder{font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert.is-focus,.fd-input.is-alert:focus,.fd-input.is-error.is-focus,.fd-input.is-error:focus,.fd-input.is-information.is-focus,.fd-input.is-information:focus,.fd-input.is-warning.is-focus,.fd-input.is-warning:focus{outline-offset:var(--fdInput_Outline_Offset_States);z-index:5}.fd-input.is-error::-webkit-input-placeholder{color:var(--sapField_TextColor)}.fd-input.is-error::-moz-placeholder{color:var(--sapField_TextColor)}.fd-input.is-error:-ms-input-placeholder{color:var(--sapField_TextColor)}.fd-input.is-error::-ms-input-placeholder{color:var(--sapField_TextColor)}.fd-input.is-error::placeholder{color:var(--sapField_TextColor)}.fd-input.is-disabled,.fd-input:disabled,.fd-input[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-input.is-disabled::-webkit-input-placeholder,.fd-input:disabled::-webkit-input-placeholder,.fd-input[aria-disabled=true]::-webkit-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-disabled::-moz-placeholder,.fd-input:disabled::-moz-placeholder,.fd-input[aria-disabled=true]::-moz-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-disabled:-ms-input-placeholder,.fd-input:disabled:-ms-input-placeholder,.fd-input[aria-disabled=true]:-ms-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-disabled::-ms-input-placeholder,.fd-input:disabled::-ms-input-placeholder,.fd-input[aria-disabled=true]::-ms-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-disabled::placeholder,.fd-input:disabled::placeholder,.fd-input[aria-disabled=true]::placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly,.fd-input[aria-readonly=true],.fd-input[readonly]{--fdInput_Outline_Offset:-.25rem;background:var(--sapField_ReadOnly_BackgroundStyle);background-color:var(--sapField_ReadOnly_Background);border-color:var(--sapField_ReadOnly_BorderColor);-webkit-box-shadow:none;box-shadow:none}.fd-input.is-readonly::-webkit-input-placeholder,.fd-input[aria-readonly=true]::-webkit-input-placeholder,.fd-input[readonly]::-webkit-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly::-moz-placeholder,.fd-input[aria-readonly=true]::-moz-placeholder,.fd-input[readonly]::-moz-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly:-ms-input-placeholder,.fd-input[aria-readonly=true]:-ms-input-placeholder,.fd-input[readonly]:-ms-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly::-ms-input-placeholder,.fd-input[aria-readonly=true]::-ms-input-placeholder,.fd-input[readonly]::-ms-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly::placeholder,.fd-input[aria-readonly=true]::placeholder,.fd-input[readonly]::placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly.is-focus,.fd-input.is-readonly.is-hover,.fd-input.is-readonly:focus,.fd-input.is-readonly:hover,.fd-input[aria-readonly=true].is-focus,.fd-input[aria-readonly=true].is-hover,.fd-input[aria-readonly=true]:focus,.fd-input[aria-readonly=true]:hover,.fd-input[readonly].is-focus,.fd-input[readonly].is-hover,.fd-input[readonly]:focus,.fd-input[readonly]:hover{--fdInput_Outline_Offset:-.25rem;background:var(--sapField_ReadOnly_BackgroundStyle);background-color:var(--sapField_ReadOnly_Background);border-color:var(--sapField_ReadOnly_BorderColor);-webkit-box-shadow:none;box-shadow:none}.fd-input.is-readonly.is-focus,.fd-input.is-readonly:focus,.fd-input[aria-readonly=true].is-focus,.fd-input[aria-readonly=true]:focus,.fd-input[readonly].is-focus,.fd-input[readonly]:focus{z-index:5}.cdk-visually-hidden{border:0;clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;width:1px;white-space:nowrap;outline:0;-webkit-appearance:none;-moz-appearance:none;left:0}[dir=rtl] .cdk-visually-hidden{left:auto;right:0}.fd-popover--slider{display:block!important}.fd-popover__body.fd-slider-tooltip-popover{height:1rem;border:none;padding-block:0;overflow:hidden;padding-inline:.5rem;border-radius:.0625rem;top:-.4375rem!important;background:var(--sapBackgroundColor);box-shadow:var(--sapContent_Shadow1)}.fd-popover__body.fd-slider-tooltip-popover .fd-slider-tooltip{line-height:1rem;text-align:center;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSmallSize)}.fd-popover__body.fd-slider-tooltip-popover:has(input){width:auto;height:auto;box-shadow:none;padding-inline:0}.fd-slider{display:block}.fd-slider.fd-slider--with-labels{padding-bottom:2rem}.fd-slider__tick-wrapper .fd-slider__label,.fd-slider__tick-wrapper .fd-slider__tick{position:absolute}.fd-slider__ticks{height:var(--fdSlider_Tick_Height)}.fd-slider__track .fd-slider__handle:focus{z-index:2;-webkit-touch-callout:none;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.fd-slider__track .fd-popover-custom{display:none}.fd-slider__labels .fd-slider__label{white-space:nowrap}[dir=rtl] .fd-slider__handle{transform:translate(50%,-50%)}\n/*! Bundled license information:\n\nfundamental-styles/dist/input.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: SliderPositionDirective, selector: "[fd-slider-position]", inputs: ["position", "vertical"] }, { kind: "component", type: PopoverComponent, selector: "fd-popover", inputs: ["title", "trigger", "fixedPosition", "id", "mobile", "mobileConfig", "preventSpaceKeyScroll"] }, { kind: "directive", type: PopoverTriggerDirective, selector: "[fdPopoverTrigger], [fd-popover-trigger]", inputs: ["fdPopoverTrigger"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i5.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i5.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i5.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: OnlyDigitsDirective, selector: "[fdkOnlyDigits]", inputs: ["decimal", "decimalSeparator"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], SliderComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SliderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-slider', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        SLIDER_VALUE_ACCESSOR,
                        registerFormItemControl(SliderComponent),
                        contentDensityObserverProviders({
                            defaultContentDensity: ContentDensityMode.COMPACT,
                            modifiers: {
                                [ContentDensityMode.COZY]: 'fd-slider--lg'
                            }
                        })
                    ], host: {
                        '(mouseenter)': 'this._componentHovered$.next(true)',
                        '(mouseleave)': 'this._componentHovered$.next(false)',
                        '(focusout)': 'onTouched()'
                    }, imports: [
                        NgTemplateOutlet,
                        SliderPositionDirective,
                        PopoverComponent,
                        PopoverTriggerDirective,
                        FormsModule,
                        OnlyDigitsDirective,
                        FdTranslatePipe
                    ], template: "<div class=\"fd-slider__inner\">\n    <ng-template [ngTemplateOutlet]=\"_isRange ? rangeMode : singleMode\"></ng-template>\n    <div class=\"fd-slider__track\" (click)=\"onTrackClick($event)\" #track>\n        <ng-template [ngTemplateOutlet]=\"_isRange ? rangeModeTrack : singleModeTrack\"></ng-template>\n    </div>\n    <div class=\"fd-slider__tick-wrapper\">\n        <div class=\"fd-slider__ticks\" (click)=\"onTrackClick($event)\">\n            @if (showTicks) {\n                @for (tick of _tickMarks; track tick; let i = $index) {\n                    <div\n                        class=\"fd-slider__tick\"\n                        fd-slider-position\n                        [vertical]=\"vertical\"\n                        [position]=\"tick.position || 0\"\n                        [class.fd-slider__tick--in-range]=\"\n                            !hideProgressBar &&\n                            (_isRange\n                                ? tick.value >= _position[0] && tick.value <= _position[1]\n                                : tick.value <= _position)\n                        \"\n                    ></div>\n                }\n            }\n        </div>\n        @if (showTicks && showTicksLabels) {\n            <div class=\"fd-slider__labels\">\n                @for (tick of _tickMarks; track tick; let i = $index; let last = $last; let first = $first) {\n                    @if (first || last || i % tickmarksBetweenLabels === 0) {\n                        <div\n                            class=\"fd-slider__label\"\n                            fd-slider-position\n                            [vertical]=\"vertical\"\n                            [position]=\"tick.position || 0\"\n                        >\n                            {{ tick.label }}\n                        </div>\n                    }\n                }\n            </div>\n        }\n    </div>\n</div>\n<ng-template #singleModeTrack>\n    @if (!hideProgressBar) {\n        <div\n            class=\"fd-slider__track-range\"\n            [style.height.%]=\"vertical ? _progress : null\"\n            [style.width.%]=\"vertical ? null : _progress\"\n        ></div>\n    }\n</ng-template>\n<ng-template #rangeModeTrack>\n    @if (!hideProgressBar) {\n        <div\n            class=\"fd-slider__track-range\"\n            [style.height.%]=\"vertical ? _rangeProgress : null\"\n            [style.width.%]=\"vertical ? null : _rangeProgress\"\n            fd-slider-position\n            [vertical]=\"vertical\"\n            [position]=\"_handle1Position < _handle2Position ? _handle1Position : _handle2Position\"\n        >\n            <div\n                class=\"fd-slider__track-focus-range\"\n                (mousedown)=\"onHandleClick($event, true)\"\n                (keydown)=\"onKeyDown($event, _handles.Both)\"\n                tabindex=\"0\"\n                #rangeGroupHandle\n            ></div>\n        </div>\n    }\n</ng-template>\n<ng-template #singleMode>\n    <div\n        #handle\n        class=\"fd-slider__handle\"\n        [class.fd-slider__handle--lg]=\"_contentDensityObserver.isCozySignal()\"\n        [attr.tabindex]=\"disabled ? -1 : 0\"\n        role=\"slider\"\n        [attr.aria-label]=\"\n            ariaLabel || ('coreSlider.singleMinMaxDetails' | fdTranslate: { min: minValue, max: maxValue })\n        \"\n        [attr.aria-labelledby]=\"ariaLabelledBy\"\n        [fdPopoverTrigger]=\"tooltipMode ? singleSliderPopover : null\"\n        [attr.aria-valuemin]=\"'coreSlider.singleValueminDetails' | fdTranslate: { value: minValue }\"\n        [attr.aria-valuemax]=\"'coreSlider.singleValuemaxDetails' | fdTranslate: { value: maxValue }\"\n        [attr.aria-valuenow]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.singleValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_position, _sliderValueTargets.SINGLE_SLIDER) })\n                : getValuenow(_position, _sliderValueTargets.SINGLE_SLIDER)\n        \"\n        [attr.aria-valuetext]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.singleValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_position, _sliderValueTargets.SINGLE_SLIDER) })\n                : getValuenow(_position, _sliderValueTargets.SINGLE_SLIDER)\n        \"\n        fd-slider-position\n        [vertical]=\"vertical\"\n        [position]=\"_progress\"\n        (mousedown)=\"onHandleClick($event); $event.stopPropagation()\"\n        (focus)=\"_handleFocused$.next(true)\"\n        (blur)=\"_handleFocused$.next(false)\"\n        (keydown)=\"onKeyDown($event)\"\n    ></div>\n    <fd-popover\n        #singleSliderPopover\n        [triggers]=\"[]\"\n        [closeOnOutsideClick]=\"false\"\n        [appendTo]=\"handle\"\n        [disabled]=\"!tooltipMode\"\n        class=\"fd-popover--slider\"\n        additionalBodyClass=\"fd-slider-tooltip-popover\"\n        placement=\"top\"\n    >\n        <ng-template\n            [ngTemplateOutlet]=\"popoverInner\"\n            [ngTemplateOutletContext]=\"{ target: _sliderValueTargets.SINGLE_SLIDER, position: _position }\"\n        ></ng-template>\n    </fd-popover>\n</ng-template>\n<ng-template #rangeMode>\n    <div\n        #rangeHandle1\n        class=\"fd-slider__handle\"\n        [class.fd-slider__handle--lg]=\"_contentDensityObserver.isCozySignal()\"\n        [attr.tabindex]=\"disabled ? -1 : 0\"\n        role=\"slider\"\n        [attr.aria-label]=\"\n            ariaLabel || ('coreSlider.multipleHandle1MinMaxDetails' | fdTranslate: { min: minValue, max: maxValue })\n        \"\n        [attr.aria-labelledby]=\"ariaLabelledBy\"\n        [fdPopoverTrigger]=\"tooltipMode ? rangeSliderPopover1 : null\"\n        [attr.aria-valuemin]=\"'coreSlider.multipleHandle1ValueminDetails' | fdTranslate: { value: minValue }\"\n        [attr.aria-valuemax]=\"'coreSlider.multipleHandle1ValuemaxDetails' | fdTranslate: { value: maxValue }\"\n        [attr.aria-valuenow]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.multipleHandle1ValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_handle1Value, _sliderValueTargets.RANGE_SLIDER1) })\n                : getValuenow(_handle1Value, _sliderValueTargets.RANGE_SLIDER1)\n        \"\n        [attr.aria-valuetext]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.multipleHandle1ValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_handle1Value, _sliderValueTargets.RANGE_SLIDER1) })\n                : getValuenow(_handle1Value, _sliderValueTargets.RANGE_SLIDER1)\n        \"\n        fd-slider-position\n        [vertical]=\"vertical\"\n        [position]=\"_handle1Position\"\n        (mousedown)=\"onHandleClick($event); $event.stopPropagation()\"\n        (keydown)=\"onKeyDown($event, _handles.First)\"\n        (focus)=\"_rangeHandle1Focused$.next(true)\"\n        (blur)=\"_rangeHandle1Focused$.next(false)\"\n    ></div>\n    <div\n        #rangeHandle2\n        class=\"fd-slider__handle\"\n        [class.fd-slider__handle--lg]=\"_contentDensityObserver.isCozySignal()\"\n        [attr.tabindex]=\"disabled ? -1 : 0\"\n        role=\"slider\"\n        [attr.aria-label]=\"\n            ariaLabel || ('coreSlider.multipleHandle2MinMaxDetails' | fdTranslate: { min: minValue, max: maxValue })\n        \"\n        [attr.aria-labelledby]=\"ariaLabelledBy\"\n        [fdPopoverTrigger]=\"tooltipMode ? rangeSliderPopover2 : null\"\n        [attr.aria-valuemin]=\"'coreSlider.multipleHandle2ValueminDetails' | fdTranslate: { value: minValue }\"\n        [attr.aria-valuemax]=\"'coreSlider.multipleHandle2ValuemaxDetails' | fdTranslate: { value: maxValue }\"\n        [attr.aria-valuenow]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.multipleHandle2ValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_handle2Value, _sliderValueTargets.RANGE_SLIDER2) })\n                : getValuenow(_handle2Value, _sliderValueTargets.RANGE_SLIDER2)\n        \"\n        [attr.aria-valuetext]=\"\n            _useSliderValuePrefix\n                ? ('coreSlider.multipleHandle2ValueNowDetails'\n                  | fdTranslate: { value: getValuenow(_handle2Value, _sliderValueTargets.RANGE_SLIDER2) })\n                : getValuenow(_handle2Value, _sliderValueTargets.RANGE_SLIDER2)\n        \"\n        fd-slider-position\n        [vertical]=\"vertical\"\n        [position]=\"_handle2Position\"\n        (mousedown)=\"onHandleClick($event); $event.stopPropagation()\"\n        (keydown)=\"onKeyDown($event, _handles.Second)\"\n        (focus)=\"_rangeHandle2Focused$.next(true)\"\n        (blur)=\"_rangeHandle2Focused$.next(false)\"\n    ></div>\n    <fd-popover\n        #rangeSliderPopover1\n        [triggers]=\"[]\"\n        [closeOnOutsideClick]=\"false\"\n        [appendTo]=\"rangeHandle1\"\n        [disabled]=\"!tooltipMode\"\n        additionalBodyClass=\"fd-slider-tooltip-popover\"\n        class=\"fd-popover--slider\"\n        placement=\"top\"\n    >\n        <ng-template\n            [ngTemplateOutlet]=\"popoverInner\"\n            [ngTemplateOutletContext]=\"{ target: _sliderValueTargets.RANGE_SLIDER1, position: _handle1Value }\"\n        ></ng-template>\n    </fd-popover>\n    <fd-popover\n        #rangeSliderPopover2\n        [triggers]=\"[]\"\n        [closeOnOutsideClick]=\"false\"\n        [appendTo]=\"rangeHandle2\"\n        [disabled]=\"!tooltipMode\"\n        additionalBodyClass=\"fd-slider-tooltip-popover\"\n        class=\"fd-popover--slider\"\n        placement=\"top\"\n    >\n        <ng-template\n            [ngTemplateOutlet]=\"popoverInner\"\n            [ngTemplateOutletContext]=\"{ target: _sliderValueTargets.RANGE_SLIDER2, position: _handle2Value }\"\n        ></ng-template>\n    </fd-popover>\n</ng-template>\n<ng-template #popoverInner let-target=\"target\" let-position=\"position\">\n    <div\n        #sliderTooltipWrapper\n        class=\"fd-slider-tooltip-wrapper\"\n        (click)=\"$event.stopPropagation()\"\n        (keydown)=\"$event.stopPropagation()\"\n        (mouseenter)=\"_popoverInputFieldHovered$.next(true)\"\n        (mouseleave)=\"_popoverInputFieldHovered$.next(false)\"\n    >\n        @if ((customValues && customValues.length > 0) || tooltipMode === 'readonly') {\n            <div class=\"fd-slider-tooltip\">\n                {{ customValues && customValues.length > 0 ? customValues[position].label : _popoverValueRef[target] }}\n            </div>\n        }\n        @if (customValues.length === 0 && tooltipMode === 'editable') {\n            <input\n                #popoverInputField\n                tabindex=\"-1\"\n                type=\"text\"\n                [disabled]=\"disabled\"\n                fdkOnlyDigits\n                [decimal]=\"true\"\n                [style.width.ch]=\"('' + _popoverValueRef[target]).length + 2\"\n                class=\"fd-input fd-slider-tooltip {{ _popoverInputFieldClass }}\"\n                [(ngModel)]=\"_popoverValueRef[target]\"\n                (blur)=\"_updateValueFromInput(popoverInputField.value, target)\"\n                (keydown.enter)=\"_updateValueFromInput(popoverInputField.value, target)\"\n                (focus)=\"_popoverInputFieldFocused$.next(true)\"\n                (blur)=\"_popoverInputFieldFocused$.next(false)\"\n            />\n        }\n    </div>\n</ng-template>\n", styles: [".fd-slider{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;min-width:4rem;padding-block:0;padding-block:1rem;padding-inline:0;padding-inline:calc(var(--fdSlider_Handle_Width)*.5 + .125rem);position:relative}.fd-slider:after,.fd-slider:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider.is-disabled,.fd-slider:disabled,.fd-slider[aria-disabled=true]{cursor:not-allowed}.fd-slider--lg{--fdSlider_Handle_Width:var(--fdSlider_Mobile_Handle_Width);--fdSlider_Handle_Height:var(--fdSlider_Mobile_Handle_Height);--fdSlider_Handle_Active_Width:var(--fdSlider_Mobile_Handle_Active_Size);--fdSlider_Handle_Active_Height:var(--fdSlider_Mobile_Handle_Active_Size);padding-inline:calc(var(--fdSlider_Mobile_Handle_Width)*.5 + .125rem)}.fd-slider__inner{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-slider__inner:after,.fd-slider__inner:before{background-color:var(--fdSlider_Endpoint_Active_Background);border:0;border:var(--fdSlider_Endpoint_Active_Border);border-radius:50%;-webkit-box-sizing:inherit;box-sizing:inherit;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);content:\"\";font-family:var(--sapFontFamily);font-size:inherit;font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdSlider_Endpoint_Size);left:-.7rem;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:absolute;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%);width:var(--fdSlider_Endpoint_Size)}.fd-slider__inner:after:after,.fd-slider__inner:after:before,.fd-slider__inner:before:after,.fd-slider__inner:before:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__inner:after{left:auto;right:-.7rem}.fd-slider:not(.fd-slider--vertical,.fd-slider--range) .fd-slider__inner[dir=rtl]:before,.fd-slider__inner:after,[dir=rtl] .fd-slider:not(.fd-slider--vertical,.fd-slider--range) .fd-slider__inner:before{background-color:var(--fdSlider_Endpoint_Background);border:var(--fdSlider_Endpoint_Border)}.fd-slider:not(.fd-slider--vertical,.fd-slider--range) .fd-slider__inner[dir=rtl]:after,[dir=rtl] .fd-slider:not(.fd-slider--vertical,.fd-slider--range) .fd-slider__inner:after{background-color:var(--fdSlider_Endpoint_Active_Background);border:var(--fdSlider_Endpoint_Active_Border)}.fd-slider__track{background-color:var(--fdSlider_Track_Background);border:0;border-radius:var(--fdSlider_Track_BorderRadius);-webkit-box-shadow:inset 0 0 0 var(--fdSlider_Track_Border_Width) var(--fdSlider_Track_Border_Color);box-shadow:inset 0 0 0 var(--fdSlider_Track_Border_Width) var(--fdSlider_Track_Border_Color);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdSlider_Track_Height);line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative;width:100%;z-index:1}.fd-slider__track:after,.fd-slider__track:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__track .fd-slider__handle.is-focus,.fd-slider__track .fd-slider__handle:focus{z-index:5;z-index:2;-webkit-touch-callout:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.fd-slider__track-range{background-color:var(--fdSlider_Track_Active_Background);border:0;border:.0625rem solid var(--fdSlider_Track_Active_Border);border-radius:.25rem;-webkit-box-shadow:var(--fdSlider_Track_Active_Box_Shadow);box-shadow:var(--fdSlider_Track_Active_Box_Shadow);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:100%;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-slider__track-range:after,.fd-slider__track-range:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__tick-wrapper{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:absolute;top:calc((var(--fdSlider_Track_Height) - var(--fdSlider_Tick_Height))/2);width:100%;z-index:2}.fd-slider__tick-wrapper:after,.fd-slider__tick-wrapper:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__ticks{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-ms-flex-pack:justify;height:var(--fdSlider_Tick_Height);justify-content:space-between}.fd-slider__ticks:after,.fd-slider__ticks:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__labels{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-ms-flex-pack:justify;height:1rem;justify-content:space-between;position:relative;top:.5rem}.fd-slider__labels:after,.fd-slider__labels:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__tick{border:0;border-left:.0625rem solid var(--fdSlider_Tick_Background);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdSlider_Tick_Height);line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-slider__tick:after,.fd-slider__tick:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__tick--in-range{border-color:var(--fdSlider_Active_Tick_Background)}.fd-slider__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_LabelColor);font-size:var(--sapFontSmallSize);position:relative;width:0}.fd-slider__label:after,.fd-slider__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__handle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:var(--fdSlider_Handle_Background);border:var(--fdSlider_Handle_Border);border-radius:var(--fdSlider_Handle_Border_Radius);cursor:pointer;height:var(--fdSlider_Handle_Height);position:absolute;top:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);width:var(--fdSlider_Handle_Width);z-index:3}.fd-slider__handle:after,.fd-slider__handle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__handle:before{content:\"\";height:var(--fdSlider_Handle_Active_Height);left:50%;position:absolute;top:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);width:var(--fdSlider_Handle_Active_Width)}.fd-slider__handle:after{color:var(--sapContent_Selected_ForegroundColor);content:\"\\e29c\";display:var(--fdSlider_Handle_Icon_Display);font-family:SAP-icons;font-size:.875rem;line-height:1}.fd-slider__handle.is-focus,.fd-slider__handle:focus{background-color:var(--fdSlider_Focus_Handle_Background);border:var(--fdSlider_Focus_Handle_Border);outline:none;z-index:5}.fd-slider__handle.is-focus:after,.fd-slider__handle:focus:after{display:none}.fd-slider__handle.is-hover,.fd-slider__handle:hover{background-color:var(--fdSlider_Hover_Handle_Background);border:var(--fdSlider_Hover_Handle_Border);border-color:var(--fdSlider_Handle_Border_Hover_Color)}.fd-slider__handle.is-hover.is-focus,.fd-slider__handle.is-hover:focus,.fd-slider__handle:hover.is-focus,.fd-slider__handle:hover:focus{background-color:var(--fdSlider_Focus_Handle_Background);border:var(--fdSlider_Focus_Handle_Border);outline:none;z-index:5}.fd-slider__handle.is-hover.is-focus:after,.fd-slider__handle.is-hover:focus:after,.fd-slider__handle:hover.is-focus:after,.fd-slider__handle:hover:focus:after{display:none}.fd-slider__handle.is-active,.fd-slider__handle:active{background-color:var(--fdSlider_Active_Handle_Background);border:var(--fdSlider_Active_Handle_Border)}.fd-slider__handle.is-active.is-focus,.fd-slider__handle.is-active:focus,.fd-slider__handle:active.is-focus,.fd-slider__handle:active:focus{background-color:var(--fdSlider_Focus_Handle_Background);border:var(--fdSlider_Focus_Handle_Border);outline:none;z-index:5}.fd-slider__handle.is-active.is-focus:after,.fd-slider__handle.is-active:focus:after,.fd-slider__handle:active.is-focus:after,.fd-slider__handle:active:focus:after{display:none}.fd-slider__track-focus-range{border:0;border-radius:var(--fdSlider_Range_Track_Border_Radius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:calc(var(--fdSlider_Handle_Height) + .5rem);left:0;line-height:normal;margin-block:0;margin-inline:0;margin-inline:calc(var(--fdSlider_Handle_Height)*-1/1.1);padding-block:0;padding-inline:0;position:absolute;right:0;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.fd-slider__track-focus-range:after,.fd-slider__track-focus-range:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-slider__track-focus-range.is-focus,.fd-slider__track-focus-range:focus{outline:var(--fdSlider_Focus_Range_Outline);z-index:5}.fd-slider--range .fd-slider__inner:after,.fd-slider--range .fd-slider__inner:before{background-color:var(--fdSlider_Endpoint_Background);border:var(--fdSlider_Endpoint_Border)}.fd-slider--range .fd-slider__inner .fd-slider__handle{background-color:var(--fdSlider_Range_Handle_Background);border:var(--fdSlider_Range_Handle_Border)}.fd-slider--range .fd-slider__inner .fd-slider__handle.is-hover,.fd-slider--range .fd-slider__inner .fd-slider__handle:hover{background-color:var(--fdSlider_Range_Hover_Handle_Background);border-color:var(--fdSlider_Range_Hover_Handle_Border_Color)}.fd-slider--range .fd-slider__inner .fd-slider__handle.is-active,.fd-slider--range .fd-slider__inner .fd-slider__handle:active{background-color:var(--fdSlider_Range_Active_Handle_Background);border-color:var(--fdSlider_Range_Active_Handle_Border_Color)}.fd-slider--range .fd-slider__inner .fd-slider__handle.is-active:after,.fd-slider--range .fd-slider__inner .fd-slider__handle:active:after{display:var(--fdSlider_Focus_Handle_Display)}.fd-slider--range .fd-slider__inner .fd-slider__handle.is-focus,.fd-slider--range .fd-slider__inner .fd-slider__handle:focus{background-color:var(--fdSlider_Range_Focus_Handle_Background);border:var(--fdSlider_Range_Focus_Handle_Border);z-index:5}.fd-slider--range .fd-slider__inner .fd-slider__handle.is-focus:after,.fd-slider--range .fd-slider__inner .fd-slider__handle:focus:after{display:var(--fdSlider_Focus_Handle_Display)}.fd-slider--vertical{height:100%}.fd-slider--vertical .fd-slider__inner{height:100%;width:var(--fdSlider_Track_Height)}.fd-slider--vertical .fd-slider__inner:after,.fd-slider--vertical .fd-slider__inner:before{left:50%;right:auto;top:auto;-webkit-transform:translateX(-50%);transform:translate(-50%)}.fd-slider--vertical .fd-slider__inner:before{bottom:-.7rem}.fd-slider--vertical .fd-slider__inner:after{top:-.7rem}.fd-slider--vertical .fd-slider__track{height:100%;width:var(--fdSlider_Track_Height)}.fd-slider--vertical .fd-slider__track-range{bottom:0;position:absolute;width:100%}.fd-slider--vertical .fd-slider__handle{bottom:0;height:var(--fdSlider_Handle_Width);left:50%;top:auto;-webkit-transform:translate(-50%,50%);transform:translate(-50%,50%);width:var(--fdSlider_Handle_Height)}.fd-slider--vertical .fd-slider__handle:after{-webkit-transform:rotate(90deg);transform:rotate(90deg)}.fd-slider--vertical .fd-slider__tick-wrapper{height:100%;left:calc((var(--fdSlider_Track_Height) - var(--fdSlider_Tick_Height))/2);right:calc((var(--fdSlider_Track_Height) - var(--fdSlider_Tick_Height))/2);top:0}.fd-slider--vertical .fd-slider__ticks{-webkit-box-orient:vertical;-webkit-box-direction:reverse;-ms-flex-direction:column-reverse;flex-direction:column-reverse;height:100%}.fd-slider--vertical .fd-slider__tick{border-left:none;border-top-style:solid;border-top-width:.0625rem;height:0;width:var(--fdSlider_Tick_Height)}.fd-slider--vertical .fd-slider__labels{height:100%;position:absolute;top:-.55rem;-webkit-box-orient:vertical;-webkit-box-direction:reverse;-ms-flex-direction:column-reverse;flex-direction:column-reverse;left:calc(var(--fdSlider_Handle_Width)*.5 + .125rem)}.fd-slider--vertical .fd-slider__labels[dir=rtl],[dir=rtl] .fd-slider--vertical .fd-slider__labels{left:auto;right:calc(var(--fdSlider_Handle_Width)*.5 + .125rem)}.fd-slider--vertical .fd-slider__label{height:.0625rem;width:auto}.fd-slider--vertical.fd-slider--range .fd-slider__track-range{left:0}.fd-slider--vertical.fd-slider--range .fd-slider__track-focus-range{height:auto;inset:0 auto 0 50%;margin-block:calc(var(--fdSlider_Handle_Height)*-1/1.1);margin-inline:0;-webkit-transform:translateX(-50%);transform:translate(-50%);width:calc(var(--fdSlider_Handle_Height) + .5rem)}.fd-slider-tooltip-popover.fd-popover__body{background:var(--sapBackgroundColor);border:none;border-radius:.0625rem;-webkit-box-shadow:var(--sapContent_Shadow1);box-shadow:var(--sapContent_Shadow1);height:1rem;overflow:hidden;padding-block:0;padding-inline:.5rem;top:-.4375rem!important}.fd-slider-tooltip-popover.fd-popover__body .fd-slider-tooltip{color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSmallSize);line-height:1rem;text-align:center}.fd-slider-tooltip-popover.fd-popover__body:has(input){-webkit-box-shadow:none;box-shadow:none;height:auto;padding-inline:0;width:auto}.fd-input{-webkit-appearance:none;-moz-appearance:none;appearance:none;background:var(--sapField_BackgroundStyle,var(--sapField_BackgroundStyle));background-color:var(--sapField_Background,var(--sapField_Background));border:0;border:var(--sapField_BorderWidth) var(--sapField_BorderStyle) var(--sapField_BorderColor);border-radius:var(--sapField_BorderCornerRadius);-webkit-box-shadow:var(--sapField_Shadow);box-shadow:var(--sapField_Shadow);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapField_TextColor);cursor:text;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdInput_Height,var(--sapElement_Height));line-height:normal;margin-block:0;margin-block:var(--fdInput_Field_Margin_Block,.25rem);margin-inline:0;min-height:var(--fdInput_Height,var(--sapElement_Height));min-width:2.75rem;outline:none;overflow:hidden;padding-block:0;padding-inline:0;padding-inline:var(--fdInput_Field_Padding_Inline,.625rem);text-overflow:ellipsis;text-shadow:var(--fdInput_Text_Shadow);white-space:nowrap;width:100%;z-index:1}.fd-input:after,.fd-input:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-input::-webkit-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:var(--fdPlaceholder_Font_Style)}.fd-input::-moz-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:var(--fdPlaceholder_Font_Style)}.fd-input:-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:var(--fdPlaceholder_Font_Style)}.fd-input::-ms-input-placeholder{color:var(--sapField_PlaceholderTextColor);font-style:var(--fdPlaceholder_Font_Style)}.fd-input::placeholder{color:var(--sapField_PlaceholderTextColor);font-style:var(--fdPlaceholder_Font_Style)}.fd-input[dir=rtl]::-webkit-input-placeholder,[dir=rtl] .fd-input::-webkit-input-placeholder{text-indent:.125rem}.fd-input[dir=rtl]::-moz-placeholder,[dir=rtl] .fd-input::-moz-placeholder{text-indent:.125rem}.fd-input[dir=rtl]:-ms-input-placeholder,[dir=rtl] .fd-input:-ms-input-placeholder{text-indent:.125rem}.fd-input[dir=rtl]::-ms-input-placeholder,[dir=rtl] .fd-input::-ms-input-placeholder{text-indent:.125rem}.fd-input[dir=rtl]::placeholder,[dir=rtl] .fd-input::placeholder{text-indent:.125rem}.fd-input::-moz-selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-input::selection{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastTextColor)}.fd-input::-ms-clear{display:none}.fd-input.is-hover,.fd-input:hover{background:var(--sapField_Hover_BackgroundStyle,var(--sapField_Hover_BackgroundStyle));background-color:var(--sapField_Hover_Background,var(--sapField_Hover_Background));border-color:var(--sapField_Hover_BorderColor);-webkit-box-shadow:var(--fdInput_Box_Shadow_Hover);box-shadow:var(--fdInput_Box_Shadow_Hover)}.fd-input.is-focus,.fd-input:focus{background:var(--sapField_Focus_Background,var(--sapField_Focus_Background));-webkit-box-shadow:none;box-shadow:none;outline:var(--fdInput_Outline_Color) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:var(--fdInput_Outline_Offset);z-index:5}.fd-input[type=search]::-webkit-search-cancel-button,.fd-input[type=search]::-webkit-search-decoration,.fd-input[type=search]::-webkit-search-results-button,.fd-input[type=search]::-webkit-search-results-decoration{-webkit-appearance:none;appearance:none}.fd-input[aria-expanded=false]{z-index:0}.fd-input.is-expanded,.fd-input[aria-expanded=true]{z-index:4}.fd-input[class*=-compact],.fd-input[class*=-condensed],[class*=-compact] .fd-input:not([class*=-cozy]),[class*=-condensed] .fd-input:not([class*=-cozy]){-webkit-box-sizing:border-box;box-sizing:border-box;height:var(--fdInput_Compact_Height,var(--sapElement_Compact_Height));margin-block:var(--fdInput_Field_Compact_Margin_Block,.1875rem);margin-inline:0;min-height:var(--fdInput_Compact_Height,var(--sapElement_Compact_Height));min-width:var(--fdInput_Field_Compact_Min_Width,2rem);padding-block:0;padding-inline:var(--fdInput_Field_Compact_Padding,.5rem)}.fd-input--no-number-spinner{-webkit-appearance:textfield;-moz-appearance:textfield;appearance:textfield}.fd-input--no-number-spinner::-webkit-inner-spin-button,.fd-input--no-number-spinner::-webkit-outer-spin-button{-webkit-appearance:none;appearance:none;margin-block:0;margin-inline:0}.fd-input.right-align{text-align:right}.fd-input.is-success{background:var(--sapField_SuccessBackgroundStyle);background-color:var(--sapField_SuccessBackground);border:var(--sapField_SuccessColor) var(--sapField_SuccessBorderWidth) var(--sapField_SuccessBorderStyle);-webkit-box-shadow:var(--sapField_SuccessShadow);box-shadow:var(--sapField_SuccessShadow)}.fd-input.is-success.is-hover,.fd-input.is-success:hover{background-color:var(--fdInput_Success_Background_Color_Hover);border-color:var(--sapField_SuccessColor);-webkit-box-shadow:var(--fdInput_Success_Box_Shadow_Hover);box-shadow:var(--fdInput_Success_Box_Shadow_Hover)}.fd-input.is-success.is-focus,.fd-input.is-success:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Success_Outline_Color);z-index:5}.fd-input.is-success.is-focus.is-hover,.fd-input.is-success.is-focus:hover,.fd-input.is-success:focus.is-hover,.fd-input.is-success:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-input.is-success.is-expanded,.fd-input.is-success[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Success_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-input.is-error{background:var(--sapField_InvalidBackgroundStyle);background-color:var(--sapField_InvalidBackground);border:var(--sapField_InvalidColor) var(--sapField_InvalidBorderWidth) var(--sapField_InvalidBorderStyle);-webkit-box-shadow:var(--sapField_InvalidShadow);box-shadow:var(--sapField_InvalidShadow)}.fd-input.is-error.is-hover,.fd-input.is-error:hover{background-color:var(--fdInput_Error_Background_Color_Hover);border-color:var(--sapField_InvalidColor);-webkit-box-shadow:var(--fdInput_Error_Box_Shadow_Hover);box-shadow:var(--fdInput_Error_Box_Shadow_Hover)}.fd-input.is-error.is-focus,.fd-input.is-error:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Error_Outline_Color);z-index:5}.fd-input.is-error.is-focus.is-hover,.fd-input.is-error.is-focus:hover,.fd-input.is-error:focus.is-hover,.fd-input.is-error:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-input.is-error.is-expanded,.fd-input.is-error[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Error_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-input.is-warning{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle);-webkit-box-shadow:var(--sapField_WarningShadow);box-shadow:var(--sapField_WarningShadow)}.fd-input.is-warning.is-hover,.fd-input.is-warning:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-input.is-warning.is-focus,.fd-input.is-warning:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-input.is-warning.is-focus.is-hover,.fd-input.is-warning.is-focus:hover,.fd-input.is-warning:focus.is-hover,.fd-input.is-warning:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-input.is-warning.is-expanded,.fd-input.is-warning[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-input.is-alert{background:var(--sapField_WarningBackgroundStyle);background-color:var(--sapField_WarningBackground);border:var(--sapField_WarningColor) var(--sapField_WarningBorderWidth) var(--sapField_WarningBorderStyle)}.fd-input.is-alert.is-hover,.fd-input.is-alert:hover{background-color:var(--fdInput_Warning_Background_Color_Hover);border-color:var(--sapField_WarningColor);-webkit-box-shadow:var(--fdInput_Warning_Box_Shadow_Hover);box-shadow:var(--fdInput_Warning_Box_Shadow_Hover)}.fd-input.is-alert.is-focus,.fd-input.is-alert:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Warning_Outline_Color);z-index:5}.fd-input.is-alert.is-focus.is-hover,.fd-input.is-alert.is-focus:hover,.fd-input.is-alert:focus.is-hover,.fd-input.is-alert:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-input.is-alert.is-expanded,.fd-input.is-alert[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Warning_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-input.is-information{background:var(--sapField_InformationBackgroundStyle);background-color:var(--sapField_InformationBackground);border:var(--sapField_InformationColor) var(--sapField_InformationBorderWidth) var(--sapField_InformationBorderStyle);-webkit-box-shadow:var(--sapField_InformationShadow);box-shadow:var(--sapField_InformationShadow)}.fd-input.is-information.is-hover,.fd-input.is-information:hover{background-color:var(--fdInput_Information_Background_Color_Hover);border-color:var(--sapField_InformationColor);-webkit-box-shadow:var(--fdInput_Information_Box_Shadow_Hover);box-shadow:var(--fdInput_Information_Box_Shadow_Hover)}.fd-input.is-information.is-focus,.fd-input.is-information:focus{background:var(--sapField_Focus_Background);outline-color:var(--fdInput_Information_Outline_Color);z-index:5}.fd-input.is-information.is-focus.is-hover,.fd-input.is-information.is-focus:hover,.fd-input.is-information:focus.is-hover,.fd-input.is-information:focus:hover{-webkit-box-shadow:none;box-shadow:none}.fd-input.is-information.is-expanded,.fd-input.is-information[aria-expanded=true]{background:var(--sapField_Focus_Background);-webkit-box-shadow:none;box-shadow:none;outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdInput_Information_Outline_Color);outline-offset:var(--fdInput_Outline_Offset)}.fd-input.is-alert,.fd-input.is-error,.fd-input.is-warning{font-style:var(--fdInput_State_Text_Style);font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert::-webkit-input-placeholder,.fd-input.is-error::-webkit-input-placeholder,.fd-input.is-warning::-webkit-input-placeholder{font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert::-moz-placeholder,.fd-input.is-error::-moz-placeholder,.fd-input.is-warning::-moz-placeholder{font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert:-ms-input-placeholder,.fd-input.is-error:-ms-input-placeholder,.fd-input.is-warning:-ms-input-placeholder{font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert::-ms-input-placeholder,.fd-input.is-error::-ms-input-placeholder,.fd-input.is-warning::-ms-input-placeholder{font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert::placeholder,.fd-input.is-error::placeholder,.fd-input.is-warning::placeholder{font-weight:var(--fdInput_State_Font_Weight)}.fd-input.is-alert.is-focus,.fd-input.is-alert:focus,.fd-input.is-error.is-focus,.fd-input.is-error:focus,.fd-input.is-information.is-focus,.fd-input.is-information:focus,.fd-input.is-warning.is-focus,.fd-input.is-warning:focus{outline-offset:var(--fdInput_Outline_Offset_States);z-index:5}.fd-input.is-error::-webkit-input-placeholder{color:var(--sapField_TextColor)}.fd-input.is-error::-moz-placeholder{color:var(--sapField_TextColor)}.fd-input.is-error:-ms-input-placeholder{color:var(--sapField_TextColor)}.fd-input.is-error::-ms-input-placeholder{color:var(--sapField_TextColor)}.fd-input.is-error::placeholder{color:var(--sapField_TextColor)}.fd-input.is-disabled,.fd-input:disabled,.fd-input[aria-disabled=true]{opacity:var(--sapContent_DisabledOpacity);pointer-events:none}.fd-input.is-disabled::-webkit-input-placeholder,.fd-input:disabled::-webkit-input-placeholder,.fd-input[aria-disabled=true]::-webkit-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-disabled::-moz-placeholder,.fd-input:disabled::-moz-placeholder,.fd-input[aria-disabled=true]::-moz-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-disabled:-ms-input-placeholder,.fd-input:disabled:-ms-input-placeholder,.fd-input[aria-disabled=true]:-ms-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-disabled::-ms-input-placeholder,.fd-input:disabled::-ms-input-placeholder,.fd-input[aria-disabled=true]::-ms-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-disabled::placeholder,.fd-input:disabled::placeholder,.fd-input[aria-disabled=true]::placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly,.fd-input[aria-readonly=true],.fd-input[readonly]{--fdInput_Outline_Offset:-.25rem;background:var(--sapField_ReadOnly_BackgroundStyle);background-color:var(--sapField_ReadOnly_Background);border-color:var(--sapField_ReadOnly_BorderColor);-webkit-box-shadow:none;box-shadow:none}.fd-input.is-readonly::-webkit-input-placeholder,.fd-input[aria-readonly=true]::-webkit-input-placeholder,.fd-input[readonly]::-webkit-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly::-moz-placeholder,.fd-input[aria-readonly=true]::-moz-placeholder,.fd-input[readonly]::-moz-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly:-ms-input-placeholder,.fd-input[aria-readonly=true]:-ms-input-placeholder,.fd-input[readonly]:-ms-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly::-ms-input-placeholder,.fd-input[aria-readonly=true]::-ms-input-placeholder,.fd-input[readonly]::-ms-input-placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly::placeholder,.fd-input[aria-readonly=true]::placeholder,.fd-input[readonly]::placeholder{color:var(--fdInput_Non_Interactive_State_Placeholder_Color);opacity:0}.fd-input.is-readonly.is-focus,.fd-input.is-readonly.is-hover,.fd-input.is-readonly:focus,.fd-input.is-readonly:hover,.fd-input[aria-readonly=true].is-focus,.fd-input[aria-readonly=true].is-hover,.fd-input[aria-readonly=true]:focus,.fd-input[aria-readonly=true]:hover,.fd-input[readonly].is-focus,.fd-input[readonly].is-hover,.fd-input[readonly]:focus,.fd-input[readonly]:hover{--fdInput_Outline_Offset:-.25rem;background:var(--sapField_ReadOnly_BackgroundStyle);background-color:var(--sapField_ReadOnly_Background);border-color:var(--sapField_ReadOnly_BorderColor);-webkit-box-shadow:none;box-shadow:none}.fd-input.is-readonly.is-focus,.fd-input.is-readonly:focus,.fd-input[aria-readonly=true].is-focus,.fd-input[aria-readonly=true]:focus,.fd-input[readonly].is-focus,.fd-input[readonly]:focus{z-index:5}.cdk-visually-hidden{border:0;clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;width:1px;white-space:nowrap;outline:0;-webkit-appearance:none;-moz-appearance:none;left:0}[dir=rtl] .cdk-visually-hidden{left:auto;right:0}.fd-popover--slider{display:block!important}.fd-popover__body.fd-slider-tooltip-popover{height:1rem;border:none;padding-block:0;overflow:hidden;padding-inline:.5rem;border-radius:.0625rem;top:-.4375rem!important;background:var(--sapBackgroundColor);box-shadow:var(--sapContent_Shadow1)}.fd-popover__body.fd-slider-tooltip-popover .fd-slider-tooltip{line-height:1rem;text-align:center;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSmallSize)}.fd-popover__body.fd-slider-tooltip-popover:has(input){width:auto;height:auto;box-shadow:none;padding-inline:0}.fd-slider{display:block}.fd-slider.fd-slider--with-labels{padding-bottom:2rem}.fd-slider__tick-wrapper .fd-slider__label,.fd-slider__tick-wrapper .fd-slider__tick{position:absolute}.fd-slider__ticks{height:var(--fdSlider_Tick_Height)}.fd-slider__track .fd-slider__handle:focus{z-index:2;-webkit-touch-callout:none;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.fd-slider__track .fd-popover-custom{display:none}.fd-slider__labels .fd-slider__label{white-space:nowrap}[dir=rtl] .fd-slider__handle{transform:translate(50%,-50%)}\n/*! Bundled license information:\n\nfundamental-styles/dist/input.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i0.Renderer2 }, { type: i1$1.Platform }, { type: i2.LiveAnnouncer }, { type: i1.RtlService, decorators: [{
                    type: Optional
                }] }, { type: i4.ContentDensityObserver }], propDecorators: { id: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.id']
            }], class: [{
                type: Input
            }], ariaLabelledBy: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], min: [{
                type: Input
            }], max: [{
                type: Input
            }], step: [{
                type: Input
            }], jump: [{
                type: Input
            }], tickmarksBetweenLabels: [{
                type: Input
            }], mode: [{
                type: Input
            }], showTicks: [{
                type: Input
            }], showTicksLabels: [{
                type: Input
            }], customValues: [{
                type: Input
            }], tooltipMode: [{
                type: Input
            }], hideProgressBar: [{
                type: Input
            }], disabled: [{
                type: Input
            }], vertical: [{
                type: Input
            }], value: [{
                type: Input
            }], trackEl: [{
                type: ViewChild,
                args: ['track', { read: ElementRef, static: true }]
            }], handle: [{
                type: ViewChild,
                args: ['handle', {
                        read: ElementRef
                    }]
            }], rangeHandle1: [{
                type: ViewChild,
                args: ['rangeHandle1', {
                        read: ElementRef
                    }]
            }], rangeHandle2: [{
                type: ViewChild,
                args: ['rangeHandle2', {
                        read: ElementRef
                    }]
            }], _rangeGroupHandle: [{
                type: ViewChild,
                args: ['rangeGroupHandle', { read: ElementRef, static: false }]
            }], _popovers: [{
                type: ViewChildren,
                args: [PopoverComponent]
            }], _sliderTooltipWrappers: [{
                type: ViewChildren,
                args: ['sliderTooltipWrapper']
            }], _isRange: [{
                type: HostBinding,
                args: ['class.fd-slider--range']
            }], buildComponentCssClass: [] } });

const EXPORTS = [SliderComponent, SliderPositionDirective];
class SliderModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SliderModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: SliderModule, imports: [PopoverModule, FormsModule, OnlyDigitsModule, ContentDensityModule, I18nModule, SliderComponent, SliderPositionDirective], exports: [SliderComponent, SliderPositionDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SliderModule, imports: [PopoverModule, FormsModule, OnlyDigitsModule, ContentDensityModule, I18nModule, SliderComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: SliderModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [PopoverModule, FormsModule, OnlyDigitsModule, ContentDensityModule, I18nModule, ...EXPORTS],
                    exports: [...EXPORTS]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { SLIDER_VALUE_ACCESSOR, SliderComponent, SliderModule, SliderPositionDirective, SliderRangeHandles, SliderValueTargets };
//# sourceMappingURL=fundamental-ngx-core-slider.mjs.map
