import { __decorate, __metadata } from 'tslib';
import { NgTemplateOutlet } from '@angular/common';
import * as i0 from '@angular/core';
import { Input, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import { applyCssClass } from '@fundamental-ngx/cdk/utils';

class Point {
    /** @hidden */
    constructor(x, y) {
        this.x = x;
        this.y = y;
    }
}
class StatusIndicatorComponent {
    /** @hidden */
    set _fillDirection(direction) {
        this.fillDirection = direction;
    }
    get _fillDirection() {
        return this.fillDirection;
    }
    /** @hidden */
    constructor(elementRef, _cd) {
        this.elementRef = elementRef;
        this._cd = _cd;
        /**
         * defines the size of the status indicator.
         * Can be one of the following: 'sm' | 'md' | 'lg' | 'xl'
         * Default size is Medium(md).
         */
        this.size = 'md';
        /**
         * defines the size of the status indicator.
         * Can be one of the following: 'sm' | 'md' | 'lg' | 'xl'
         */
        this.labelSize = 'sm';
        /**
         * value to define fill direction
         */
        this.fillDirection = 'clockwise';
        /**
         * FillingType to represent the fill pattern of the component
         */
        this.fillingType = 'lineardown';
        /** @hidden */
        this.pointsArray = [];
    }
    /** @hidden
     * CssClassBuilder interface implementation
     * function must return single string
     * function is responsible for order which css classes are applied
     */
    buildComponentCssClass() {
        return [
            'fd-status-indicator',
            this.size ? `fd-status-indicator--${this.size}` : '',
            this.status ? `fd-status-indicator--${this.status}` : '',
            this.clickable ? `fd-status-indicator--link` : '',
            this.labelPosition === 'right' || this.labelPosition === 'left'
                ? `fd-status-indicator--horizontal-label`
                : '',
            this.class
        ];
    }
    /** @hidden */
    ngAfterViewInit() {
        this._angleCalculation();
        this._cd.detectChanges();
    }
    /** @hidden */
    ngOnChanges() {
        this._calculateFilling();
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    _calculateFilling() {
        if (this.fillPercentage < 0 || this.fillPercentage === undefined) {
            this.fillCalculator = 0;
        }
        else {
            this.fillCalculator = (this.fillPercentage * this.path.length) / 100;
        }
    }
    /** @hidden */
    _angleCalculation() {
        let sPointsAttributeValue;
        let polygonPoints;
        switch (this.fillingType) {
            case 'angled':
                this.binaryString = this._convertAngleToBinary(this.angle);
                this._assignBinaryValue(this.binaryString);
                break;
            case 'radial': {
                const tempPercent = this.fillCalculator % 1;
                const fillNumber = Number(tempPercent.toFixed(2));
                const element = this.elementRef.nativeElement.querySelectorAll('svg');
                for (let i = 1; i < element.length; i++) {
                    sPointsAttributeValue = this._getPolygonPointsForCircularFilling(fillNumber * 100, element[i].getBBox());
                    polygonPoints = sPointsAttributeValue.reduce((acc, item) => acc + item.x + ',' + item.y + ' ', '');
                    this.pointsArray.push(polygonPoints);
                }
                break;
            }
            case 'linearup':
                this.binaryString = this._convertAngleToBinary(90);
                this._assignBinaryValue(this.binaryString);
                break;
            case 'lineardown':
                this.binaryString = this._convertAngleToBinary(270);
                this._assignBinaryValue(this.binaryString);
                break;
            case 'linearleft':
                this.binaryString = this._convertAngleToBinary(180);
                this._assignBinaryValue(this.binaryString);
                break;
            default:
                throw new Error(`fdStatusIndicator: No fillType found for ${this.fillingType}.`);
        }
    }
    /** @hidden */
    _convertAngleToBinary(angle) {
        if (angle > 0 && angle <= 45) {
            return '1,0,0,1';
        }
        else if (angle >= 45 && angle < 90) {
            return '0,0,0,1';
        }
        else if (angle >= 90 && angle < 135) {
            return '0,0,0,1';
        }
        else if (angle >= 135 && angle < 180) {
            return '0,0,1,1';
        }
        else if (angle >= 180 && angle < 225) {
            return '0,0,1,0';
        }
        else if (angle >= 225 && angle < 270) {
            return '0,1,1,0';
        }
        else if (angle >= 270 && angle < 315) {
            return '0,1,0,0';
        }
        else if (angle >= 315 && angle < 360) {
            return '1,1,0,0';
        }
        else if (angle === 0 || angle === 360) {
            return '1,0,0,0';
        }
        else {
            return 'invalid';
        }
    }
    /** @hidden */
    _assignBinaryValue(binaryString) {
        const binaryValue = binaryString.split(',');
        this.x1 = binaryValue[0];
        this.y1 = binaryValue[1];
        this.x2 = binaryValue[2];
        this.y2 = binaryValue[3];
    }
    /** @hidden */
    _getPolygonPointsForCircularFilling(value, boundingBoxSvg) {
        const angle = 3.6 * value;
        const points = [];
        let xDifferenceFromBoundaryCentre;
        let yDifferenceFromBoundaryCentre;
        let polygonPoint;
        // starts at 12, the algorithm computes the coordination for clockwise direction only
        // counter clockwise direction is managed by symmetry
        const oStartPoint = new Point(boundingBoxSvg.x + boundingBoxSvg.width / 2, boundingBoxSvg.y);
        const oCentrePoint = new Point(boundingBoxSvg.x + boundingBoxSvg.width / 2, boundingBoxSvg.y + boundingBoxSvg.height / 2);
        // Reflects x coordinate by centre point for Counter Clockwise type
        const _adjustIfCounterClockwise = (oPoint) => {
            const res = Object.assign({}, oPoint);
            if (this._fillDirection === 'counterclockwise') {
                const iXDistanceFromCentre = oPoint.x - oCentrePoint.x;
                res.x = oCentrePoint.x - iXDistanceFromCentre;
            }
            return res;
        };
        // Boundary centre is given by angle distance from the beginning (0°). The returned difference is related
        // to x or y coordinate depending on boundary centre angle (e.g. 0° -> x, 90° -> y, 180° -> x  270° -> y).
        // Boundary length is length of the corresponding side of bounding box (width for x, height for y).
        const computeDifferenceFromBoundaryCentre = (inAngle, iBoundaryCentreAngle, iBoundaryLength) => {
            const tan = Math.tan(((iBoundaryCentreAngle - inAngle) * Math.PI) / 180);
            return (tan * iBoundaryLength) / 2;
        };
        points.push(oStartPoint);
        if (0 < angle && angle < 45) {
            xDifferenceFromBoundaryCentre = computeDifferenceFromBoundaryCentre(angle, 0, boundingBoxSvg.height);
            polygonPoint = new Point(oStartPoint.x - xDifferenceFromBoundaryCentre, oStartPoint.y);
            points.push(_adjustIfCounterClockwise(polygonPoint));
        }
        if (45 <= angle) {
            points.push(_adjustIfCounterClockwise(new Point(boundingBoxSvg.x + boundingBoxSvg.width, boundingBoxSvg.y)));
        }
        if (45 < angle && angle < 135) {
            yDifferenceFromBoundaryCentre = computeDifferenceFromBoundaryCentre(angle, 90, boundingBoxSvg.width);
            polygonPoint = new Point(boundingBoxSvg.x + boundingBoxSvg.width, boundingBoxSvg.y + boundingBoxSvg.height / 2 - yDifferenceFromBoundaryCentre);
            points.push(_adjustIfCounterClockwise(polygonPoint));
        }
        if (135 <= angle) {
            points.push(_adjustIfCounterClockwise(new Point(boundingBoxSvg.x + boundingBoxSvg.width, boundingBoxSvg.y + boundingBoxSvg.height)));
        }
        if (135 < angle && angle < 225) {
            xDifferenceFromBoundaryCentre = computeDifferenceFromBoundaryCentre(angle, 180, boundingBoxSvg.height);
            polygonPoint = new Point(boundingBoxSvg.x + boundingBoxSvg.width / 2 + xDifferenceFromBoundaryCentre, boundingBoxSvg.y + boundingBoxSvg.height);
            points.push(_adjustIfCounterClockwise(polygonPoint));
        }
        if (225 <= angle) {
            points.push(_adjustIfCounterClockwise(new Point(boundingBoxSvg.x, boundingBoxSvg.y + boundingBoxSvg.height)));
        }
        if (225 < angle && angle < 315) {
            yDifferenceFromBoundaryCentre = computeDifferenceFromBoundaryCentre(angle, 270, boundingBoxSvg.width);
            polygonPoint = new Point(boundingBoxSvg.x, boundingBoxSvg.y + boundingBoxSvg.height / 2 + yDifferenceFromBoundaryCentre);
            points.push(_adjustIfCounterClockwise(polygonPoint));
        }
        if (315 <= angle) {
            points.push(_adjustIfCounterClockwise(new Point(boundingBoxSvg.x, boundingBoxSvg.y)));
        }
        if (315 < angle && angle <= 360) {
            xDifferenceFromBoundaryCentre = computeDifferenceFromBoundaryCentre(angle, 360, boundingBoxSvg.height);
            polygonPoint = new Point(boundingBoxSvg.x + boundingBoxSvg.width / 2 - xDifferenceFromBoundaryCentre, boundingBoxSvg.y);
            points.push(_adjustIfCounterClockwise(polygonPoint));
        }
        points.push(oCentrePoint);
        return points;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: StatusIndicatorComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: StatusIndicatorComponent, isStandalone: true, selector: "fd-status-indicator", inputs: { id: "id", size: "size", status: "status", statusLabel: "statusLabel", viewBox: "viewBox", clickable: "clickable", labelSize: "labelSize", ariaLabel: "ariaLabel", ariaRoleDescription: "ariaRoleDescription", focusable: "focusable", role: "role", ariaValueText: "ariaValueText", title: "title", labelPosition: "labelPosition", path: "path", fillPercentage: "fillPercentage", fillDirection: "fillDirection", fillingType: "fillingType", angle: "angle" }, host: { properties: { "attr.aria-label": "ariaLabel", "attr.aria-roledescription": "ariaRoleDescription", "attr.focusable": "focusable", "attr.title": "title", "attr.role": "role", "attr.aria-valuetext": "ariaValueText", "attr.aria-valuenow": "fillPercentage ? fillPercentage : 0", "attr.aria-valuemin": "0", "attr.aria-valuemax": "100", "attr.tabindex": "focusable ? 0 : -1" } }, usesOnChanges: true, ngImport: i0, template: "@if (labelPosition === 'left' || labelPosition === 'top') {\n    <span\n        [class.fd-status-indicator__label--sm]=\"labelSize === 'sm'\"\n        [class.fd-status-indicator__label--md]=\"labelSize === 'md'\"\n        [class.fd-status-indicator__label--lg]=\"labelSize === 'lg'\"\n        [class.fd-status-indicator__label--xl]=\"labelSize === 'xl'\"\n        [class.fd-status-indicator__label--top]=\"labelPosition === 'top'\"\n        [class.fd-status-indicator__label--left]=\"labelPosition === 'left'\"\n        class=\"fd-status-indicator__label\"\n        >{{ statusLabel }}\n    </span>\n}\n<svg\n    [attr.id]=\"id\"\n    data-sap-ui=\"__shape0-__box21-24\"\n    version=\"1.1\"\n    [attr.viewBox]=\"viewBox\"\n    xlmns=\"http://www.w3.org/2000/svg\"\n    preserveAspectRatio=\"xMidYMid meet\"\n    class=\"fd-status-indicator__svg\"\n>\n    <ng-container [ngTemplateOutlet]=\"svgTemplate\"></ng-container>\n</svg>\n@if (labelPosition === 'right' || labelPosition === 'bottom') {\n    <span\n        [class.fd-status-indicator__label--sm]=\"labelSize === 'sm'\"\n        [class.fd-status-indicator__label--md]=\"labelSize === 'md'\"\n        [class.fd-status-indicator__label--lg]=\"labelSize === 'lg'\"\n        [class.fd-status-indicator__label--xl]=\"labelSize === 'xl'\"\n        [class.fd-status-indicator__label--right]=\"labelPosition === 'right'\"\n        [class.fd-status-indicator__label--bottom]=\"labelPosition === 'bottom'\"\n        class=\"fd-status-indicator__label\"\n        >{{ statusLabel }}\n    </span>\n}\n<ng-template #svgTemplate>\n    @for (path of path; track path; let i = $index) {\n        <svg\n            xlmns=\"http://www.w3.org/2000/svg\"\n            preserveAspectRatio=\"xMidYMid meet\"\n            overflow=\"visible\"\n            [attr.id]=\"id + i\"\n            data-sap-ui=\"id\"\n        >\n            <defs>\n                @if (!(fillCalculator - i > 0 && fillCalculator - i < 1) || fillingType !== 'radial') {\n                    <linearGradient\n                        id=\"{{ id + i }}-gradient\"\n                        [attr.x1]=\"x1\"\n                        [attr.y1]=\"y1\"\n                        [attr.x2]=\"x2\"\n                        [attr.y2]=\"y2\"\n                    >\n                        <stop [attr.offset]=\"fillCalculator - i\" stop-color=\"white\">\n                            <animate\n                                attributeName=\"offset\"\n                                attr.values=\"0, {{ fillCalculator - i }}\"\n                                repeatCount=\"1\"\n                                dur=\"1s\"\n                                begin=\"0s\"\n                            />\n                        </stop>\n                        <stop [attr.offset]=\"fillCalculator - i\" stop-color=\"transparent\">\n                            <animate\n                                attributeName=\"offset\"\n                                attr.values=\"0, {{ fillCalculator - i }}\"\n                                repeatCount=\"1\"\n                                dur=\"1s\"\n                                begin=\"0s\"\n                            />\n                        </stop>\n                    </linearGradient>\n                }\n                <mask #maskTemplate id=\"{{ id + i }}-mask\">\n                    @if (!(fillCalculator - i > 0 && fillCalculator - i < 1) || fillingType !== 'radial') {\n                        <path\n                            id=\"{{ id + i }}-mask-shape\"\n                            [attr.d]=\"path\"\n                            stroke-width=\"0\"\n                            stroke=\"white\"\n                            attr.fill=\"url(#{{ id + i }}-gradient)\"\n                        ></path>\n                    }\n                    @if (fillingType === 'radial' && fillCalculator - i > 0 && fillCalculator - i < 1) {\n                        <polygon id=\"{{ id + i }}-mask-shape\" fill=\"white\" [attr.points]=\"pointsArray[i]\"></polygon>\n                    }\n                </mask>\n            </defs>\n            <path\n                id=\"{{ id + i }}-shape\"\n                [attr.d]=\"path\"\n                stroke-width=\"0\"\n                stroke=\"#89919A\"\n                attr.mask=\"url(#{{ id + i }}-mask)\"\n            ></path>\n            <path\n                id=\"{{ id + i }}-shape-border\"\n                [attr.d]=\"path\"\n                stroke-width=\"0.25\"\n                stroke=\"#89919A\"\n                fill=\"transparent\"\n            ></path>\n        </svg>\n    }\n</ng-template>\n", styles: [".fd-status-indicator{color:var(--sapContent_LabelColor);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;stroke:var(--sapNeutralElementColor);stroke-width:.25;fill:transparent;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:center;-ms-flex-align:center;align-items:center;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-status-indicator.is-focus,.fd-status-indicator:focus{outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);outline-offset:var(--sapContent_FocusWidth);z-index:5}.fd-status-indicator:after,.fd-status-indicator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-status-indicator--horizontal-label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row}.fd-status-indicator--horizontal-label:after,.fd-status-indicator--horizontal-label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-status-indicator--link{cursor:pointer}.fd-status-indicator__label,.fd-status-indicator__label--sm{font-size:var(--sapFontSmallSize,.75rem)}.fd-status-indicator__label--sm.fd-status-indicator__label--top{-webkit-margin-after:.375rem;margin-block-end:.375rem}.fd-status-indicator__label--sm.fd-status-indicator__label--right{-webkit-margin-start:.375rem;margin-inline-start:.375rem}.fd-status-indicator__label--sm.fd-status-indicator__label--right[dir=rtl],[dir=rtl] .fd-status-indicator__label--sm.fd-status-indicator__label--right{-webkit-transform:matrix(1,0,0,1,22,1);transform:matrix(1,0,0,1,22,1)}.fd-status-indicator__label--sm.fd-status-indicator__label--left{-webkit-margin-end:.375rem;margin-inline-end:.375rem}.fd-status-indicator__label--sm.fd-status-indicator__label--left[dir=rtl],[dir=rtl] .fd-status-indicator__label--sm.fd-status-indicator__label--left{-webkit-transform:matrix(1,0,0,1,-22,1);transform:matrix(1,0,0,1,-22,1)}.fd-status-indicator__label--sm.fd-status-indicator__label--bottom{margin-top:.375rem}.fd-status-indicator__label--md{font-size:var(--sapFontSize,.875rem)}.fd-status-indicator__label--md.fd-status-indicator__label--top{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-status-indicator__label--md.fd-status-indicator__label--right{-webkit-margin-start:.5rem;margin-inline-start:.5rem}.fd-status-indicator__label--md.fd-status-indicator__label--right[dir=rtl],[dir=rtl] .fd-status-indicator__label--md.fd-status-indicator__label--right{-webkit-transform:matrix(1,0,0,1,22,1);transform:matrix(1,0,0,1,22,1)}.fd-status-indicator__label--md.fd-status-indicator__label--left{-webkit-margin-end:.5rem;margin-inline-end:.5rem}.fd-status-indicator__label--md.fd-status-indicator__label--left[dir=rtl],[dir=rtl] .fd-status-indicator__label--md.fd-status-indicator__label--left{-webkit-transform:matrix(1,0,0,1,-22,1);transform:matrix(1,0,0,1,-22,1)}.fd-status-indicator__label--md.fd-status-indicator__label--bottom{margin-top:.5rem}.fd-status-indicator__label--lg{font-size:1.125rem}.fd-status-indicator__label--lg.fd-status-indicator__label--top{-webkit-margin-after:.75rem;margin-block-end:.75rem}.fd-status-indicator__label--lg.fd-status-indicator__label--right{-webkit-margin-start:.75rem;margin-inline-start:.75rem}.fd-status-indicator__label--lg.fd-status-indicator__label--right[dir=rtl],[dir=rtl] .fd-status-indicator__label--lg.fd-status-indicator__label--right{-webkit-transform:matrix(1,0,0,1,22,1);transform:matrix(1,0,0,1,22,1)}.fd-status-indicator__label--lg.fd-status-indicator__label--left{-webkit-margin-end:.75rem;margin-inline-end:.75rem}.fd-status-indicator__label--lg.fd-status-indicator__label--left[dir=rtl],[dir=rtl] .fd-status-indicator__label--lg.fd-status-indicator__label--left{-webkit-transform:matrix(1,0,0,1,-22,1);transform:matrix(1,0,0,1,-22,1)}.fd-status-indicator__label--lg.fd-status-indicator__label--bottom{margin-top:.75rem}.fd-status-indicator__label--xl{font-size:1.875rem}.fd-status-indicator__label--xl.fd-status-indicator__label--top{-webkit-margin-after:1rem;margin-block-end:1rem}.fd-status-indicator__label--xl.fd-status-indicator__label--right{-webkit-margin-start:1rem;margin-inline-start:1rem}.fd-status-indicator__label--xl.fd-status-indicator__label--right[dir=rtl],[dir=rtl] .fd-status-indicator__label--xl.fd-status-indicator__label--right{-webkit-transform:matrix(1,0,0,1,22,1);transform:matrix(1,0,0,1,22,1)}.fd-status-indicator__label--xl.fd-status-indicator__label--left{-webkit-margin-end:1rem;margin-inline-end:1rem}.fd-status-indicator__label--xl.fd-status-indicator__label--left[dir=rtl],[dir=rtl] .fd-status-indicator__label--xl.fd-status-indicator__label--left{-webkit-transform:matrix(1,0,0,1,-22,1);transform:matrix(1,0,0,1,-22,1)}.fd-status-indicator__label--xl.fd-status-indicator__label--bottom{margin-top:1rem}.fd-status-indicator--positive{fill:var(--sapPositiveElementColor);color:var(--sapPositiveElementColor)}.fd-status-indicator--critical{fill:var(--sapCriticalElementColor);color:var(--sapCriticalElementColor)}.fd-status-indicator--negative{fill:var(--sapNegativeElementColor);color:var(--sapNegativeElementColor)}.fd-status-indicator--sm .fd-status-indicator__svg{height:1.375rem;width:1.875rem}.fd-status-indicator--md .fd-status-indicator__svg{height:1.875rem;width:2.8125rem}.fd-status-indicator--lg .fd-status-indicator__svg{height:3.4375rem;width:5rem}.fd-status-indicator--xl .fd-status-indicator__svg{height:6.25rem;width:9.0625rem}\n/*! Bundled license information:\n\nfundamental-styles/dist/status-indicator.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], StatusIndicatorComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: StatusIndicatorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-status-indicator', host: {
                        '[attr.aria-label]': 'ariaLabel',
                        '[attr.aria-roledescription]': 'ariaRoleDescription',
                        '[attr.focusable]': 'focusable',
                        '[attr.title]': 'title',
                        '[attr.role]': 'role',
                        '[attr.aria-valuetext]': 'ariaValueText',
                        '[attr.aria-valuenow]': 'fillPercentage ? fillPercentage : 0',
                        '[attr.aria-valuemin]': '0',
                        '[attr.aria-valuemax]': '100',
                        '[attr.tabindex]': 'focusable ? 0 : -1'
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, imports: [NgTemplateOutlet], template: "@if (labelPosition === 'left' || labelPosition === 'top') {\n    <span\n        [class.fd-status-indicator__label--sm]=\"labelSize === 'sm'\"\n        [class.fd-status-indicator__label--md]=\"labelSize === 'md'\"\n        [class.fd-status-indicator__label--lg]=\"labelSize === 'lg'\"\n        [class.fd-status-indicator__label--xl]=\"labelSize === 'xl'\"\n        [class.fd-status-indicator__label--top]=\"labelPosition === 'top'\"\n        [class.fd-status-indicator__label--left]=\"labelPosition === 'left'\"\n        class=\"fd-status-indicator__label\"\n        >{{ statusLabel }}\n    </span>\n}\n<svg\n    [attr.id]=\"id\"\n    data-sap-ui=\"__shape0-__box21-24\"\n    version=\"1.1\"\n    [attr.viewBox]=\"viewBox\"\n    xlmns=\"http://www.w3.org/2000/svg\"\n    preserveAspectRatio=\"xMidYMid meet\"\n    class=\"fd-status-indicator__svg\"\n>\n    <ng-container [ngTemplateOutlet]=\"svgTemplate\"></ng-container>\n</svg>\n@if (labelPosition === 'right' || labelPosition === 'bottom') {\n    <span\n        [class.fd-status-indicator__label--sm]=\"labelSize === 'sm'\"\n        [class.fd-status-indicator__label--md]=\"labelSize === 'md'\"\n        [class.fd-status-indicator__label--lg]=\"labelSize === 'lg'\"\n        [class.fd-status-indicator__label--xl]=\"labelSize === 'xl'\"\n        [class.fd-status-indicator__label--right]=\"labelPosition === 'right'\"\n        [class.fd-status-indicator__label--bottom]=\"labelPosition === 'bottom'\"\n        class=\"fd-status-indicator__label\"\n        >{{ statusLabel }}\n    </span>\n}\n<ng-template #svgTemplate>\n    @for (path of path; track path; let i = $index) {\n        <svg\n            xlmns=\"http://www.w3.org/2000/svg\"\n            preserveAspectRatio=\"xMidYMid meet\"\n            overflow=\"visible\"\n            [attr.id]=\"id + i\"\n            data-sap-ui=\"id\"\n        >\n            <defs>\n                @if (!(fillCalculator - i > 0 && fillCalculator - i < 1) || fillingType !== 'radial') {\n                    <linearGradient\n                        id=\"{{ id + i }}-gradient\"\n                        [attr.x1]=\"x1\"\n                        [attr.y1]=\"y1\"\n                        [attr.x2]=\"x2\"\n                        [attr.y2]=\"y2\"\n                    >\n                        <stop [attr.offset]=\"fillCalculator - i\" stop-color=\"white\">\n                            <animate\n                                attributeName=\"offset\"\n                                attr.values=\"0, {{ fillCalculator - i }}\"\n                                repeatCount=\"1\"\n                                dur=\"1s\"\n                                begin=\"0s\"\n                            />\n                        </stop>\n                        <stop [attr.offset]=\"fillCalculator - i\" stop-color=\"transparent\">\n                            <animate\n                                attributeName=\"offset\"\n                                attr.values=\"0, {{ fillCalculator - i }}\"\n                                repeatCount=\"1\"\n                                dur=\"1s\"\n                                begin=\"0s\"\n                            />\n                        </stop>\n                    </linearGradient>\n                }\n                <mask #maskTemplate id=\"{{ id + i }}-mask\">\n                    @if (!(fillCalculator - i > 0 && fillCalculator - i < 1) || fillingType !== 'radial') {\n                        <path\n                            id=\"{{ id + i }}-mask-shape\"\n                            [attr.d]=\"path\"\n                            stroke-width=\"0\"\n                            stroke=\"white\"\n                            attr.fill=\"url(#{{ id + i }}-gradient)\"\n                        ></path>\n                    }\n                    @if (fillingType === 'radial' && fillCalculator - i > 0 && fillCalculator - i < 1) {\n                        <polygon id=\"{{ id + i }}-mask-shape\" fill=\"white\" [attr.points]=\"pointsArray[i]\"></polygon>\n                    }\n                </mask>\n            </defs>\n            <path\n                id=\"{{ id + i }}-shape\"\n                [attr.d]=\"path\"\n                stroke-width=\"0\"\n                stroke=\"#89919A\"\n                attr.mask=\"url(#{{ id + i }}-mask)\"\n            ></path>\n            <path\n                id=\"{{ id + i }}-shape-border\"\n                [attr.d]=\"path\"\n                stroke-width=\"0.25\"\n                stroke=\"#89919A\"\n                fill=\"transparent\"\n            ></path>\n        </svg>\n    }\n</ng-template>\n", styles: [".fd-status-indicator{color:var(--sapContent_LabelColor);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;stroke:var(--sapNeutralElementColor);stroke-width:.25;fill:transparent;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:center;-ms-flex-align:center;align-items:center;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-status-indicator.is-focus,.fd-status-indicator:focus{outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);outline-offset:var(--sapContent_FocusWidth);z-index:5}.fd-status-indicator:after,.fd-status-indicator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-status-indicator--horizontal-label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row}.fd-status-indicator--horizontal-label:after,.fd-status-indicator--horizontal-label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-status-indicator--link{cursor:pointer}.fd-status-indicator__label,.fd-status-indicator__label--sm{font-size:var(--sapFontSmallSize,.75rem)}.fd-status-indicator__label--sm.fd-status-indicator__label--top{-webkit-margin-after:.375rem;margin-block-end:.375rem}.fd-status-indicator__label--sm.fd-status-indicator__label--right{-webkit-margin-start:.375rem;margin-inline-start:.375rem}.fd-status-indicator__label--sm.fd-status-indicator__label--right[dir=rtl],[dir=rtl] .fd-status-indicator__label--sm.fd-status-indicator__label--right{-webkit-transform:matrix(1,0,0,1,22,1);transform:matrix(1,0,0,1,22,1)}.fd-status-indicator__label--sm.fd-status-indicator__label--left{-webkit-margin-end:.375rem;margin-inline-end:.375rem}.fd-status-indicator__label--sm.fd-status-indicator__label--left[dir=rtl],[dir=rtl] .fd-status-indicator__label--sm.fd-status-indicator__label--left{-webkit-transform:matrix(1,0,0,1,-22,1);transform:matrix(1,0,0,1,-22,1)}.fd-status-indicator__label--sm.fd-status-indicator__label--bottom{margin-top:.375rem}.fd-status-indicator__label--md{font-size:var(--sapFontSize,.875rem)}.fd-status-indicator__label--md.fd-status-indicator__label--top{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-status-indicator__label--md.fd-status-indicator__label--right{-webkit-margin-start:.5rem;margin-inline-start:.5rem}.fd-status-indicator__label--md.fd-status-indicator__label--right[dir=rtl],[dir=rtl] .fd-status-indicator__label--md.fd-status-indicator__label--right{-webkit-transform:matrix(1,0,0,1,22,1);transform:matrix(1,0,0,1,22,1)}.fd-status-indicator__label--md.fd-status-indicator__label--left{-webkit-margin-end:.5rem;margin-inline-end:.5rem}.fd-status-indicator__label--md.fd-status-indicator__label--left[dir=rtl],[dir=rtl] .fd-status-indicator__label--md.fd-status-indicator__label--left{-webkit-transform:matrix(1,0,0,1,-22,1);transform:matrix(1,0,0,1,-22,1)}.fd-status-indicator__label--md.fd-status-indicator__label--bottom{margin-top:.5rem}.fd-status-indicator__label--lg{font-size:1.125rem}.fd-status-indicator__label--lg.fd-status-indicator__label--top{-webkit-margin-after:.75rem;margin-block-end:.75rem}.fd-status-indicator__label--lg.fd-status-indicator__label--right{-webkit-margin-start:.75rem;margin-inline-start:.75rem}.fd-status-indicator__label--lg.fd-status-indicator__label--right[dir=rtl],[dir=rtl] .fd-status-indicator__label--lg.fd-status-indicator__label--right{-webkit-transform:matrix(1,0,0,1,22,1);transform:matrix(1,0,0,1,22,1)}.fd-status-indicator__label--lg.fd-status-indicator__label--left{-webkit-margin-end:.75rem;margin-inline-end:.75rem}.fd-status-indicator__label--lg.fd-status-indicator__label--left[dir=rtl],[dir=rtl] .fd-status-indicator__label--lg.fd-status-indicator__label--left{-webkit-transform:matrix(1,0,0,1,-22,1);transform:matrix(1,0,0,1,-22,1)}.fd-status-indicator__label--lg.fd-status-indicator__label--bottom{margin-top:.75rem}.fd-status-indicator__label--xl{font-size:1.875rem}.fd-status-indicator__label--xl.fd-status-indicator__label--top{-webkit-margin-after:1rem;margin-block-end:1rem}.fd-status-indicator__label--xl.fd-status-indicator__label--right{-webkit-margin-start:1rem;margin-inline-start:1rem}.fd-status-indicator__label--xl.fd-status-indicator__label--right[dir=rtl],[dir=rtl] .fd-status-indicator__label--xl.fd-status-indicator__label--right{-webkit-transform:matrix(1,0,0,1,22,1);transform:matrix(1,0,0,1,22,1)}.fd-status-indicator__label--xl.fd-status-indicator__label--left{-webkit-margin-end:1rem;margin-inline-end:1rem}.fd-status-indicator__label--xl.fd-status-indicator__label--left[dir=rtl],[dir=rtl] .fd-status-indicator__label--xl.fd-status-indicator__label--left{-webkit-transform:matrix(1,0,0,1,-22,1);transform:matrix(1,0,0,1,-22,1)}.fd-status-indicator__label--xl.fd-status-indicator__label--bottom{margin-top:1rem}.fd-status-indicator--positive{fill:var(--sapPositiveElementColor);color:var(--sapPositiveElementColor)}.fd-status-indicator--critical{fill:var(--sapCriticalElementColor);color:var(--sapCriticalElementColor)}.fd-status-indicator--negative{fill:var(--sapNegativeElementColor);color:var(--sapNegativeElementColor)}.fd-status-indicator--sm .fd-status-indicator__svg{height:1.375rem;width:1.875rem}.fd-status-indicator--md .fd-status-indicator__svg{height:1.875rem;width:2.8125rem}.fd-status-indicator--lg .fd-status-indicator__svg{height:3.4375rem;width:5rem}.fd-status-indicator--xl .fd-status-indicator__svg{height:6.25rem;width:9.0625rem}\n/*! Bundled license information:\n\nfundamental-styles/dist/status-indicator.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }], propDecorators: { id: [{
                type: Input
            }], size: [{
                type: Input
            }], status: [{
                type: Input
            }], statusLabel: [{
                type: Input
            }], viewBox: [{
                type: Input
            }], clickable: [{
                type: Input
            }], labelSize: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], ariaRoleDescription: [{
                type: Input
            }], focusable: [{
                type: Input
            }], role: [{
                type: Input
            }], ariaValueText: [{
                type: Input
            }], title: [{
                type: Input
            }], labelPosition: [{
                type: Input
            }], path: [{
                type: Input
            }], fillPercentage: [{
                type: Input
            }], fillDirection: [{
                type: Input
            }], fillingType: [{
                type: Input
            }], angle: [{
                type: Input
            }], buildComponentCssClass: [] } });

class StatusIndicatorModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: StatusIndicatorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: StatusIndicatorModule, imports: [StatusIndicatorComponent], exports: [StatusIndicatorComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: StatusIndicatorModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: StatusIndicatorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [StatusIndicatorComponent],
                    exports: [StatusIndicatorComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { Point, StatusIndicatorComponent, StatusIndicatorModule };
//# sourceMappingURL=fundamental-ngx-core-status-indicator.mjs.map
