import * as i0 from '@angular/core';
import { Directive, HostBinding, Input, ViewEncapsulation, ChangeDetectionStrategy, Component, EventEmitter, HostListener, Output, ContentChild, InjectionToken, TemplateRef, Optional, Inject, inject, NgZone, ElementRef, ViewChild, ViewChildren, forwardRef, ContentChildren, DestroyRef, NgModule } from '@angular/core';
import { FD_DEFAULT_ICON_FONT_FAMILY, IconComponent } from '@fundamental-ngx/core/icon';
import { FdTranslatePipe } from '@fundamental-ngx/i18n';
import { __decorate, __metadata } from 'tslib';
import * as i2 from '@fundamental-ngx/cdk/utils';
import { applyCssClass, AbstractFdNgxClass, KeyUtil, warnOnce, scrollTop } from '@fundamental-ngx/cdk/utils';
import { ENTER, SPACE, LEFT_ARROW, RIGHT_ARROW } from '@angular/cdk/keycodes';
import { CdkScrollable } from '@angular/cdk/overlay';
import { NgTemplateOutlet } from '@angular/common';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import * as i1 from '@fundamental-ngx/core/content-density';
import { contentDensityObserverProviders } from '@fundamental-ngx/core/content-density';
import { MenuTriggerDirective, MenuComponent, MenuItemComponent, MenuInteractiveComponent, MenuTitleDirective } from '@fundamental-ngx/core/menu';
import { OverflowLayoutComponent, OverflowItemRefDirective, OverflowLayoutItemDirective, OverflowLayoutFocusableItemDirective, OverflowExpandDirective } from '@fundamental-ngx/core/overflow-layout';
import { ScrollSpyDirective } from '@fundamental-ngx/core/scroll-spy';
import { ScrollbarDirective } from '@fundamental-ngx/core/scrollbar';
import { FD_TABLIST } from '@fundamental-ngx/core/shared';
import { Subject, first, Subscription, merge, fromEvent } from 'rxjs';
import { startWith, map, filter, delay, tap, switchMap, take, debounceTime, first as first$1 } from 'rxjs/operators';
import { FocusKeyManager } from '@angular/cdk/a11y';

/**
 * Directive used to identify the template which will populate the tab header.
 * Used to achieve complex headers that require more than a string.
 *
 * ```html
 * <fd-tab>
 *      <ng-template fd-tab-title>
 *          <fd-icon [glyph]="'delete'"></fd-icon>
 *          <span>Tab Label</span>
 *      </ng-template>
 * </fd-tab>
 * ```
 */
class TabTitleDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabTitleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabTitleDirective, isStandalone: true, selector: "[fdTabTitleTemplate], [fd-tab-title-template]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTabTitleTemplate], [fd-tab-title-template]',
                    standalone: true
                }]
        }] });
/**
 * Directive for counter element, available in most of the modes on `tab` component
 */
class TabCountDirective {
    constructor() {
        /** @hidden */
        this.fdTabsCountClass = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabCountDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabCountDirective, isStandalone: true, selector: "[fdTabCount], [fd-tab-count]", host: { properties: { "class.fd-tabs__count": "this.fdTabsCountClass" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabCountDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTabCount], [fd-tab-count]',
                    standalone: true
                }]
        }], propDecorators: { fdTabsCountClass: [{
                type: HostBinding,
                args: ['class.fd-tabs__count']
            }] } });
/**
 * Directive for icon element, available in most of the modes on `tab` component
 */
class TabIconComponent {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /** Icon font family */
        this.iconFont = FD_DEFAULT_ICON_FONT_FAMILY;
    }
    /** @hidden CssClassBuilder interface implementation
     * function must return single string
     * function is responsible for order which css classes are applied
     */
    buildComponentCssClass() {
        return ['fd-tabs__icon', this.class];
    }
    /** @hidden
     * Function runs when component is initialized
     * function should build component css class
     * function should build css style
     */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabIconComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: TabIconComponent, isStandalone: true, selector: "[fd-tab-icon]", inputs: { class: "class", icon: "icon", iconFont: "iconFont" }, usesOnChanges: true, ngImport: i0, template: `
        @if (icon) {
            <fd-icon role="presentation" [glyph]="icon" [font]="iconFont"></fd-icon>
        }
        <ng-content></ng-content>
    `, isInline: true, dependencies: [{ kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], TabIconComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabIconComponent, decorators: [{
            type: Component,
            args: [{
                    // eslint-disable-next-line @angular-eslint/component-selector
                    selector: '[fd-tab-icon]',
                    template: `
        @if (icon) {
            <fd-icon role="presentation" [glyph]="icon" [font]="iconFont"></fd-icon>
        }
        <ng-content></ng-content>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    imports: [IconComponent]
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { class: [{
                type: Input
            }], icon: [{
                type: Input
            }], iconFont: [{
                type: Input
            }], buildComponentCssClass: [] } });
class TabTagDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabTagDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabTagDirective, isStandalone: true, selector: "[fdTabTag], [fd-tab-tag]", host: { classAttribute: "fd-tabs__tag" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabTagDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTabTag], [fd-tab-tag]',
                    host: {
                        class: 'fd-tabs__tag'
                    },
                    standalone: true
                }]
        }] });
class TabLabelDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabLabelDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabLabelDirective, isStandalone: true, selector: "[fdTabLabel], [fd-tab-label]", host: { classAttribute: "fd-tabs__label" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabLabelDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTabLabel], [fd-tab-label]',
                    host: {
                        class: 'fd-tabs__label'
                    },
                    standalone: true
                }]
        }] });
class TabProcessDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabProcessDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabProcessDirective, isStandalone: true, selector: "[fdTabProcess], [fd-tab-process]", host: { classAttribute: "fd-tabs__process" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabProcessDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTabProcess], [fd-tab-process]',
                    host: {
                        class: 'fd-tabs__process'
                    },
                    standalone: true
                }]
        }] });
class TabHeaderDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabHeaderDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabHeaderDirective, isStandalone: true, selector: "[fdTabHeader], [fd-tab-header]", host: { classAttribute: "fd-tabs__header" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabHeaderDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTabHeader], [fd-tab-header]',
                    host: {
                        class: 'fd-tabs__header'
                    },
                    standalone: true
                }]
        }] });
class TabCounterHeaderDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabCounterHeaderDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabCounterHeaderDirective, isStandalone: true, selector: "[fdTabCounterHeader], [fd-tab-counter-header]", host: { classAttribute: "fd-tabs__counter-header" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabCounterHeaderDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTabCounterHeader], [fd-tab-counter-header]',
                    host: {
                        class: 'fd-tabs__counter-header'
                    },
                    standalone: true
                }]
        }] });
class TabProcessIconDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabProcessIconDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabProcessIconDirective, isStandalone: true, selector: "[fdTabProcessIcon], [fd-tab-process-icon]", host: { classAttribute: "fd-tabs__process-icon" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabProcessIconDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTabProcessIcon], [fd-tab-process-icon]',
                    host: {
                        class: 'fd-tabs__process-icon'
                    },
                    standalone: true
                }]
        }] });
class TabSeparatorDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabSeparatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabSeparatorDirective, isStandalone: true, selector: "[fdTabSeparator], [fd-tab-separator]", host: { classAttribute: "fd-tabs__separator" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabSeparatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTabSeparator], [fd-tab-separator]',
                    host: {
                        class: 'fd-tabs__separator'
                    },
                    standalone: true
                }]
        }] });

/**
 * Represents a list of tab-panels.
 */
class TabItemExpandComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabItemExpandComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: TabItemExpandComponent, isStandalone: true, selector: "fd-item-expand", host: { attributes: { "role": "tab" }, classAttribute: "fd-tabs__item fd-tabs__item--overflow" }, ngImport: i0, template: "<a class=\"fd-tabs__link\" role=\"tab\" [attr.tabindex]=\"0\">\n    <span fd-tab-tag>{{ 'coreTabs.tabListExpandButtonText' | fdTranslate }}</span>\n    <fd-icon glyph=\"slim-arrow-down\" aria-label=\"See More\"></fd-icon>\n</a>\n", styles: [".fd-tabs__item--overflow{margin-left:auto;margin-right:0}[dir=rtl] .fd-tabs__item--overflow,.fd-tabs__item--overflow[dir=rtl]{margin-left:0;margin-right:auto}.fd-tabs__item--overflow fd-icon:not(:only-child){margin-left:.5rem}[dir=rtl] .fd-tabs__item--overflow fd-icon:not(:only-child),.fd-tabs__item--overflow fd-icon:not(:only-child)[dir=rtl]{margin-left:0;margin-right:.5rem}\n"], dependencies: [{ kind: "directive", type: TabTagDirective, selector: "[fdTabTag], [fd-tab-tag]" }, { kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabItemExpandComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-item-expand', host: {
                        role: 'tab',
                        class: 'fd-tabs__item fd-tabs__item--overflow'
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, imports: [TabTagDirective, IconComponent, FdTranslatePipe], template: "<a class=\"fd-tabs__link\" role=\"tab\" [attr.tabindex]=\"0\">\n    <span fd-tab-tag>{{ 'coreTabs.tabListExpandButtonText' | fdTranslate }}</span>\n    <fd-icon glyph=\"slim-arrow-down\" aria-label=\"See More\"></fd-icon>\n</a>\n", styles: [".fd-tabs__item--overflow{margin-left:auto;margin-right:0}[dir=rtl] .fd-tabs__item--overflow,.fd-tabs__item--overflow[dir=rtl]{margin-left:0;margin-right:auto}.fd-tabs__item--overflow fd-icon:not(:only-child){margin-left:.5rem}[dir=rtl] .fd-tabs__item--overflow fd-icon:not(:only-child),.fd-tabs__item--overflow fd-icon:not(:only-child)[dir=rtl]{margin-left:0;margin-right:.5rem}\n"] }]
        }] });

/**
 * Tab link for nav mode
 *
 * ```html
 * <a fd-tab-link>
 *    link
 * </a>
 * ```
 */
class TabLinkDirective extends AbstractFdNgxClass {
    constructor() {
        super(...arguments);
        /** Event Emitted always when, any keyboard event is dispatched on this element */
        this.keyDown = new EventEmitter();
        /** Event Emitted when item has been focused. */
        this.focused = new EventEmitter();
    }
    /** @hidden */
    _onFocus() {
        this.focused.emit();
    }
    /** @hidden */
    _onKeyUp(event) {
        if (KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            this.focused.emit();
        }
    }
    /** @hidden */
    _setProperties() {
        this._addClassToElement('fd-tabs__link');
        if (this.active) {
            this._addClassToElement('is-selected');
        }
    }
    /** @hidden */
    focus() {
        this.elementRef.nativeElement.focus();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabLinkDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabLinkDirective, isStandalone: true, selector: "[fd-tab-link]", inputs: { active: "active", disabled: "disabled" }, outputs: { keyDown: "keyDown", focused: "focused" }, host: { attributes: { "role": "tab", "tabindex": "-1" }, listeners: { "focus": "_onFocus()", "keyup": "_onKeyUp($event)" }, properties: { "attr.aria-selected": "this.active", "attr.aria-disabled": "this.disabled", "class.is-disabled": "this.disabled" } }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabLinkDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-tab-link]',
                    host: {
                        role: 'tab',
                        tabindex: '-1'
                    },
                    standalone: true
                }]
        }], propDecorators: { active: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-selected']
            }], disabled: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-disabled']
            }, {
                type: HostBinding,
                args: ['class.is-disabled']
            }], keyDown: [{
                type: Output
            }], focused: [{
                type: Output
            }], _onFocus: [{
                type: HostListener,
                args: ['focus']
            }], _onKeyUp: [{
                type: HostListener,
                args: ['keyup', ['$event']]
            }] } });

/**
 * Tab Item is optional wrapper for Tab link
 *
 * ```html
 * <div fd-tab-item>
 *    <a fd-tab-link>
 *        link
 *    </a>
 * </div>
 * ```
 */
class TabItemDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /** Apply user custom styles */
        this.class = '';
        /** Disabled state for tab item */
        this.disabled = false;
        /** Defines if there will be added fd-tabs__item class. Enabled by default. */
        this.fdTabItemClass = true;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [
            this.fdTabItemClass ? 'fd-tabs__item' : '',
            this.header ? 'fd-tabs__item--header' : '',
            this.tabItemState ? `fd-tabs__item--${this.tabItemState}` : '',
            this.class
        ];
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabItemDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TabItemDirective, isStandalone: true, selector: "[fd-tab-item]", inputs: { class: "class", tabItemState: "tabItemState", header: "header", disabled: "disabled", fdTabItemClass: "fdTabItemClass" }, host: { properties: { "attr.aria-disabled": "this.disabled", "class.is-disabled": "this.disabled" } }, queries: [{ propertyName: "linkItem", first: true, predicate: TabLinkDirective, descendants: true }], usesOnChanges: true, ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], TabItemDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabItemDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-tab-item]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { class: [{
                type: Input
            }], tabItemState: [{
                type: Input
            }], header: [{
                type: Input
            }], disabled: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-disabled']
            }, {
                type: HostBinding,
                args: ['class.is-disabled']
            }], fdTabItemClass: [{
                type: Input
            }], linkItem: [{
                type: ContentChild,
                args: [TabLinkDirective]
            }], buildComponentCssClass: [] } });

const LIST_COMPONENT = new InjectionToken('ListComponent');

let tabPanelUniqueId = 0;
class TabPanelStateChange {
    /**
     * Tab panel state change event
     * @param target Tab panel that is being changed
     * @param state New state of the tab panel
     */
    constructor(target, state) {
        this.target = target;
        this.state = state;
    }
}
/**
 * Represents the body of a tab element. It also contains elements pertaining to the associated tab header.
 */
class TabPanelComponent {
    /** @hidden */
    get _panelId() {
        return this.id + '-panel';
    }
    /** @hidden */
    constructor(elementRef, _changeDetRef, _ngZone, _tabsComponent) {
        this.elementRef = elementRef;
        this._changeDetRef = _changeDetRef;
        this._ngZone = _ngZone;
        this._tabsComponent = _tabsComponent;
        /** Id of the tab. If none is provided, one will be generated. */
        this.id = 'fd-tab-panel' + tabPanelUniqueId++;
        /** Glyph icon, it can be used only on  */
        this.header = false;
        /** Disabled state for tab item */
        this.disabled = false;
        /** Event that is emitted when the tab panel has been opened. */
        this.opened = new EventEmitter();
        /** Event that is emitted when the tab panel has been closed. */
        this.closed = new EventEmitter();
        /** @hidden */
        this._expandedClass = false;
        /** @hidden Event that is emitted when the tab panel . */
        this._expandedStateChange = new Subject();
        /** @hidden */
        this._forcedVisibility = false;
        /** @hidden Whether to display tab panel content */
        this._expanded = false;
    }
    /** @hidden
     * Thanks to OnPush change strategy detection on tab-list parent component,
     * every change of any property should be reported. */
    ngOnChanges() {
        this._tabsComponent?.tabPanelPropertyChanged.next();
    }
    /** Whether tab panel content is expanded */
    get expanded() {
        return this._expanded;
    }
    /** Whether to expand tab panel content */
    open(open) {
        this._expandedStateChange.next(new TabPanelStateChange(this, open));
    }
    /** @hidden Set new expand state */
    _expand(expanded) {
        if (this._expanded !== expanded) {
            this._expanded = expanded;
            if (expanded) {
                this.opened.emit();
            }
            else {
                this.closed.emit();
            }
            this._changeDetRef.detectChanges();
            this._ngZone.onStable.pipe(first()).subscribe(() => this._updateHost());
        }
    }
    /** @hidden */
    _focusFirstFocusableElement() {
        this.elementRef.nativeElement
            .querySelector('button, [href], input, select, textarea, [tabindex]:not([tabindex="-1"])')
            ?.focus({ preventScroll: true });
    }
    /** @hidden */
    _updateHost() {
        this._expandedClass = this.expanded;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabPanelComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: i0.NgZone }, { token: LIST_COMPONENT, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: TabPanelComponent, isStandalone: true, selector: "fd-tab", inputs: { id: "id", ariaLabel: "ariaLabel", ariaLabelledBy: "ariaLabelledBy", title: "title", count: "count", glyph: "glyph", header: "header", disabled: "disabled", tabState: "tabState" }, outputs: { opened: "opened", closed: "closed" }, host: { attributes: { "role": "tabpanel" }, properties: { "id": "_panelId", "attr.aria-labelledby": "id", "class.is-expanded": "this._expandedClass" }, classAttribute: "fd-tabs__panel" }, queries: [{ propertyName: "titleTemplate", first: true, predicate: TabTitleDirective, descendants: true, read: TemplateRef }], usesOnChanges: true, ngImport: i0, template: "@if (expanded) {\n    <ng-content></ng-content>\n}\n", changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabPanelComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-tab', host: {
                        role: 'tabpanel',
                        class: 'fd-tabs__panel',
                        '[id]': '_panelId',
                        '[attr.aria-labelledby]': 'id'
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, imports: [], template: "@if (expanded) {\n    <ng-content></ng-content>\n}\n" }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i0.NgZone }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [LIST_COMPONENT]
                }] }], propDecorators: { id: [{
                type: Input
            }], ariaLabel: [{
                type: Input
            }], ariaLabelledBy: [{
                type: Input
            }], title: [{
                type: Input
            }], count: [{
                type: Input
            }], glyph: [{
                type: Input
            }], header: [{
                type: Input
            }], disabled: [{
                type: Input
            }], tabState: [{
                type: Input
            }], opened: [{
                type: Output
            }], closed: [{
                type: Output
            }], titleTemplate: [{
                type: ContentChild,
                args: [TabTitleDirective, { read: TemplateRef }]
            }], _expandedClass: [{
                type: HostBinding,
                args: ['class.is-expanded']
            }] } });

/** @hidden */
class TabInfo {
    /** @hidden */
    constructor(tabPanel) {
        this.panel = tabPanel;
        this.active = tabPanel.expanded;
    }
    /** Tab header title */
    get title() {
        return this.panel.title;
    }
    /** Whether the tab is disabled */
    get disabled() {
        return this.panel.disabled;
    }
    /** Whether the tab is tab header */
    get isHeader() {
        return this.panel.header;
    }
    /** @hidden */
    get id() {
        return this.panel.id;
    }
    /** @hidden */
    get ariaLabel() {
        return this.panel.ariaLabel;
    }
    /** @hidden */
    get ariaLabelledBy() {
        return this.panel.ariaLabelledBy;
    }
    /** @hidden */
    get tabState() {
        return this.panel.tabState;
    }
    /** @hidden */
    get titleTemplate() {
        return this.panel.titleTemplate;
    }
    /** @hidden */
    get count() {
        return this.panel.count;
    }
    /** @hidden */
    get glyph() {
        return this.panel.glyph;
    }
    /** @hidden */
    get forcedVisibility() {
        return this.panel._forcedVisibility;
    }
    /** @hidden */
    get panelId() {
        return this.panel._panelId;
    }
}

/**
 * Represents a list of tab-panels.
 * @deprecated
 * Use `@fundamental-ngx/platform/icon-tab-bar` instead
 */
class TabListComponent {
    /** @hidden */
    get contentContainer() {
        return this._scrollbar?.elementRef;
    }
    /** Scrollable element reference. */
    get scrollableElement() {
        return this._scrollbar?.elementRef;
    }
    /** @hidden */
    constructor(_changeDetectorRef, _contentDensityObserver, _destroyRef) {
        this._changeDetectorRef = _changeDetectorRef;
        this._contentDensityObserver = _contentDensityObserver;
        this._destroyRef = _destroyRef;
        /** Size of tab, it's mostly about adding spacing on tab container, available sizes 's' | 'm' | 'l' | 'xl' | 'xxl' */
        this.size = 'm';
        /** Whether to move tabs overflowing in the tab bar to the dropdown */
        this.collapseOverflow = true;
        /** Limits the maximum number of tabs visible in the tab bar in collapseOverflow mode.
         * Other tabs will be moved to the collapsed tabs dropdown */
        this.maxVisibleTabs = Infinity;
        /** Whether to open tab content one under another without collapsing */
        this.stackContent = false;
        /** Maximum height of the content */
        this.maxContentHeight = '100%';
        /** Whether to enable collapsing expanded tab on expanded tab click */
        this.collapsibleTabs = false;
        /** Whether to try to keep selected tab (default value) on tabs change or to select default one (first if not specified). */
        this.selectDefaultOnTabsChange = false;
        /** Whether to focus the first focusable element in a tab panel when using stacked tabs. */
        this.focusFirstFocusableElement = true;
        /** Event emitted when the selected panel changes. */
        this.selectedTabChange = new EventEmitter();
        /** Event emitted when the selected panel index changes. */
        this.selectedTabIndexChange = new EventEmitter();
        /** Event emitted when visible items count has been changed. */
        this.visibleItemsCount = new EventEmitter();
        /** Event emitted when hidden items count has been changed. */
        this.hiddenItemsCount = new EventEmitter();
        /** @hidden Collection of tabs in original order */
        this._tabArray = [];
        /** @hidden Whether to disable scroll spy */
        this._disableScrollSpy = false;
        /** @hidden */
        this._init = true;
        /** @hidden */
        this._currentNumberOfTabs = 0;
        /** Event is thrown always when tab is selected by keyboard actions */
        this.tabSelected = new Subject();
        /** Event is thrown always, when some property is changed */
        this.tabPanelPropertyChanged = new Subject();
        /** @hidden */
        this._subscriptions = new Subscription();
        /** @hidden */
        this._zone = inject(NgZone);
        warnOnce('TabListComponent is deprecated, use `@fundamental-ngx/platform/icon-tab-bar` instead');
    }
    /** @hidden */
    ngAfterContentInit() {
        this._setupTabPanelsChangeListeners();
    }
    /** @hidden */
    ngAfterViewInit() {
        this._initStackContentSubscription();
        this._listenOnTabPanelsExpandedChange();
        this._listenOnTabPanelsAndInitiallyExpandTabPanel();
        this._listenOnPropertiesChange();
    }
    /** @hidden */
    ngOnDestroy() {
        this._subscriptions.unsubscribe();
    }
    /** @hidden */
    _tabHeaderClickHandler(tabPanel) {
        this._expandTab(tabPanel, !tabPanel.expanded);
    }
    /** @hidden */
    _tabHeaderKeydownHandler(event, tabPanel) {
        if (!KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            return;
        }
        event.preventDefault();
        this._tabHeaderClickHandler(tabPanel);
    }
    /** @hidden */
    _overflowingTabHeaderClickHandler(tabPanel) {
        this._tabArray.forEach((tab) => {
            tab.panel._forcedVisibility = tab.panel === tabPanel;
        });
        this._expandTab(tabPanel, true, false);
        this._overflowLayout.triggerRecalculation();
        this._detectChanges();
    }
    /** @hidden */
    selectTab(id) {
        this.highlightActiveTab(id);
    }
    /** @hidden */
    highlightActiveTab(id) {
        const tab = this._tabArray.find((_tab) => _tab.panel._panelId === id);
        if (tab) {
            const _tabWasActive = tab.active;
            this._activateStackedTab(tab.panel, false);
            if (!_tabWasActive) {
                this._selectedTabChange(tab.panel);
            }
        }
    }
    /** @hidden */
    _onTriggerKeydown(event, menuRef) {
        if (KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            event.preventDefault();
            menuRef.toggle();
        }
    }
    /** @hidden */
    get _tabPanelsChange$() {
        return this.tabPanels.changes.pipe(startWith(this.tabPanels), map((tabPanels) => tabPanels.toArray()), takeUntilDestroyed(this._destroyRef));
    }
    /** @hidden */
    _detectChanges() {
        if (this._changeDetectorRef && !this._changeDetectorRef['destroyed']) {
            this._changeDetectorRef.detectChanges();
        }
    }
    /** @hidden */
    _setupTabPanelsChangeListeners() {
        this._listenOnTabPanelsAndUpdateStorageStructures();
    }
    /** @hidden Setup mechanisms required for handling the stacked content behavior */
    _initStackContentSubscription() {
        this._tabPanelsChange$
            .pipe(filter(() => this.stackContent), delay(0), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => this._tabArray.filter((tab) => !tab.panel.disabled).forEach((tab) => tab.panel._expand(true)));
    }
    /** @hidden */
    _listenOnTabPanelsAndUpdateStorageStructures() {
        this._tabPanelsChange$
            .pipe(map((tabPanels) => tabPanels.map((el) => this._tabArray?.find((tabInfo) => tabInfo.panel === el) || new TabInfo(el))), tap((tabs) => (this._tabArray = tabs)), switchMap(() => this._zone.onStable.pipe(startWith(this._zone.isStable))), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => {
            if (this.stackContent && this._currentNumberOfTabs !== this._tabArray.length) {
                this._zone.onMicrotaskEmpty.pipe(take(1)).subscribe(() => {
                    this._scrollSpy?.onScroll(undefined, true);
                    this._currentNumberOfTabs = this._tabArray.length;
                });
            }
        });
    }
    /** @hidden */
    _listenOnTabPanelsExpandedChange() {
        this._tabPanelsChange$
            .pipe(map((tabPanels) => tabPanels.map((tab) => tab._expandedStateChange.asObservable())), switchMap((tabPanels) => merge(...tabPanels)), takeUntilDestroyed(this._destroyRef))
            .subscribe((event) => {
            this._tabArray.forEach((tab) => {
                tab.panel._forcedVisibility = tab.panel === event.target;
            });
            this._expandTab(event.target, event.state);
            this._overflowLayout.triggerRecalculation();
        });
    }
    /** @hidden */
    _listenOnTabPanelsAndInitiallyExpandTabPanel() {
        this._tabPanelsChange$.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            const activeTab = this._tabArray.find((_tab) => _tab.active);
            let tab;
            if (!activeTab || this.selectDefaultOnTabsChange) {
                if (this.defaultTab) {
                    tab = this._tabArray.find((_tab) => !_tab.disabled && _tab.id === this.defaultTab);
                }
                if (!tab) {
                    tab = this._tabArray.find((_tab) => !_tab.disabled);
                }
            }
            if (tab && activeTab !== tab) {
                this._expandTab(tab.panel, true);
            }
        });
    }
    /** @hidden */
    _listenOnPropertiesChange() {
        merge(this.tabPanelPropertyChanged, this.tabPanels.changes)
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe(() => this._detectChanges());
    }
    /** @hidden */
    _activateStackedTab(tabPanel, scroll = true) {
        if (scroll) {
            this._scrollToPanel(tabPanel);
        }
        this._tabArray.forEach((tab) => {
            tab.active = tab.panel === tabPanel;
        });
    }
    /** @hidden */
    _activateExpandableTab(tabPanel, expand) {
        const collapse = this.collapsibleTabs && !expand;
        this._tabArray.forEach((tab) => {
            const isActive = tab.panel === tabPanel && !collapse;
            tab.panel._expand(isActive);
            tab.active = isActive;
        });
    }
    /** @hidden */
    _expandTab(tabPanel, expand, detectChanges = true) {
        if (this.stackContent) {
            this._activateStackedTab(tabPanel);
        }
        else {
            if (!this._canChangeExpandState(tabPanel, expand)) {
                return;
            }
            this._activateExpandableTab(tabPanel, expand);
        }
        if (detectChanges) {
            this._detectChanges();
        }
        this._selectedTabChange(tabPanel);
    }
    /** @hidden */
    _scrollToPanel(tabPanel) {
        const panelElement = tabPanel.elementRef.nativeElement;
        const containerElement = this.contentContainer.nativeElement;
        const distanceToScroll = panelElement.offsetTop - containerElement.offsetTop;
        const maximumScrollTop = containerElement.scrollHeight - containerElement.clientHeight;
        const currentScrollPosition = Math.ceil(containerElement.scrollTop);
        if (!(currentScrollPosition === maximumScrollTop && distanceToScroll > maximumScrollTop)) {
            !this._init ? (this._disableScrollSpy = true) : (this._init = false);
            fromEvent(containerElement, 'scroll')
                .pipe(debounceTime(100), first$1(), takeUntilDestroyed(this._destroyRef))
                .subscribe(() => (this._disableScrollSpy = false));
            scrollTop(containerElement, distanceToScroll);
        }
        if (this.focusFirstFocusableElement) {
            tabPanel._focusFirstFocusableElement();
        }
    }
    /** @hidden Whether tab can be expanded/collapsed */
    _canChangeExpandState(tabPanel, expand) {
        return !tabPanel.disabled && expand !== tabPanel.expanded && expand === false ? this.collapsibleTabs : true;
    }
    /** @hidden */
    _selectedTabChange(tabPanel) {
        this.selectedTabChange.emit(tabPanel);
        const index = this._tabArray.findIndex((tabInfo) => tabInfo.panel === tabPanel);
        this.selectedTabIndexChange.emit(index);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabListComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i1.ContentDensityObserver }, { token: i0.DestroyRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: TabListComponent, isStandalone: true, selector: "fd-tab-list", inputs: { size: "size", mode: "mode", collapseOverflow: "collapseOverflow", maxVisibleTabs: "maxVisibleTabs", stackContent: "stackContent", maxContentHeight: "maxContentHeight", collapsibleTabs: "collapsibleTabs", defaultTab: "defaultTab", selectDefaultOnTabsChange: "selectDefaultOnTabsChange", focusFirstFocusableElement: "focusFirstFocusableElement" }, outputs: { selectedTabChange: "selectedTabChange", selectedTabIndexChange: "selectedTabIndexChange", visibleItemsCount: "visibleItemsCount", hiddenItemsCount: "hiddenItemsCount" }, host: { classAttribute: "fd-tabs-custom" }, providers: [
            contentDensityObserverProviders(),
            {
                provide: LIST_COMPONENT,
                useExisting: TabListComponent
            },
            {
                provide: FD_TABLIST,
                useExisting: TabListComponent
            }
        ], queries: [{ propertyName: "tabPanels", predicate: i0.forwardRef(() => TabPanelComponent) }], viewQueries: [{ propertyName: "overflowTrigger", first: true, predicate: TabItemExpandComponent, descendants: true, read: ElementRef }, { propertyName: "headerContainer", first: true, predicate: ["headerContainer"], descendants: true, read: ElementRef }, { propertyName: "_scrollbar", first: true, predicate: ScrollbarDirective, descendants: true }, { propertyName: "menu", first: true, predicate: ["menu"], descendants: true, read: MenuComponent }, { propertyName: "_overflowLayout", first: true, predicate: OverflowLayoutComponent, descendants: true }, { propertyName: "_scrollSpy", first: true, predicate: ["scrollSpy"], descendants: true, read: ScrollSpyDirective }, { propertyName: "tabHeaderLinks", predicate: TabLinkDirective, descendants: true }, { propertyName: "tabHeaders", predicate: TabItemDirective, descendants: true }], ngImport: i0, template: "<div #headerContainer role=\"tablist\" class=\"fd-tabs\" [class]=\"(mode ? 'fd-tabs--' + mode : '') + (' fd-tabs--' + size)\">\n    <fd-overflow-layout\n        [maxVisibleItems]=\"maxVisibleTabs\"\n        [enableKeyboardNavigation]=\"true\"\n        navigationTrigger=\"keydown\"\n        (hiddenItemsCount)=\"hiddenItemsCount.emit($event)\"\n        (visibleItemsCount)=\"visibleItemsCount.emit($event)\"\n    >\n        @for (tab of _tabArray; track tab; let i = $index; let last = $last) {\n            <div\n                fd-tab-item\n                *fdOverflowItemRef=\"tab\"\n                fdOverflowLayoutItem\n                [forceVisibility]=\"tab.panel._forcedVisibility\"\n                [header]=\"tab.isHeader\"\n                [tabItemState]=\"tab.tabState\"\n            >\n                <a\n                    fd-tab-link\n                    role=\"tab\"\n                    [id]=\"tab.id\"\n                    [attr.aria-controls]=\"tab.panelId\"\n                    [attr.aria-label]=\"tab.ariaLabel || null\"\n                    [attr.aria-labelledby]=\"!tab.ariaLabel && tab.ariaLabelledBy ? tab.ariaLabelledBy : null\"\n                    fdOverflowLayoutFocusableItem\n                    [focusable]=\"tab.active\"\n                    [navigable]=\"!tab.disabled\"\n                    [active]=\"tab.active\"\n                    [disabled]=\"tab.disabled\"\n                    (keydown)=\"_tabHeaderKeydownHandler($event, tab.panel)\"\n                    (click)=\"_tabHeaderClickHandler(tab.panel)\"\n                >\n                    <ng-template [ngTemplateOutlet]=\"tab.titleTemplate || null\"></ng-template>\n                    @if (!tab.titleTemplate) {\n                        @switch (mode) {\n                            @case ('filter') {\n                                @if (tab.isHeader) {\n                                    <span fd-tab-header>\n                                        @if (tab.count) {\n                                            <span fd-tab-counter-header>{{ tab.count }}</span>\n                                        }\n                                        @if (tab.title) {\n                                            <span fd-tab-label>{{ tab.title }}</span>\n                                        }\n                                    </span>\n                                }\n                                @if (!tab.isHeader) {\n                                    <span fd-tab-icon [icon]=\"tab.glyph\">\n                                        <p fd-tab-count>{{ tab.count }}</p>\n                                    </span>\n                                    <span fd-tab-label>{{ tab.title }}</span>\n                                }\n                            }\n                            @case ('icon-only') {\n                                <span fd-tab-icon [icon]=\"tab.glyph\">\n                                    <p fd-tab-count>{{ tab.count }}</p>\n                                </span>\n                            }\n                            @case ('process') {\n                                @if (tab.glyph) {\n                                    <span fd-tab-icon [icon]=\"tab.glyph\"></span>\n                                }\n                                <div fd-tab-process>\n                                    @if (tab.count) {\n                                        <span fd-tab-label>{{ tab.count }}</span>\n                                    }\n                                    @if (tab.title) {\n                                        <span fd-tab-label>{{ tab.title }}</span>\n                                    }\n                                </div>\n                            }\n                            @default {\n                                @if (tab.count) {\n                                    <p fd-tab-count>{{ tab.count }}</p>\n                                }\n                                <span fd-tab-tag>{{ tab.title }}</span>\n                            }\n                        }\n                    }\n                </a>\n                @if (mode === 'process' && !last) {\n                    <div fd-tab-process-icon></div>\n                }\n            </div>\n            @if (tab.isHeader) {\n                <div fd-tab-separator></div>\n            }\n        }\n        <ng-container *fdOverflowExpand=\"let tabs; items: _tabArray\">\n            @if (tabs.length > 0) {\n                <fd-item-expand [fdMenuTrigger]=\"menu\" (keydown)=\"_onTriggerKeydown($event, menu)\"> </fd-item-expand>\n            }\n            <fd-menu #menu>\n                @for (tab of tabs; track tab) {\n                    <li fd-menu-item (onSelect)=\"_overflowingTabHeaderClickHandler(tab.item.panel)\">\n                        <div fd-menu-interactive>\n                            <ng-template\n                                [ngTemplateOutlet]=\"\n                                    !tab.item.titleTemplate && mode === 'icon-only'\n                                        ? iconOnlyTemplate\n                                        : tab.item.titleTemplate || textTitle\n                                \"\n                                [ngTemplateOutletContext]=\"{ $implicit: tab.item }\"\n                            ></ng-template>\n                        </div>\n                    </li>\n                }\n            </fd-menu>\n        </ng-container>\n    </fd-overflow-layout>\n</div>\n<div\n    class=\"fd-tabs__content\"\n    [style.max-height]=\"maxContentHeight\"\n    fdScrollSpy\n    #scrollSpy=\"fdScrollSpy\"\n    fd-scrollbar\n    [trackedTags]=\"['fd-tab']\"\n    [scrollSpyDisabled]=\"_disableScrollSpy\"\n    (spyChange)=\"highlightActiveTab($event.id)\"\n>\n    <ng-content></ng-content>\n</div>\n<ng-template #textTitle let-tab>\n    <span fd-menu-title>{{ tab.title }}</span>\n</ng-template>\n<ng-template #iconOnlyTemplate let-tab>\n    <span fd-tab-icon [icon]=\"tab.glyph\">\n        <p fd-tab-count>{{ tab.count }}</p>\n    </span>\n</ng-template>\n", styles: [".fd-tabs{--fdTabs_Icon_Size:1.125rem;--fdTabs_Icon_Selection_Height:2.625rem;--fdTabs_Label_Padding_Bottom:.375rem;--fdTabs_Filter_Link_Height:5.5rem;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-padding-start:0;background-color:var(--sapObjectHeader_Background);border-color:var(--sapObjectHeader_BorderColor);-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow);color:var(--sapContent_LabelColor);list-style:none;padding-inline-start:0}.fd-tabs:after,.fd-tabs:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__count{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-after:.125rem;color:var(--sapContent_LabelColor);padding-block-end:.125rem}.fd-tabs__count:after,.fd-tabs__count:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);cursor:pointer;display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-block:.875rem;padding-inline:0;padding-inline:.75rem;position:relative;text-decoration:none;-webkit-transition:0s;transition:0s}.fd-tabs__link:after,.fd-tabs__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__link.is-selected .fd-tabs__icon,.fd-tabs__link[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__link.is-selected .fd-tabs__icon:after,.fd-tabs__link.is-selected .fd-tabs__tag:after,.fd-tabs__link[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__link[aria-selected=true] .fd-tabs__tag:after{background-color:var(--fdIcon_Tab_Bar_Selection_Bar_Color)}.fd-tabs__link.is-focus,.fd-tabs__link:focus{-webkit-box-shadow:none;box-shadow:none;outline:none;z-index:5}.fd-tabs__link.is-focus .fd-tabs__icon:before,.fd-tabs__link.is-focus .fd-tabs__tag:before,.fd-tabs__link:focus .fd-tabs__icon:before,.fd-tabs__link:focus .fd-tabs__tag:before{content:\"\";inset:0;outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:var(--sapContent_FocusWidth);position:absolute}.fd-tabs__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-inline:.25rem;padding-block:0;padding-inline:0;position:relative}.fd-tabs__item:after,.fd-tabs__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__item.is-selected .fd-tabs__tag,.fd-tabs__item[aria-selected=true] .fd-tabs__tag{color:var(--fdIcon_Tab_Bar_Selection_Color)}.fd-tabs__item.is-selected .fd-tabs__icon,.fd-tabs__item[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item.is-selected .fd-tabs__icon:after,.fd-tabs__item.is-selected .fd-tabs__link:after,.fd-tabs__item.is-selected .fd-tabs__tag:after,.fd-tabs__item[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item[aria-selected=true] .fd-tabs__tag:after{background-color:var(--fdIcon_Tab_Bar_Selection_Bar_Color)}.fd-tabs__item--error .fd-tabs__icon{border-color:var(--sapErrorColor);color:var(--sapErrorColor)}.fd-tabs__item--error .fd-tabs__link .fd-tabs__tag{color:var(--sapErrorColor)}.fd-tabs__item--error.is-selected .fd-tabs__icon,.fd-tabs__item--error[aria-selected=true] .fd-tabs__icon{background-color:var(--sapErrorColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--error.is-selected .fd-tabs__icon:after,.fd-tabs__item--error.is-selected .fd-tabs__link:after,.fd-tabs__item--error.is-selected .fd-tabs__tag:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapErrorColor)}.fd-tabs__item--warning .fd-tabs__icon{border-color:var(--sapWarningColor);color:var(--sapWarningColor)}.fd-tabs__item--warning .fd-tabs__link .fd-tabs__tag{color:var(--sapWarningColor)}.fd-tabs__item--warning.is-selected .fd-tabs__icon,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__icon{background-color:var(--sapWarningColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--warning.is-selected .fd-tabs__icon:after,.fd-tabs__item--warning.is-selected .fd-tabs__link:after,.fd-tabs__item--warning.is-selected .fd-tabs__tag:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapWarningColor)}.fd-tabs__item--success .fd-tabs__icon{border-color:var(--sapSuccessColor);color:var(--sapSuccessColor)}.fd-tabs__item--success .fd-tabs__link .fd-tabs__tag{color:var(--sapSuccessColor)}.fd-tabs__item--success.is-selected .fd-tabs__icon,.fd-tabs__item--success[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSuccessColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--success.is-selected .fd-tabs__icon:after,.fd-tabs__item--success.is-selected .fd-tabs__link:after,.fd-tabs__item--success.is-selected .fd-tabs__tag:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapSuccessColor)}.fd-tabs__item--information .fd-tabs__icon{border-color:var(--sapInformationColor);color:var(--sapInformationColor)}.fd-tabs__item--information .fd-tabs__link .fd-tabs__tag{color:var(--sapInformationColor)}.fd-tabs__item--information.is-selected .fd-tabs__icon,.fd-tabs__item--information[aria-selected=true] .fd-tabs__icon{background-color:var(--sapInformationColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--information.is-selected .fd-tabs__icon:after,.fd-tabs__item--information.is-selected .fd-tabs__link:after,.fd-tabs__item--information.is-selected .fd-tabs__tag:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapInformationColor)}.fd-tabs__item--neutral .fd-tabs__icon{border-color:var(--sapNeutralColor);color:var(--sapNeutralColor)}.fd-tabs__item--neutral .fd-tabs__link .fd-tabs__tag{color:var(--sapNeutralColor)}.fd-tabs__item--neutral.is-selected .fd-tabs__icon,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__icon{background-color:var(--sapNeutralColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--neutral.is-selected .fd-tabs__icon:after,.fd-tabs__item--neutral.is-selected .fd-tabs__link:after,.fd-tabs__item--neutral.is-selected .fd-tabs__tag:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapNeutralColor)}.fd-tabs__item:first-child{-webkit-margin-start:0;margin-inline-start:0}.fd-tabs__item:first-child .fd-tabs__link{-webkit-margin-start:.1875rem;margin-inline-start:.1875rem;-webkit-padding-start:0;padding-inline-start:0}.fd-tabs__icon{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:transparent;border:var(--fdIcon_Tab_Bar_Icon_Border_Weight) solid var(--fdIcon_Tab_Bar_Icon_Border_Color);border-radius:50%;color:var(--fdIcon_Tab_Bar_Inactive_Tab_Icon_Color);height:var(--fdTabs_Icon_Selection_Height);margin-block:0;margin-inline:.188rem;position:relative;width:var(--fdTabs_Icon_Selection_Height)}.fd-tabs__icon:after,.fd-tabs__icon:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__icon [class*=sap-icon],.fd-tabs__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;font-size:var(--fdTabs_Icon_Size);line-height:1}.fd-tabs__icon:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs__tag{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:inline-block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-tabs__tag:after,.fd-tabs__tag:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__tag:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs__panel{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tabs__panel:after,.fd-tabs__panel:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__panel[aria-expanded=false]{display:none}.fd-tabs__panel.is-expanded,.fd-tabs__panel[aria-expanded=true]{display:block}.fd-tabs__counter-header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:1.5rem;font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1.5rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-tabs__counter-header:after,.fd-tabs__counter-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__overflow{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-margin-start:auto;margin-inline-start:auto}.fd-tabs__overflow:after,.fd-tabs__overflow:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__overflow [class*=sap-icon],.fd-tabs__overflow[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-tabs__process-icon{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_NonInteractiveIconColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:1rem;font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;padding-inline:.5rem}.fd-tabs__process-icon:after,.fd-tabs__process-icon:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__process-icon:before{content:\"\\e0c7\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-tabs__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-start:.125rem;color:var(--sapContent_LabelColor);font-size:var(--sapFontSmallSize);max-width:100%;padding-inline-start:.125rem}.fd-tabs__label:after,.fd-tabs__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__label:first-child{-webkit-padding-after:var(--fdTabs_Label_Padding_Bottom);padding-block-end:var(--fdTabs_Label_Padding_Bottom)}.fd-tabs__separator{border:0;border-right:solid var(--sapGroup_TitleBorderColor);border-right-width:.0625rem;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:2rem;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;margin-inline:.25rem;padding-block:0;padding-inline:0}.fd-tabs__separator:after,.fd-tabs__separator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs__header:after,.fd-tabs__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__header .fd-tabs__label{max-width:4rem}.fd-tabs--filter .fd-tabs__count,.fd-tabs--icon-only .fd-tabs__count,.fd-tabs--process .fd-tabs__count{font-size:var(--sapFontSmallSize)}.fd-tabs--filter .fd-tabs__item:first-child .fd-tabs__link,.fd-tabs--icon-only .fd-tabs__item:first-child .fd-tabs__link,.fd-tabs--process .fd-tabs__item:first-child .fd-tabs__link{margin-block:0;margin-inline:0}.fd-tabs--icon-only .fd-tabs__link,.fd-tabs--process .fd-tabs__link{padding-block:1rem 1rem}.fd-tabs--icon-only .fd-tabs__icon:after,.fd-tabs--process .fd-tabs__icon:after{bottom:-1.0625rem}.fd-tabs--filter .fd-tabs__count,.fd-tabs--icon-only .fd-tabs__count{left:calc(100% + .1875rem);position:absolute;top:0}.fd-tabs--filter[dir=rtl] .fd-tabs__count,.fd-tabs--icon-only[dir=rtl] .fd-tabs__count,[dir=rtl] .fd-tabs--filter .fd-tabs__count,[dir=rtl] .fd-tabs--icon-only .fd-tabs__count{left:auto;right:calc(100% + .1875rem)}.fd-tabs--process .fd-tabs__item{margin-block:0;margin-inline:0 .25rem}.fd-tabs--process .fd-tabs__item,.fd-tabs--process .fd-tabs__link{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs--process .fd-tabs__link{padding-inline:0}.fd-tabs--process .fd-tabs__icon{margin-block:0;margin-inline:.1875rem}.fd-tabs--process .fd-tabs__label{line-height:.875rem;max-width:7.5rem;overflow:hidden;white-space:nowrap}.fd-tabs--process[dir=rtl] .fd-tabs__item,[dir=rtl] .fd-tabs--process .fd-tabs__item{margin-block:0;margin-inline:.25rem 0}.fd-tabs--process[dir=rtl] .fd-tabs__item:first-child .fd-tabs__link,[dir=rtl] .fd-tabs--process .fd-tabs__item:first-child .fd-tabs__link{padding-inline:0}.fd-tabs--filter{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs--filter .fd-tabs__item{margin-block:0;margin-inline:0;padding-block:0;padding-inline:.25rem;width:5.375rem}.fd-tabs--filter .fd-tabs__item--header{width:auto}.fd-tabs--filter .fd-tabs__icon{-webkit-margin-after:.375rem;margin-block-end:.375rem}.fd-tabs--filter .fd-tabs__icon:after{content:none}.fd-tabs--filter .fd-tabs__label{line-height:.875rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-tabs--filter .fd-tabs__link{display:-webkit-box;display:-ms-flexbox;display:flex;height:var(--fdTabs_Filter_Link_Height);padding-block:.875rem .625rem;padding-inline:.188rem;text-align:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;position:relative}.fd-tabs--filter .fd-tabs__link:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;bottom:0;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs--filter .fd-tabs__link.is-focus,.fd-tabs--filter .fd-tabs__link:focus{-webkit-box-shadow:none;box-shadow:none;outline:none;z-index:5}.fd-tabs--filter[dir=rtl] .fd-tabs__item:first-child .fd-tabs__link,[dir=rtl] .fd-tabs--filter .fd-tabs__item:first-child .fd-tabs__link{padding-inline:.188rem}.fd-tabs[class*=-compact],.fd-tabs[class*=-condensed],[class*=-compact] .fd-tabs:not([class*=-cozy]),[class*=-condensed] .fd-tabs:not([class*=-cozy]){--fdTabs_Icon_Size:1.125rem;--fdTabs_Icon_Selection_Height:1.875rem;--fdTabs_Label_Padding_Bottom:.25rem;--fdTabs_Filter_Link_Height:4.75rem}.fd-tabs--s{padding-block:0;padding-inline:1rem}.fd-tabs--l,.fd-tabs--m{padding-block:0;padding-inline:2rem}.fd-tabs--xl,.fd-tabs--xxl{padding-block:0;padding-inline:3rem}.fd-tabs[dir=rtl] .fd-tabs__process-icon,[dir=rtl] .fd-tabs .fd-tabs__process-icon{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.fd-tabs__process{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tabs__process:after,.fd-tabs__process:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs-custom{display:flex;flex-direction:column;height:100%}.fd-tabs-custom .is-disabled{pointer-events:none;opacity:.4}.fd-tabs{flex-grow:0;flex-wrap:nowrap}.fd-tabs__content{overflow-y:auto;flex-grow:1}.fd-tabs__item{flex-shrink:0}.fd-tabs__tag{white-space:nowrap}.fd-tabs__wrapper{flex-grow:1;display:flex;flex-wrap:wrap;align-items:center}.fd-tabs__wrapper--collapsible{overflow:hidden;flex-wrap:nowrap}.fd-tabs .fd-overflow-layout__items-container .fd-tabs__item:first-child{margin-left:.25rem}.fd-tabs .fd-overflow-layout__items-container .fd-tabs__item:first-child .fd-tabs__link{margin:0;padding:.875rem .75rem}.fd-tabs .fd-overflow-layout__items-container .fd-overflow-layout__item--first .fd-tabs__item{margin-left:0}.fd-tabs .fd-overflow-layout__items-container .fd-overflow-layout__item--first .fd-tabs__item .fd-tabs__link{margin-left:.1875rem;padding-left:0}\n/*! Bundled license information:\n\nfundamental-styles/dist/tabs.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "component", type: OverflowLayoutComponent, selector: "fd-overflow-layout", inputs: ["maxVisibleItems", "navigationTrigger", "showMorePosition", "renderShowMoreButton", "reverseHiddenItems", "enableKeyboardNavigation", "ariaRole", "moreItemsButtonText"], outputs: ["visibleItemsCount", "hiddenItemsCount", "hiddenItemsChange"] }, { kind: "directive", type: OverflowItemRefDirective, selector: "[fdOverflowItemRef]", inputs: ["fdOverflowItemRef"] }, { kind: "directive", type: TabItemDirective, selector: "[fd-tab-item]", inputs: ["class", "tabItemState", "header", "disabled", "fdTabItemClass"] }, { kind: "directive", type: OverflowLayoutItemDirective, selector: "[fdOverflowLayoutItem]", inputs: ["forceVisibility"], outputs: ["hiddenChange"] }, { kind: "directive", type: TabLinkDirective, selector: "[fd-tab-link]", inputs: ["active", "disabled"], outputs: ["keyDown", "focused"] }, { kind: "directive", type: OverflowLayoutFocusableItemDirective, selector: "[fdOverflowLayoutFocusableItem], [fdOverflowLayoutItem][focusable]", inputs: ["focusable", "navigable"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: TabHeaderDirective, selector: "[fdTabHeader], [fd-tab-header]" }, { kind: "directive", type: TabCounterHeaderDirective, selector: "[fdTabCounterHeader], [fd-tab-counter-header]" }, { kind: "directive", type: TabLabelDirective, selector: "[fdTabLabel], [fd-tab-label]" }, { kind: "component", type: TabIconComponent, selector: "[fd-tab-icon]", inputs: ["class", "icon", "iconFont"] }, { kind: "directive", type: TabCountDirective, selector: "[fdTabCount], [fd-tab-count]" }, { kind: "directive", type: TabProcessDirective, selector: "[fdTabProcess], [fd-tab-process]" }, { kind: "directive", type: TabTagDirective, selector: "[fdTabTag], [fd-tab-tag]" }, { kind: "directive", type: TabProcessIconDirective, selector: "[fdTabProcessIcon], [fd-tab-process-icon]" }, { kind: "directive", type: TabSeparatorDirective, selector: "[fdTabSeparator], [fd-tab-separator]" }, { kind: "directive", type: OverflowExpandDirective, selector: "[fdOverflowExpand]", inputs: ["fdOverflowExpandItems"] }, { kind: "component", type: TabItemExpandComponent, selector: "fd-item-expand" }, { kind: "directive", type: MenuTriggerDirective, selector: "[fdMenuTrigger]", inputs: ["fdMenuTrigger"] }, { kind: "component", type: MenuComponent, selector: "fd-menu", inputs: ["mobile", "disabled", "focusTrapped", "focusAutoCapture", "openOnHoverTime", "mobileConfig", "ariaLabel", "ariaLabelledby", "id"], outputs: ["activePath"] }, { kind: "component", type: MenuItemComponent, selector: "li[fd-menu-item]", inputs: ["disabled", "itemId", "submenu", "parentSubmenu", "hasSeparator"], outputs: ["onSelect"], exportAs: ["fd-menu-item"] }, { kind: "component", type: MenuInteractiveComponent, selector: "[fd-menu-interactive]" }, { kind: "directive", type: ScrollSpyDirective, selector: "[fdScrollSpy]", inputs: ["trackedTags", "fireEmpty", "targetPercent", "targetOffset", "scrollSpyDisabled"], outputs: ["spyChange"], exportAs: ["fdScrollSpy"] }, { kind: "directive", type: ScrollbarDirective, selector: "[fdScrollbar], [fd-scrollbar]", inputs: ["noHorizontalScroll", "noVerticalScroll", "alwaysVisible"] }, { kind: "directive", type: MenuTitleDirective, selector: "[fd-menu-title]" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-tab-list', host: {
                        class: 'fd-tabs-custom'
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        contentDensityObserverProviders(),
                        {
                            provide: LIST_COMPONENT,
                            useExisting: TabListComponent
                        },
                        {
                            provide: FD_TABLIST,
                            useExisting: TabListComponent
                        }
                    ], imports: [
                        OverflowLayoutComponent,
                        OverflowItemRefDirective,
                        TabItemDirective,
                        OverflowLayoutItemDirective,
                        TabLinkDirective,
                        OverflowLayoutFocusableItemDirective,
                        NgTemplateOutlet,
                        TabHeaderDirective,
                        TabCounterHeaderDirective,
                        TabLabelDirective,
                        TabIconComponent,
                        TabCountDirective,
                        TabProcessDirective,
                        TabTagDirective,
                        TabProcessIconDirective,
                        TabSeparatorDirective,
                        OverflowExpandDirective,
                        TabItemExpandComponent,
                        MenuTriggerDirective,
                        MenuComponent,
                        MenuItemComponent,
                        MenuInteractiveComponent,
                        ScrollSpyDirective,
                        CdkScrollable,
                        ScrollbarDirective,
                        MenuTitleDirective
                    ], template: "<div #headerContainer role=\"tablist\" class=\"fd-tabs\" [class]=\"(mode ? 'fd-tabs--' + mode : '') + (' fd-tabs--' + size)\">\n    <fd-overflow-layout\n        [maxVisibleItems]=\"maxVisibleTabs\"\n        [enableKeyboardNavigation]=\"true\"\n        navigationTrigger=\"keydown\"\n        (hiddenItemsCount)=\"hiddenItemsCount.emit($event)\"\n        (visibleItemsCount)=\"visibleItemsCount.emit($event)\"\n    >\n        @for (tab of _tabArray; track tab; let i = $index; let last = $last) {\n            <div\n                fd-tab-item\n                *fdOverflowItemRef=\"tab\"\n                fdOverflowLayoutItem\n                [forceVisibility]=\"tab.panel._forcedVisibility\"\n                [header]=\"tab.isHeader\"\n                [tabItemState]=\"tab.tabState\"\n            >\n                <a\n                    fd-tab-link\n                    role=\"tab\"\n                    [id]=\"tab.id\"\n                    [attr.aria-controls]=\"tab.panelId\"\n                    [attr.aria-label]=\"tab.ariaLabel || null\"\n                    [attr.aria-labelledby]=\"!tab.ariaLabel && tab.ariaLabelledBy ? tab.ariaLabelledBy : null\"\n                    fdOverflowLayoutFocusableItem\n                    [focusable]=\"tab.active\"\n                    [navigable]=\"!tab.disabled\"\n                    [active]=\"tab.active\"\n                    [disabled]=\"tab.disabled\"\n                    (keydown)=\"_tabHeaderKeydownHandler($event, tab.panel)\"\n                    (click)=\"_tabHeaderClickHandler(tab.panel)\"\n                >\n                    <ng-template [ngTemplateOutlet]=\"tab.titleTemplate || null\"></ng-template>\n                    @if (!tab.titleTemplate) {\n                        @switch (mode) {\n                            @case ('filter') {\n                                @if (tab.isHeader) {\n                                    <span fd-tab-header>\n                                        @if (tab.count) {\n                                            <span fd-tab-counter-header>{{ tab.count }}</span>\n                                        }\n                                        @if (tab.title) {\n                                            <span fd-tab-label>{{ tab.title }}</span>\n                                        }\n                                    </span>\n                                }\n                                @if (!tab.isHeader) {\n                                    <span fd-tab-icon [icon]=\"tab.glyph\">\n                                        <p fd-tab-count>{{ tab.count }}</p>\n                                    </span>\n                                    <span fd-tab-label>{{ tab.title }}</span>\n                                }\n                            }\n                            @case ('icon-only') {\n                                <span fd-tab-icon [icon]=\"tab.glyph\">\n                                    <p fd-tab-count>{{ tab.count }}</p>\n                                </span>\n                            }\n                            @case ('process') {\n                                @if (tab.glyph) {\n                                    <span fd-tab-icon [icon]=\"tab.glyph\"></span>\n                                }\n                                <div fd-tab-process>\n                                    @if (tab.count) {\n                                        <span fd-tab-label>{{ tab.count }}</span>\n                                    }\n                                    @if (tab.title) {\n                                        <span fd-tab-label>{{ tab.title }}</span>\n                                    }\n                                </div>\n                            }\n                            @default {\n                                @if (tab.count) {\n                                    <p fd-tab-count>{{ tab.count }}</p>\n                                }\n                                <span fd-tab-tag>{{ tab.title }}</span>\n                            }\n                        }\n                    }\n                </a>\n                @if (mode === 'process' && !last) {\n                    <div fd-tab-process-icon></div>\n                }\n            </div>\n            @if (tab.isHeader) {\n                <div fd-tab-separator></div>\n            }\n        }\n        <ng-container *fdOverflowExpand=\"let tabs; items: _tabArray\">\n            @if (tabs.length > 0) {\n                <fd-item-expand [fdMenuTrigger]=\"menu\" (keydown)=\"_onTriggerKeydown($event, menu)\"> </fd-item-expand>\n            }\n            <fd-menu #menu>\n                @for (tab of tabs; track tab) {\n                    <li fd-menu-item (onSelect)=\"_overflowingTabHeaderClickHandler(tab.item.panel)\">\n                        <div fd-menu-interactive>\n                            <ng-template\n                                [ngTemplateOutlet]=\"\n                                    !tab.item.titleTemplate && mode === 'icon-only'\n                                        ? iconOnlyTemplate\n                                        : tab.item.titleTemplate || textTitle\n                                \"\n                                [ngTemplateOutletContext]=\"{ $implicit: tab.item }\"\n                            ></ng-template>\n                        </div>\n                    </li>\n                }\n            </fd-menu>\n        </ng-container>\n    </fd-overflow-layout>\n</div>\n<div\n    class=\"fd-tabs__content\"\n    [style.max-height]=\"maxContentHeight\"\n    fdScrollSpy\n    #scrollSpy=\"fdScrollSpy\"\n    fd-scrollbar\n    [trackedTags]=\"['fd-tab']\"\n    [scrollSpyDisabled]=\"_disableScrollSpy\"\n    (spyChange)=\"highlightActiveTab($event.id)\"\n>\n    <ng-content></ng-content>\n</div>\n<ng-template #textTitle let-tab>\n    <span fd-menu-title>{{ tab.title }}</span>\n</ng-template>\n<ng-template #iconOnlyTemplate let-tab>\n    <span fd-tab-icon [icon]=\"tab.glyph\">\n        <p fd-tab-count>{{ tab.count }}</p>\n    </span>\n</ng-template>\n", styles: [".fd-tabs{--fdTabs_Icon_Size:1.125rem;--fdTabs_Icon_Selection_Height:2.625rem;--fdTabs_Label_Padding_Bottom:.375rem;--fdTabs_Filter_Link_Height:5.5rem;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-padding-start:0;background-color:var(--sapObjectHeader_Background);border-color:var(--sapObjectHeader_BorderColor);-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow);color:var(--sapContent_LabelColor);list-style:none;padding-inline-start:0}.fd-tabs:after,.fd-tabs:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__count{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-after:.125rem;color:var(--sapContent_LabelColor);padding-block-end:.125rem}.fd-tabs__count:after,.fd-tabs__count:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);cursor:pointer;display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-block:.875rem;padding-inline:0;padding-inline:.75rem;position:relative;text-decoration:none;-webkit-transition:0s;transition:0s}.fd-tabs__link:after,.fd-tabs__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__link.is-selected .fd-tabs__icon,.fd-tabs__link[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__link.is-selected .fd-tabs__icon:after,.fd-tabs__link.is-selected .fd-tabs__tag:after,.fd-tabs__link[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__link[aria-selected=true] .fd-tabs__tag:after{background-color:var(--fdIcon_Tab_Bar_Selection_Bar_Color)}.fd-tabs__link.is-focus,.fd-tabs__link:focus{-webkit-box-shadow:none;box-shadow:none;outline:none;z-index:5}.fd-tabs__link.is-focus .fd-tabs__icon:before,.fd-tabs__link.is-focus .fd-tabs__tag:before,.fd-tabs__link:focus .fd-tabs__icon:before,.fd-tabs__link:focus .fd-tabs__tag:before{content:\"\";inset:0;outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:var(--sapContent_FocusWidth);position:absolute}.fd-tabs__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-inline:.25rem;padding-block:0;padding-inline:0;position:relative}.fd-tabs__item:after,.fd-tabs__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__item.is-selected .fd-tabs__tag,.fd-tabs__item[aria-selected=true] .fd-tabs__tag{color:var(--fdIcon_Tab_Bar_Selection_Color)}.fd-tabs__item.is-selected .fd-tabs__icon,.fd-tabs__item[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item.is-selected .fd-tabs__icon:after,.fd-tabs__item.is-selected .fd-tabs__link:after,.fd-tabs__item.is-selected .fd-tabs__tag:after,.fd-tabs__item[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item[aria-selected=true] .fd-tabs__tag:after{background-color:var(--fdIcon_Tab_Bar_Selection_Bar_Color)}.fd-tabs__item--error .fd-tabs__icon{border-color:var(--sapErrorColor);color:var(--sapErrorColor)}.fd-tabs__item--error .fd-tabs__link .fd-tabs__tag{color:var(--sapErrorColor)}.fd-tabs__item--error.is-selected .fd-tabs__icon,.fd-tabs__item--error[aria-selected=true] .fd-tabs__icon{background-color:var(--sapErrorColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--error.is-selected .fd-tabs__icon:after,.fd-tabs__item--error.is-selected .fd-tabs__link:after,.fd-tabs__item--error.is-selected .fd-tabs__tag:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapErrorColor)}.fd-tabs__item--warning .fd-tabs__icon{border-color:var(--sapWarningColor);color:var(--sapWarningColor)}.fd-tabs__item--warning .fd-tabs__link .fd-tabs__tag{color:var(--sapWarningColor)}.fd-tabs__item--warning.is-selected .fd-tabs__icon,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__icon{background-color:var(--sapWarningColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--warning.is-selected .fd-tabs__icon:after,.fd-tabs__item--warning.is-selected .fd-tabs__link:after,.fd-tabs__item--warning.is-selected .fd-tabs__tag:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapWarningColor)}.fd-tabs__item--success .fd-tabs__icon{border-color:var(--sapSuccessColor);color:var(--sapSuccessColor)}.fd-tabs__item--success .fd-tabs__link .fd-tabs__tag{color:var(--sapSuccessColor)}.fd-tabs__item--success.is-selected .fd-tabs__icon,.fd-tabs__item--success[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSuccessColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--success.is-selected .fd-tabs__icon:after,.fd-tabs__item--success.is-selected .fd-tabs__link:after,.fd-tabs__item--success.is-selected .fd-tabs__tag:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapSuccessColor)}.fd-tabs__item--information .fd-tabs__icon{border-color:var(--sapInformationColor);color:var(--sapInformationColor)}.fd-tabs__item--information .fd-tabs__link .fd-tabs__tag{color:var(--sapInformationColor)}.fd-tabs__item--information.is-selected .fd-tabs__icon,.fd-tabs__item--information[aria-selected=true] .fd-tabs__icon{background-color:var(--sapInformationColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--information.is-selected .fd-tabs__icon:after,.fd-tabs__item--information.is-selected .fd-tabs__link:after,.fd-tabs__item--information.is-selected .fd-tabs__tag:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapInformationColor)}.fd-tabs__item--neutral .fd-tabs__icon{border-color:var(--sapNeutralColor);color:var(--sapNeutralColor)}.fd-tabs__item--neutral .fd-tabs__link .fd-tabs__tag{color:var(--sapNeutralColor)}.fd-tabs__item--neutral.is-selected .fd-tabs__icon,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__icon{background-color:var(--sapNeutralColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--neutral.is-selected .fd-tabs__icon:after,.fd-tabs__item--neutral.is-selected .fd-tabs__link:after,.fd-tabs__item--neutral.is-selected .fd-tabs__tag:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapNeutralColor)}.fd-tabs__item:first-child{-webkit-margin-start:0;margin-inline-start:0}.fd-tabs__item:first-child .fd-tabs__link{-webkit-margin-start:.1875rem;margin-inline-start:.1875rem;-webkit-padding-start:0;padding-inline-start:0}.fd-tabs__icon{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:transparent;border:var(--fdIcon_Tab_Bar_Icon_Border_Weight) solid var(--fdIcon_Tab_Bar_Icon_Border_Color);border-radius:50%;color:var(--fdIcon_Tab_Bar_Inactive_Tab_Icon_Color);height:var(--fdTabs_Icon_Selection_Height);margin-block:0;margin-inline:.188rem;position:relative;width:var(--fdTabs_Icon_Selection_Height)}.fd-tabs__icon:after,.fd-tabs__icon:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__icon [class*=sap-icon],.fd-tabs__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;font-size:var(--fdTabs_Icon_Size);line-height:1}.fd-tabs__icon:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs__tag{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:inline-block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-tabs__tag:after,.fd-tabs__tag:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__tag:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs__panel{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tabs__panel:after,.fd-tabs__panel:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__panel[aria-expanded=false]{display:none}.fd-tabs__panel.is-expanded,.fd-tabs__panel[aria-expanded=true]{display:block}.fd-tabs__counter-header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:1.5rem;font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1.5rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-tabs__counter-header:after,.fd-tabs__counter-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__overflow{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-margin-start:auto;margin-inline-start:auto}.fd-tabs__overflow:after,.fd-tabs__overflow:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__overflow [class*=sap-icon],.fd-tabs__overflow[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-tabs__process-icon{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_NonInteractiveIconColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:1rem;font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;padding-inline:.5rem}.fd-tabs__process-icon:after,.fd-tabs__process-icon:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__process-icon:before{content:\"\\e0c7\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-tabs__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-start:.125rem;color:var(--sapContent_LabelColor);font-size:var(--sapFontSmallSize);max-width:100%;padding-inline-start:.125rem}.fd-tabs__label:after,.fd-tabs__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__label:first-child{-webkit-padding-after:var(--fdTabs_Label_Padding_Bottom);padding-block-end:var(--fdTabs_Label_Padding_Bottom)}.fd-tabs__separator{border:0;border-right:solid var(--sapGroup_TitleBorderColor);border-right-width:.0625rem;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:2rem;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;margin-inline:.25rem;padding-block:0;padding-inline:0}.fd-tabs__separator:after,.fd-tabs__separator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs__header:after,.fd-tabs__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__header .fd-tabs__label{max-width:4rem}.fd-tabs--filter .fd-tabs__count,.fd-tabs--icon-only .fd-tabs__count,.fd-tabs--process .fd-tabs__count{font-size:var(--sapFontSmallSize)}.fd-tabs--filter .fd-tabs__item:first-child .fd-tabs__link,.fd-tabs--icon-only .fd-tabs__item:first-child .fd-tabs__link,.fd-tabs--process .fd-tabs__item:first-child .fd-tabs__link{margin-block:0;margin-inline:0}.fd-tabs--icon-only .fd-tabs__link,.fd-tabs--process .fd-tabs__link{padding-block:1rem 1rem}.fd-tabs--icon-only .fd-tabs__icon:after,.fd-tabs--process .fd-tabs__icon:after{bottom:-1.0625rem}.fd-tabs--filter .fd-tabs__count,.fd-tabs--icon-only .fd-tabs__count{left:calc(100% + .1875rem);position:absolute;top:0}.fd-tabs--filter[dir=rtl] .fd-tabs__count,.fd-tabs--icon-only[dir=rtl] .fd-tabs__count,[dir=rtl] .fd-tabs--filter .fd-tabs__count,[dir=rtl] .fd-tabs--icon-only .fd-tabs__count{left:auto;right:calc(100% + .1875rem)}.fd-tabs--process .fd-tabs__item{margin-block:0;margin-inline:0 .25rem}.fd-tabs--process .fd-tabs__item,.fd-tabs--process .fd-tabs__link{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs--process .fd-tabs__link{padding-inline:0}.fd-tabs--process .fd-tabs__icon{margin-block:0;margin-inline:.1875rem}.fd-tabs--process .fd-tabs__label{line-height:.875rem;max-width:7.5rem;overflow:hidden;white-space:nowrap}.fd-tabs--process[dir=rtl] .fd-tabs__item,[dir=rtl] .fd-tabs--process .fd-tabs__item{margin-block:0;margin-inline:.25rem 0}.fd-tabs--process[dir=rtl] .fd-tabs__item:first-child .fd-tabs__link,[dir=rtl] .fd-tabs--process .fd-tabs__item:first-child .fd-tabs__link{padding-inline:0}.fd-tabs--filter{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs--filter .fd-tabs__item{margin-block:0;margin-inline:0;padding-block:0;padding-inline:.25rem;width:5.375rem}.fd-tabs--filter .fd-tabs__item--header{width:auto}.fd-tabs--filter .fd-tabs__icon{-webkit-margin-after:.375rem;margin-block-end:.375rem}.fd-tabs--filter .fd-tabs__icon:after{content:none}.fd-tabs--filter .fd-tabs__label{line-height:.875rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-tabs--filter .fd-tabs__link{display:-webkit-box;display:-ms-flexbox;display:flex;height:var(--fdTabs_Filter_Link_Height);padding-block:.875rem .625rem;padding-inline:.188rem;text-align:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;position:relative}.fd-tabs--filter .fd-tabs__link:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;bottom:0;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs--filter .fd-tabs__link.is-focus,.fd-tabs--filter .fd-tabs__link:focus{-webkit-box-shadow:none;box-shadow:none;outline:none;z-index:5}.fd-tabs--filter[dir=rtl] .fd-tabs__item:first-child .fd-tabs__link,[dir=rtl] .fd-tabs--filter .fd-tabs__item:first-child .fd-tabs__link{padding-inline:.188rem}.fd-tabs[class*=-compact],.fd-tabs[class*=-condensed],[class*=-compact] .fd-tabs:not([class*=-cozy]),[class*=-condensed] .fd-tabs:not([class*=-cozy]){--fdTabs_Icon_Size:1.125rem;--fdTabs_Icon_Selection_Height:1.875rem;--fdTabs_Label_Padding_Bottom:.25rem;--fdTabs_Filter_Link_Height:4.75rem}.fd-tabs--s{padding-block:0;padding-inline:1rem}.fd-tabs--l,.fd-tabs--m{padding-block:0;padding-inline:2rem}.fd-tabs--xl,.fd-tabs--xxl{padding-block:0;padding-inline:3rem}.fd-tabs[dir=rtl] .fd-tabs__process-icon,[dir=rtl] .fd-tabs .fd-tabs__process-icon{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.fd-tabs__process{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tabs__process:after,.fd-tabs__process:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs-custom{display:flex;flex-direction:column;height:100%}.fd-tabs-custom .is-disabled{pointer-events:none;opacity:.4}.fd-tabs{flex-grow:0;flex-wrap:nowrap}.fd-tabs__content{overflow-y:auto;flex-grow:1}.fd-tabs__item{flex-shrink:0}.fd-tabs__tag{white-space:nowrap}.fd-tabs__wrapper{flex-grow:1;display:flex;flex-wrap:wrap;align-items:center}.fd-tabs__wrapper--collapsible{overflow:hidden;flex-wrap:nowrap}.fd-tabs .fd-overflow-layout__items-container .fd-tabs__item:first-child{margin-left:.25rem}.fd-tabs .fd-overflow-layout__items-container .fd-tabs__item:first-child .fd-tabs__link{margin:0;padding:.875rem .75rem}.fd-tabs .fd-overflow-layout__items-container .fd-overflow-layout__item--first .fd-tabs__item{margin-left:0}.fd-tabs .fd-overflow-layout__items-container .fd-overflow-layout__item--first .fd-tabs__item .fd-tabs__link{margin-left:.1875rem;padding-left:0}\n/*! Bundled license information:\n\nfundamental-styles/dist/tabs.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i1.ContentDensityObserver }, { type: i0.DestroyRef }], propDecorators: { size: [{
                type: Input
            }], mode: [{
                type: Input
            }], collapseOverflow: [{
                type: Input
            }], maxVisibleTabs: [{
                type: Input
            }], stackContent: [{
                type: Input
            }], maxContentHeight: [{
                type: Input
            }], collapsibleTabs: [{
                type: Input
            }], defaultTab: [{
                type: Input
            }], selectDefaultOnTabsChange: [{
                type: Input
            }], focusFirstFocusableElement: [{
                type: Input
            }], selectedTabChange: [{
                type: Output
            }], selectedTabIndexChange: [{
                type: Output
            }], visibleItemsCount: [{
                type: Output
            }], hiddenItemsCount: [{
                type: Output
            }], tabPanels: [{
                type: ContentChildren,
                args: [forwardRef(() => TabPanelComponent)]
            }], tabHeaderLinks: [{
                type: ViewChildren,
                args: [TabLinkDirective]
            }], tabHeaders: [{
                type: ViewChildren,
                args: [TabItemDirective]
            }], overflowTrigger: [{
                type: ViewChild,
                args: [TabItemExpandComponent, { read: ElementRef }]
            }], headerContainer: [{
                type: ViewChild,
                args: ['headerContainer', { read: ElementRef }]
            }], _scrollbar: [{
                type: ViewChild,
                args: [ScrollbarDirective]
            }], menu: [{
                type: ViewChild,
                args: ['menu', { read: MenuComponent }]
            }], _overflowLayout: [{
                type: ViewChild,
                args: [OverflowLayoutComponent]
            }], _scrollSpy: [{
                type: ViewChild,
                args: ['scrollSpy', { read: ScrollSpyDirective }]
            }] } });

class TabNavComponent {
    /** @hidden */
    constructor(elementRef, _contentDensityObserver, _rtlService) {
        this.elementRef = elementRef;
        this._contentDensityObserver = _contentDensityObserver;
        this._rtlService = _rtlService;
        /** Size of tab, it's mostly about adding spacing on tab container, available sizes 's' | 'm' | 'l' | 'xl' | 'xxl' */
        this.size = 'm';
        /** @hidden */
        this._subscriptions = new Subscription();
        /** An RxJS Subject that will kill the data stream upon component’s destruction (for unsubscribing)  */
        this._destroyRef = inject(DestroyRef);
        this._dir = this._rtlService?.rtl.value ? 'rtl' : 'ltr';
        this._contentDensityObserver.subscribe();
    }
    /** @hidden
     * CssClassBuilder interface implementation
     * function must return single string
     * function is responsible for order which css classes are applied
     */
    buildComponentCssClass() {
        return [`fd-tabs`, this.mode ? 'fd-tabs--' + this.mode : '', `fd-tabs--${this.size}`, this.class];
    }
    /** @hidden */
    _keyUpHandler(event) {
        if (KeyUtil.isKeyCode(event, [LEFT_ARROW, RIGHT_ARROW])) {
            this._keyboardEventsManager.onKeydown(event);
        }
    }
    /** @hidden */
    ngAfterContentInit() {
        this._setupKeyManager();
        this._refreshSubscription();
        this._listenOnContentQueryListChange();
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnDestroy() {
        this._subscriptions.unsubscribe();
        this._keyboardEventsManager?.destroy();
    }
    /** Function that gives possibility to get all the link directives, with and without nav__item wrapper */
    get tabLinks() {
        let tabLinks = [];
        if (this.links) {
            tabLinks = tabLinks.concat(this.links.map((link) => link));
        }
        if (this.items) {
            tabLinks = tabLinks.concat(this.items.filter((item) => !!item.linkItem).map((item) => item.linkItem));
        }
        return tabLinks;
    }
    /**
     * Function to select a new tab from an index.
     * @param tabIndex Index of the tab to select.
     */
    selectTab(tabIndex) {
        this.tabLinks[tabIndex].elementRef.nativeElement.click();
    }
    /**
     * @hidden
     * Every time any of query is changed, ex. tab is removed or added
     * reference to keydown subscriptions handler is renewed
     */
    _listenOnContentQueryListChange() {
        merge(this.links.changes, this.items.changes)
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe(() => this._refreshSubscription());
    }
    /** Whether any QueryList detects any changes */
    _refreshSubscription() {
        this._subscriptions.unsubscribe();
        this._subscriptions = new Subscription();
        this._listenToFocusedLinks();
        this.links.changes.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._listenToFocusedLinks();
        });
    }
    /** @hidden */
    _listenToFocusedLinks() {
        const links = this.links.toArray();
        links.forEach((link) => {
            this._subscriptions.add(link.focused.subscribe(() => {
                this._keyboardEventsManager.setActiveItem(links.findIndex((item) => item === link));
            }));
        });
    }
    /** @hidden */
    _setupKeyManager() {
        this._keyboardEventsManager?.destroy();
        this._keyboardEventsManager = new FocusKeyManager(this.links).withWrap().withHorizontalOrientation(this._dir);
        this._rtlService?.rtl.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((isRtl) => {
            this._keyboardEventsManager.withHorizontalOrientation(isRtl ? 'rtl' : 'ltr');
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabNavComponent, deps: [{ token: i0.ElementRef }, { token: i1.ContentDensityObserver }, { token: i2.RtlService, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: TabNavComponent, isStandalone: true, selector: "[fd-tab-nav]", inputs: { class: "class", mode: "mode", size: "size" }, host: { listeners: { "keyup": "_keyUpHandler($event)" } }, providers: [contentDensityObserverProviders()], queries: [{ propertyName: "links", predicate: TabLinkDirective, descendants: true }, { propertyName: "items", predicate: TabItemDirective, descendants: true }], usesOnChanges: true, ngImport: i0, template: ` <ng-content></ng-content>`, isInline: true, styles: [".fd-tabs{--fdTabs_Icon_Size:1.125rem;--fdTabs_Icon_Selection_Height:2.625rem;--fdTabs_Label_Padding_Bottom:.375rem;--fdTabs_Filter_Link_Height:5.5rem;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-padding-start:0;background-color:var(--sapObjectHeader_Background);border-color:var(--sapObjectHeader_BorderColor);-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow);color:var(--sapContent_LabelColor);list-style:none;padding-inline-start:0}.fd-tabs:after,.fd-tabs:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__count{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-after:.125rem;color:var(--sapContent_LabelColor);padding-block-end:.125rem}.fd-tabs__count:after,.fd-tabs__count:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);cursor:pointer;display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-block:.875rem;padding-inline:0;padding-inline:.75rem;position:relative;text-decoration:none;-webkit-transition:0s;transition:0s}.fd-tabs__link:after,.fd-tabs__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__link.is-selected .fd-tabs__icon,.fd-tabs__link[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__link.is-selected .fd-tabs__icon:after,.fd-tabs__link.is-selected .fd-tabs__tag:after,.fd-tabs__link[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__link[aria-selected=true] .fd-tabs__tag:after{background-color:var(--fdIcon_Tab_Bar_Selection_Bar_Color)}.fd-tabs__link.is-focus,.fd-tabs__link:focus{-webkit-box-shadow:none;box-shadow:none;outline:none;z-index:5}.fd-tabs__link.is-focus .fd-tabs__icon:before,.fd-tabs__link.is-focus .fd-tabs__tag:before,.fd-tabs__link:focus .fd-tabs__icon:before,.fd-tabs__link:focus .fd-tabs__tag:before{content:\"\";inset:0;outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:var(--sapContent_FocusWidth);position:absolute}.fd-tabs__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-inline:.25rem;padding-block:0;padding-inline:0;position:relative}.fd-tabs__item:after,.fd-tabs__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__item.is-selected .fd-tabs__tag,.fd-tabs__item[aria-selected=true] .fd-tabs__tag{color:var(--fdIcon_Tab_Bar_Selection_Color)}.fd-tabs__item.is-selected .fd-tabs__icon,.fd-tabs__item[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item.is-selected .fd-tabs__icon:after,.fd-tabs__item.is-selected .fd-tabs__link:after,.fd-tabs__item.is-selected .fd-tabs__tag:after,.fd-tabs__item[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item[aria-selected=true] .fd-tabs__tag:after{background-color:var(--fdIcon_Tab_Bar_Selection_Bar_Color)}.fd-tabs__item--error .fd-tabs__icon{border-color:var(--sapErrorColor);color:var(--sapErrorColor)}.fd-tabs__item--error .fd-tabs__link .fd-tabs__tag{color:var(--sapErrorColor)}.fd-tabs__item--error.is-selected .fd-tabs__icon,.fd-tabs__item--error[aria-selected=true] .fd-tabs__icon{background-color:var(--sapErrorColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--error.is-selected .fd-tabs__icon:after,.fd-tabs__item--error.is-selected .fd-tabs__link:after,.fd-tabs__item--error.is-selected .fd-tabs__tag:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapErrorColor)}.fd-tabs__item--warning .fd-tabs__icon{border-color:var(--sapWarningColor);color:var(--sapWarningColor)}.fd-tabs__item--warning .fd-tabs__link .fd-tabs__tag{color:var(--sapWarningColor)}.fd-tabs__item--warning.is-selected .fd-tabs__icon,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__icon{background-color:var(--sapWarningColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--warning.is-selected .fd-tabs__icon:after,.fd-tabs__item--warning.is-selected .fd-tabs__link:after,.fd-tabs__item--warning.is-selected .fd-tabs__tag:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapWarningColor)}.fd-tabs__item--success .fd-tabs__icon{border-color:var(--sapSuccessColor);color:var(--sapSuccessColor)}.fd-tabs__item--success .fd-tabs__link .fd-tabs__tag{color:var(--sapSuccessColor)}.fd-tabs__item--success.is-selected .fd-tabs__icon,.fd-tabs__item--success[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSuccessColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--success.is-selected .fd-tabs__icon:after,.fd-tabs__item--success.is-selected .fd-tabs__link:after,.fd-tabs__item--success.is-selected .fd-tabs__tag:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapSuccessColor)}.fd-tabs__item--information .fd-tabs__icon{border-color:var(--sapInformationColor);color:var(--sapInformationColor)}.fd-tabs__item--information .fd-tabs__link .fd-tabs__tag{color:var(--sapInformationColor)}.fd-tabs__item--information.is-selected .fd-tabs__icon,.fd-tabs__item--information[aria-selected=true] .fd-tabs__icon{background-color:var(--sapInformationColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--information.is-selected .fd-tabs__icon:after,.fd-tabs__item--information.is-selected .fd-tabs__link:after,.fd-tabs__item--information.is-selected .fd-tabs__tag:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapInformationColor)}.fd-tabs__item--neutral .fd-tabs__icon{border-color:var(--sapNeutralColor);color:var(--sapNeutralColor)}.fd-tabs__item--neutral .fd-tabs__link .fd-tabs__tag{color:var(--sapNeutralColor)}.fd-tabs__item--neutral.is-selected .fd-tabs__icon,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__icon{background-color:var(--sapNeutralColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--neutral.is-selected .fd-tabs__icon:after,.fd-tabs__item--neutral.is-selected .fd-tabs__link:after,.fd-tabs__item--neutral.is-selected .fd-tabs__tag:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapNeutralColor)}.fd-tabs__item:first-child{-webkit-margin-start:0;margin-inline-start:0}.fd-tabs__item:first-child .fd-tabs__link{-webkit-margin-start:.1875rem;margin-inline-start:.1875rem;-webkit-padding-start:0;padding-inline-start:0}.fd-tabs__icon{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:transparent;border:var(--fdIcon_Tab_Bar_Icon_Border_Weight) solid var(--fdIcon_Tab_Bar_Icon_Border_Color);border-radius:50%;color:var(--fdIcon_Tab_Bar_Inactive_Tab_Icon_Color);height:var(--fdTabs_Icon_Selection_Height);margin-block:0;margin-inline:.188rem;position:relative;width:var(--fdTabs_Icon_Selection_Height)}.fd-tabs__icon:after,.fd-tabs__icon:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__icon [class*=sap-icon],.fd-tabs__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;font-size:var(--fdTabs_Icon_Size);line-height:1}.fd-tabs__icon:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs__tag{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:inline-block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-tabs__tag:after,.fd-tabs__tag:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__tag:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs__panel{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tabs__panel:after,.fd-tabs__panel:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__panel[aria-expanded=false]{display:none}.fd-tabs__panel.is-expanded,.fd-tabs__panel[aria-expanded=true]{display:block}.fd-tabs__counter-header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:1.5rem;font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1.5rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-tabs__counter-header:after,.fd-tabs__counter-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__overflow{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-margin-start:auto;margin-inline-start:auto}.fd-tabs__overflow:after,.fd-tabs__overflow:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__overflow [class*=sap-icon],.fd-tabs__overflow[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-tabs__process-icon{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_NonInteractiveIconColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:1rem;font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;padding-inline:.5rem}.fd-tabs__process-icon:after,.fd-tabs__process-icon:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__process-icon:before{content:\"\\e0c7\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-tabs__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-start:.125rem;color:var(--sapContent_LabelColor);font-size:var(--sapFontSmallSize);max-width:100%;padding-inline-start:.125rem}.fd-tabs__label:after,.fd-tabs__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__label:first-child{-webkit-padding-after:var(--fdTabs_Label_Padding_Bottom);padding-block-end:var(--fdTabs_Label_Padding_Bottom)}.fd-tabs__separator{border:0;border-right:solid var(--sapGroup_TitleBorderColor);border-right-width:.0625rem;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:2rem;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;margin-inline:.25rem;padding-block:0;padding-inline:0}.fd-tabs__separator:after,.fd-tabs__separator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs__header:after,.fd-tabs__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__header .fd-tabs__label{max-width:4rem}.fd-tabs--filter .fd-tabs__count,.fd-tabs--icon-only .fd-tabs__count,.fd-tabs--process .fd-tabs__count{font-size:var(--sapFontSmallSize)}.fd-tabs--filter .fd-tabs__item:first-child .fd-tabs__link,.fd-tabs--icon-only .fd-tabs__item:first-child .fd-tabs__link,.fd-tabs--process .fd-tabs__item:first-child .fd-tabs__link{margin-block:0;margin-inline:0}.fd-tabs--icon-only .fd-tabs__link,.fd-tabs--process .fd-tabs__link{padding-block:1rem 1rem}.fd-tabs--icon-only .fd-tabs__icon:after,.fd-tabs--process .fd-tabs__icon:after{bottom:-1.0625rem}.fd-tabs--filter .fd-tabs__count,.fd-tabs--icon-only .fd-tabs__count{left:calc(100% + .1875rem);position:absolute;top:0}.fd-tabs--filter[dir=rtl] .fd-tabs__count,.fd-tabs--icon-only[dir=rtl] .fd-tabs__count,[dir=rtl] .fd-tabs--filter .fd-tabs__count,[dir=rtl] .fd-tabs--icon-only .fd-tabs__count{left:auto;right:calc(100% + .1875rem)}.fd-tabs--process .fd-tabs__item{margin-block:0;margin-inline:0 .25rem}.fd-tabs--process .fd-tabs__item,.fd-tabs--process .fd-tabs__link{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs--process .fd-tabs__link{padding-inline:0}.fd-tabs--process .fd-tabs__icon{margin-block:0;margin-inline:.1875rem}.fd-tabs--process .fd-tabs__label{line-height:.875rem;max-width:7.5rem;overflow:hidden;white-space:nowrap}.fd-tabs--process[dir=rtl] .fd-tabs__item,[dir=rtl] .fd-tabs--process .fd-tabs__item{margin-block:0;margin-inline:.25rem 0}.fd-tabs--process[dir=rtl] .fd-tabs__item:first-child .fd-tabs__link,[dir=rtl] .fd-tabs--process .fd-tabs__item:first-child .fd-tabs__link{padding-inline:0}.fd-tabs--filter{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs--filter .fd-tabs__item{margin-block:0;margin-inline:0;padding-block:0;padding-inline:.25rem;width:5.375rem}.fd-tabs--filter .fd-tabs__item--header{width:auto}.fd-tabs--filter .fd-tabs__icon{-webkit-margin-after:.375rem;margin-block-end:.375rem}.fd-tabs--filter .fd-tabs__icon:after{content:none}.fd-tabs--filter .fd-tabs__label{line-height:.875rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-tabs--filter .fd-tabs__link{display:-webkit-box;display:-ms-flexbox;display:flex;height:var(--fdTabs_Filter_Link_Height);padding-block:.875rem .625rem;padding-inline:.188rem;text-align:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;position:relative}.fd-tabs--filter .fd-tabs__link:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;bottom:0;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs--filter .fd-tabs__link.is-focus,.fd-tabs--filter .fd-tabs__link:focus{-webkit-box-shadow:none;box-shadow:none;outline:none;z-index:5}.fd-tabs--filter[dir=rtl] .fd-tabs__item:first-child .fd-tabs__link,[dir=rtl] .fd-tabs--filter .fd-tabs__item:first-child .fd-tabs__link{padding-inline:.188rem}.fd-tabs[class*=-compact],.fd-tabs[class*=-condensed],[class*=-compact] .fd-tabs:not([class*=-cozy]),[class*=-condensed] .fd-tabs:not([class*=-cozy]){--fdTabs_Icon_Size:1.125rem;--fdTabs_Icon_Selection_Height:1.875rem;--fdTabs_Label_Padding_Bottom:.25rem;--fdTabs_Filter_Link_Height:4.75rem}.fd-tabs--s{padding-block:0;padding-inline:1rem}.fd-tabs--l,.fd-tabs--m{padding-block:0;padding-inline:2rem}.fd-tabs--xl,.fd-tabs--xxl{padding-block:0;padding-inline:3rem}.fd-tabs[dir=rtl] .fd-tabs__process-icon,[dir=rtl] .fd-tabs .fd-tabs__process-icon{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.fd-tabs__process{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tabs__process:after,.fd-tabs__process:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}\n/*! Bundled license information:\n\nfundamental-styles/dist/tabs.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], TabNavComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabNavComponent, decorators: [{
            type: Component,
            args: [{ selector: '[fd-tab-nav]', template: ` <ng-content></ng-content>`, providers: [contentDensityObserverProviders()], encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, styles: [".fd-tabs{--fdTabs_Icon_Size:1.125rem;--fdTabs_Icon_Selection_Height:2.625rem;--fdTabs_Label_Padding_Bottom:.375rem;--fdTabs_Filter_Link_Height:5.5rem;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-ms-flex-wrap:wrap;flex-wrap:wrap;-webkit-padding-start:0;background-color:var(--sapObjectHeader_Background);border-color:var(--sapObjectHeader_BorderColor);-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow);color:var(--sapContent_LabelColor);list-style:none;padding-inline-start:0}.fd-tabs:after,.fd-tabs:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__count{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-after:.125rem;color:var(--sapContent_LabelColor);padding-block-end:.125rem}.fd-tabs__count:after,.fd-tabs__count:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);cursor:pointer;display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-block:.875rem;padding-inline:0;padding-inline:.75rem;position:relative;text-decoration:none;-webkit-transition:0s;transition:0s}.fd-tabs__link:after,.fd-tabs__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__link.is-selected .fd-tabs__icon,.fd-tabs__link[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__link.is-selected .fd-tabs__icon:after,.fd-tabs__link.is-selected .fd-tabs__tag:after,.fd-tabs__link[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__link[aria-selected=true] .fd-tabs__tag:after{background-color:var(--fdIcon_Tab_Bar_Selection_Bar_Color)}.fd-tabs__link.is-focus,.fd-tabs__link:focus{-webkit-box-shadow:none;box-shadow:none;outline:none;z-index:5}.fd-tabs__link.is-focus .fd-tabs__icon:before,.fd-tabs__link.is-focus .fd-tabs__tag:before,.fd-tabs__link:focus .fd-tabs__icon:before,.fd-tabs__link:focus .fd-tabs__tag:before{content:\"\";inset:0;outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:var(--sapContent_FocusWidth);position:absolute}.fd-tabs__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-inline:.25rem;padding-block:0;padding-inline:0;position:relative}.fd-tabs__item:after,.fd-tabs__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__item.is-selected .fd-tabs__tag,.fd-tabs__item[aria-selected=true] .fd-tabs__tag{color:var(--fdIcon_Tab_Bar_Selection_Color)}.fd-tabs__item.is-selected .fd-tabs__icon,.fd-tabs__item[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSelectedColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item.is-selected .fd-tabs__icon:after,.fd-tabs__item.is-selected .fd-tabs__link:after,.fd-tabs__item.is-selected .fd-tabs__tag:after,.fd-tabs__item[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item[aria-selected=true] .fd-tabs__tag:after{background-color:var(--fdIcon_Tab_Bar_Selection_Bar_Color)}.fd-tabs__item--error .fd-tabs__icon{border-color:var(--sapErrorColor);color:var(--sapErrorColor)}.fd-tabs__item--error .fd-tabs__link .fd-tabs__tag{color:var(--sapErrorColor)}.fd-tabs__item--error.is-selected .fd-tabs__icon,.fd-tabs__item--error[aria-selected=true] .fd-tabs__icon{background-color:var(--sapErrorColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--error.is-selected .fd-tabs__icon:after,.fd-tabs__item--error.is-selected .fd-tabs__link:after,.fd-tabs__item--error.is-selected .fd-tabs__tag:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--error[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapErrorColor)}.fd-tabs__item--warning .fd-tabs__icon{border-color:var(--sapWarningColor);color:var(--sapWarningColor)}.fd-tabs__item--warning .fd-tabs__link .fd-tabs__tag{color:var(--sapWarningColor)}.fd-tabs__item--warning.is-selected .fd-tabs__icon,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__icon{background-color:var(--sapWarningColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--warning.is-selected .fd-tabs__icon:after,.fd-tabs__item--warning.is-selected .fd-tabs__link:after,.fd-tabs__item--warning.is-selected .fd-tabs__tag:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--warning[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapWarningColor)}.fd-tabs__item--success .fd-tabs__icon{border-color:var(--sapSuccessColor);color:var(--sapSuccessColor)}.fd-tabs__item--success .fd-tabs__link .fd-tabs__tag{color:var(--sapSuccessColor)}.fd-tabs__item--success.is-selected .fd-tabs__icon,.fd-tabs__item--success[aria-selected=true] .fd-tabs__icon{background-color:var(--sapSuccessColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--success.is-selected .fd-tabs__icon:after,.fd-tabs__item--success.is-selected .fd-tabs__link:after,.fd-tabs__item--success.is-selected .fd-tabs__tag:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--success[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapSuccessColor)}.fd-tabs__item--information .fd-tabs__icon{border-color:var(--sapInformationColor);color:var(--sapInformationColor)}.fd-tabs__item--information .fd-tabs__link .fd-tabs__tag{color:var(--sapInformationColor)}.fd-tabs__item--information.is-selected .fd-tabs__icon,.fd-tabs__item--information[aria-selected=true] .fd-tabs__icon{background-color:var(--sapInformationColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--information.is-selected .fd-tabs__icon:after,.fd-tabs__item--information.is-selected .fd-tabs__link:after,.fd-tabs__item--information.is-selected .fd-tabs__tag:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--information[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapInformationColor)}.fd-tabs__item--neutral .fd-tabs__icon{border-color:var(--sapNeutralColor);color:var(--sapNeutralColor)}.fd-tabs__item--neutral .fd-tabs__link .fd-tabs__tag{color:var(--sapNeutralColor)}.fd-tabs__item--neutral.is-selected .fd-tabs__icon,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__icon{background-color:var(--sapNeutralColor);color:var(--sapContent_ContrastIconColor)}.fd-tabs__item--neutral.is-selected .fd-tabs__icon:after,.fd-tabs__item--neutral.is-selected .fd-tabs__link:after,.fd-tabs__item--neutral.is-selected .fd-tabs__tag:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__icon:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__link:after,.fd-tabs__item--neutral[aria-selected=true] .fd-tabs__tag:after{background-color:var(--sapNeutralColor)}.fd-tabs__item:first-child{-webkit-margin-start:0;margin-inline-start:0}.fd-tabs__item:first-child .fd-tabs__link{-webkit-margin-start:.1875rem;margin-inline-start:.1875rem;-webkit-padding-start:0;padding-inline-start:0}.fd-tabs__icon{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:transparent;border:var(--fdIcon_Tab_Bar_Icon_Border_Weight) solid var(--fdIcon_Tab_Bar_Icon_Border_Color);border-radius:50%;color:var(--fdIcon_Tab_Bar_Inactive_Tab_Icon_Color);height:var(--fdTabs_Icon_Selection_Height);margin-block:0;margin-inline:.188rem;position:relative;width:var(--fdTabs_Icon_Selection_Height)}.fd-tabs__icon:after,.fd-tabs__icon:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__icon [class*=sap-icon],.fd-tabs__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;font-size:var(--fdTabs_Icon_Size);line-height:1}.fd-tabs__icon:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs__tag{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:inline-block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative}.fd-tabs__tag:after,.fd-tabs__tag:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__tag:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs__panel{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tabs__panel:after,.fd-tabs__panel:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__panel[aria-expanded=false]{display:none}.fd-tabs__panel.is-expanded,.fd-tabs__panel[aria-expanded=true]{display:block}.fd-tabs__counter-header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:1.5rem;font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1.5rem;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-tabs__counter-header:after,.fd-tabs__counter-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__overflow{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-margin-start:auto;margin-inline-start:auto}.fd-tabs__overflow:after,.fd-tabs__overflow:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__overflow [class*=sap-icon],.fd-tabs__overflow[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-tabs__process-icon{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_NonInteractiveIconColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:1rem;font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;padding-inline:.5rem}.fd-tabs__process-icon:after,.fd-tabs__process-icon:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__process-icon:before{content:\"\\e0c7\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-tabs__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-start:.125rem;color:var(--sapContent_LabelColor);font-size:var(--sapFontSmallSize);max-width:100%;padding-inline-start:.125rem}.fd-tabs__label:after,.fd-tabs__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__label:first-child{-webkit-padding-after:var(--fdTabs_Label_Padding_Bottom);padding-block-end:var(--fdTabs_Label_Padding_Bottom)}.fd-tabs__separator{border:0;border-right:solid var(--sapGroup_TitleBorderColor);border-right-width:.0625rem;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:2rem;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;margin-inline:.25rem;padding-block:0;padding-inline:0}.fd-tabs__separator:after,.fd-tabs__separator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs__header:after,.fd-tabs__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tabs__header .fd-tabs__label{max-width:4rem}.fd-tabs--filter .fd-tabs__count,.fd-tabs--icon-only .fd-tabs__count,.fd-tabs--process .fd-tabs__count{font-size:var(--sapFontSmallSize)}.fd-tabs--filter .fd-tabs__item:first-child .fd-tabs__link,.fd-tabs--icon-only .fd-tabs__item:first-child .fd-tabs__link,.fd-tabs--process .fd-tabs__item:first-child .fd-tabs__link{margin-block:0;margin-inline:0}.fd-tabs--icon-only .fd-tabs__link,.fd-tabs--process .fd-tabs__link{padding-block:1rem 1rem}.fd-tabs--icon-only .fd-tabs__icon:after,.fd-tabs--process .fd-tabs__icon:after{bottom:-1.0625rem}.fd-tabs--filter .fd-tabs__count,.fd-tabs--icon-only .fd-tabs__count{left:calc(100% + .1875rem);position:absolute;top:0}.fd-tabs--filter[dir=rtl] .fd-tabs__count,.fd-tabs--icon-only[dir=rtl] .fd-tabs__count,[dir=rtl] .fd-tabs--filter .fd-tabs__count,[dir=rtl] .fd-tabs--icon-only .fd-tabs__count{left:auto;right:calc(100% + .1875rem)}.fd-tabs--process .fd-tabs__item{margin-block:0;margin-inline:0 .25rem}.fd-tabs--process .fd-tabs__item,.fd-tabs--process .fd-tabs__link{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs--process .fd-tabs__link{padding-inline:0}.fd-tabs--process .fd-tabs__icon{margin-block:0;margin-inline:.1875rem}.fd-tabs--process .fd-tabs__label{line-height:.875rem;max-width:7.5rem;overflow:hidden;white-space:nowrap}.fd-tabs--process[dir=rtl] .fd-tabs__item,[dir=rtl] .fd-tabs--process .fd-tabs__item{margin-block:0;margin-inline:.25rem 0}.fd-tabs--process[dir=rtl] .fd-tabs__item:first-child .fd-tabs__link,[dir=rtl] .fd-tabs--process .fd-tabs__item:first-child .fd-tabs__link{padding-inline:0}.fd-tabs--filter{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tabs--filter .fd-tabs__item{margin-block:0;margin-inline:0;padding-block:0;padding-inline:.25rem;width:5.375rem}.fd-tabs--filter .fd-tabs__item--header{width:auto}.fd-tabs--filter .fd-tabs__icon{-webkit-margin-after:.375rem;margin-block-end:.375rem}.fd-tabs--filter .fd-tabs__icon:after{content:none}.fd-tabs--filter .fd-tabs__label{line-height:.875rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-tabs--filter .fd-tabs__link{display:-webkit-box;display:-ms-flexbox;display:flex;height:var(--fdTabs_Filter_Link_Height);padding-block:.875rem .625rem;padding-inline:.188rem;text-align:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;position:relative}.fd-tabs--filter .fd-tabs__link:after{border-radius:.125rem .125rem 0 0;bottom:-.875rem;bottom:0;content:\"\";display:inline-block;height:var(--fdIcon_Tab_Bar_Selection_Bar_Height);left:-.1875rem;position:absolute;-webkit-transition:all .125s ease-in;transition:all .125s ease-in;width:calc(100% + .375rem)}.fd-tabs--filter .fd-tabs__link.is-focus,.fd-tabs--filter .fd-tabs__link:focus{-webkit-box-shadow:none;box-shadow:none;outline:none;z-index:5}.fd-tabs--filter[dir=rtl] .fd-tabs__item:first-child .fd-tabs__link,[dir=rtl] .fd-tabs--filter .fd-tabs__item:first-child .fd-tabs__link{padding-inline:.188rem}.fd-tabs[class*=-compact],.fd-tabs[class*=-condensed],[class*=-compact] .fd-tabs:not([class*=-cozy]),[class*=-condensed] .fd-tabs:not([class*=-cozy]){--fdTabs_Icon_Size:1.125rem;--fdTabs_Icon_Selection_Height:1.875rem;--fdTabs_Label_Padding_Bottom:.25rem;--fdTabs_Filter_Link_Height:4.75rem}.fd-tabs--s{padding-block:0;padding-inline:1rem}.fd-tabs--l,.fd-tabs--m{padding-block:0;padding-inline:2rem}.fd-tabs--xl,.fd-tabs--xxl{padding-block:0;padding-inline:3rem}.fd-tabs[dir=rtl] .fd-tabs__process-icon,[dir=rtl] .fd-tabs .fd-tabs__process-icon{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.fd-tabs__process{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tabs__process:after,.fd-tabs__process:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}\n/*! Bundled license information:\n\nfundamental-styles/dist/tabs.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i1.ContentDensityObserver }, { type: i2.RtlService, decorators: [{
                    type: Optional
                }] }], propDecorators: { class: [{
                type: Input
            }], mode: [{
                type: Input
            }], size: [{
                type: Input
            }], links: [{
                type: ContentChildren,
                args: [TabLinkDirective, { descendants: true }]
            }], items: [{
                type: ContentChildren,
                args: [TabItemDirective, { descendants: true }]
            }], buildComponentCssClass: [], _keyUpHandler: [{
                type: HostListener,
                args: ['keyup', ['$event']]
            }] } });

const components = [
    TabListComponent,
    TabPanelComponent,
    TabTitleDirective,
    TabNavComponent,
    TabItemDirective,
    TabLinkDirective,
    TabTagDirective,
    TabIconComponent,
    TabCountDirective,
    TabLabelDirective,
    TabProcessDirective,
    TabHeaderDirective,
    TabCounterHeaderDirective,
    TabProcessIconDirective,
    TabSeparatorDirective
];
/**
 * @deprecated
 * Use `@fundamental-ngx/platform/icon-tab-bar` instead
 */
class TabsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: TabsModule, imports: [TabListComponent,
            TabPanelComponent,
            TabTitleDirective,
            TabNavComponent,
            TabItemDirective,
            TabLinkDirective,
            TabTagDirective,
            TabIconComponent,
            TabCountDirective,
            TabLabelDirective,
            TabProcessDirective,
            TabHeaderDirective,
            TabCounterHeaderDirective,
            TabProcessIconDirective,
            TabSeparatorDirective], exports: [TabListComponent,
            TabPanelComponent,
            TabTitleDirective,
            TabNavComponent,
            TabItemDirective,
            TabLinkDirective,
            TabTagDirective,
            TabIconComponent,
            TabCountDirective,
            TabLabelDirective,
            TabProcessDirective,
            TabHeaderDirective,
            TabCounterHeaderDirective,
            TabProcessIconDirective,
            TabSeparatorDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabsModule, imports: [TabListComponent,
            TabIconComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TabsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...components],
                    exports: [...components]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LIST_COMPONENT, TabCountDirective, TabCounterHeaderDirective, TabHeaderDirective, TabIconComponent, TabItemDirective, TabItemExpandComponent, TabLabelDirective, TabLinkDirective, TabListComponent, TabNavComponent, TabPanelComponent, TabPanelStateChange, TabProcessDirective, TabProcessIconDirective, TabSeparatorDirective, TabTagDirective, TabTitleDirective, TabsModule };
//# sourceMappingURL=fundamental-ngx-core-tabs.mjs.map
