import * as i1 from '@fundamental-ngx/cdk/data-source';
import { BaseDataSource, DataProvider, isDataSource, DataSourceDirective, FD_DATA_SOURCE_TRANSFORMER } from '@fundamental-ngx/cdk/data-source';
import { isObservable, Subject, Subscription, filter, switchMap, fromEvent, startWith, distinctUntilChanged } from 'rxjs';
import { __decorate, __metadata } from 'tslib';
import { FocusKeyManager } from '@angular/cdk/a11y';
import { DOWN_ARROW, UP_ARROW, LEFT_ARROW, RIGHT_ARROW } from '@angular/cdk/keycodes';
import { NgTemplateOutlet, NgClass, NgStyle } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, TemplateRef, Input, Directive, Injector, signal, Injectable, EventEmitter, ElementRef, DestroyRef, ChangeDetectorRef, effect, HostListener, ContentChildren, ViewChildren, ContentChild, Output, ViewEncapsulation, Component, input, ViewChild, HostBinding, ChangeDetectionStrategy, NgModule, InjectionToken } from '@angular/core';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import * as i2 from '@fundamental-ngx/cdk/forms';
import { CvaDirective } from '@fundamental-ngx/cdk/forms';
import { uuidv4, SelectionService, RtlService, KeyUtil, RepeatDirective, SelectableItemDirective, applyCssClass, ClickedDirective, FDK_SELECTABLE_ITEM_PROVIDER } from '@fundamental-ngx/cdk/utils';
import { ContentDensityObserver, contentDensityObserverProviders } from '@fundamental-ngx/core/content-density';
import { SkeletonComponent } from '@fundamental-ngx/core/skeleton';
import { FdTranslatePipe } from '@fundamental-ngx/i18n';
import * as i2$1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { CheckboxComponent } from '@fundamental-ngx/core/checkbox';
import { IconComponent } from '@fundamental-ngx/core/icon';
import { RadioButtonComponent } from '@fundamental-ngx/core/radio';

class FdTreeDataSource extends BaseDataSource {
    /** @hidden */
    constructor(dataProvider) {
        super(dataProvider);
        this.dataProvider = dataProvider;
        /** @hidden */
        this.limitless = true;
    }
}
class ArrayTreeDataSource extends FdTreeDataSource {
    /** @hidden */
    constructor(data) {
        super(new DataProvider(data));
    }
}
class ObservableTreeDataSource extends FdTreeDataSource {
    /** @hidden */
    constructor(data) {
        super(new DataProvider(data));
    }
}

class TreeDataSourceParser {
    /**
     * Transforms plain array or observable into DataSource class.
     * @param source
     */
    parse(source) {
        if (isDataSource(source)) {
            return source;
        }
        if (Array.isArray(source)) {
            return new ArrayTreeDataSource(source);
        }
        if (isObservable(source)) {
            return new ObservableTreeDataSource(source);
        }
        return undefined;
    }
}

class TreeItemDefDirective {
    constructor() {
        /** Template reference. */
        this.templateRef = inject(TemplateRef);
    }
    /** @hidden */
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemDefDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TreeItemDefDirective, isStandalone: true, selector: "[fdTreeItemDef]", inputs: { fdTreeItemDefAs: "fdTreeItemDefAs" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemDefDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTreeItemDef]',
                    standalone: true
                }]
        }], propDecorators: { fdTreeItemDefAs: [{
                type: Input
            }] } });

class TreeItemDirective {
    /** @hidden */
    constructor(injector) {
        this.injector = Injector.create({ providers: [], parent: injector });
    }
    /** Sets tree item. */
    setTreeItem(item) {
        this.treeItem = item;
    }
    /** @hidden */
    ngOnDestroy() {
        this.treeItem = null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemDirective, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TreeItemDirective, isStandalone: true, selector: "[fdTreeItem]", exportAs: ["fdTreeItem"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTreeItem]',
                    exportAs: 'fdTreeItem',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.Injector }] });

class BaseTreeItem {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BaseTreeItem, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: BaseTreeItem, isStandalone: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: BaseTreeItem, decorators: [{
            type: Directive
        }] });

class TreeService {
    constructor() {
        /**
         * @hidden
         */
        this.detectChanges = new Subject();
        /** @hidden */
        this._expandableItems = new Map();
        /** @hidden */
        this._selectionMode$ = signal({ mode: 'none', placement: 'none' });
        /** @hidden */
        this._expandedLevel = signal(undefined);
        /** @hidden */
        this._navigationIndicator$ = signal(false);
    }
    /** Current expanded level. */
    get expandedLevel() {
        return this._expandedLevel.asReadonly();
    }
    /** Tree selection mode. */
    get selectionMode() {
        return this._selectionMode$.asReadonly();
    }
    /** Whether to show navigation indicator. */
    get navigationIndicator() {
        return this._navigationIndicator$.asReadonly();
    }
    /** Sets whether the navigation indicator should be visible. */
    setNavigationIndicator(value) {
        this._navigationIndicator$.set(value);
    }
    /** @hidden */
    normalizeTreeItems(items, parentId = null, level = 1) {
        if (!items) {
            return [];
        }
        return [...items].map((item) => ({
            ...item,
            ...{
                level,
                parentId,
                renderer: this.treeItemTemplateRef,
                id: item.id || uuidv4()
            }
        }));
    }
    /**
     * Adds expandable item to the object of expandable items.
     * @param id
     * @param level
     */
    addExpandableItem(id, level, expanded) {
        const levelCollection = this._expandableItems.get(level) || {};
        levelCollection[id] = expanded;
        this._expandableItems.set(level, levelCollection);
        this._emitNewExpandedLevel();
    }
    /**
     * Removes expandable item from the object of expandable items.
     * @param id
     * @param level
     */
    removeExpandableItem(id, level) {
        const levelCollection = this._expandableItems.get(level) || {};
        delete levelCollection[id];
        this._expandableItems.set(level, levelCollection);
        this._emitNewExpandedLevel();
    }
    /**
     * Sets selection mode and it's placement.
     * @param mode Selection mode.
     * @param placement Selection control placement.
     */
    setSelectionMode(mode, placement) {
        this._selectionMode$.set({ mode, placement });
    }
    /** @hidden */
    _emitNewExpandedLevel() {
        // We need to go from level 1 to deeper level since level 4 may be expanded, yet level 2 not.
        const levels = Array.from(this._expandableItems.keys()).sort();
        let lastLevel;
        for (const level of levels) {
            const levelExpandableItems = this._expandableItems.get(level);
            if (Object.values(levelExpandableItems).every((v) => !v)) {
                break;
            }
            lastLevel = level;
        }
        this._expandedLevel.set(lastLevel);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeService, decorators: [{
            type: Injectable
        }] });

class TreeComponent {
    /**
     * Whether the Tree component has navigation indicators.
     */
    set navigationIndicator(value) {
        if (value === this._navigationIndicator) {
            return;
        }
        this._navigationIndicator = value;
        this._treeService.setNavigationIndicator(value);
    }
    get navigationIndicator() {
        return this._navigationIndicator;
    }
    /** Tree item template definition. */
    set treeItemDef(value) {
        this._treeItemDef = value;
        // Set new renderer
        this._treeService.treeItemTemplateRef = value?.templateRef;
        this._items = this._treeService.normalizeTreeItems(this._items);
    }
    get treeItemDef() {
        return this._treeItemDef;
    }
    /** @hidden */
    get multiple() {
        return this.selection === 'multiple';
    }
    /** @hidden */
    get toggle() {
        return true;
    }
    /** @hidden */
    constructor() {
        /**
         * Whether the tree should be borderless.
         */
        this.noBorder = false;
        /** Type of tree items selection. */
        this.selection = 'none';
        /** Placement of the selection control. */
        this.selectionPlacement = 'none';
        /**
         * Whether the sections should be dependent for selection mode.
         * If true, selection control will shift, according to the level.
         * If false, selection control will stay on the same place ignoring the item level.
         */
        this.independentSections = false;
        /** Event emitted when data loading is started. */
        this.dataRequested = new EventEmitter();
        /** Event emitted when data loading is finished. */
        this.dataReceived = new EventEmitter();
        /** Event emitted when selected state changed. */
        this.selectedChange = new EventEmitter();
        /** @hidden */
        this._items = [];
        /**
         * @hidden
         * Used for skeleton to appear before first meaningful data being loaded.
         */
        this._initialDataLoaded = false;
        /** @hidden */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this._treeService = inject(TreeService);
        /** @hidden */
        this._navigationIndicator = false;
        /** @hidden */
        this._contentDensityObserver = inject(ContentDensityObserver);
        /** @hidden */
        this._dataSourceDirective = inject(DataSourceDirective);
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._selectionService = inject(SelectionService);
        /** @hidden */
        this._rtl = inject(RtlService, {
            optional: true
        });
        /** @hidden */
        this._cvaDirective = inject(CvaDirective);
        /** @hidden */
        this._cdr = inject(ChangeDetectorRef);
        /** @hidden */
        this._dsSubscription = null;
        /**
         * @hidden
         * Sorted tree item components.
         */
        this._sortedTreeItems = [];
        /**
         * @hidden
         * All tree item components.
         */
        this._allItems = [];
        this._selectionService.registerRootComponent(this);
        this._contentDensityObserver.subscribe();
        effect(() => {
            this._expandedLevel = this._treeService.expandedLevel();
            this.buildComponentCssClass();
        });
    }
    /** @hidden */
    buildComponentCssClass() {
        return [
            this.class,
            this._expandedLevel ? `expanded-level-${this._expandedLevel}` : '',
            this.noBorder ? 'fd-tree--no-border' : '',
            this._items.length === 0 && this._initialDataLoaded ? 'fd-tree--no-data' : '',
            this.independentSections ? 'fd-tree--independent-multi-selection' : '',
            'fd-tree'
        ];
    }
    /**
     * @hidden
     * Keyboard navigation
     * @param event Keyboard event.
     */
    _onKeyUp(event) {
        if (KeyUtil.isKeyCode(event, [DOWN_ARROW, UP_ARROW])) {
            if (event.defaultPrevented) {
                return;
            }
            event.preventDefault();
            this._focusKeyManager?.onKeydown(event);
        }
    }
    /** @hidden */
    ngOnInit() {
        this._openDataStream();
        this.buildComponentCssClass();
        this._treeService.detectChanges.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._cdr.detectChanges();
        });
        if (this.selection !== 'none') {
            this._selectionService.setValue(this._cvaDirective.value);
            this._cvaDirective.ngControl?.valueChanges?.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
                this._selectionService.setValue(this._cvaDirective.value);
            });
        }
    }
    /** @hidden */
    ngOnChanges(changes) {
        this.buildComponentCssClass();
        if ('selection' in changes || 'selectionPlacement' in changes) {
            this._treeService.setSelectionMode(this.selection, this.selectionPlacement);
            this._setSelectionListener();
        }
    }
    /** @hidden */
    ngAfterViewInit() {
        this._listenToTreeItemsChanges();
        this._listenToTreeItemDirectiveChanges();
    }
    /** @hidden */
    ngOnDestroy() {
        this._dsSubscription?.unsubscribe();
        this._eventSub?.unsubscribe();
        this._selectionSub?.unsubscribe();
    }
    /** @hidden */
    _onItemFocused(treeItem) {
        let focusedIndex = -1;
        this._sortedTreeItems.forEach((item, index) => {
            const isFocused = treeItem === item;
            item.setContainerTabIndex(isFocused ? 0 : -1);
            if (isFocused) {
                focusedIndex = index;
            }
        });
        if (focusedIndex === -1) {
            return;
        }
        this._focusKeyManager.setActiveItem(focusedIndex);
    }
    /** @hidden */
    _onItemKeyDown(event, treeItem) {
        if (!treeItem) {
            return;
        }
        const isRtl = !!this._rtl?.rtlSignal();
        const expandKey = isRtl ? LEFT_ARROW : RIGHT_ARROW;
        const collapseKey = isRtl ? RIGHT_ARROW : LEFT_ARROW;
        if (KeyUtil.isKeyCode(event, expandKey) && (treeItem.hasDsChildren || treeItem.hasProjectedChildren)) {
            if (event.defaultPrevented) {
                return;
            }
            event.preventDefault();
            this._expandTreeSection(treeItem);
            return;
        }
        if (KeyUtil.isKeyCode(event, collapseKey)) {
            if (event.defaultPrevented) {
                return;
            }
            event.preventDefault();
            this._collapseTreeSection(treeItem);
            return;
        }
    }
    /** @hidden */
    _trackFn(index, item) {
        return item.id;
    }
    /**
     * @hidden
     * Select list interface method implementation.
     * Sets value for control value accessor and emits it.
     * @param value value of the selection.
     */
    onChange(value) {
        this._cvaDirective.setValue(value, true);
    }
    /** @hidden */
    _expandTreeSection(treeItem) {
        if (treeItem.expanded) {
            // Shift focus on the first child item
            const itemIndex = this._sortedTreeItems.findIndex((item) => item.id === treeItem.id);
            const nextItem = this._sortedTreeItems[itemIndex + 1];
            if (nextItem?.parentId === treeItem.id) {
                this._focusKeyManager.setActiveItem(itemIndex + 1);
            }
            return;
        }
        treeItem.expanded = true;
        this._cdr.detectChanges();
    }
    /** @hidden */
    _collapseTreeSection(treeItem) {
        if (!treeItem.expanded && treeItem.parentId) {
            const parentItemIndex = this._sortedTreeItems.findIndex((item) => item.id === treeItem.parentId);
            if (parentItemIndex > -1) {
                this._focusKeyManager.setActiveItem(parentItemIndex);
                return;
            }
        }
        treeItem.expanded = false;
        this._cdr.detectChanges();
    }
    /** @hidden */
    _openDataStream() {
        this._dsSubscription?.unsubscribe();
        this._dsSubscription = new Subscription();
        this._dsSubscription.add(this._dataSourceDirective.dataSourceProvider?.dataRequested.subscribe(this.dataRequested));
        this._dsSubscription.add(this._dataSourceDirective.dataSourceProvider?.dataReceived.subscribe(this.dataReceived));
        this._dsSubscription.add(this._dataSourceDirective.dataSourceProvider?.dataReceived
            .pipe(filter((received) => received), switchMap(() => this._dataSourceDirective.dataChanged$))
            .subscribe((data) => {
            this._initialDataLoaded = true;
            this._items = this._treeService.normalizeTreeItems(data);
            this.buildComponentCssClass();
            this._cdr.markForCheck();
        }));
        this._dataSourceDirective.dataSourceProvider?.match();
    }
    /** @hidden */
    _setupEventListeners() {
        this._eventSub?.unsubscribe();
        this._eventSub = new Subscription();
        this._sortedTreeItems.forEach((item) => {
            this._eventSub.add(fromEvent(item.elementRef.nativeElement, 'keydown').subscribe((event) => {
                this._onItemKeyDown(event, item);
            }));
            this._eventSub.add(fromEvent(item.itemContainer?.nativeElement, 'focus').subscribe(() => {
                this._onItemFocused(item);
            }));
        });
    }
    /** @hidden */
    _sortTreeItems(items) {
        const components = [];
        const rootItems = items.filter((item) => item.level === 1);
        rootItems.forEach((treeItem, index) => {
            treeItem.setPosition(rootItems.length, index + 1);
        });
        items.forEach((item) => {
            if (!item || components.includes(item)) {
                return;
            }
            components.push(item);
            if (item.children.length === 0) {
                return;
            }
            const childItems = this._sortTreeItems(this._allItems.filter((i) => i.parentId === item.id));
            childItems.forEach((treeItem, index) => {
                treeItem.setPosition(childItems.length, index + 1);
            });
            components.push(...childItems);
        });
        return components;
    }
    /** @hidden */
    _setSelectionListener() {
        this._selectionSub?.unsubscribe();
        if (this.selection !== 'none') {
            this._selectionService.setValue(this._cvaDirective.value);
            this._selectionSub = this._cvaDirective.ngControl?.valueChanges
                ?.pipe(takeUntilDestroyed(this._destroyRef))
                .subscribe(() => {
                this._selectionService.setValue(this._cvaDirective.value);
            });
        }
    }
    /** @hidden */
    _listenToTreeItemDirectiveChanges() {
        this._treeItemDirectives.changes
            .pipe(startWith(null), filter(() => this.treeItemDef !== undefined), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => {
            this._allItems = this._treeItemDirectives.toArray().map((item) => item.treeItem);
            const flattenedItems = this._sortTreeItems(this._allItems);
            this._setFlattenedItems(flattenedItems);
        });
    }
    /** @hidden */
    _listenToTreeItemsChanges() {
        this._projectedTreeItems.changes
            .pipe(startWith(null), filter(() => !this.treeItemDef), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => {
            this._allItems = this._projectedTreeItems.toArray();
            const flattenedItems = this._sortTreeItems(this._allItems);
            this._setFlattenedItems(flattenedItems);
        });
    }
    /** @hidden */
    _setFlattenedItems(items) {
        this._sortedTreeItems = items;
        const activeItem = this._focusKeyManager?.activeItem;
        const newActiveItemIndex = items.findIndex((item) => item === activeItem);
        this._focusKeyManager?.destroy();
        this._focusKeyManager = new FocusKeyManager(items)
            .withVerticalOrientation(true)
            .skipPredicate((item) => !item.keyboardAccessible);
        if (newActiveItemIndex > -1) {
            this._focusKeyManager.setActiveItem(newActiveItemIndex);
        }
        this._selectionService.initialize(this._sortedTreeItems.map((item) => item.selectableListItem));
        this._setupEventListeners();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: TreeComponent, isStandalone: true, selector: "fd-tree", inputs: { class: "class", noBorder: "noBorder", selection: "selection", selectionPlacement: "selectionPlacement", independentSections: "independentSections", navigationIndicator: "navigationIndicator" }, outputs: { dataRequested: "dataRequested", dataReceived: "dataReceived", selectedChange: "selectedChange" }, host: { attributes: { "role": "tree" }, listeners: { "keydown": "_onKeyUp($event)" } }, providers: [
            contentDensityObserverProviders(),
            TreeService,
            SelectionService,
            {
                provide: FD_DATA_SOURCE_TRANSFORMER,
                useClass: TreeDataSourceParser
            }
        ], queries: [{ propertyName: "treeItemDef", first: true, predicate: TreeItemDefDirective, descendants: true }, { propertyName: "_projectedTreeItems", predicate: BaseTreeItem, descendants: true }], viewQueries: [{ propertyName: "_treeItemDirectives", predicate: TreeItemDirective, descendants: true }], usesOnChanges: true, hostDirectives: [{ directive: i1.DataSourceDirective, inputs: ["dataSource", "dataSource"], outputs: ["dataChanged", "dataChanged"] }, { directive: i2.CvaDirective, inputs: ["name", "name", "id", "id", "state", "state", "stateMessage", "stateMessage", "disabled", "disabled", "readonly", "readonly"] }], ngImport: i0, template: "<ng-template #dataSourceRenderer>\n    <ng-template\n        [ngTemplateOutlet]=\"!_initialDataLoaded ? loadingRenderer : dataLoadedTpl\"\n        [ngTemplateOutletContext]=\"{ $implicit: 1 }\"\n    ></ng-template>\n    <ng-template #loadingRenderer let-level>\n        <div *fdkRepeat=\"5\" role=\"treeitem\" [attr.aria-level]=\"level\" class=\"fd-tree__item\">\n            <div class=\"fd-tree__item-container\">\n                <div class=\"fd-tree__content\">\n                    <span class=\"fd-tree__text\">\n                        <fd-skeleton type=\"text\" width=\"100px\" textLines=\"1\"></fd-skeleton>\n                    </span>\n                </div>\n            </div>\n        </div>\n    </ng-template>\n    <ng-template #dataLoadedTpl>\n        @if (_items.length > 0 && treeItemDef) {\n            @for (item of _items; track _trackFn($index, item)) {\n                <ng-template\n                    [ngTemplateOutlet]=\"renderer\"\n                    [ngTemplateOutletContext]=\"{ $implicit: item }\"\n                ></ng-template>\n            }\n        } @else {\n            <div role=\"treeitem\" aria-level=\"1\" class=\"fd-tree__item\">\n                <div class=\"fd-tree__item-container\">\n                    <div class=\"fd-tree__content\">\n                        <span class=\"fd-tree__text\">{{ 'coreTree.noData' | fdTranslate }}</span>\n                    </div>\n                </div>\n            </div>\n        }\n    </ng-template>\n    <ng-template #renderer let-item>\n        <ng-container fdTreeItem fdkSelectableItem #treeItemDirective=\"fdTreeItem\">\n            <ng-template\n                [ngTemplateOutlet]=\"item.renderer\"\n                [ngTemplateOutletContext]=\"{ $implicit: item }\"\n                [ngTemplateOutletInjector]=\"treeItemDirective.injector\"\n            ></ng-template>\n        </ng-container>\n        @if (\n            treeItemDirective.treeItem?.hasDsChildren &&\n            !!treeItemDirective.treeItem?.expanded &&\n            !treeItemDirective.treeItem?.childrenLoaded\n        ) {\n            <ng-template\n                [ngTemplateOutlet]=\"loadingRenderer\"\n                [ngTemplateOutletContext]=\"{ $implicit: item.level + 1 }\"\n            ></ng-template>\n        }\n        @if (treeItemDirective.treeItem?.children; as childItems) {\n            @if (childItems && childItems.length > 0 && !!treeItemDirective?.treeItem?.expanded) {\n                <div class=\"fd-tree\">\n                    @for (child of childItems; track _trackFn($index, child)) {\n                        <ng-template\n                            [ngTemplateOutlet]=\"renderer\"\n                            [ngTemplateOutletContext]=\"{ $implicit: child }\"\n                        ></ng-template>\n                    }\n                </div>\n            }\n        }\n    </ng-template>\n</ng-template>\n<ng-template #projectedContentRenderer>\n    <ng-content select=\"fd-tree-item\"></ng-content>\n</ng-template>\n<ng-template [ngTemplateOutlet]=\"treeItemDef ? dataSourceRenderer : projectedContentRenderer\"></ng-template>\n", styles: [":root{--fdList_Item_Background_Color:var(--sapList_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor);--fdList_Item_Text_Font_Size:var(--sapFontLargeSize);--fdList_Item_Icon_Font_Size:1.125rem;--fdList_Item_Height:var(--sapElement_LineHeight);--fdList_Status_Text_Color:var(--sapNeutralTextColor);--fdList_Message_Background_Color:var(--sapNeutralBackground)}.fd-tree{--fdTree_Button_Spacing:var(--fdList_Button_Spacing);--fdTree_Expander_Size:2.75rem;--fdTree_Expander_Icon_Font_Size:var(--sapFontLargeSize);--fdTree_Item_Height:2.75rem;--fdTree_Item_Font_Size:var(--sapFontLargeSize);--fdTree_Item_Wrap_Text_Line_Height:1.4;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;list-style-type:none;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%}.fd-tree[class*=-compact],.fd-tree[class*=-condensed],[class*=-compact] .fd-tree:not([class*=-cozy]),[class*=-condensed] .fd-tree:not([class*=-cozy]){--fdTree_Expander_Size:2rem;--fdTree_Expander_Icon_Font_Size:var(--sapFontSmallSize);--fdTree_Item_Height:2rem;--fdTree_Item_Font_Size:var(--sapFontSize);--fdTree_Item_Wrap_Text_Line_Height:1.4}.fd-tree .has-highlight-indicator{--fdTree_Item_Highlight_Color:var(--sapInformationBorderColor);-webkit-box-shadow:inset .375rem 0 0 0 var(--fdTree_Item_Highlight_Color);box-shadow:inset .375rem 0 0 0 var(--fdTree_Item_Highlight_Color)}.fd-tree .has-highlight-indicator--error{--fdTree_Item_Highlight_Color:var(--sapErrorBorderColor)}.fd-tree .has-highlight-indicator--warning{--fdTree_Item_Highlight_Color:var(--sapWarningBorderColor)}.fd-tree .has-highlight-indicator--success{--fdTree_Item_Highlight_Color:var(--sapSuccessBorderColor)}.fd-tree .has-highlight-indicator[dir=rtl],[dir=rtl] .fd-tree .has-highlight-indicator{-webkit-box-shadow:inset -.375rem 0 0 0 var(--fdTree_Item_Highlight_Color);box-shadow:inset -.375rem 0 0 0 var(--fdTree_Item_Highlight_Color)}.fd-tree .has-highlight-indicator.is-navigated{-webkit-box-shadow:inset -.1875rem 0 0 0 var(--sapSelectedColor),inset .375rem 0 0 0 var(--fdTree_Item_Highlight_Color);box-shadow:inset -.1875rem 0 0 0 var(--sapSelectedColor),inset .375rem 0 0 0 var(--fdTree_Item_Highlight_Color)}.fd-tree .has-highlight-indicator.is-navigated[dir=rtl],[dir=rtl] .fd-tree .has-highlight-indicator.is-navigated{-webkit-box-shadow:inset .1875rem 0 0 0 var(--sapSelectedColor),inset -.375rem 0 0 0 var(--fdTree_Item_Highlight_Color);box-shadow:inset .1875rem 0 0 0 var(--sapSelectedColor),inset -.375rem 0 0 0 var(--fdTree_Item_Highlight_Color)}.fd-tree .fd-tree__item .fd-tree__item-container .fd-tree__expander{-webkit-margin-start:var(--fdTree_Item_Level_Spacing);margin-inline-start:var(--fdTree_Item_Level_Spacing)}.fd-tree .fd-tree__item .fd-tree__item-container .fd-form-item:first-child,.fd-tree .fd-tree__item .fd-tree__item-container .fd-tree__content{-webkit-margin-start:calc(var(--fdTree_Item_Level_Spacing, 0rem) + var(--fdTree_Expander_Size));margin-inline-start:calc(var(--fdTree_Item_Level_Spacing, 0rem) + var(--fdTree_Expander_Size))}.fd-tree .fd-tree__item .fd-tree__item-container .fd-form-item+.fd-tree__content,.fd-tree .fd-tree__item .fd-tree__item-container .fd-tree__expander+.fd-tree__content,.fd-tree.fd-tree--independent-multi-selection .fd-tree__item .fd-tree__item-container .fd-form-item:first-child{-webkit-margin-start:0;margin-inline-start:0}.fd-tree.fd-tree--independent-multi-selection .fd-tree__item .fd-tree__item-container .fd-form-item:first-child+.fd-tree__content{-webkit-margin-start:calc(var(--fdTree_Item_Level_Spacing, 0rem) + var(--fdTree_Expander_Size));margin-inline-start:calc(var(--fdTree_Item_Level_Spacing, 0rem) + var(--fdTree_Expander_Size))}.fd-tree.expanded-level-1 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-2 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-2 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-3 .fd-tree__item[aria-level=\"2\"],.fd-tree.expanded-level-4 .fd-tree__item[aria-level=\"2\"],.fd-tree.expanded-level-5 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-3 .fd-tree__item[aria-level=\"3\"],.fd-tree.expanded-level-4 .fd-tree__item[aria-level=\"3\"],.fd-tree.expanded-level-5 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-3 .fd-tree__item[aria-level=\"4\"],.fd-tree.expanded-level-4 .fd-tree__item[aria-level=\"4\"],.fd-tree.expanded-level-5 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-3 .fd-tree__item[aria-level=\"5\"],.fd-tree.expanded-level-4 .fd-tree__item[aria-level=\"5\"],.fd-tree.expanded-level-5 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-3 .fd-tree__item[aria-level=\"6\"],.fd-tree.expanded-level-4 .fd-tree__item[aria-level=\"6\"],.fd-tree.expanded-level-5 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree .fd-tree__item-container .fd-form-item:first-child label,.fd-tree .fd-tree__item-container .fd-tree__expander+.fd-form-item label{margin-block:0;margin-inline:0}.fd-tree .fd-tree__expander+.fd-tree__content{-webkit-margin-start:0;margin-inline-start:0}.fd-tree:after,.fd-tree:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree[aria-hidden=true]{display:none}.fd-tree__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tree__item:after,.fd-tree__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container{background:var(--sapList_Background);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_BorderColor)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-selected,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container[aria-selected=true]{background:var(--sapList_SelectionBackgroundColor);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active{cursor:pointer;position:relative}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-selected,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active.is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active.is-selected,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active.is-selected.is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active.is-selected:hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active:hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active[aria-selected=true],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active[aria-selected=true].is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active[aria-selected=true]:hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active.is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active.is-selected,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active.is-selected.is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active.is-selected:hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active:hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active[aria-selected=true],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active[aria-selected=true].is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-focus,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:focus{outline:none;pointer-events:all}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-focus:before,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-focus.is-active:before,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-focus:active:before,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:focus.is-active:before,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active .fd-button,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active .fd-tree__icon [class*=sap-icon],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active .fd-tree__icon[class*=sap-icon],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active .fd-tree__text,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active .fd-button,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active .fd-tree__icon [class*=sap-icon],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active .fd-tree__icon[class*=sap-icon],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active .fd-tree__text{color:var(--sapList_Active_TextColor)}.fd-tree__item-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--sapList_AlternatingBackground);border-bottom:var(--sapList_BorderWidth) solid transparent;min-height:var(--fdTree_Item_Height);position:relative;width:100%;-webkit-padding-end:1rem;padding-inline-end:1rem}.fd-tree__item-container:after,.fd-tree__item-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree__item-container.is-selected,.fd-tree__item-container[aria-selected=true]{background:var(--sapList_SelectionBackgroundColor);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-tree__item-container.is-navigated{-webkit-box-shadow:inset -.1875rem 0 0 0 var(--sapSelectedColor);box-shadow:inset -.1875rem 0 0 0 var(--sapSelectedColor)}.fd-tree__item-container.is-navigated[dir=rtl],[dir=rtl] .fd-tree__item-container.is-navigated{-webkit-box-shadow:inset .1875rem 0 0 0 var(--sapSelectedColor);box-shadow:inset .1875rem 0 0 0 var(--sapSelectedColor)}.fd-tree__item-container.is-focus,.fd-tree__item-container:focus{outline:none;pointer-events:all}.fd-tree__item-container.is-focus:before,.fd-tree__item-container:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-tree__item-container.is-focus.is-active:before,.fd-tree__item-container.is-focus:active:before,.fd-tree__item-container:focus.is-active:before,.fd-tree__item-container:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-tree__item-container--active{cursor:pointer;position:relative}.fd-tree__item-container--active.is-hover,.fd-tree__item-container--active:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-tree__item-container--active.is-selected,.fd-tree__item-container--active[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-tree__item-container--active.is-active,.fd-tree__item-container--active.is-active.is-hover,.fd-tree__item-container--active.is-active.is-selected,.fd-tree__item-container--active.is-active.is-selected.is-hover,.fd-tree__item-container--active.is-active.is-selected:hover,.fd-tree__item-container--active.is-active:hover,.fd-tree__item-container--active.is-active[aria-selected=true],.fd-tree__item-container--active.is-active[aria-selected=true].is-hover,.fd-tree__item-container--active.is-active[aria-selected=true]:hover,.fd-tree__item-container--active:active,.fd-tree__item-container--active:active.is-hover,.fd-tree__item-container--active:active.is-selected,.fd-tree__item-container--active:active.is-selected.is-hover,.fd-tree__item-container--active:active.is-selected:hover,.fd-tree__item-container--active:active:hover,.fd-tree__item-container--active:active[aria-selected=true],.fd-tree__item-container--active:active[aria-selected=true].is-hover,.fd-tree__item-container--active:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-tree__item-container--active.is-focus,.fd-tree__item-container--active:focus{outline:none;pointer-events:all}.fd-tree__item-container--active.is-focus:before,.fd-tree__item-container--active:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-tree__item-container--active.is-focus.is-active:before,.fd-tree__item-container--active.is-focus:active:before,.fd-tree__item-container--active:focus.is-active:before,.fd-tree__item-container--active:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-tree__item-container--active.is-active .fd-button,.fd-tree__item-container--active.is-active .fd-tree__icon [class*=sap-icon],.fd-tree__item-container--active.is-active .fd-tree__icon[class*=sap-icon],.fd-tree__item-container--active.is-active .fd-tree__text,.fd-tree__item-container--active:active .fd-button,.fd-tree__item-container--active:active .fd-tree__icon [class*=sap-icon],.fd-tree__item-container--active:active .fd-tree__icon[class*=sap-icon],.fd-tree__item-container--active:active .fd-tree__text{color:var(--sapList_Active_TextColor)}.fd-tree__button{-webkit-margin-start:var(--fdTree_Button_Spacing);margin-inline-start:var(--fdTree_Button_Spacing)}.fd-tree__expander{-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:transparent;background-image:none;background:transparent;border:0;border-radius:var(--sapButton_BorderCornerRadius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapButton_IconColor);cursor:pointer;display:inline-block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;min-height:var(--fdTree_Expander_Size);min-width:var(--fdTree_Expander_Size);outline:0;padding-block:0;padding-inline:0;text-decoration:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;vertical-align:middle;white-space:nowrap}.fd-tree__expander:after,.fd-tree__expander:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree__expander::-moz-focus-inner{border:0}.fd-tree__expander.is-focus,.fd-tree__expander:focus{outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);outline-offset:var(--fdButton_Outline_Offset);z-index:5}.fd-tree__expander .fd-tree__icon{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tree__expander .fd-tree__icon:after,.fd-tree__expander .fd-tree__icon:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree__expander .fd-tree__icon [class*=sap-icon],.fd-tree__expander .fd-tree__icon[class*=sap-icon]{color:var(--sapButton_IconColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-size:var(--fdTree_Expander_Icon_Font_Size);-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tree__expander[dir=rtl] .fd-tree__icon,[dir=rtl] .fd-tree__expander .fd-tree__icon{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.fd-tree__expander.is-expanded,.fd-tree__expander[aria-expanded=true]{border-bottom:none}.fd-tree__expander.is-expanded[dir=rtl] .fd-tree__icon,.fd-tree__expander[aria-expanded=true][dir=rtl] .fd-tree__icon,[dir=rtl] .fd-tree__expander.is-expanded .fd-tree__icon,[dir=rtl] .fd-tree__expander[aria-expanded=true] .fd-tree__icon{-webkit-transform:rotate(0);transform:rotate(0)}.fd-tree__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;min-height:var(--fdTree_Item_Height);text-decoration:none;width:100%}.fd-tree__content:after,.fd-tree__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree__content--wrap,.fd-tree__content--wrap .fd-tree__text{overflow:visible;text-overflow:clip;white-space:normal}.fd-tree__content--wrap .fd-tree__text{line-height:var(--fdTree_Item_Wrap_Text_Line_Height)}.fd-tree__icon{line-height:var(--fdTree_Expander_Size);min-height:var(--fdTree_Expander_Size);min-width:var(--fdTree_Expander_Size)}.fd-tree__icon,.fd-tree__icon [class*=sap-icon],.fd-tree__icon[class*=sap-icon]{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tree__icon [class*=sap-icon],.fd-tree__icon[class*=sap-icon]{color:var(--sapContent_NonInteractiveIconColor);font-size:1.125rem}.fd-tree__icon--navigation [class*=sap-icon],.fd-tree__icon--navigation[class*=sap-icon]{font-size:.75rem;min-width:2.5rem}.fd-tree__icon--navigation:last-child{-webkit-margin-end:-1rem;margin-inline-end:-1rem}.fd-tree__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapList_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdTree_Item_Font_Size);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:var(--fdTree_Item_Height);margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:100%}.fd-tree__text:after,.fd-tree__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree--no-border .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container{border-bottom:var(--sapList_BorderWidth) solid transparent}.fd-tree--no-border .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-selected,.fd-tree--no-border .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container{cursor:pointer;position:relative}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-selected,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active.is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active.is-selected,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active.is-selected.is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active.is-selected:hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active:hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active[aria-selected=true],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active[aria-selected=true].is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active[aria-selected=true]:hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active.is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active.is-selected,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active.is-selected.is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active.is-selected:hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active:hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active[aria-selected=true],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active[aria-selected=true].is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-focus,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:focus{outline:none;pointer-events:all}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-focus:before,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-focus.is-active:before,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-focus:active:before,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:focus.is-active:before,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active .fd-button,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active .fd-tree__icon [class*=sap-icon],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active .fd-tree__icon[class*=sap-icon],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active .fd-tree__text,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active .fd-button,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active .fd-tree__icon [class*=sap-icon],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active .fd-tree__icon[class*=sap-icon],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active .fd-tree__text{color:var(--sapList_Active_TextColor)}.fd-tree--active .fd-tree__item-container{cursor:pointer;position:relative}.fd-tree--active .fd-tree__item-container.is-hover,.fd-tree--active .fd-tree__item-container:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-tree--active .fd-tree__item-container.is-selected,.fd-tree--active .fd-tree__item-container[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-tree--active .fd-tree__item-container.is-active,.fd-tree--active .fd-tree__item-container.is-active.is-hover,.fd-tree--active .fd-tree__item-container.is-active.is-selected,.fd-tree--active .fd-tree__item-container.is-active.is-selected.is-hover,.fd-tree--active .fd-tree__item-container.is-active.is-selected:hover,.fd-tree--active .fd-tree__item-container.is-active:hover,.fd-tree--active .fd-tree__item-container.is-active[aria-selected=true],.fd-tree--active .fd-tree__item-container.is-active[aria-selected=true].is-hover,.fd-tree--active .fd-tree__item-container.is-active[aria-selected=true]:hover,.fd-tree--active .fd-tree__item-container:active,.fd-tree--active .fd-tree__item-container:active.is-hover,.fd-tree--active .fd-tree__item-container:active.is-selected,.fd-tree--active .fd-tree__item-container:active.is-selected.is-hover,.fd-tree--active .fd-tree__item-container:active.is-selected:hover,.fd-tree--active .fd-tree__item-container:active:hover,.fd-tree--active .fd-tree__item-container:active[aria-selected=true],.fd-tree--active .fd-tree__item-container:active[aria-selected=true].is-hover,.fd-tree--active .fd-tree__item-container:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-tree--active .fd-tree__item-container.is-focus,.fd-tree--active .fd-tree__item-container:focus{outline:none;pointer-events:all}.fd-tree--active .fd-tree__item-container.is-focus:before,.fd-tree--active .fd-tree__item-container:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-tree--active .fd-tree__item-container.is-focus.is-active:before,.fd-tree--active .fd-tree__item-container.is-focus:active:before,.fd-tree--active .fd-tree__item-container:focus.is-active:before,.fd-tree--active .fd-tree__item-container:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-tree--active .fd-tree__item-container.is-active .fd-button,.fd-tree--active .fd-tree__item-container.is-active .fd-tree__icon [class*=sap-icon],.fd-tree--active .fd-tree__item-container.is-active .fd-tree__icon[class*=sap-icon],.fd-tree--active .fd-tree__item-container.is-active .fd-tree__text,.fd-tree--active .fd-tree__item-container:active .fd-button,.fd-tree--active .fd-tree__item-container:active .fd-tree__icon [class*=sap-icon],.fd-tree--active .fd-tree__item-container:active .fd-tree__icon[class*=sap-icon],.fd-tree--active .fd-tree__item-container:active .fd-tree__text{color:var(--sapList_Active_TextColor)}.fd-tree--no-data .fd-tree__text{text-align:center}.fd-tree{display:block}.fd-tree__expander--loading{display:flex;align-items:center;justify-content:center}[dir=rtl] .fd-tree__expander:not(.is-expanded),.fd-tree__expander:not(.is-expanded)[dir=rtl]{transform:rotate(180deg)}[dir=rtl] .fd-tree__icon--navigation,.fd-tree__icon--navigation[dir=rtl]{transform:rotate(180deg)}\n/*! Bundled license information:\n\nfundamental-styles/dist/tree.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: RepeatDirective, selector: "[fdkRepeat]", inputs: ["fdkRepeat"] }, { kind: "component", type: SkeletonComponent, selector: "fd-skeleton", inputs: ["animated", "type", "textLines", "width", "height"] }, { kind: "directive", type: TreeItemDirective, selector: "[fdTreeItem]", exportAs: ["fdTreeItem"] }, { kind: "directive", type: SelectableItemDirective, selector: "[fdkSelectableItem]", inputs: ["value", "fdkSelectableItem"], outputs: ["clicked", "selected"], exportAs: ["fdkSelectableItem"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], TreeComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-tree', encapsulation: ViewEncapsulation.None, hostDirectives: [
                        {
                            directive: DataSourceDirective,
                            inputs: ['dataSource'],
                            outputs: ['dataChanged']
                        },
                        {
                            directive: CvaDirective,
                            inputs: ['name', 'id', 'state', 'stateMessage', 'disabled', 'readonly']
                        }
                    ], host: {
                        role: 'tree'
                    }, providers: [
                        contentDensityObserverProviders(),
                        TreeService,
                        SelectionService,
                        {
                            provide: FD_DATA_SOURCE_TRANSFORMER,
                            useClass: TreeDataSourceParser
                        }
                    ], imports: [
                        NgTemplateOutlet,
                        RepeatDirective,
                        SkeletonComponent,
                        TreeItemDirective,
                        SelectableItemDirective,
                        FdTranslatePipe
                    ], template: "<ng-template #dataSourceRenderer>\n    <ng-template\n        [ngTemplateOutlet]=\"!_initialDataLoaded ? loadingRenderer : dataLoadedTpl\"\n        [ngTemplateOutletContext]=\"{ $implicit: 1 }\"\n    ></ng-template>\n    <ng-template #loadingRenderer let-level>\n        <div *fdkRepeat=\"5\" role=\"treeitem\" [attr.aria-level]=\"level\" class=\"fd-tree__item\">\n            <div class=\"fd-tree__item-container\">\n                <div class=\"fd-tree__content\">\n                    <span class=\"fd-tree__text\">\n                        <fd-skeleton type=\"text\" width=\"100px\" textLines=\"1\"></fd-skeleton>\n                    </span>\n                </div>\n            </div>\n        </div>\n    </ng-template>\n    <ng-template #dataLoadedTpl>\n        @if (_items.length > 0 && treeItemDef) {\n            @for (item of _items; track _trackFn($index, item)) {\n                <ng-template\n                    [ngTemplateOutlet]=\"renderer\"\n                    [ngTemplateOutletContext]=\"{ $implicit: item }\"\n                ></ng-template>\n            }\n        } @else {\n            <div role=\"treeitem\" aria-level=\"1\" class=\"fd-tree__item\">\n                <div class=\"fd-tree__item-container\">\n                    <div class=\"fd-tree__content\">\n                        <span class=\"fd-tree__text\">{{ 'coreTree.noData' | fdTranslate }}</span>\n                    </div>\n                </div>\n            </div>\n        }\n    </ng-template>\n    <ng-template #renderer let-item>\n        <ng-container fdTreeItem fdkSelectableItem #treeItemDirective=\"fdTreeItem\">\n            <ng-template\n                [ngTemplateOutlet]=\"item.renderer\"\n                [ngTemplateOutletContext]=\"{ $implicit: item }\"\n                [ngTemplateOutletInjector]=\"treeItemDirective.injector\"\n            ></ng-template>\n        </ng-container>\n        @if (\n            treeItemDirective.treeItem?.hasDsChildren &&\n            !!treeItemDirective.treeItem?.expanded &&\n            !treeItemDirective.treeItem?.childrenLoaded\n        ) {\n            <ng-template\n                [ngTemplateOutlet]=\"loadingRenderer\"\n                [ngTemplateOutletContext]=\"{ $implicit: item.level + 1 }\"\n            ></ng-template>\n        }\n        @if (treeItemDirective.treeItem?.children; as childItems) {\n            @if (childItems && childItems.length > 0 && !!treeItemDirective?.treeItem?.expanded) {\n                <div class=\"fd-tree\">\n                    @for (child of childItems; track _trackFn($index, child)) {\n                        <ng-template\n                            [ngTemplateOutlet]=\"renderer\"\n                            [ngTemplateOutletContext]=\"{ $implicit: child }\"\n                        ></ng-template>\n                    }\n                </div>\n            }\n        }\n    </ng-template>\n</ng-template>\n<ng-template #projectedContentRenderer>\n    <ng-content select=\"fd-tree-item\"></ng-content>\n</ng-template>\n<ng-template [ngTemplateOutlet]=\"treeItemDef ? dataSourceRenderer : projectedContentRenderer\"></ng-template>\n", styles: [":root{--fdList_Item_Background_Color:var(--sapList_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor);--fdList_Item_Text_Font_Size:var(--sapFontLargeSize);--fdList_Item_Icon_Font_Size:1.125rem;--fdList_Item_Height:var(--sapElement_LineHeight);--fdList_Status_Text_Color:var(--sapNeutralTextColor);--fdList_Message_Background_Color:var(--sapNeutralBackground)}.fd-tree{--fdTree_Button_Spacing:var(--fdList_Button_Spacing);--fdTree_Expander_Size:2.75rem;--fdTree_Expander_Icon_Font_Size:var(--sapFontLargeSize);--fdTree_Item_Height:2.75rem;--fdTree_Item_Font_Size:var(--sapFontLargeSize);--fdTree_Item_Wrap_Text_Line_Height:1.4;border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;list-style-type:none;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%}.fd-tree[class*=-compact],.fd-tree[class*=-condensed],[class*=-compact] .fd-tree:not([class*=-cozy]),[class*=-condensed] .fd-tree:not([class*=-cozy]){--fdTree_Expander_Size:2rem;--fdTree_Expander_Icon_Font_Size:var(--sapFontSmallSize);--fdTree_Item_Height:2rem;--fdTree_Item_Font_Size:var(--sapFontSize);--fdTree_Item_Wrap_Text_Line_Height:1.4}.fd-tree .has-highlight-indicator{--fdTree_Item_Highlight_Color:var(--sapInformationBorderColor);-webkit-box-shadow:inset .375rem 0 0 0 var(--fdTree_Item_Highlight_Color);box-shadow:inset .375rem 0 0 0 var(--fdTree_Item_Highlight_Color)}.fd-tree .has-highlight-indicator--error{--fdTree_Item_Highlight_Color:var(--sapErrorBorderColor)}.fd-tree .has-highlight-indicator--warning{--fdTree_Item_Highlight_Color:var(--sapWarningBorderColor)}.fd-tree .has-highlight-indicator--success{--fdTree_Item_Highlight_Color:var(--sapSuccessBorderColor)}.fd-tree .has-highlight-indicator[dir=rtl],[dir=rtl] .fd-tree .has-highlight-indicator{-webkit-box-shadow:inset -.375rem 0 0 0 var(--fdTree_Item_Highlight_Color);box-shadow:inset -.375rem 0 0 0 var(--fdTree_Item_Highlight_Color)}.fd-tree .has-highlight-indicator.is-navigated{-webkit-box-shadow:inset -.1875rem 0 0 0 var(--sapSelectedColor),inset .375rem 0 0 0 var(--fdTree_Item_Highlight_Color);box-shadow:inset -.1875rem 0 0 0 var(--sapSelectedColor),inset .375rem 0 0 0 var(--fdTree_Item_Highlight_Color)}.fd-tree .has-highlight-indicator.is-navigated[dir=rtl],[dir=rtl] .fd-tree .has-highlight-indicator.is-navigated{-webkit-box-shadow:inset .1875rem 0 0 0 var(--sapSelectedColor),inset -.375rem 0 0 0 var(--fdTree_Item_Highlight_Color);box-shadow:inset .1875rem 0 0 0 var(--sapSelectedColor),inset -.375rem 0 0 0 var(--fdTree_Item_Highlight_Color)}.fd-tree .fd-tree__item .fd-tree__item-container .fd-tree__expander{-webkit-margin-start:var(--fdTree_Item_Level_Spacing);margin-inline-start:var(--fdTree_Item_Level_Spacing)}.fd-tree .fd-tree__item .fd-tree__item-container .fd-form-item:first-child,.fd-tree .fd-tree__item .fd-tree__item-container .fd-tree__content{-webkit-margin-start:calc(var(--fdTree_Item_Level_Spacing, 0rem) + var(--fdTree_Expander_Size));margin-inline-start:calc(var(--fdTree_Item_Level_Spacing, 0rem) + var(--fdTree_Expander_Size))}.fd-tree .fd-tree__item .fd-tree__item-container .fd-form-item+.fd-tree__content,.fd-tree .fd-tree__item .fd-tree__item-container .fd-tree__expander+.fd-tree__content,.fd-tree.fd-tree--independent-multi-selection .fd-tree__item .fd-tree__item-container .fd-form-item:first-child{-webkit-margin-start:0;margin-inline-start:0}.fd-tree.fd-tree--independent-multi-selection .fd-tree__item .fd-tree__item-container .fd-form-item:first-child+.fd-tree__content{-webkit-margin-start:calc(var(--fdTree_Item_Level_Spacing, 0rem) + var(--fdTree_Expander_Size));margin-inline-start:calc(var(--fdTree_Item_Level_Spacing, 0rem) + var(--fdTree_Expander_Size))}.fd-tree.expanded-level-1 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-2 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-2 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-3 .fd-tree__item[aria-level=\"2\"],.fd-tree.expanded-level-4 .fd-tree__item[aria-level=\"2\"],.fd-tree.expanded-level-5 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-3 .fd-tree__item[aria-level=\"3\"],.fd-tree.expanded-level-4 .fd-tree__item[aria-level=\"3\"],.fd-tree.expanded-level-5 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-3 .fd-tree__item[aria-level=\"4\"],.fd-tree.expanded-level-4 .fd-tree__item[aria-level=\"4\"],.fd-tree.expanded-level-5 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-3 .fd-tree__item[aria-level=\"5\"],.fd-tree.expanded-level-4 .fd-tree__item[aria-level=\"5\"],.fd-tree.expanded-level-5 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-3 .fd-tree__item[aria-level=\"6\"],.fd-tree.expanded-level-4 .fd-tree__item[aria-level=\"6\"],.fd-tree.expanded-level-5 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-6 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-7 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-8 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-9 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-10 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-11 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"1\"]{--fdTree_Item_Level_Spacing:0rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"2\"]{--fdTree_Item_Level_Spacing:.25rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"3\"]{--fdTree_Item_Level_Spacing:.5rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"4\"]{--fdTree_Item_Level_Spacing:.75rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"5\"]{--fdTree_Item_Level_Spacing:1rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"6\"]{--fdTree_Item_Level_Spacing:1.25rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"7\"]{--fdTree_Item_Level_Spacing:1.5rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"8\"]{--fdTree_Item_Level_Spacing:1.75rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"9\"]{--fdTree_Item_Level_Spacing:2rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"10\"]{--fdTree_Item_Level_Spacing:2.25rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"11\"]{--fdTree_Item_Level_Spacing:2.5rem}.fd-tree.expanded-level-12 .fd-tree__item[aria-level=\"12\"]{--fdTree_Item_Level_Spacing:2.75rem}.fd-tree .fd-tree__item-container .fd-form-item:first-child label,.fd-tree .fd-tree__item-container .fd-tree__expander+.fd-form-item label{margin-block:0;margin-inline:0}.fd-tree .fd-tree__expander+.fd-tree__content{-webkit-margin-start:0;margin-inline-start:0}.fd-tree:after,.fd-tree:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree[aria-hidden=true]{display:none}.fd-tree__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tree__item:after,.fd-tree__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container{background:var(--sapList_Background);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_BorderColor)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-selected,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container[aria-selected=true]{background:var(--sapList_SelectionBackgroundColor);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active{cursor:pointer;position:relative}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-selected,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active.is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active.is-selected,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active.is-selected.is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active.is-selected:hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active:hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active[aria-selected=true],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active[aria-selected=true].is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active[aria-selected=true]:hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active.is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active.is-selected,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active.is-selected.is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active.is-selected:hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active:hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active[aria-selected=true],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active[aria-selected=true].is-hover,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-focus,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:focus{outline:none;pointer-events:all}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-focus:before,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-focus.is-active:before,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-focus:active:before,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:focus.is-active:before,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active .fd-button,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active .fd-tree__icon [class*=sap-icon],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active .fd-tree__icon[class*=sap-icon],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active.is-active .fd-tree__text,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active .fd-button,.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active .fd-tree__icon [class*=sap-icon],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active .fd-tree__icon[class*=sap-icon],.fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container--active:active .fd-tree__text{color:var(--sapList_Active_TextColor)}.fd-tree__item-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--sapList_AlternatingBackground);border-bottom:var(--sapList_BorderWidth) solid transparent;min-height:var(--fdTree_Item_Height);position:relative;width:100%;-webkit-padding-end:1rem;padding-inline-end:1rem}.fd-tree__item-container:after,.fd-tree__item-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree__item-container.is-selected,.fd-tree__item-container[aria-selected=true]{background:var(--sapList_SelectionBackgroundColor);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-tree__item-container.is-navigated{-webkit-box-shadow:inset -.1875rem 0 0 0 var(--sapSelectedColor);box-shadow:inset -.1875rem 0 0 0 var(--sapSelectedColor)}.fd-tree__item-container.is-navigated[dir=rtl],[dir=rtl] .fd-tree__item-container.is-navigated{-webkit-box-shadow:inset .1875rem 0 0 0 var(--sapSelectedColor);box-shadow:inset .1875rem 0 0 0 var(--sapSelectedColor)}.fd-tree__item-container.is-focus,.fd-tree__item-container:focus{outline:none;pointer-events:all}.fd-tree__item-container.is-focus:before,.fd-tree__item-container:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-tree__item-container.is-focus.is-active:before,.fd-tree__item-container.is-focus:active:before,.fd-tree__item-container:focus.is-active:before,.fd-tree__item-container:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-tree__item-container--active{cursor:pointer;position:relative}.fd-tree__item-container--active.is-hover,.fd-tree__item-container--active:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-tree__item-container--active.is-selected,.fd-tree__item-container--active[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-tree__item-container--active.is-active,.fd-tree__item-container--active.is-active.is-hover,.fd-tree__item-container--active.is-active.is-selected,.fd-tree__item-container--active.is-active.is-selected.is-hover,.fd-tree__item-container--active.is-active.is-selected:hover,.fd-tree__item-container--active.is-active:hover,.fd-tree__item-container--active.is-active[aria-selected=true],.fd-tree__item-container--active.is-active[aria-selected=true].is-hover,.fd-tree__item-container--active.is-active[aria-selected=true]:hover,.fd-tree__item-container--active:active,.fd-tree__item-container--active:active.is-hover,.fd-tree__item-container--active:active.is-selected,.fd-tree__item-container--active:active.is-selected.is-hover,.fd-tree__item-container--active:active.is-selected:hover,.fd-tree__item-container--active:active:hover,.fd-tree__item-container--active:active[aria-selected=true],.fd-tree__item-container--active:active[aria-selected=true].is-hover,.fd-tree__item-container--active:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-tree__item-container--active.is-focus,.fd-tree__item-container--active:focus{outline:none;pointer-events:all}.fd-tree__item-container--active.is-focus:before,.fd-tree__item-container--active:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-tree__item-container--active.is-focus.is-active:before,.fd-tree__item-container--active.is-focus:active:before,.fd-tree__item-container--active:focus.is-active:before,.fd-tree__item-container--active:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-tree__item-container--active.is-active .fd-button,.fd-tree__item-container--active.is-active .fd-tree__icon [class*=sap-icon],.fd-tree__item-container--active.is-active .fd-tree__icon[class*=sap-icon],.fd-tree__item-container--active.is-active .fd-tree__text,.fd-tree__item-container--active:active .fd-button,.fd-tree__item-container--active:active .fd-tree__icon [class*=sap-icon],.fd-tree__item-container--active:active .fd-tree__icon[class*=sap-icon],.fd-tree__item-container--active:active .fd-tree__text{color:var(--sapList_Active_TextColor)}.fd-tree__button{-webkit-margin-start:var(--fdTree_Button_Spacing);margin-inline-start:var(--fdTree_Button_Spacing)}.fd-tree__expander{-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:transparent;background-image:none;background:transparent;border:0;border-radius:var(--sapButton_BorderCornerRadius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapButton_IconColor);cursor:pointer;display:inline-block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;min-height:var(--fdTree_Expander_Size);min-width:var(--fdTree_Expander_Size);outline:0;padding-block:0;padding-inline:0;text-decoration:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;vertical-align:middle;white-space:nowrap}.fd-tree__expander:after,.fd-tree__expander:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree__expander::-moz-focus-inner{border:0}.fd-tree__expander.is-focus,.fd-tree__expander:focus{outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);outline-offset:var(--fdButton_Outline_Offset);z-index:5}.fd-tree__expander .fd-tree__icon{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-tree__expander .fd-tree__icon:after,.fd-tree__expander .fd-tree__icon:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree__expander .fd-tree__icon [class*=sap-icon],.fd-tree__expander .fd-tree__icon[class*=sap-icon]{color:var(--sapButton_IconColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-size:var(--fdTree_Expander_Icon_Font_Size);-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tree__expander[dir=rtl] .fd-tree__icon,[dir=rtl] .fd-tree__expander .fd-tree__icon{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.fd-tree__expander.is-expanded,.fd-tree__expander[aria-expanded=true]{border-bottom:none}.fd-tree__expander.is-expanded[dir=rtl] .fd-tree__icon,.fd-tree__expander[aria-expanded=true][dir=rtl] .fd-tree__icon,[dir=rtl] .fd-tree__expander.is-expanded .fd-tree__icon,[dir=rtl] .fd-tree__expander[aria-expanded=true] .fd-tree__icon{-webkit-transform:rotate(0);transform:rotate(0)}.fd-tree__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;min-height:var(--fdTree_Item_Height);text-decoration:none;width:100%}.fd-tree__content:after,.fd-tree__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree__content--wrap,.fd-tree__content--wrap .fd-tree__text{overflow:visible;text-overflow:clip;white-space:normal}.fd-tree__content--wrap .fd-tree__text{line-height:var(--fdTree_Item_Wrap_Text_Line_Height)}.fd-tree__icon{line-height:var(--fdTree_Expander_Size);min-height:var(--fdTree_Expander_Size);min-width:var(--fdTree_Expander_Size)}.fd-tree__icon,.fd-tree__icon [class*=sap-icon],.fd-tree__icon[class*=sap-icon]{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-tree__icon [class*=sap-icon],.fd-tree__icon[class*=sap-icon]{color:var(--sapContent_NonInteractiveIconColor);font-size:1.125rem}.fd-tree__icon--navigation [class*=sap-icon],.fd-tree__icon--navigation[class*=sap-icon]{font-size:.75rem;min-width:2.5rem}.fd-tree__icon--navigation:last-child{-webkit-margin-end:-1rem;margin-inline-end:-1rem}.fd-tree__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapList_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdTree_Item_Font_Size);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:var(--fdTree_Item_Height);margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:100%}.fd-tree__text:after,.fd-tree__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-tree--no-border .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container{border-bottom:var(--sapList_BorderWidth) solid transparent}.fd-tree--no-border .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-selected,.fd-tree--no-border .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container{cursor:pointer;position:relative}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-selected,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active.is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active.is-selected,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active.is-selected.is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active.is-selected:hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active:hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active[aria-selected=true],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active[aria-selected=true].is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active[aria-selected=true]:hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active.is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active.is-selected,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active.is-selected.is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active.is-selected:hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active:hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active[aria-selected=true],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active[aria-selected=true].is-hover,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-focus,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:focus{outline:none;pointer-events:all}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-focus:before,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-focus.is-active:before,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-focus:active:before,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:focus.is-active:before,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active .fd-button,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active .fd-tree__icon [class*=sap-icon],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active .fd-tree__icon[class*=sap-icon],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container.is-active .fd-tree__text,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active .fd-button,.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active .fd-tree__icon [class*=sap-icon],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active .fd-tree__icon[class*=sap-icon],.fd-tree--active .fd-tree__item[aria-level=\"1\"]>.fd-tree__item-container:active .fd-tree__text{color:var(--sapList_Active_TextColor)}.fd-tree--active .fd-tree__item-container{cursor:pointer;position:relative}.fd-tree--active .fd-tree__item-container.is-hover,.fd-tree--active .fd-tree__item-container:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-tree--active .fd-tree__item-container.is-selected,.fd-tree--active .fd-tree__item-container[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-tree--active .fd-tree__item-container.is-active,.fd-tree--active .fd-tree__item-container.is-active.is-hover,.fd-tree--active .fd-tree__item-container.is-active.is-selected,.fd-tree--active .fd-tree__item-container.is-active.is-selected.is-hover,.fd-tree--active .fd-tree__item-container.is-active.is-selected:hover,.fd-tree--active .fd-tree__item-container.is-active:hover,.fd-tree--active .fd-tree__item-container.is-active[aria-selected=true],.fd-tree--active .fd-tree__item-container.is-active[aria-selected=true].is-hover,.fd-tree--active .fd-tree__item-container.is-active[aria-selected=true]:hover,.fd-tree--active .fd-tree__item-container:active,.fd-tree--active .fd-tree__item-container:active.is-hover,.fd-tree--active .fd-tree__item-container:active.is-selected,.fd-tree--active .fd-tree__item-container:active.is-selected.is-hover,.fd-tree--active .fd-tree__item-container:active.is-selected:hover,.fd-tree--active .fd-tree__item-container:active:hover,.fd-tree--active .fd-tree__item-container:active[aria-selected=true],.fd-tree--active .fd-tree__item-container:active[aria-selected=true].is-hover,.fd-tree--active .fd-tree__item-container:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-tree--active .fd-tree__item-container.is-focus,.fd-tree--active .fd-tree__item-container:focus{outline:none;pointer-events:all}.fd-tree--active .fd-tree__item-container.is-focus:before,.fd-tree--active .fd-tree__item-container:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-tree--active .fd-tree__item-container.is-focus.is-active:before,.fd-tree--active .fd-tree__item-container.is-focus:active:before,.fd-tree--active .fd-tree__item-container:focus.is-active:before,.fd-tree--active .fd-tree__item-container:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-tree--active .fd-tree__item-container.is-active .fd-button,.fd-tree--active .fd-tree__item-container.is-active .fd-tree__icon [class*=sap-icon],.fd-tree--active .fd-tree__item-container.is-active .fd-tree__icon[class*=sap-icon],.fd-tree--active .fd-tree__item-container.is-active .fd-tree__text,.fd-tree--active .fd-tree__item-container:active .fd-button,.fd-tree--active .fd-tree__item-container:active .fd-tree__icon [class*=sap-icon],.fd-tree--active .fd-tree__item-container:active .fd-tree__icon[class*=sap-icon],.fd-tree--active .fd-tree__item-container:active .fd-tree__text{color:var(--sapList_Active_TextColor)}.fd-tree--no-data .fd-tree__text{text-align:center}.fd-tree{display:block}.fd-tree__expander--loading{display:flex;align-items:center;justify-content:center}[dir=rtl] .fd-tree__expander:not(.is-expanded),.fd-tree__expander:not(.is-expanded)[dir=rtl]{transform:rotate(180deg)}[dir=rtl] .fd-tree__icon--navigation,.fd-tree__icon--navigation[dir=rtl]{transform:rotate(180deg)}\n/*! Bundled license information:\n\nfundamental-styles/dist/tree.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [], propDecorators: { class: [{
                type: Input
            }], noBorder: [{
                type: Input
            }], selection: [{
                type: Input
            }], selectionPlacement: [{
                type: Input
            }], independentSections: [{
                type: Input
            }], navigationIndicator: [{
                type: Input
            }], dataRequested: [{
                type: Output
            }], dataReceived: [{
                type: Output
            }], selectedChange: [{
                type: Output
            }], treeItemDef: [{
                type: ContentChild,
                args: [TreeItemDefDirective]
            }], _treeItemDirectives: [{
                type: ViewChildren,
                args: [TreeItemDirective]
            }], _projectedTreeItems: [{
                type: ContentChildren,
                args: [BaseTreeItem, { descendants: true }]
            }], buildComponentCssClass: [], _onKeyUp: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }] } });

class TreeItemComponent extends BaseTreeItem {
    /**
     * Tree item parent ID.
     */
    set parentId(value) {
        this._parentId = value;
    }
    get parentId() {
        return this._parentId || this._parentTreeItem?.id;
    }
    /**
     * Tree item level.
     */
    set level(value) {
        this._level = value;
    }
    get level() {
        return this._level || (this._parentTreeItem !== null ? this._parentTreeItem.level + 1 : 1);
    }
    /**
     * Whether the tree item is expanded.
     */
    set expanded(value) {
        if (value === this._expanded) {
            return;
        }
        this._treeService.addExpandableItem(this.id, this.level, value);
        this._expanded = value;
        if (value) {
            setTimeout(() => {
                this._treeService.detectChanges.next();
                this._dataSourceDirective.dataSourceProvider?.match();
            });
        }
        else {
            this.children = [];
            this.childrenLoaded = false;
            this._treeService.detectChanges.next();
        }
        this._cdr.detectChanges();
    }
    get expanded() {
        return this._expanded;
    }
    /** Whether the tree item has any type of child nodes. */
    get hasChildren() {
        return !!this.childNodes || this.hasProjectedChildren;
    }
    /** Whether the tree item has content-projected child nodes. */
    get hasProjectedChildren() {
        return this._projectedTreeItems && this._projectedTreeItems.length > 0;
    }
    /** Whether the tree item has data source children. */
    get hasDsChildren() {
        return this._dsChildrenNumber > 0;
    }
    /** Whether the item is accessible via keyboard. */
    get keyboardAccessible() {
        return this._parentTreeItem === null
            ? true
            : this._parentTreeItem.keyboardAccessible && this._parentTreeItem.expanded;
    }
    /** @hidden */
    constructor() {
        super();
        /**
         * Tree item ID.
         */
        this.id = uuidv4();
        /**
         * Whether the tree item is navigatable.
         */
        this.navigatable = false;
        /**
         * Tree item child nodes data source.
         */
        this.childNodes = [];
        /**
         * Whether to wrap content.
         */
        this.wrapContent = false;
        /**
         * Event emitted when user clicks on tree item.
         */
        this.treeItemClick = new EventEmitter();
        /**
         * Event emitted when `expanded` state changes.
         */
        this.expandedChange = new EventEmitter();
        /**
         * @hidden
         * Selection state.
         */
        this._selectionState = false;
        /** @hidden */
        this.children = [];
        /** @hidden */
        this.childrenLoaded = false;
        /** @Hidden */
        this._containerTabIndex = 0;
        /** @hidden */
        this._totalChildrenLoaded = false;
        /** @hidden */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this._treeService = inject(TreeService);
        /**
         * Custom background color
         */
        this.backgroundColor = input();
        /**
         * Custom styles
         */
        this.customStyles = input();
        /** @hidden */
        this._expanded = false;
        /** @hidden */
        this._dsChildrenNumber = 0;
        /** @hidden */
        this._clicked$ = new Subject();
        /** @hidden */
        this._treeItemDir = inject(TreeItemDirective, {
            optional: true
        });
        /** @hidden */
        this._dataSourceDirective = inject(DataSourceDirective);
        /** @hidden */
        this._cdr = inject(ChangeDetectorRef);
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._parentTreeItem = inject(TreeItemComponent, {
            optional: true,
            skipSelf: true
        });
        this._treeItemDir?.setTreeItem(this);
        this.clicked = this._clicked$.asObservable();
    }
    /** @hidden */
    ngOnInit() {
        this._dataSourceDirective.dataSource = this.childNodes;
        this._treeService.addExpandableItem(this.id, this.level, this.expanded);
        this._dataSourceDirective.dataSourceProvider
            ?.getTotalItems()
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe((totalItems) => {
            this._dsChildrenNumber = totalItems;
            this._totalChildrenLoaded = true;
            this._cdr.detectChanges();
        });
        this._dataSourceDirective.dataSourceProvider?.dataReceived
            .pipe(filter((received) => received), switchMap(() => this._dataSourceDirective.dataChanged$), takeUntilDestroyed(this._destroyRef))
            .subscribe((data) => {
            this.children = this._treeService.normalizeTreeItems(data, this.id, this.level + 1);
            this.childrenLoaded = true;
            setTimeout(() => {
                this._treeService.detectChanges.next();
                this._cdr.detectChanges();
            });
        });
    }
    /** @hidden */
    ngAfterViewInit() {
        this._projectedTreeItems.changes
            .pipe(startWith(null), distinctUntilChanged(), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => {
            this._cdr.detectChanges();
            this._projectedTreeItems.forEach((treeItem, index) => {
                treeItem.setPosition(this._projectedTreeItems.length, index + 1);
            });
        });
    }
    /** @hidden */
    ngOnDestroy() {
        this._treeService.removeExpandableItem(this.id, this.level);
    }
    /**
     * Sets position of the current item in the set.
     * @param totalItems Total items amount in the set.
     * @param currentIndex Current item position in the set.
     */
    setPosition(totalItems, currentIndex) {
        this._setSize = totalItems;
        this._currentPosition = currentIndex;
    }
    /** Method to focus on the tree item. */
    focus() {
        this.itemContainer?.nativeElement.focus();
    }
    /** Method for setting the focusable tabindex. */
    setContainerTabIndex(value) {
        this._containerTabIndex = value;
        this._cdr.markForCheck();
    }
    /** @hidden */
    _toggleExpandState(event) {
        // Do not bubble up to selection change event.
        event.stopImmediatePropagation();
        this.expanded = !this.expanded;
        this.expandedChange.emit(this.expanded);
        this.focus();
    }
    /** @hidden */
    _onClick(event) {
        event.stopImmediatePropagation();
        this._clicked$.next(event);
        this.treeItemClick.emit(event);
    }
    /** @hidden */
    _setSelected(selected) {
        this._selectionState = selected;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: TreeItemComponent, isStandalone: true, selector: "fd-tree-item", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: false, isRequired: false, transformFunction: null }, id: { classPropertyName: "id", publicName: "id", isSignal: false, isRequired: false, transformFunction: null }, ariaLabel: { classPropertyName: "ariaLabel", publicName: "ariaLabel", isSignal: false, isRequired: false, transformFunction: null }, parentId: { classPropertyName: "parentId", publicName: "parentId", isSignal: false, isRequired: false, transformFunction: null }, navigatable: { classPropertyName: "navigatable", publicName: "navigatable", isSignal: false, isRequired: false, transformFunction: null }, state: { classPropertyName: "state", publicName: "state", isSignal: false, isRequired: false, transformFunction: null }, childNodes: { classPropertyName: "childNodes", publicName: "childNodes", isSignal: false, isRequired: false, transformFunction: null }, wrapContent: { classPropertyName: "wrapContent", publicName: "wrapContent", isSignal: false, isRequired: false, transformFunction: null }, level: { classPropertyName: "level", publicName: "level", isSignal: false, isRequired: false, transformFunction: null }, expanded: { classPropertyName: "expanded", publicName: "expanded", isSignal: false, isRequired: false, transformFunction: null }, backgroundColor: { classPropertyName: "backgroundColor", publicName: "backgroundColor", isSignal: true, isRequired: false, transformFunction: null }, customStyles: { classPropertyName: "customStyles", publicName: "customStyles", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { treeItemClick: "treeItemClick", expandedChange: "expandedChange" }, host: { attributes: { "role": "presentation" }, properties: { "attr.aria-label": "this.ariaLabel", "attr.aria-level": "this.level" }, classAttribute: "fd-tree__item" }, providers: [
            {
                provide: FDK_SELECTABLE_ITEM_PROVIDER,
                useExisting: TreeItemComponent
            },
            {
                provide: BaseTreeItem,
                useExisting: TreeItemComponent
            }
        ], queries: [{ propertyName: "_projectedTreeItems", predicate: BaseTreeItem }], viewQueries: [{ propertyName: "itemContainer", first: true, predicate: ["itemContainer"], descendants: true, read: ElementRef }, { propertyName: "selectableListItem", first: true, predicate: SelectableItemDirective, descendants: true }], usesInheritance: true, hostDirectives: [{ directive: i1.DataSourceDirective }], ngImport: i0, template: "<div\n    class=\"fd-tree__item-container\"\n    [attr.tabindex]=\"_containerTabIndex\"\n    (fdkClicked)=\"_onClick($event)\"\n    fdkSelectableItem\n    (selected)=\"_setSelected($event)\"\n    [value]=\"value\"\n    [attr.aria-haspopup]=\"children.length > 0 || hasProjectedChildren\"\n    [attr.aria-expanded]=\"expanded\"\n    [attr.aria-setsize]=\"_setSize\"\n    [attr.aria-posinset]=\"_currentPosition\"\n    role=\"treeitem\"\n    [attr.aria-level]=\"level\"\n    [style.background-color]=\"backgroundColor()\"\n    [ngStyle]=\"customStyles()\"\n    #itemContainer\n    [ngClass]=\"[\n        state ? 'has-highlight-indicator has-highlight-indicator--' + state : '',\n        navigatable ? 'fd-tree__item-container--active' : '',\n        wrapContent ? 'fd-tree__content--wrap' : ''\n    ]\"\n>\n    @if (_treeService.selectionMode().placement === 'left') {\n        <ng-template [ngTemplateOutlet]=\"selection\"></ng-template>\n    }\n    @if (hasChildren) {\n        @if (hasDsChildren || hasProjectedChildren) {\n            <span\n                (click)=\"_toggleExpandState($event)\"\n                class=\"fd-tree__expander\"\n                aria-hidden=\"true\"\n                role=\"presentation\"\n                [attr.aria-label]=\"(expanded ? 'coreTree.collapse' : 'coreTree.expand') | fdTranslate\"\n                [class.is-expanded]=\"expanded\"\n            >\n                <fd-icon\n                    class=\"fd-tree__icon\"\n                    [glyph]=\"expanded ? 'navigation-down-arrow' : 'navigation-right-arrow'\"\n                ></fd-icon>\n            </span>\n        }\n        @if (!_totalChildrenLoaded) {\n            <div class=\"fd-tree__expander fd-tree__expander--loading\">\n                <fd-skeleton type=\"rectangle\" width=\"1rem\" height=\"1rem\"></fd-skeleton>\n            </div>\n        }\n        @if (_treeService.selectionMode().placement === 'afterExpand') {\n            <ng-template [ngTemplateOutlet]=\"selection\"></ng-template>\n        }\n    }\n    <div class=\"fd-tree__content\">\n        <ng-content select=\"[fdTreeItemIcon]\"></ng-content>\n        <ng-content select=\"[fdTreeItemText]\"></ng-content>\n    </div>\n    <ng-content select=\"[fdTreeItemButton]\"></ng-content>\n    @if (_treeService.selectionMode().placement === 'right') {\n        <ng-template [ngTemplateOutlet]=\"selection\"></ng-template>\n    }\n    @if (navigatable && _treeService.navigationIndicator()) {\n        <fd-icon glyph=\"slim-arrow-right\" class=\"fd-tree__icon fd-tree__icon--navigation\"></fd-icon>\n    }\n</div>\n@if (hasProjectedChildren && expanded) {\n    <div class=\"fd-tree\">\n        <ng-content select=\"fd-tree-item\"></ng-content>\n    </div>\n}\n<ng-template #selection>\n    <div class=\"fd-form-item\">\n        @if (_treeService.selectionMode().mode === 'multiple') {\n            <fd-checkbox\n                [(ngModel)]=\"_selectionState\"\n                [ngModelOptions]=\"{ standalone: true }\"\n                [standalone]=\"true\"\n                tabIndexValue=\"-1\"\n            ></fd-checkbox>\n        }\n        @if (_treeService.selectionMode().mode === 'single') {\n            <fd-radio-button\n                [(ngModel)]=\"_selectionState\"\n                [ngModelOptions]=\"{ standalone: true }\"\n                [selectedValue]=\"_selectionState\"\n                [value]=\"true\"\n                tabIndex=\"-1\"\n                [standalone]=\"true\"\n                tabIndexValue=\"-1\"\n            ></fd-radio-button>\n        }\n    </div>\n</ng-template>\n", dependencies: [{ kind: "directive", type: SelectableItemDirective, selector: "[fdkSelectableItem]", inputs: ["value", "fdkSelectableItem"], outputs: ["clicked", "selected"], exportAs: ["fdkSelectableItem"] }, { kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "directive", type: ClickedDirective, selector: "[fdkClicked]", outputs: ["fdkClicked"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }, { kind: "component", type: SkeletonComponent, selector: "fd-skeleton", inputs: ["animated", "type", "textLines", "width", "height"] }, { kind: "component", type: CheckboxComponent, selector: "fd-checkbox", inputs: ["wrapLabel", "valignLabel", "ariaLabel", "role", "value", "ariaLabelledBy", "ariaDescribedBy", "title", "inputId", "state", "name", "label", "disabled", "readonly", "tristate", "tristateSelectable", "labelClass", "required", "displayOnly", "values", "standalone"], outputs: ["focusChange"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i2$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: RadioButtonComponent, selector: "fd-radio-button", inputs: ["ariaLabel", "ariaLabelledBy", "ariaDescribedBy", "title", "tabIndex", "state", "disabled", "readOnly", "selectedValue", "name", "id", "value", "required", "standalone", "wrapLabel", "valignLabel"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-tree-item', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, hostDirectives: [DataSourceDirective], host: {
                        class: 'fd-tree__item',
                        role: 'presentation'
                    }, providers: [
                        {
                            provide: FDK_SELECTABLE_ITEM_PROVIDER,
                            useExisting: TreeItemComponent
                        },
                        {
                            provide: BaseTreeItem,
                            useExisting: TreeItemComponent
                        }
                    ], imports: [
                        SelectableItemDirective,
                        NgClass,
                        NgStyle,
                        ClickedDirective,
                        NgTemplateOutlet,
                        IconComponent,
                        SkeletonComponent,
                        CheckboxComponent,
                        FormsModule,
                        RadioButtonComponent,
                        FdTranslatePipe
                    ], template: "<div\n    class=\"fd-tree__item-container\"\n    [attr.tabindex]=\"_containerTabIndex\"\n    (fdkClicked)=\"_onClick($event)\"\n    fdkSelectableItem\n    (selected)=\"_setSelected($event)\"\n    [value]=\"value\"\n    [attr.aria-haspopup]=\"children.length > 0 || hasProjectedChildren\"\n    [attr.aria-expanded]=\"expanded\"\n    [attr.aria-setsize]=\"_setSize\"\n    [attr.aria-posinset]=\"_currentPosition\"\n    role=\"treeitem\"\n    [attr.aria-level]=\"level\"\n    [style.background-color]=\"backgroundColor()\"\n    [ngStyle]=\"customStyles()\"\n    #itemContainer\n    [ngClass]=\"[\n        state ? 'has-highlight-indicator has-highlight-indicator--' + state : '',\n        navigatable ? 'fd-tree__item-container--active' : '',\n        wrapContent ? 'fd-tree__content--wrap' : ''\n    ]\"\n>\n    @if (_treeService.selectionMode().placement === 'left') {\n        <ng-template [ngTemplateOutlet]=\"selection\"></ng-template>\n    }\n    @if (hasChildren) {\n        @if (hasDsChildren || hasProjectedChildren) {\n            <span\n                (click)=\"_toggleExpandState($event)\"\n                class=\"fd-tree__expander\"\n                aria-hidden=\"true\"\n                role=\"presentation\"\n                [attr.aria-label]=\"(expanded ? 'coreTree.collapse' : 'coreTree.expand') | fdTranslate\"\n                [class.is-expanded]=\"expanded\"\n            >\n                <fd-icon\n                    class=\"fd-tree__icon\"\n                    [glyph]=\"expanded ? 'navigation-down-arrow' : 'navigation-right-arrow'\"\n                ></fd-icon>\n            </span>\n        }\n        @if (!_totalChildrenLoaded) {\n            <div class=\"fd-tree__expander fd-tree__expander--loading\">\n                <fd-skeleton type=\"rectangle\" width=\"1rem\" height=\"1rem\"></fd-skeleton>\n            </div>\n        }\n        @if (_treeService.selectionMode().placement === 'afterExpand') {\n            <ng-template [ngTemplateOutlet]=\"selection\"></ng-template>\n        }\n    }\n    <div class=\"fd-tree__content\">\n        <ng-content select=\"[fdTreeItemIcon]\"></ng-content>\n        <ng-content select=\"[fdTreeItemText]\"></ng-content>\n    </div>\n    <ng-content select=\"[fdTreeItemButton]\"></ng-content>\n    @if (_treeService.selectionMode().placement === 'right') {\n        <ng-template [ngTemplateOutlet]=\"selection\"></ng-template>\n    }\n    @if (navigatable && _treeService.navigationIndicator()) {\n        <fd-icon glyph=\"slim-arrow-right\" class=\"fd-tree__icon fd-tree__icon--navigation\"></fd-icon>\n    }\n</div>\n@if (hasProjectedChildren && expanded) {\n    <div class=\"fd-tree\">\n        <ng-content select=\"fd-tree-item\"></ng-content>\n    </div>\n}\n<ng-template #selection>\n    <div class=\"fd-form-item\">\n        @if (_treeService.selectionMode().mode === 'multiple') {\n            <fd-checkbox\n                [(ngModel)]=\"_selectionState\"\n                [ngModelOptions]=\"{ standalone: true }\"\n                [standalone]=\"true\"\n                tabIndexValue=\"-1\"\n            ></fd-checkbox>\n        }\n        @if (_treeService.selectionMode().mode === 'single') {\n            <fd-radio-button\n                [(ngModel)]=\"_selectionState\"\n                [ngModelOptions]=\"{ standalone: true }\"\n                [selectedValue]=\"_selectionState\"\n                [value]=\"true\"\n                tabIndex=\"-1\"\n                [standalone]=\"true\"\n                tabIndexValue=\"-1\"\n            ></fd-radio-button>\n        }\n    </div>\n</ng-template>\n" }]
        }], ctorParameters: () => [], propDecorators: { value: [{
                type: Input
            }], id: [{
                type: Input
            }], ariaLabel: [{
                type: HostBinding,
                args: ['attr.aria-label']
            }, {
                type: Input
            }], parentId: [{
                type: Input
            }], navigatable: [{
                type: Input
            }], state: [{
                type: Input
            }], childNodes: [{
                type: Input
            }], wrapContent: [{
                type: Input
            }], level: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-level']
            }], expanded: [{
                type: Input
            }], treeItemClick: [{
                type: Output
            }], expandedChange: [{
                type: Output
            }], itemContainer: [{
                type: ViewChild,
                args: ['itemContainer', { read: ElementRef }]
            }], selectableListItem: [{
                type: ViewChild,
                args: [SelectableItemDirective]
            }], _projectedTreeItems: [{
                type: ContentChildren,
                args: [BaseTreeItem]
            }] } });

class TreeItemButtonDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemButtonDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TreeItemButtonDirective, isStandalone: true, selector: "[fdTreeItemButton]", host: { classAttribute: "fd-tree__button" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTreeItemButton]',
                    host: {
                        class: 'fd-tree__button'
                    },
                    standalone: true
                }]
        }] });

class TreeItemIconDirective {
    constructor() {
        /** @hidden */
        this._role = 'presentation';
        /** @hidden */
        this._ariaHidden = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemIconDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TreeItemIconDirective, isStandalone: true, selector: "[fdTreeItemIcon]", host: { properties: { "attr.role": "this._role", "attr.aria-hidden": "this._ariaHidden" }, classAttribute: "fd-tree__icon" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemIconDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTreeItemIcon]',
                    host: {
                        class: 'fd-tree__icon'
                    },
                    standalone: true
                }]
        }], propDecorators: { _role: [{
                type: HostBinding,
                args: ['attr.role']
            }], _ariaHidden: [{
                type: HostBinding,
                args: ['attr.aria-hidden']
            }] } });
class TreeItemTextDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemTextDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TreeItemTextDirective, isStandalone: true, selector: "[fdTreeItemText]", host: { classAttribute: "fd-tree__text" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeItemTextDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTreeItemText]',
                    host: {
                        class: 'fd-tree__text'
                    },
                    standalone: true
                }]
        }] });

const components = [
    TreeComponent,
    TreeItemComponent,
    TreeItemDefDirective,
    TreeItemDirective,
    TreeItemIconDirective,
    TreeItemTextDirective,
    TreeItemButtonDirective
];
/**
 * @deprecated
 *
 * Use direct imports of `TreeComponent`,
        `TreeItemComponent`,
        `TreeItemDefDirective`,
        `TreeItemDirective`,
        `TreeItemIconDirective`,
        `TreeItemTextDirective`,
        `TreeItemButtonDirective`
 */
class TreeModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: TreeModule, imports: [TreeComponent,
            TreeItemComponent,
            TreeItemDefDirective,
            TreeItemDirective,
            TreeItemIconDirective,
            TreeItemTextDirective,
            TreeItemButtonDirective], exports: [TreeComponent,
            TreeItemComponent,
            TreeItemDefDirective,
            TreeItemDirective,
            TreeItemIconDirective,
            TreeItemTextDirective,
            TreeItemButtonDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeModule, imports: [TreeComponent,
            TreeItemComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TreeModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...components],
                    exports: [...components]
                }]
        }] });

const FD_TREE_ITEM = new InjectionToken('FdTreeItem');

/**
 * Generated bundle index. Do not edit.
 */

export { ArrayTreeDataSource, BaseTreeItem, FD_TREE_ITEM, FdTreeDataSource, ObservableTreeDataSource, TreeComponent, TreeDataSourceParser, TreeItemButtonDirective, TreeItemComponent, TreeItemDefDirective, TreeItemDirective, TreeItemIconDirective, TreeItemTextDirective, TreeModule };
//# sourceMappingURL=fundamental-ngx-core-tree.mjs.map
