import * as i0 from '@angular/core';
import { OnChanges, OnInit, ElementRef, InjectionToken } from '@angular/core';
import { CssClassBuilder, Nullable } from '@fundamental-ngx/cdk/utils';

type GenericTagType = 'error' | 'success' | 'warning' | 'information';
declare class GenericTagComponent implements OnChanges, OnInit, CssClassBuilder {
    /** User's custom classes */
    class: string;
    /**
     * The type of the Generic Tag.
     * Can be one of the following: 'error' | 'success' | 'warning' | 'information'.
     * For default Generic Tag omit this property.
     */
    type: Nullable<GenericTagType>;
    /**
     * Required input
     * The KPI Name of the Generic tag. Standard text.
     * Always use a meaningful title. Keep it simple and try to use no more than 3 words.
     */
    name: string;
    /**
     * The KPI Value of the Generic tag.
     * The value represents the numeric (key) attribute and its unit.
     */
    value: Nullable<string>;
    /**
     *  Aria defines role description for the Generic Tag
     */
    ariaRoleDescription: Nullable<string>;
    /** @hidden */
    readonly elementRef: ElementRef<any>;
    /** @hidden
     * CssClassBuilder interface implementation
     * function must return single string
     * function is responsible for order which css classes are applied
     */
    buildComponentCssClass(): string[];
    /** @hidden */
    ngOnChanges(): void;
    /** @hidden */
    ngOnInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<GenericTagComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GenericTagComponent, "[fd-generic-tag]", never, { "class": { "alias": "class"; "required": false; }; "type": { "alias": "type"; "required": false; }; "name": { "alias": "name"; "required": true; }; "value": { "alias": "value"; "required": false; }; "ariaRoleDescription": { "alias": "ariaRoleDescription"; "required": false; }; }, {}, never, never, true, never>;
}

declare class GenericTagModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<GenericTagModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<GenericTagModule, never, [typeof GenericTagComponent], [typeof GenericTagComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<GenericTagModule>;
}

declare const FD_GENERIC_TAG_COMPONENT: InjectionToken<unknown>;

export { FD_GENERIC_TAG_COMPONENT, GenericTagComponent, GenericTagModule };
export type { GenericTagType };
