import * as i0 from '@angular/core';
import { OnInit, EventEmitter } from '@angular/core';

/**
 * A directive designed to help navigation elements determine the element currently in view of the user.
 */
declare class ScrollSpyDirective implements OnInit {
    /**
     * An array of tags to track.
     */
    trackedTags: string[];
    /**
     * Whether events are still fired if there is no tag present on the user's screen.
     */
    fireEmpty: boolean;
    /**
     * A number that represent at what location in the container the event is fired.
     * 0.5 would fire the events in the middle of the container,
     * 0 for the top and 1 for the bottom.
     */
    targetPercent: number;
    /**
     * Number that represents the offset in pixels for fired target. `100` value means that the event will be fired for
     * target that is 100 pixels below the spy container.
     */
    targetOffset: number;
    /**
     * Whether to disable scroll spy
     */
    scrollSpyDisabled: boolean;
    /**
     * Event fired on the scroll element when a new item becomes activated by the scrollspy .
     * The returned value is the HTMLElement itself.
     */
    readonly spyChange: EventEmitter<HTMLElement>;
    /** @hidden */
    private _currentActive;
    /** @hidden */
    private readonly _elRef;
    /** @hidden */
    private readonly _destroyRef;
    /** @hidden */
    onScroll(event?: Event, forced?: boolean): void;
    /** @hidden */
    ngOnInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ScrollSpyDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ScrollSpyDirective, "[fdScrollSpy]", ["fdScrollSpy"], { "trackedTags": { "alias": "trackedTags"; "required": false; }; "fireEmpty": { "alias": "fireEmpty"; "required": false; }; "targetPercent": { "alias": "targetPercent"; "required": false; }; "targetOffset": { "alias": "targetOffset"; "required": false; }; "scrollSpyDisabled": { "alias": "scrollSpyDisabled"; "required": false; }; }, { "spyChange": "spyChange"; }, never, never, true, never>;
}

/**
 * @deprecated
 * Use direct `ScrollSpyDirective` import.
 */
declare class ScrollSpyModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<ScrollSpyModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<ScrollSpyModule, never, [typeof ScrollSpyDirective], [typeof ScrollSpyDirective]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<ScrollSpyModule>;
}

export { ScrollSpyDirective, ScrollSpyModule };
