import * as i0 from '@angular/core';
import { Attribute, Directive, Optional, Injectable, EventEmitter, inject, DestroyRef, ElementRef, ViewChild, Output, Input, ChangeDetectionStrategy, ViewEncapsulation, Component, input, Inject, model, forwardRef, HostListener, HostBinding, NgModule } from '@angular/core';
import { resolveTranslationSignal, FdTranslatePipe, FD_LANGUAGE_ENGLISH, FD_LANGUAGE } from '@fundamental-ngx/i18n';
import * as i2 from '@fundamental-ngx/core/datetime';
import { DATE_TIME_FORMATS } from '@fundamental-ngx/core/datetime';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { ButtonComponent } from '@fundamental-ngx/core/button';
import { Subject, switchMap, startWith, map, Subscription } from 'rxjs';
import * as i1 from '@fundamental-ngx/cdk/utils';
import { applyCssClass, FocusableListDirective, FocusableItemDirective } from '@fundamental-ngx/cdk/utils';
import { __decorate, __metadata } from 'tslib';
import equal from 'fast-deep-equal';
import { NgClass } from '@angular/common';
import { NG_VALUE_ACCESSOR, NG_VALIDATORS } from '@angular/forms';
import * as i1$1 from '@fundamental-ngx/core/content-density';
import { ContentDensityModule, contentDensityObserverProviders } from '@fundamental-ngx/core/content-density';

class CalendarCloseButtonDirective {
    /** @hidden */
    constructor(_originalAriaLabel, _originalTitle) {
        this._originalAriaLabel = _originalAriaLabel;
        this._originalTitle = _originalTitle;
        /** @hidden */
        this._closeCalendarLabel = resolveTranslationSignal('coreCalendar.closeCalendarLabel');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarCloseButtonDirective, deps: [{ token: 'aria-label', attribute: true }, { token: 'title', attribute: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CalendarCloseButtonDirective, isStandalone: true, selector: "[fd-calendar-close-button]", host: { properties: { "attr.aria-label": "_originalAriaLabel || _closeCalendarLabel()", "attr.title": "_originalTitle || _closeCalendarLabel()" }, classAttribute: "fd-calendar__close-button" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarCloseButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-calendar-close-button]',
                    host: {
                        class: 'fd-calendar__close-button',
                        '[attr.aria-label]': '_originalAriaLabel || _closeCalendarLabel()',
                        '[attr.title]': '_originalTitle || _closeCalendarLabel()'
                    },
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Attribute,
                    args: ['aria-label']
                }] }, { type: undefined, decorators: [{
                    type: Attribute,
                    args: ['title']
                }] }] });

class CalendarService {
    /** @hidden */
    constructor(_rtlService) {
        this._rtlService = _rtlService;
        /** Row amount */
        this.rowAmount = 3;
        /** Column amount */
        this.colAmount = 4;
        /** Event thrown, when the element is selected by space or enter keys */
        this.onKeySelect = new Subject();
        /** Event thrown, when the focus goes after list of elements */
        this.onListEndApproach = new Subject();
        /** Event thrown, when the focus goes before list of elements */
        this.onListStartApproach = new Subject();
        /** Event thrown, when the focus is changed. */
        this.onFocusIdChange = new Subject();
    }
    /**
     * Standardized method to calculate grid [x][y] to index number
     */
    getId(row, col) {
        return row * this.colAmount + col;
    }
    /**
     * Method that handles keydown events, dedicated for All Calendar views, which have a list with row x col elements.
     * Triggers the events, when the focus approaches start and end of list. Or when there is basic change of focus.
     * Triggers also event, when the element is selected by enter key, or space bar.
     * @param event KeyboardEvent
     * @param index which is number (0 - (rowAmount * colAmount))
     */
    onKeydownHandler(event, index) {
        const rtl = !!this._rtlService?.rtlSignal();
        switch (event.key) {
            case 'Spacebar':
            case 'Enter':
            case ' ': {
                event.preventDefault();
                this.onKeySelect.next({ index, event });
                break;
            }
            case 'Left':
            case 'ArrowLeft': {
                event.preventDefault();
                if (!rtl) {
                    this.focusLeftElement(index);
                }
                else {
                    this.focusRightElement(index);
                }
                break;
            }
            case 'Right':
            case 'ArrowRight': {
                event.preventDefault();
                if (!rtl) {
                    this.focusRightElement(index);
                }
                else {
                    this.focusLeftElement(index);
                }
                break;
            }
            case 'Up':
            case 'ArrowUp': {
                event.preventDefault();
                if (index <= this.colAmount - 1) {
                    this.onListStartApproach.next(this.getId(this.rowAmount - 1, 0) + index);
                }
                else {
                    this.onFocusIdChange.next(index - this.colAmount);
                }
                break;
            }
            case 'Down':
            case 'ArrowDown': {
                event.preventDefault();
                if (index >= this.getId(this.rowAmount - 1, 0)) {
                    this.onListEndApproach.next(index - this.getId(this.rowAmount - 1, 0));
                }
                else {
                    this.onFocusIdChange.next(index + this.colAmount);
                }
                break;
            }
            case 'Tab': {
                if (!event.shiftKey) {
                    if (typeof this.focusEscapeFunction === 'function') {
                        this.focusEscapeFunction(event);
                    }
                    else {
                        const element = document.getElementById(this.leftArrowId);
                        if (element) {
                            element.focus();
                        }
                    }
                    event.preventDefault();
                    break;
                }
            }
        }
    }
    /**
     * @hidden
     * Right Element focus trigger
     */
    focusRightElement(index) {
        if (index === this.getId(this.rowAmount, 0) - 1) {
            this.onListEndApproach.next(0);
        }
        else {
            this.onFocusIdChange.next(index + 1);
        }
    }
    /**
     * @hidden
     * Left Element focus trigger
     */
    focusLeftElement(index) {
        if (index === 0) {
            this.onListStartApproach.next(this.getId(this.rowAmount, 0) - 1);
        }
        else {
            this.onFocusIdChange.next(index - 1);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarService, deps: [{ token: i1.RtlService, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.RtlService, decorators: [{
                    type: Optional
                }] }] });

/** Enum of calendarTypes */
var CalendarTypeEnum;
(function (CalendarTypeEnum) {
    CalendarTypeEnum["Single"] = "single";
    CalendarTypeEnum["Range"] = "range";
})(CalendarTypeEnum || (CalendarTypeEnum = {}));
/** Type for the calendar view */
var FdCalendarViewEnum;
(function (FdCalendarViewEnum) {
    FdCalendarViewEnum["Day"] = "day";
    FdCalendarViewEnum["Month"] = "month";
    FdCalendarViewEnum["Year"] = "year";
    FdCalendarViewEnum["AggregatedYear"] = "aggregatedYear";
})(FdCalendarViewEnum || (FdCalendarViewEnum = {}));

/**
 * Internal use only.
 * Header of the calendar component.
 */
class CalendarHeaderComponent {
    /**
     * Object to customize year grid
     */
    set calendarYearGrid(yearGrid) {
        this._amountOfYearsPerPeriod = yearGrid.cols * yearGrid.rows - 1;
        this._calculateSelectAggregatedYearLabel();
    }
    /** Aria label for the previous button. Depends on the active view. */
    get previousAriaLabel() {
        return this.isOnDayView ? 'coreCalendar.previousMonthLabel' : 'coreCalendar.previousYearLabel';
    }
    /** Aria label for the next button. Depends on the active view. */
    get nextAriaLabel() {
        return this.isOnDayView ? 'coreCalendar.nextMonthLabel' : 'coreCalendar.nextYearLabel';
    }
    /** Button aria label to open month selection view. */
    get selectMonthAriaLabel() {
        return this.isOnMonthView ? 'coreCalendar.dateSelectionLabel' : 'coreCalendar.monthSelectionLabel';
    }
    /** Button aria label to open aggregated years selection view. */
    get selectAggregatedYearAriaLabel() {
        return this.isOnAggregatedYearsView
            ? 'coreCalendar.dateSelectionLabel'
            : 'coreCalendar.yearsRangeSelectionLabel';
    }
    /** Get information is calendar is on aggregated years view */
    get isOnAggregatedYearsView() {
        return this.activeView === FdCalendarViewEnum.AggregatedYear;
    }
    /** Get information is calendar is on year view */
    get isOnYearView() {
        return this.activeView === FdCalendarViewEnum.Year;
    }
    /** Get information is calendar is on month view */
    get isOnMonthView() {
        return this.activeView === FdCalendarViewEnum.Month;
    }
    /** Get information is calendar is on day view */
    get isOnDayView() {
        return this.activeView === FdCalendarViewEnum.Day;
    }
    /**
     * Component id
     */
    get viewId() {
        return this.id + '-header';
    }
    /**
     * @hidden
     * Previous button id
     */
    get _prevButtonId() {
        return this.viewId + '-left-arrow';
    }
    /**
     * @hidden
     * Next button id
     */
    get _nextButtonId() {
        return this.viewId + '-right-arrow';
    }
    /**
     * @hidden
     * Month label id
     */
    get _monthButtonLabelId() {
        return this.viewId + '-month-label';
    }
    /**
     * @hidden
     * Select month aria label id
     */
    get _selectMonthButtonAriaLabelId() {
        return this.viewId + '-select-month-aria-label';
    }
    /**
     * @hidden
     * Year label id
     */
    get _yearButtonLabelId() {
        return this.viewId + '-year-label';
    }
    /**
     * @hidden
     * Select year aria label id
     */
    get _selectYearButtonAriaLabelId() {
        return this.viewId + '-select-year-aria-label';
    }
    /**
     * @hidden
     * Years range label id
     */
    get _yearsRangeButtonLabelId() {
        return this.viewId + '-years-range-label';
    }
    /**
     * @hidden
     * Select years range aria label id
     */
    get _selectYearsRangeButtonAriaLabelId() {
        return this.viewId + '-select-years-range-aria-label';
    }
    /** @hidden */
    constructor(_changeDetRef, _calendarService, _dateTimeAdapter) {
        this._changeDetRef = _changeDetRef;
        this._calendarService = _calendarService;
        this._dateTimeAdapter = _dateTimeAdapter;
        /** Whether calendar should be rendered in mobile landscape mode. */
        this.mobileLandscape = false;
        /** Event emitted when the active view should change. */
        this.activeViewChange = new EventEmitter();
        /** Event emitted when the previous button is clicked. */
        this.previousClicked = new EventEmitter();
        /** Event emitted when the next button is clicked. */
        this.nextClicked = new EventEmitter();
        /** @hidden  */
        this._destroyRef = inject(DestroyRef);
        /** Month names */
        this._monthNames = [];
        /** Get information about amount of years displayed at once on year view  */
        this._amountOfYearsPerPeriod = 1;
    }
    /** @hidden */
    ngOnChanges(changes) {
        if ((changes.currentlyDisplayed && !changes.currentlyDisplayed.firstChange) ||
            (changes.activeView && !changes.activeView.firstChange)) {
            this._calculateLabels();
        }
    }
    /** @hidden */
    ngOnInit() {
        this._calendarService.leftArrowId = this._prevButtonId;
        this._calculateMonthNames();
        this._calculateLabels();
        this._listenToLocaleChanges();
    }
    /**
     * Focus on focusable control within the header
     */
    focus() {
        this._prevButtonComponent.nativeElement?.focus();
    }
    /** @hidden */
    _processViewChange(type, event) {
        if (event) {
            event.stopPropagation();
        }
        this.activeView = type === this.activeView ? FdCalendarViewEnum.Day : type;
        this.activeViewChange.emit(this.activeView);
    }
    /** @hidden */
    _listenToLocaleChanges() {
        this._dateTimeAdapter.localeChanges.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._calculateMonthNames();
            this._calculateLabels();
            this._changeDetRef.markForCheck();
        });
    }
    /** @hidden */
    _calculateLabels() {
        this._calculateSelectMonthLabel();
        this._calculateSelectYearLabel();
        this._calculateSelectAggregatedYearLabel();
    }
    /** @hidden */
    _calculateSelectMonthLabel() {
        this.selectMonthLabel = this._monthNames[this._getNormalizedDate().month - 1];
    }
    /** @hidden */
    _calculateSelectYearLabel() {
        this.selectYearLabel = this._getYearName(this._getNormalizedDate().year);
    }
    /** @hidden */
    _calculateSelectAggregatedYearLabel() {
        this.selectAggregatedYearLabel = `${this._getYearName(this._getNormalizedDate().year)}-${this._getYearName(this._getNormalizedDate().year + this._amountOfYearsPerPeriod)}`;
    }
    /** @hidden */
    _calculateMonthNames() {
        this._monthNames = this._dateTimeAdapter.getMonthNames('long');
    }
    /** @hidden */
    _getYearName(year) {
        return this._dateTimeAdapter.getYearName(this._dateTimeAdapter.createDate(year));
    }
    /** @hidden */
    _getNormalizedDate() {
        return {
            year: isNaN(this.currentlyDisplayed.year)
                ? this._dateTimeAdapter.getYear(this._dateTimeAdapter.now())
                : this.currentlyDisplayed.year,
            month: isNaN(this.currentlyDisplayed.month)
                ? this._dateTimeAdapter.getMonth(this._dateTimeAdapter.now())
                : this.currentlyDisplayed.month
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarHeaderComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: CalendarService }, { token: i2.DatetimeAdapter }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CalendarHeaderComponent, isStandalone: true, selector: "fd-calendar-header", inputs: { activeView: "activeView", currentlyDisplayed: "currentlyDisplayed", previousButtonDisabled: "previousButtonDisabled", nextButtonDisabled: "nextButtonDisabled", calendarYearGrid: "calendarYearGrid", id: "id", mobileLandscape: "mobileLandscape" }, outputs: { activeViewChange: "activeViewChange", previousClicked: "previousClicked", nextClicked: "nextClicked" }, host: { properties: { "attr.id": "viewId" } }, viewQueries: [{ propertyName: "_prevButtonComponent", first: true, predicate: ["prevButton"], descendants: true, read: ElementRef }], usesOnChanges: true, ngImport: i0, template: "<header class=\"fd-calendar__navigation\" [class.fd-calendar__navigation--main]=\"mobileLandscape\">\n    <div class=\"fd-calendar__action fd-calendar__action--arrow-left\">\n        <button\n            #prevButton\n            fd-button\n            fdType=\"transparent\"\n            glyph=\"slim-arrow-left\"\n            [attr.id]=\"_prevButtonId\"\n            [disabled]=\"previousButtonDisabled\"\n            [attr.title]=\"previousAriaLabel | fdTranslate\"\n            [ariaLabel]=\"previousAriaLabel | fdTranslate\"\n            type=\"button\"\n            (click)=\"previousClicked.emit()\"\n        ></button>\n    </div>\n    @if (isOnDayView || isOnMonthView) {\n        @if (!isOnMonthView) {\n            <div class=\"fd-calendar__action\">\n                <!-- Select month button -->\n                <button\n                    fd-button\n                    type=\"button\"\n                    fdType=\"transparent\"\n                    [attr.aria-labelledby]=\"_monthButtonLabelId + ' ' + _selectMonthButtonAriaLabelId\"\n                    [attr.data-fd-calendar-month]=\"currentlyDisplayed.month\"\n                    (click)=\"_processViewChange('month', $event)\"\n                >\n                    <span [attr.id]=\"_monthButtonLabelId\">{{ selectMonthLabel }}</span>\n                </button>\n            </div>\n        }\n        <div class=\"fd-calendar__action\">\n            <!-- Select year button -->\n            <button\n                fd-button\n                type=\"button\"\n                fdType=\"transparent\"\n                [attr.aria-labelledby]=\"_yearButtonLabelId + ' ' + _selectYearButtonAriaLabelId\"\n                [attr.data-fd-calendar-year]=\"currentlyDisplayed.year\"\n                (click)=\"_processViewChange('year', $event)\"\n            >\n                <span [attr.id]=\"_yearButtonLabelId\">{{ selectYearLabel }}</span>\n            </button>\n        </div>\n    }\n    @if (isOnAggregatedYearsView || isOnYearView) {\n        <div class=\"fd-calendar__action\" aria-live=\"polite\">\n            <button\n                fd-button\n                fdType=\"transparent\"\n                [attr.aria-labelledby]=\"_yearsRangeButtonLabelId + ' ' + _selectYearsRangeButtonAriaLabelId\"\n                (click)=\"_processViewChange('aggregatedYear', $event)\"\n                type=\"button\"\n            >\n                <span [attr.id]=\"_yearsRangeButtonLabelId\">{{ selectAggregatedYearLabel }}</span>\n            </button>\n        </div>\n    }\n    <div class=\"fd-calendar__action fd-calendar__action--arrow-right\">\n        <button\n            fd-button\n            fdType=\"transparent\"\n            glyph=\"slim-arrow-right\"\n            [attr.id]=\"_nextButtonId\"\n            [disabled]=\"nextButtonDisabled\"\n            [attr.title]=\"nextAriaLabel | fdTranslate\"\n            [ariaLabel]=\"nextAriaLabel | fdTranslate\"\n            (click)=\"nextClicked.emit()\"\n            type=\"button\"\n        ></button>\n    </div>\n</header>\n<!-- Hidden elements for aria purposes -->\n<div hidden aria-hidden=\"true\">\n    <div [attr.id]=\"_selectMonthButtonAriaLabelId\">{{ selectMonthAriaLabel | fdTranslate }}</div>\n    <div [attr.id]=\"_selectYearButtonAriaLabelId\">{{ 'coreCalendar.yearSelectionLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_selectYearsRangeButtonAriaLabelId\">{{ selectAggregatedYearAriaLabel | fdTranslate }}</div>\n</div>\n", styles: [""], dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-calendar-header', encapsulation: ViewEncapsulation.None, host: {
                        '[attr.id]': 'viewId'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, imports: [ButtonComponent, FdTranslatePipe], template: "<header class=\"fd-calendar__navigation\" [class.fd-calendar__navigation--main]=\"mobileLandscape\">\n    <div class=\"fd-calendar__action fd-calendar__action--arrow-left\">\n        <button\n            #prevButton\n            fd-button\n            fdType=\"transparent\"\n            glyph=\"slim-arrow-left\"\n            [attr.id]=\"_prevButtonId\"\n            [disabled]=\"previousButtonDisabled\"\n            [attr.title]=\"previousAriaLabel | fdTranslate\"\n            [ariaLabel]=\"previousAriaLabel | fdTranslate\"\n            type=\"button\"\n            (click)=\"previousClicked.emit()\"\n        ></button>\n    </div>\n    @if (isOnDayView || isOnMonthView) {\n        @if (!isOnMonthView) {\n            <div class=\"fd-calendar__action\">\n                <!-- Select month button -->\n                <button\n                    fd-button\n                    type=\"button\"\n                    fdType=\"transparent\"\n                    [attr.aria-labelledby]=\"_monthButtonLabelId + ' ' + _selectMonthButtonAriaLabelId\"\n                    [attr.data-fd-calendar-month]=\"currentlyDisplayed.month\"\n                    (click)=\"_processViewChange('month', $event)\"\n                >\n                    <span [attr.id]=\"_monthButtonLabelId\">{{ selectMonthLabel }}</span>\n                </button>\n            </div>\n        }\n        <div class=\"fd-calendar__action\">\n            <!-- Select year button -->\n            <button\n                fd-button\n                type=\"button\"\n                fdType=\"transparent\"\n                [attr.aria-labelledby]=\"_yearButtonLabelId + ' ' + _selectYearButtonAriaLabelId\"\n                [attr.data-fd-calendar-year]=\"currentlyDisplayed.year\"\n                (click)=\"_processViewChange('year', $event)\"\n            >\n                <span [attr.id]=\"_yearButtonLabelId\">{{ selectYearLabel }}</span>\n            </button>\n        </div>\n    }\n    @if (isOnAggregatedYearsView || isOnYearView) {\n        <div class=\"fd-calendar__action\" aria-live=\"polite\">\n            <button\n                fd-button\n                fdType=\"transparent\"\n                [attr.aria-labelledby]=\"_yearsRangeButtonLabelId + ' ' + _selectYearsRangeButtonAriaLabelId\"\n                (click)=\"_processViewChange('aggregatedYear', $event)\"\n                type=\"button\"\n            >\n                <span [attr.id]=\"_yearsRangeButtonLabelId\">{{ selectAggregatedYearLabel }}</span>\n            </button>\n        </div>\n    }\n    <div class=\"fd-calendar__action fd-calendar__action--arrow-right\">\n        <button\n            fd-button\n            fdType=\"transparent\"\n            glyph=\"slim-arrow-right\"\n            [attr.id]=\"_nextButtonId\"\n            [disabled]=\"nextButtonDisabled\"\n            [attr.title]=\"nextAriaLabel | fdTranslate\"\n            [ariaLabel]=\"nextAriaLabel | fdTranslate\"\n            (click)=\"nextClicked.emit()\"\n            type=\"button\"\n        ></button>\n    </div>\n</header>\n<!-- Hidden elements for aria purposes -->\n<div hidden aria-hidden=\"true\">\n    <div [attr.id]=\"_selectMonthButtonAriaLabelId\">{{ selectMonthAriaLabel | fdTranslate }}</div>\n    <div [attr.id]=\"_selectYearButtonAriaLabelId\">{{ 'coreCalendar.yearSelectionLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_selectYearsRangeButtonAriaLabelId\">{{ selectAggregatedYearAriaLabel | fdTranslate }}</div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: CalendarService }, { type: i2.DatetimeAdapter }], propDecorators: { activeView: [{
                type: Input
            }], currentlyDisplayed: [{
                type: Input
            }], previousButtonDisabled: [{
                type: Input
            }], nextButtonDisabled: [{
                type: Input
            }], calendarYearGrid: [{
                type: Input
            }], id: [{
                type: Input
            }], mobileLandscape: [{
                type: Input
            }], activeViewChange: [{
                type: Output
            }], previousClicked: [{
                type: Output
            }], nextClicked: [{
                type: Output
            }], _prevButtonComponent: [{
                type: ViewChild,
                args: ['prevButton', { read: ElementRef }]
            }] } });

class CalendarLegendFocusingService {
    constructor() {
        /** Subject to emit the focused element */
        this.focusedLegendItemSubject$ = new Subject();
    }
    /** Clearing the focused element */
    clearFocusedElement() {
        this.focusedLegendItemSubject$.next({ legendId: null, specialDayNumber: null });
    }
    /** Setting the elements that are getting currently focused */
    _handleLegendItemFocus(legendId, specialDayNumber) {
        this.focusedLegendItemSubject$.next({ legendId, specialDayNumber });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarLegendFocusingService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarLegendFocusingService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarLegendFocusingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class CalendarLegendItemComponent {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /** The text of the legend item */
        this.text = input();
        /** The color of the legend item marker */
        this.color = input();
        /** If the marker is a circle or a square */
        this.circle = input();
        /** @hidden */
        this.class = input('');
    }
    /** @hidden */
    buildComponentCssClass() {
        return [`fd-calendar-legend__item ${this.class()} ${this.getAppointmentClass()} ${this.getColorClass()}`];
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    getAppointmentClass() {
        return this.circle() ? `fd-calendar-legend__item--appointment` : '';
    }
    /** @hidden */
    getColorClass() {
        return this.color() ? `fd-calendar-legend__item--${this.color()}` : '';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarLegendItemComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "20.0.2", type: CalendarLegendItemComponent, isStandalone: true, selector: "fd-calendar-legend-item", inputs: { text: { classPropertyName: "text", publicName: "text", isSignal: true, isRequired: false, transformFunction: null }, color: { classPropertyName: "color", publicName: "color", isSignal: true, isRequired: false, transformFunction: null }, circle: { classPropertyName: "circle", publicName: "circle", isSignal: true, isRequired: false, transformFunction: null }, class: { classPropertyName: "class", publicName: "class", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "tabindex": "0" } }, usesOnChanges: true, ngImport: i0, template: `
        <span class="fd-calendar-legend__marker"></span>
        <span class="fd-calendar-legend__text">
            <ng-content>{{ text() }}</ng-content>
        </span>
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CalendarLegendItemComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarLegendItemComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-calendar-legend-item',
                    standalone: true,
                    imports: [],
                    encapsulation: ViewEncapsulation.None,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    template: `
        <span class="fd-calendar-legend__marker"></span>
        <span class="fd-calendar-legend__text">
            <ng-content>{{ text() }}</ng-content>
        </span>
    `,
                    host: {
                        tabindex: '0'
                    }
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CalendarLegendComponent {
    constructor(datetimeAdapter, focusingService) {
        this.datetimeAdapter = datetimeAdapter;
        this.focusingService = focusingService;
        /** The unique identifier of the calendar legend. This is a required property. */
        this.legendId = input.required();
        /**
         * Make it a column instead
         */
        this.col = input(false);
        /** Whether to display the legend item for today's date. */
        this.displayTodayLegendItem = input(true);
        /** Whether to display the legend item for the currently selected date. */
        this.displaySelectedLegendItem = input(true);
        /** Whether to display the legend item for work days. */
        this.displayWorkDayLegendItem = input(true);
        /** Whether to display the legend item for non-work days. */
        this.displayNonWorkDayLegendItem = input(true);
        /**
         * Special days rules to be displayed in the legend
         */
        this.specialDaysRules = input([]);
    }
    /** @hidden */
    _handleFocusedElementEvent(specialDayNumber) {
        this.focusingService._handleLegendItemFocus(this.legendId(), specialDayNumber);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarLegendComponent, deps: [{ token: i2.DatetimeAdapter }, { token: CalendarLegendFocusingService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CalendarLegendComponent, isStandalone: true, selector: "fd-calendar-legend", inputs: { legendId: { classPropertyName: "legendId", publicName: "legendId", isSignal: true, isRequired: true, transformFunction: null }, col: { classPropertyName: "col", publicName: "col", isSignal: true, isRequired: false, transformFunction: null }, displayTodayLegendItem: { classPropertyName: "displayTodayLegendItem", publicName: "displayTodayLegendItem", isSignal: true, isRequired: false, transformFunction: null }, displaySelectedLegendItem: { classPropertyName: "displaySelectedLegendItem", publicName: "displaySelectedLegendItem", isSignal: true, isRequired: false, transformFunction: null }, displayWorkDayLegendItem: { classPropertyName: "displayWorkDayLegendItem", publicName: "displayWorkDayLegendItem", isSignal: true, isRequired: false, transformFunction: null }, displayNonWorkDayLegendItem: { classPropertyName: "displayNonWorkDayLegendItem", publicName: "displayNonWorkDayLegendItem", isSignal: true, isRequired: false, transformFunction: null }, specialDaysRules: { classPropertyName: "specialDaysRules", publicName: "specialDaysRules", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "class.fd-calendar-legend--auto-column": "col()" }, classAttribute: "fd-calendar-legend" }, ngImport: i0, template: `
        <ng-content></ng-content>
        <ng-container>
            <div fdkFocusableList>
                @if (displayTodayLegendItem()) {
                    <fd-calendar-legend-item
                        fdkFocusableItem
                        class="fd-calendar-legend__item--today"
                        [text]="'coreCalendar.todayLabel' | fdTranslate"
                        (focus)="_handleFocusedElementEvent(null)"
                        (blur)="_handleFocusedElementEvent(null)"
                    ></fd-calendar-legend-item>
                }
                @if (displaySelectedLegendItem()) {
                    <fd-calendar-legend-item
                        fdkFocusableItem
                        class="fd-calendar-legend__item--selected"
                        [text]="'coreCalendar.dateSelectedLabel' | fdTranslate"
                        (focus)="_handleFocusedElementEvent(null)"
                        (blur)="_handleFocusedElementEvent(null)"
                    ></fd-calendar-legend-item>
                }
                @if (displayWorkDayLegendItem()) {
                    <fd-calendar-legend-item
                        fdkFocusableItem
                        class="fd-calendar-legend__item--work"
                        [text]="'coreCalendar.workDayLabel' | fdTranslate"
                        (focus)="_handleFocusedElementEvent(null)"
                        (blur)="_handleFocusedElementEvent(null)"
                    ></fd-calendar-legend-item>
                }
                @if (displayNonWorkDayLegendItem()) {
                    <fd-calendar-legend-item
                        fdkFocusableItem
                        class="fd-calendar-legend__item--non-work"
                        [text]="'coreCalendar.nonWorkDayLabel' | fdTranslate"
                        (focus)="_handleFocusedElementEvent(null)"
                        (blur)="_handleFocusedElementEvent(null)"
                    ></fd-calendar-legend-item>
                }

                @for (rule of specialDaysRules(); track rule.specialDayNumber) {
                    <fd-calendar-legend-item
                        fdkFocusableItem
                        [text]="rule.legendText"
                        [circle]="rule.appointment"
                        [color]="'placeholder-' + rule.specialDayNumber"
                        (focus)="_handleFocusedElementEvent(rule.specialDayNumber)"
                        (blur)="_handleFocusedElementEvent(null)"
                    ></fd-calendar-legend-item>
                }
            </div>
        </ng-container>
    `, isInline: true, dependencies: [{ kind: "component", type: CalendarLegendItemComponent, selector: "fd-calendar-legend-item", inputs: ["text", "color", "circle", "class"] }, { kind: "directive", type: FocusableListDirective, selector: "[fdkFocusableList]", inputs: ["focusable", "navigationDirection", "contentDirection", "wrap", "listFocusedEventAnnouncer"], outputs: ["itemFocused"], exportAs: ["fdkFocusableList"] }, { kind: "directive", type: FocusableItemDirective, selector: "[fdkFocusableItem]", inputs: ["fdkFocusableItem", "cellFocusedEventAnnouncer"], outputs: ["cellFocused"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarLegendComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-calendar-legend',
                    standalone: true,
                    template: `
        <ng-content></ng-content>
        <ng-container>
            <div fdkFocusableList>
                @if (displayTodayLegendItem()) {
                    <fd-calendar-legend-item
                        fdkFocusableItem
                        class="fd-calendar-legend__item--today"
                        [text]="'coreCalendar.todayLabel' | fdTranslate"
                        (focus)="_handleFocusedElementEvent(null)"
                        (blur)="_handleFocusedElementEvent(null)"
                    ></fd-calendar-legend-item>
                }
                @if (displaySelectedLegendItem()) {
                    <fd-calendar-legend-item
                        fdkFocusableItem
                        class="fd-calendar-legend__item--selected"
                        [text]="'coreCalendar.dateSelectedLabel' | fdTranslate"
                        (focus)="_handleFocusedElementEvent(null)"
                        (blur)="_handleFocusedElementEvent(null)"
                    ></fd-calendar-legend-item>
                }
                @if (displayWorkDayLegendItem()) {
                    <fd-calendar-legend-item
                        fdkFocusableItem
                        class="fd-calendar-legend__item--work"
                        [text]="'coreCalendar.workDayLabel' | fdTranslate"
                        (focus)="_handleFocusedElementEvent(null)"
                        (blur)="_handleFocusedElementEvent(null)"
                    ></fd-calendar-legend-item>
                }
                @if (displayNonWorkDayLegendItem()) {
                    <fd-calendar-legend-item
                        fdkFocusableItem
                        class="fd-calendar-legend__item--non-work"
                        [text]="'coreCalendar.nonWorkDayLabel' | fdTranslate"
                        (focus)="_handleFocusedElementEvent(null)"
                        (blur)="_handleFocusedElementEvent(null)"
                    ></fd-calendar-legend-item>
                }

                @for (rule of specialDaysRules(); track rule.specialDayNumber) {
                    <fd-calendar-legend-item
                        fdkFocusableItem
                        [text]="rule.legendText"
                        [circle]="rule.appointment"
                        [color]="'placeholder-' + rule.specialDayNumber"
                        (focus)="_handleFocusedElementEvent(rule.specialDayNumber)"
                        (blur)="_handleFocusedElementEvent(null)"
                    ></fd-calendar-legend-item>
                }
            </div>
        </ng-container>
    `,
                    host: {
                        class: 'fd-calendar-legend',
                        '[class.fd-calendar-legend--auto-column]': 'col()'
                    },
                    imports: [CalendarLegendItemComponent, FocusableListDirective, FocusableItemDirective, FdTranslatePipe]
                }]
        }], ctorParameters: () => [{ type: i2.DatetimeAdapter }, { type: CalendarLegendFocusingService }] });

/**
 * Calendar active cell strategy
 */
class AbstractCalendarActiveCellStrategy {
}
class DefaultCalendarActiveCellStrategy extends AbstractCalendarActiveCellStrategy {
    /**
     * Calculate which table cell should be active
     */
    getActiveCell(cells) {
        const selected = cells.find((cell) => cell.selected);
        if (selected) {
            return selected;
        }
        const current = cells.find((cell) => cell.current);
        if (current) {
            return current;
        }
        return cells[0] || null;
    }
}

class CalendarAggregatedYearViewComponent {
    /**
     * View ID
     */
    get viewId() {
        return this.id + '-years-range-view';
    }
    /**
     * @hidden
     * Today cell label ID
     */
    get _todayLabelId() {
        return this.viewId + '-today-label';
    }
    /**
     * @hidden
     * Selected date label ID
     */
    get _selectedDateLabelId() {
        return this.viewId + '-selected-date-label';
    }
    /** @hidden */
    constructor(_eRef, _changeDetectorRef, _calendarService, _dateTimeAdapter, _dateTimeFormats) {
        this._eRef = _eRef;
        this._changeDetectorRef = _changeDetectorRef;
        this._calendarService = _calendarService;
        this._dateTimeAdapter = _dateTimeAdapter;
        this._dateTimeFormats = _dateTimeFormats;
        /** Event fired when a year is selected. */
        this.yearsClicked = new EventEmitter();
        /**
         * @hidden
         */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._initiated = false;
        // default values
        this._currentYear = _dateTimeAdapter.getYear(_dateTimeAdapter.today());
    }
    /** @hidden */
    ngOnInit() {
        this._initiated = true;
        this._setupKeyboardService();
        this._firstYearInList = this.yearSelected - this._yearsInOnePeriod();
        this._constructYearsGrid();
        this._dateTimeAdapter.localeChanges.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._constructYearsGrid();
            this._changeDetectorRef.markForCheck();
        });
    }
    /** @hidden */
    ngOnChanges(changes) {
        if (this._initiated &&
            ('yearSelected' in changes ||
                'aggregatedYearsViewGrid' in changes ||
                'yearViewGrid' in changes ||
                'id' in changes)) {
            this._constructYearsGrid();
        }
    }
    /** Method that sends the year to the parent component when it is clicked. */
    selectYear(selectedYear, event) {
        if (event) {
            event.stopPropagation();
        }
        this._yearsSelected = selectedYear.years;
        this.yearsClicked.emit(this._yearsSelected);
    }
    /** Method used to load the previous 12 years to be displayed. */
    loadNextYearsList() {
        this._firstYearInList += this._periodsAmount() * this._yearsInOnePeriod();
        this._constructYearsGrid();
    }
    /** Method used to load the next 12 years to be displayed. */
    loadPreviousYearsList() {
        this._firstYearInList -= this._periodsAmount() * this._yearsInOnePeriod();
        this._constructYearsGrid();
    }
    /**
     * Set focus on month cell.
     * It can be a selected cell, current month cell or first cell in the list
     */
    setFocusOnCell() {
        const cellToFocus = new DefaultCalendarActiveCellStrategy().getActiveCell(this._getYearsList());
        if (!cellToFocus?.id) {
            return;
        }
        this._focusElementBySelector(`#${cellToFocus.id}`);
    }
    /** Method for handling the keyboard navigation. */
    _onKeydownYearHandler(event, index) {
        this._calendarService.onKeydownHandler(event, index);
    }
    /**
     * @hidden
     * Method that allows to focus elements inside this component
     */
    _focusElementBySelector(elementSelector) {
        const elementToFocus = this._eRef.nativeElement.querySelector(elementSelector);
        if (elementToFocus?.focus) {
            elementToFocus.focus();
        }
    }
    /**
     * @hidden
     * Method returning index of aggregated year index cell
     */
    _getIndex(rowIndex, colIndex) {
        return this._calendarService.getId(rowIndex, colIndex);
    }
    /**
     * @hidden
     * Get id of calendar's aggregated year item
     */
    _getId(index) {
        return this.viewId + '-aggregated-years-' + index;
    }
    /**
     * @hidden
     * Check if specified year is between start year and end year)
     */
    _isBetween(aggregatedYear, yearToCheck) {
        return aggregatedYear.endYear >= yearToCheck && aggregatedYear.startYear <= yearToCheck;
    }
    /** @hidden */
    _constructYearsGrid() {
        const displayedYearsAmount = this.aggregatedYearsViewGrid.cols * this.aggregatedYearsViewGrid.rows;
        const calendarYearList = [];
        this._calendarYearListGrid = [];
        for (let index = 0; index < displayedYearsAmount; ++index) {
            /**
             * Generates object with certain period of years,
             * which depends on amount of years displayed in year view
             */
            const years = {
                startYear: this._firstYearInList + this._yearsInOnePeriod() * index,
                endYear: this._firstYearInList + this._yearsInOnePeriod() * (index + 1) - 1
            };
            calendarYearList.push({
                years,
                label: this._getYearsName(years),
                ariaLabel: this._getAriaYearsName(years),
                selected: this._isBetween(years, this.yearSelected),
                current: this._isBetween(years, this._currentYear),
                index
            });
        }
        /** Creating 2d grid */
        while (calendarYearList.length) {
            this._calendarYearListGrid.push(calendarYearList.splice(0, this.aggregatedYearsViewGrid.cols));
        }
        const yearsCellSelected = calendarYearList.find((cell) => this._isBetween(cell.years, this.yearSelected));
        this._yearsSelected = yearsCellSelected ? yearsCellSelected.years : null;
        this._activeYear = this._getActiveYear();
        this._calendarYearListGrid.forEach((row, rowIndex) => {
            row.forEach((cell, colIndex) => {
                cell.id = this._getId(this._getIndex(rowIndex, colIndex));
                cell.tabIndex = cell.years === this._activeYear ? 0 : -1;
            });
        });
        this._changeDetectorRef.detectChanges();
    }
    /**
     * @hidden
     * Returns year name as a string.
     */
    _getYearsName(years) {
        const startYearFormatted = this._dateTimeAdapter.getYearName(this._dateTimeAdapter.createDate(years.startYear, 1, 1));
        const endYearFormatted = this._dateTimeAdapter.getYearName(this._dateTimeAdapter.createDate(years.endYear, 1, 1));
        return `${this._getYearString(years.startYear, startYearFormatted)} - ${this._getYearString(years.endYear, endYearFormatted)}`;
    }
    /**
     * @hidden
     * Returns aria year name as a string.
     */
    _getAriaYearsName(years) {
        const startYearFormatted = this._dateTimeAdapter.format(this._dateTimeAdapter.createDate(years.startYear, 1, 1), this._dateTimeFormats.display.yearA11yLabel);
        const endYearFormatted = this._dateTimeAdapter.format(this._dateTimeAdapter.createDate(years.endYear, 1, 1), this._dateTimeFormats.display.yearA11yLabel);
        return `${this._getYearString(years.startYear, startYearFormatted)} - ${this._getYearString(years.endYear, endYearFormatted)}`;
    }
    /**
     * @hidden
     * Returns year name taking into account yearMapping.
     */
    _getYearString(year, defaultStr) {
        if (typeof this.aggregatedYearsViewGrid.yearMapping === 'function') {
            return this.aggregatedYearsViewGrid.yearMapping(year);
        }
        return defaultStr;
    }
    /**
     * @hidden
     * Amount of years displayed in year view
     */
    _yearsInOnePeriod() {
        if (this.yearViewGrid) {
            return this.yearViewGrid.cols * this.yearViewGrid.rows;
        }
        else {
            return 12;
        }
    }
    /**
     * @hidden
     * Amount of years displayed in aggregated year view
     */
    _periodsAmount() {
        return this.aggregatedYearsViewGrid.cols * this.aggregatedYearsViewGrid.rows;
    }
    /**
     * @hidden
     * Method that returns active cell, which means:
     * if there is any selected year, return selected year
     * if there is no selected year, but there is current year, return current year
     * if there is no current year, or selected, return first one
     */
    _getActiveYear() {
        const selectedYearCell = this._getYearsList().find(({ years }) => this._isBetween(years, this.yearSelected));
        if (selectedYearCell) {
            return selectedYearCell.years;
        }
        const currentYearCell = this._getYearsList().find(({ years }) => this._isBetween(years, this._currentYear));
        if (currentYearCell) {
            return currentYearCell.years;
        }
        return this._calendarYearListGrid[0][0].years;
    }
    /**
     * @hidden
     * Returns transformed 1d array from 2d year grid.
     */
    _getYearsList() {
        return [].concat(...this._calendarYearListGrid);
    }
    /**
     * @hidden
     * Method to put configuration and listeners on calendar keyboard service
     */
    _setupKeyboardService() {
        this._calendarService.rowAmount = this.aggregatedYearsViewGrid.rows;
        this._calendarService.colAmount = this.aggregatedYearsViewGrid.cols;
        this._calendarService.focusEscapeFunction = this.focusEscapeFunction;
        this._calendarService.onFocusIdChange.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((index) => {
            this._focusOnCellByIndex(index);
        });
        this._calendarService.onKeySelect
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe(({ index }) => this.selectYear(this._getYearsList()[index]));
        this._calendarService.onListStartApproach.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((index) => {
            this.loadPreviousYearsList();
            this._changeDetectorRef.detectChanges();
            this._focusOnCellByIndex(index);
        });
        this._calendarService.onListEndApproach.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((index) => {
            this.loadNextYearsList();
            this._changeDetectorRef.detectChanges();
            this._focusOnCellByIndex(index);
        });
    }
    /** @hidden */
    _focusOnCellByIndex(index) {
        this._focusElementBySelector(`#${this._getId(index)}`);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarAggregatedYearViewComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: CalendarService }, { token: i2.DatetimeAdapter }, { token: DATE_TIME_FORMATS }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CalendarAggregatedYearViewComponent, isStandalone: true, selector: "fd-calendar-aggregated-year-view", inputs: { id: "id", focusEscapeFunction: "focusEscapeFunction", yearSelected: "yearSelected", aggregatedYearsViewGrid: "aggregatedYearsViewGrid", yearViewGrid: "yearViewGrid" }, outputs: { yearsClicked: "yearsClicked" }, host: { properties: { "attr.id": "viewId" } }, usesOnChanges: true, ngImport: i0, template: "<table\n    class=\"fd-calendar__content fd-calendar__content--years\"\n    role=\"grid\"\n    [attr.aria-roledescription]=\"'coreCalendar.calendarYearsRangeViewDescription' | fdTranslate\"\n>\n    <tbody class=\"fd-calendar__group\" role=\"rowgroup\">\n        @for (colYears of _calendarYearListGrid; track colYears + '' + rowIndex; let rowIndex = $index) {\n            <tr class=\"fd-calendar__row\">\n                @for (cell of colYears; track cell + '' + colIndex; let colIndex = $index) {\n                    <td\n                        class=\"fd-calendar__my-item\"\n                        role=\"gridcell\"\n                        [class.fd-calendar__my-item--current]=\"cell.current\"\n                        [class.is-active]=\"cell.selected\"\n                        [attr.id]=\"cell.id\"\n                        [attr.tabindex]=\"cell.tabIndex\"\n                        [attr.data-fd-calendar-years]=\"cell.years.startYear + '-' + cell.years.endYear\"\n                        (keydown)=\"_onKeydownYearHandler($event, cell.index)\"\n                        (click)=\"selectYear(cell, $event)\"\n                    >\n                        <button\n                            fd-button\n                            fdType=\"transparent\"\n                            class=\"fd-calendar__my-item-button\"\n                            [class.is-active]=\"cell.current\"\n                            tabindex=\"-1\"\n                        >\n                            <span\n                                class=\"fd-calendar__text\"\n                                [attr.aria-labelledby]=\"\n                                    cell.id +\n                                    '-aria-label ' +\n                                    (cell.current ? _todayLabelId + ' ' : '') +\n                                    (cell.selected ? _selectedDateLabelId : '')\n                                \"\n                            >\n                                {{ cell.label }}\n                            </span>\n                        </button>\n                        <span hidden aria-hidden=\"true\" [attr.id]=\"cell.id + '-aria-label'\">\n                            {{ cell.ariaLabel }}\n                        </span>\n                    </td>\n                }\n            </tr>\n        }\n    </tbody>\n</table>\n<!-- Hidden elements for aria purposes -->\n<div hidden aria-hidden=\"true\">\n    <div [attr.id]=\"_todayLabelId\">{{ 'coreCalendar.todayLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_selectedDateLabelId\">{{ 'coreCalendar.dateSelectedLabel' | fdTranslate }}</div>\n</div>\n", styles: [""], dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarAggregatedYearViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-calendar-aggregated-year-view', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        '[attr.id]': 'viewId'
                    }, imports: [ButtonComponent, FdTranslatePipe], template: "<table\n    class=\"fd-calendar__content fd-calendar__content--years\"\n    role=\"grid\"\n    [attr.aria-roledescription]=\"'coreCalendar.calendarYearsRangeViewDescription' | fdTranslate\"\n>\n    <tbody class=\"fd-calendar__group\" role=\"rowgroup\">\n        @for (colYears of _calendarYearListGrid; track colYears + '' + rowIndex; let rowIndex = $index) {\n            <tr class=\"fd-calendar__row\">\n                @for (cell of colYears; track cell + '' + colIndex; let colIndex = $index) {\n                    <td\n                        class=\"fd-calendar__my-item\"\n                        role=\"gridcell\"\n                        [class.fd-calendar__my-item--current]=\"cell.current\"\n                        [class.is-active]=\"cell.selected\"\n                        [attr.id]=\"cell.id\"\n                        [attr.tabindex]=\"cell.tabIndex\"\n                        [attr.data-fd-calendar-years]=\"cell.years.startYear + '-' + cell.years.endYear\"\n                        (keydown)=\"_onKeydownYearHandler($event, cell.index)\"\n                        (click)=\"selectYear(cell, $event)\"\n                    >\n                        <button\n                            fd-button\n                            fdType=\"transparent\"\n                            class=\"fd-calendar__my-item-button\"\n                            [class.is-active]=\"cell.current\"\n                            tabindex=\"-1\"\n                        >\n                            <span\n                                class=\"fd-calendar__text\"\n                                [attr.aria-labelledby]=\"\n                                    cell.id +\n                                    '-aria-label ' +\n                                    (cell.current ? _todayLabelId + ' ' : '') +\n                                    (cell.selected ? _selectedDateLabelId : '')\n                                \"\n                            >\n                                {{ cell.label }}\n                            </span>\n                        </button>\n                        <span hidden aria-hidden=\"true\" [attr.id]=\"cell.id + '-aria-label'\">\n                            {{ cell.ariaLabel }}\n                        </span>\n                    </td>\n                }\n            </tr>\n        }\n    </tbody>\n</table>\n<!-- Hidden elements for aria purposes -->\n<div hidden aria-hidden=\"true\">\n    <div [attr.id]=\"_todayLabelId\">{{ 'coreCalendar.todayLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_selectedDateLabelId\">{{ 'coreCalendar.dateSelectedLabel' | fdTranslate }}</div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: CalendarService }, { type: i2.DatetimeAdapter }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DATE_TIME_FORMATS]
                }] }], propDecorators: { id: [{
                type: Input
            }], focusEscapeFunction: [{
                type: Input
            }], yearSelected: [{
                type: Input
            }], aggregatedYearsViewGrid: [{
                type: Input
            }], yearViewGrid: [{
                type: Input
            }], yearsClicked: [{
                type: Output
            }] } });

/**
 * Active Calendar Day cell strategy
 */
class ActiveCalendarDayCellStrategy extends AbstractCalendarActiveCellStrategy {
    /**
     * Calculate which table cell should be active
     */
    getActiveCell(cells) {
        const selected = cells.find((cell) => cell.selected);
        if (selected) {
            return selected;
        }
        const current = cells.find((cell) => cell.current);
        if (current) {
            return current;
        }
        const fistDayInMonth = cells.find((cell) => cell.monthStatus === 'current');
        if (fistDayInMonth) {
            return fistDayInMonth;
        }
        return cells[0] || null;
    }
}

/** A class representing a range of dates. */
class DateRange {
    /**
     * Date range.
     * @param start
     * @param end
     */
    constructor(
    /** The start date of the range. */
    start, 
    /** The end date of the range. */
    end) {
        this.start = start;
        this.end = end;
    }
}

/** Component representing the day view of the calendar. */
class CalendarDayViewComponent {
    /** Currently displayed month and year for days */
    set currentlyDisplayed(currentlyDisplayed) {
        if (!equal(currentlyDisplayed, this._currentlyDisplayed)) {
            this._currentlyDisplayed = currentlyDisplayed;
            this._buildDayViewGrid();
        }
    }
    get currentlyDisplayed() {
        return this._currentlyDisplayed;
    }
    /** The currently selected date model in single mode. */
    set selectedDate(date) {
        this._selectedDate = date;
        if (this._dayViewGrid) {
            const dayFromDate = this._calendarDayList.find((day) => this._isSameDay(day.date, date));
            this._changeSelectedSingleDay(dayFromDate, this._calendarDayList);
        }
    }
    get selectedDate() {
        return this._selectedDate;
    }
    /** The currently selected date model in multiple mode. */
    set selectedMultipleDates(dates) {
        this._selectedMultipleDates = dates;
        if (dates && this._dayViewGrid) {
            const formattedDates = this._calendarDayList.filter((day) => dates?.some((date) => this._isSameDay(day.date, date)));
            this._changeSelectedMultipleDays(formattedDates, this._calendarDayList);
        }
    }
    get selectedMultipleDates() {
        return this._selectedMultipleDates;
    }
    /** The currently selected FdDates model start and end in range mode. */
    set selectedRangeDate(dateRange) {
        if (dateRange &&
            this.selectedRangeDate &&
            this._isSameDay(dateRange.start, this.selectedRangeDate.start) &&
            this._isSameDay(dateRange.end, this.selectedRangeDate.end)) {
            return;
        }
        this._selectedRangeDate = dateRange;
        if (this._dayViewGrid) {
            this._changeSelectedRangeDays(dateRange, this._calendarDayList);
        }
    }
    get selectedRangeDate() {
        return this._selectedRangeDate;
    }
    /** The currently selected FdDates model start and end in multiple range mode. */
    set selectedMultipleDateRanges(dateRanges) {
        if (dateRanges &&
            this.selectedMultipleDateRanges &&
            dateRanges.length === this.selectedMultipleDateRanges.length &&
            dateRanges.every((range, index) => this._isSameDay(range.start, this.selectedMultipleDateRanges[index].start) &&
                this._isSameDay(range.end, this.selectedMultipleDateRanges[index].end))) {
            return;
        }
        this._selectedMultipleDateRanges = dateRanges || [];
        if (this._dayViewGrid) {
            this._changeSelectedMultipleRangeDays(dateRanges, this._calendarDayList);
        }
    }
    get selectedMultipleDateRanges() {
        return this._selectedMultipleDateRanges;
    }
    /** @hidden */
    constructor(eRef, changeDetRef, calendarService, legendFocusedService, _dateTimeFormats, _dateTimeAdapter) {
        this.eRef = eRef;
        this.changeDetRef = changeDetRef;
        this.calendarService = calendarService;
        this.legendFocusedService = legendFocusedService;
        this._dateTimeFormats = _dateTimeFormats;
        this._dateTimeAdapter = _dateTimeAdapter;
        /** Event emitted always, when next month is selected, by focus */
        this.nextMonthSelect = new EventEmitter();
        /** Event emitted always, when previous month is selected, by focus */
        this.previousMonthSelect = new EventEmitter();
        /** Event thrown every time selected date in single mode is changed */
        this.selectedDateChange = new EventEmitter();
        /** Event thrown every time the selected dates in multiple mode are changed. */
        this.selectedMultipleDatesChange = new EventEmitter();
        /** Event thrown every time selected first or last date in range mode is changed */
        this.selectedRangeDateChange = new EventEmitter();
        /** Event thrown every time the first or last date in multiple range mode is changed. */
        this.selectedMultipleDateRangesChange = new EventEmitter();
        /**
         * Function used to disable certain dates in the calendar.
         * @param date date type
         */
        this.disableFunction = model();
        /**
         * Function used to disable certain dates in the calendar for the range start selection.
         * @param date date representation
         */
        this.disableRangeStartFunction = model();
        /**
         * Function used to disable certain dates in the calendar for the range end selection.
         * @param date date representation
         */
        this.disableRangeEndFunction = model();
        /** The day of the week the calendar should start on. 1 represents Sunday, 2 is Monday, 3 is Tuesday, and so on. */
        this.startingDayOfWeek = model();
        /** The type of calendar, 'single' for single date selection or 'range' for a range of dates. */
        this.calType = model(CalendarTypeEnum.Single);
        /** Id of the calendar. If none is provided, one will be generated. */
        this.id = input();
        /** @hidden Id of the associated legend, passed from the parent calendar component. */
        this.associatedLegendId = input();
        /**
         * Whether user wants to mark day cells on hover.
         * Works only on range mode, when start date is selected.
         */
        this.rangeHoverEffect = model(false);
        /**
         * Whether user wants to mark sunday/saturday with `fd-calendar__item--weekend` class
         */
        this.markWeekends = input(false);
        /**
         * Whether user wants to show week numbers next to days
         */
        this.showWeekNumbers = input(true);
        /**
         * Whether the user wants to select multiple days or multiple range dates.
         * If `displayWeekNumbers` is true, the user can click on the week number to mark the related row.
         * The user can click on week days to mark the related column.
         * Note: Clickable selection for week row or column does not work for range selections.
         */
        this.allowMultipleSelection = model(false);
        /** Function that allows to specify which function would be called, when focus wants to escape */
        this.focusEscapeFunction = input();
        /**
         * Special days mark, it can be used by passing array of object with
         * Special day number, list 1-20 [class:`fd-calendar__item--legend-{{number}}`] is available there:
         * https://sap.github.io/fundamental-styles/components/calendar.html calendar special days section
         * Rule accepts method with date object as a parameter. ex:
         * `rule: (date: D) => this.dateAdapter.getDay(date) === 1`, which will mark all sundays as special day.
         */
        this.specialDaysRules = input([]);
        /**
         * @hidden
         * Array of CSS classes for each week day in calendar header, computed based on whether the calendar type is 'multi'
         * and the date is not disabled.
         */
        this._weekHeaderClasses = [];
        /** @hidden */
        this._selectedMultipleDates = [];
        /** @hidden */
        this._selectedMultipleDateRanges = [];
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /**
         * @hidden
         * Days per week
         */
        this._amountOfCols = 7;
        /** @hidden */
        this._isOnRangePick = false;
        /** @hidden */
        this._isInitiated = false;
        /**
         * @hidden
         * global variable to store the new range.
         */
        this._newRange = null;
    }
    /** @hidden */
    ngOnInit() {
        this._isInitiated = true;
        this._setupKeyboardService();
        this._refreshShortWeekDays();
        this._buildDayViewGrid();
        this._computeWeekHeaderClasses();
        this._dateTimeAdapter.localeChanges.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._refreshShortWeekDays();
            this._buildDayViewGrid();
            this.changeDetRef.markForCheck();
        });
        this.legendFocusedService.focusedLegendItemSubject$
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe(({ legendId, specialDayNumber }) => {
            if (!specialDayNumber) {
                this._legendBlurred();
            }
            else if (legendId !== null && specialDayNumber !== null) {
                this._focusOnLegendsDay(legendId, specialDayNumber);
            }
        });
    }
    /** @hidden */
    ngOnChanges(changes) {
        /** Changes of those properties are done inside its setters */
        if (!changes['selectedDate'] &&
            !changes['selectedMultipleDates'] &&
            !changes['selectedRangeDate'] &&
            !changes['currentlyDisplayed']) {
            this._buildDayViewGrid();
        }
        if (changes['startingDayOfWeek']) {
            this._refreshShortWeekDays();
        }
        if (changes['specialDaysRules']) {
            this._buildDayViewGrid();
        }
    }
    /**
     * @hidden
     * Selects a date in single mode, toggles selection in multi mode, or sets the range in range mode.
     * Handles the selection of a date based on the calendar type.
     * @param day The calendar day to be selected.
     * @param event Optional mouse event for handling event propagation.
     */
    selectDate(day, event) {
        if (event) {
            event.stopPropagation();
            event.preventDefault();
        }
        if (day.disabled || day.blocked) {
            return;
        }
        if (this.allowMultipleSelection()) {
            if (this.calType() === CalendarTypeEnum.Single) {
                this._toggleMultiDate(day);
            }
            else if (this.calType() === CalendarTypeEnum.Range) {
                this._selectMultipleRangeDates(day);
            }
        }
        else {
            if (this.calType() === CalendarTypeEnum.Single) {
                this._selectSingleDate(day);
            }
            else if (this.calType() === CalendarTypeEnum.Range) {
                this._selectRangeDate(day);
            }
        }
        this._handleRangeHoverEffect(event);
        this.changeDetRef.markForCheck();
    }
    /**
     * Toggles the selection of a week on the calendar.
     * If the provided week is already fully selected, it will deselect it.
     * If the provided week is not fully selected, it will select the entire week and clear any previous selections.
     * @param selectedWeek Array of CalendarDay objects representing the week to be toggled.
     */
    handleWeekSelectionByDays(selectedWeek) {
        this.toggleWeekSelection(selectedWeek);
    }
    /**
     * Toggles the selection of a week on the calendar based on the weekday index.
     * If the provided week is already fully selected, it will deselect it.
     * If the provided week is not fully selected, it will select the entire week and clear any previous selections.
     * @param weekDayIndex The index of the weekday to be toggled.
     */
    handleWeekSelectionByIndex(weekDayIndex) {
        const selectedWeek = this._dayViewGrid.map((row) => row[weekDayIndex]);
        this.toggleWeekSelection(selectedWeek);
    }
    /**
     * Set focus on default focusable cell
     */
    setFocusOnCell() {
        const cellToFocus = new ActiveCalendarDayCellStrategy().getActiveCell(this._calendarDayList);
        if (!cellToFocus?.index && cellToFocus?.index !== 0) {
            return;
        }
        this.focusOnCellByIndex(cellToFocus.index);
    }
    /** @hidden */
    _refreshHoverRange(day) {
        if (this.allowMultipleSelection()) {
            this._handleMultiRangeHover(day);
        }
        else {
            this._handleSingleRangeHover(day);
        }
    }
    /**
     * @hidden
     *  Amount of selected days
     *  0, when there is no day selected, or start date is invalid,
     *  1, when there is only valid start date, or end date is same as start date,
     *  2, when both dates are valid
     */
    get _selectCounter() {
        if (!this.selectedRangeDate || !this._dateTimeAdapter.isValid(this.selectedRangeDate.start)) {
            return 0;
        }
        if (this.selectedRangeDate.start &&
            (!this._dateTimeAdapter.isValid(this.selectedRangeDate.end) ||
                this._isSameDay(this.selectedRangeDate.start, this.selectedRangeDate.end))) {
            return 1;
        }
        if (this._dateTimeAdapter.isValid(this.selectedRangeDate.start) &&
            this._dateTimeAdapter.isValid(this.selectedRangeDate.end)) {
            return 2;
        }
        return 0;
    }
    /**
     * @hidden
     * Total amount of selected days across multiple ranges.
     * Sums the counts of valid days in each date range.
     */
    get _selectMultipleCounter() {
        let counter = this._selectedMultipleDateRanges.reduce((count, range) => {
            if (range.start) {
                count++;
            }
            if (range.end) {
                count++;
            }
            return count;
        }, 0);
        // Account for the newRange
        if (this._newRange) {
            if (this._newRange.start) {
                counter++;
            }
            if (this._newRange.end) {
                counter++;
            }
        }
        return counter;
    }
    /**
     * @hidden
     * Method that returns short weekday name.
     * Can be changed by user by providing other class which implements DatetimeAdapter
     */
    get shortWeekDays() {
        return this._shortWeekDays;
    }
    /**
     * @hidden
     * Method that returns weekday name.
     * Can be changed by user by providing other class which implements DatetimeAdapter
     */
    get longWeekDays() {
        return this._longWeekDays;
    }
    /**
     * @hidden
     * Function that gives array of all displayed CalendarDays
     */
    get _calendarDayList() {
        return this._dayViewGrid.reduce((totalCalendarRows, calendarRow) => {
            if (!calendarRow) {
                calendarRow = [];
            }
            return totalCalendarRows.concat(calendarRow);
        }, []);
    }
    /**
     * View ID
     */
    get viewId() {
        return this.id() + '-day-view';
    }
    /**
     * @hidden
     * Week column header ID
     */
    get _weekNumbersColumnHeaderId() {
        return this.viewId + '-week-column-header';
    }
    /**
     * @hidden
     * Today cell label ID
     */
    get _todayLabelId() {
        return this.viewId + '-today-label';
    }
    /**
     * @hidden
     * Selected date label ID
     */
    get _selectedDateLabelId() {
        return this.viewId + '-selected-date-label';
    }
    /**
     * @hidden
     * Date range start date label ID
     */
    get _dateRangeStartLabelId() {
        return this.viewId + '-range-start-date-label';
    }
    /**
     * @hidden
     * Date range end date label ID
     */
    get _dateRangeEndLabelId() {
        return this.viewId + '-range-end-date-label';
    }
    /**
     * @hidden
     * Date in past label ID
     */
    get _dateInPastLabelId() {
        return this.viewId + '-day-in-past-label';
    }
    /**
     * @hidden
     * Method that handles day cells keydown events,
     * @param event KeyboardEvent
     * @param cell CalendarDay
     * @param index with specified column and row as a x and y
     */
    _onKeydownDayHandler(event, cell, index) {
        if (event.key === 'Tab' && !event.shiftKey) {
            if (this.focusEscapeFunction()) {
                this.focusEscapeFunction()(event);
            }
        }
        else {
            this.calendarService.onKeydownHandler(event, index);
        }
    }
    /**
     * @hidden
     *  Method that allow to focus elements inside this component
     */
    _focusElementBySelector(elementSelector) {
        const elementToFocus = this.eRef.nativeElement.querySelector(elementSelector);
        if (elementToFocus?.focus) {
            elementToFocus.focus();
        }
    }
    /**
     * @hidden
     * Standardized method to calculate grid [x][y] to index number of flatten list
     */
    _getIndex(rowIndex, colIndex) {
        return this.calendarService.getId(rowIndex, colIndex);
    }
    /**
     * @hidden
     * Method that selects previous month
     * Triggered only when the month is changed during changing focus
     * Also triggers event to parent calendar component and rebuilds day view grid
     */
    _selectPreviousMonth() {
        this._currentlyDisplayed = this._getPreviousMonth();
        this._buildDayViewGrid();
        this.previousMonthSelect.emit();
    }
    /**
     * @hidden
     * Method that selects next month
     * Triggered only when the month is changed during changing focus
     * Also triggers event to parent calendar component and rebuilds day view grid
     */
    _selectNextMonth() {
        this._currentlyDisplayed = this._getNextMonth();
        this._buildDayViewGrid();
        this.nextMonthSelect.emit();
    }
    /** @hidden */
    _focusOnLegendsDay(legendId, specialDayNumber) {
        const associatedLegendId = this.associatedLegendId();
        if (legendId && associatedLegendId && associatedLegendId === legendId) {
            this._dayViewGrid.forEach((row) => {
                row.forEach((day) => {
                    day.shouldHideSpecialDayMarker = day.specialDayNumber !== specialDayNumber;
                });
            });
            this.changeDetRef.markForCheck();
        }
    }
    /** @hidden */
    _legendBlurred() {
        this._dayViewGrid.forEach((row) => {
            row.forEach((day) => {
                day.shouldHideSpecialDayMarker = false;
            });
        });
        this.changeDetRef.markForCheck();
    }
    /**
     * @hidden
     * Method that creates array of CalendarDay models which will be shown on day grid,
     * depending on current month and year.
     */
    _populateCalendar() {
        let calendar = [];
        calendar = this._getPreviousMonthDays(calendar);
        calendar = calendar.concat(this._getCurrentMonthDays());
        calendar = this._getNextMonthDays(calendar);
        calendar.forEach((call, index) => {
            call.id = this._getCellIdByIndex(index);
            call.index = index;
        });
        if (this.allowMultipleSelection()) {
            if (this.calType() === CalendarTypeEnum.Single && this._selectedMultipleDates) {
                const _days = calendar.filter((day) => this._selectedMultipleDates?.some((date) => this._isSameDay(day.date, date)));
                this._changeSelectedMultipleDays(_days, calendar);
            }
            if (this.calType() === CalendarTypeEnum.Range && this._selectedMultipleDateRanges) {
                this._changeSelectedMultipleRangeDays(this._selectedMultipleDateRanges, calendar);
            }
        }
        else {
            if (this.calType() === CalendarTypeEnum.Single && this._selectedDate) {
                const _day = calendar.find((day) => this._isSameDay(day.date, this._selectedDate));
                this._changeSelectedSingleDay(_day, calendar);
            }
            if (this.calType() === CalendarTypeEnum.Range && this._selectedRangeDate) {
                this._changeSelectedRangeDays(this._selectedRangeDate, calendar);
            }
        }
        return calendar;
    }
    /**
     * @hidden
     * Method that builds 2 dimensions day view grid, also sets up currently displayed month, or year,
     * when there is not any.
     */
    _buildDayViewGrid() {
        if (!this._isInitiated) {
            return;
        }
        if (!this.currentlyDisplayed || this._isInvalidDate()) {
            if (this.selectedDate) {
                this._currentlyDisplayed = {
                    month: this._dateTimeAdapter.getMonth(this.selectedDate),
                    year: this._dateTimeAdapter.getYear(this.selectedDate)
                };
            }
            else {
                const today = this._dateTimeAdapter.today();
                this._currentlyDisplayed = {
                    month: this._dateTimeAdapter.getMonth(today),
                    year: this._dateTimeAdapter.getYear(today)
                };
            }
        }
        const calendarDays = this._populateCalendar();
        const dayViewGrid = [];
        while (calendarDays.length > 0) {
            dayViewGrid.push(calendarDays.splice(0, this._amountOfCols));
        }
        this.calendarService.rowAmount = dayViewGrid.length;
        this._dayViewGrid = dayViewGrid;
        this._weeks = this._refreshWeekCount();
    }
    /** @hidden */
    _isInvalidDate() {
        return isNaN(this.currentlyDisplayed.year) || isNaN(this.currentlyDisplayed.month);
    }
    /**
     * @hidden
     * Get id of calendar's day item
     */
    _getCellIdByIndex(index) {
        return this.viewId + '-day-' + index + '';
    }
    /**
     * @hidden
     * Method which provides array of CalendarDay,
     * which contains every single day of currently shown month/year.
     */
    _getCurrentMonthDays() {
        const month = this.currentlyDisplayed.month;
        const year = this.currentlyDisplayed.year;
        const calendarDays = [];
        const amountOfDaysInCurrentMonth = this._dateTimeAdapter.getNumDaysInMonth(this._dateTimeAdapter.createDate(year, month, 1));
        const now = this._dateTimeAdapter.now();
        for (let dayNumber = 1; dayNumber <= amountOfDaysInCurrentMonth; dayNumber++) {
            const date = this._dateTimeAdapter.createDate(year, month, dayNumber);
            calendarDays.push({
                ...this._getDay(date),
                monthStatus: 'current',
                current: this._isSameDay(now, date)
            });
        }
        const cell = this._getActiveCell(calendarDays);
        cell && (cell.isTabIndexed = true);
        return calendarDays;
    }
    /**
     * @hidden
     * Method that returns active cell, which means:
     * if there is any selected day, return selected day
     * if there is no selected day, but there is today day, return today day
     * if there is no today, or selected, return first one
     */
    _getActiveCell(calendarDays) {
        return new ActiveCalendarDayCellStrategy().getActiveCell(calendarDays);
    }
    /**
     * @hidden
     * Method which provides array of CalendarDay,
     * which contains last 0-6 days of previous month/year. Theses days
     * fills the gap between starting startingDayOfWeek and first day of current month
     */
    _getPreviousMonthDays(calendarDays) {
        const month = this.currentlyDisplayed.month > 1 ? this.currentlyDisplayed.month - 1 : 12;
        const year = this.currentlyDisplayed.month > 1 ? this.currentlyDisplayed.year : this.currentlyDisplayed.year - 1;
        const amountOfDaysInCurrentMonth = this._dateTimeAdapter.getNumDaysInMonth(this._dateTimeAdapter.createDate(year, month, 1));
        const prevMonthLastDate = this._dateTimeAdapter.createDate(year, month, amountOfDaysInCurrentMonth);
        const prevMonthLastDay = amountOfDaysInCurrentMonth;
        let prevMonthLastWeekDay = this._dateTimeAdapter.getDayOfWeek(prevMonthLastDate) - this.startingDayOfWeek();
        /** Checking if there are some days cut by startingDayOfWeek option
         *  If yes, there is whole week added, to avoid hiding
         */
        if (prevMonthLastWeekDay < 0) {
            prevMonthLastWeekDay = prevMonthLastWeekDay + 7;
        }
        if (prevMonthLastWeekDay < 6) {
            while (prevMonthLastWeekDay >= 0) {
                const prevMonthDay = prevMonthLastDay - prevMonthLastWeekDay;
                const date = this._dateTimeAdapter.createDate(year, month, prevMonthDay);
                calendarDays.push({ ...this._getDay(date), monthStatus: 'previous' });
                prevMonthLastWeekDay--;
            }
        }
        return calendarDays;
    }
    /**
     * @hidden
     * Method which provides array of CalendarDay, which contains first days of next month/year. Theses days
     * fills the gap between last day of current day and end of 6-weeks calendar grid.
     */
    _getNextMonthDays(calendarDays) {
        const month = this.currentlyDisplayed.month < 12 ? this.currentlyDisplayed.month + 1 : 1;
        const year = this.currentlyDisplayed.month < 12 ? this.currentlyDisplayed.year : this.currentlyDisplayed.year + 1;
        // The calendar grid can have 5 (35 days) or 6 (42 days) weeks
        const nextMonthDisplayedDays = (42 - calendarDays.length) % 7;
        for (let nextD = 1; nextD <= nextMonthDisplayedDays; nextD++) {
            const date = this._dateTimeAdapter.createDate(year, month, nextD);
            calendarDays.push({ ...this._getDay(date), monthStatus: 'next' });
        }
        return calendarDays;
    }
    /** @hidden */
    _isWeekendDay(dayOfWeek) {
        return dayOfWeek === 1 || dayOfWeek === 7;
    }
    /**
     * @hidden
     * Method that generates whole day model basing on date, disabling functions, block functions, and actually
     * chosen range / single date.
     */
    _getDay(date) {
        const weekDay = this._dateTimeAdapter.getDayOfWeek(date);
        const dayOfMonth = this._dateTimeAdapter.getDate(date);
        const dateNames = this._dateTimeAdapter.getDateNames();
        const isPast = this._dateTimeAdapter.compareDate(date, this._dateTimeAdapter.today()) < 0;
        const day = {
            date,
            label: dateNames[dayOfMonth - 1],
            weekDay,
            weekend: this._isWeekendDay(weekDay),
            ariaLabel: this._dateTimeAdapter.format(date, this._dateTimeFormats.display.dateA11yLabel),
            specialDayNumber: this._getSpecialDay(date) ?? undefined,
            past: isPast
        };
        /** Apply disabled state to days marked with passed function */
        if (this.disableFunction()) {
            day.disabled = this.disableFunction()(date);
        }
        return day;
    }
    /**
     * @hidden
     * Method that is called to refresh i18n short week days.
     */
    _refreshShortWeekDays() {
        const shortDayOfWeekNames = this._dateTimeAdapter.getDayOfWeekNames('short');
        const dayOfWeekNames = this._dateTimeAdapter.getDayOfWeekNames('long');
        this._shortWeekDays = shortDayOfWeekNames
            .slice(this.startingDayOfWeek() - 1)
            .concat(shortDayOfWeekNames.slice(0, this.startingDayOfWeek() - 1));
        this._longWeekDays = dayOfWeekNames
            .slice(this.startingDayOfWeek() - 1)
            .concat(dayOfWeekNames.slice(0, this.startingDayOfWeek() - 1));
        this.changeDetRef.markForCheck();
    }
    /**
     * @hidden
     * Gets special day number of specified date model
     */
    _getSpecialDay(date) {
        const specialDay = this.specialDaysRules().find((specialDayRule) => specialDayRule.rule(date));
        if (specialDay) {
            return specialDay.specialDayNumber;
        }
        return null;
    }
    /**
     * @hidden
     * Method that returns array of week's count
     */
    _refreshWeekCount() {
        const calendarDayList = this._calendarDayList;
        const weekNumbers = [];
        for (let index = 6; index < calendarDayList.length; index = index + 6) {
            weekNumbers.push(this._dateTimeAdapter.getWeekName(calendarDayList[index].date));
        }
        return weekNumbers;
    }
    /**
     * @hidden
     * Get year and month for previous year
     */
    _getPreviousMonth() {
        if (this._currentlyDisplayed.month > 1) {
            return { year: this._currentlyDisplayed.year, month: this._currentlyDisplayed.month - 1 };
        }
        else {
            return { year: this._currentlyDisplayed.year - 1, month: 12 };
        }
    }
    /**
     * @hidden
     * Get year and month for next year
     */
    _getNextMonth() {
        if (this._currentlyDisplayed.month < 12) {
            return { year: this._currentlyDisplayed.year, month: this._currentlyDisplayed.month + 1 };
        }
        else {
            return { year: this._currentlyDisplayed.year + 1, month: 1 };
        }
    }
    /**
     * @hidden
     * Method to put configuration and listeners on calendar keyboard service
     */
    _setupKeyboardService() {
        this.calendarService.colAmount = this._amountOfCols;
        this.calendarService.focusEscapeFunction = this.focusEscapeFunction();
        this.calendarService.onFocusIdChange.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((index) => {
            this._refreshHoverRange(this._calendarDayList[index]);
            this.focusOnCellByIndex(index);
        });
        this.calendarService.onKeySelect.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(({ index, event }) => {
            this.selectDate(this._calendarDayList[index], event);
        });
        this.calendarService.onListStartApproach.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((index) => {
            this._selectPreviousMonth();
            /**
             * Calculate focused cell in new grid
             */
            const originalMonth = this._getNextMonth(); // month that was before moving back
            const originalAmountOfWeeks = this._dateTimeAdapter.getAmountOfWeeks(originalMonth.year, originalMonth.month, this.startingDayOfWeek());
            const prevMonthAmountOfWeeks = this._dateTimeAdapter.getAmountOfWeeks(this._currentlyDisplayed.year, this._currentlyDisplayed.month, this.startingDayOfWeek());
            // trigger rendering for new grid so focus can be set
            this.changeDetRef.detectChanges();
            this.focusOnCellByIndex(index - 7 * (originalAmountOfWeeks - prevMonthAmountOfWeeks));
        });
        this.calendarService.onListEndApproach.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((index) => {
            this._selectNextMonth();
            // trigger rendering for new grid so focus can be set
            this.changeDetRef.detectChanges();
            this.focusOnCellByIndex(index);
        });
    }
    /**
     * @hidden
     * Change selection flag on days to false, besides the selected one
     */
    _changeSelectedSingleDay(day, calendar) {
        calendar.forEach((_day) => (_day.selected = false));
        if (day && !day.blocked && !day.disabled) {
            day.selected = true;
        }
        this.refreshTabIndex(calendar);
    }
    /**
     * @hidden
     * Change selection flag on days to false, besides the selected one
     *
     * @param dates - An array of CalendarDay objects to be marked as selected
     * @param calendar - The calendar array containing all CalendarDay objects
     */
    _changeSelectedMultipleDays(dates, calendar) {
        calendar.forEach((day) => (day.selected = false));
        if (dates) {
            dates.forEach((date) => {
                const matchingDay = calendar.find((day) => this._isSameDay(day.date, date.date));
                if (matchingDay && !matchingDay.blocked && !matchingDay.disabled) {
                    matchingDay.selected = true;
                }
            });
        }
        this.refreshTabIndex(calendar);
    }
    /**
     * @hidden
     * Change properties of range days, this method is called, to not rebuild whole grid from scratch,
     * it just changes properties of newly selected/unselected days.
     */
    _changeSelectedRangeDays(dates, calendar) {
        /** Pull list of calendar days */
        const calendarList = calendar;
        /** Reset changing properties */
        calendarList.forEach((_day) => (_day.selectedFirst =
            _day.selectedLast =
                _day.selected =
                    _day.isTabIndexed =
                        _day.disabled =
                            _day.hoverRange =
                                _day.selectedRange =
                                    false));
        if (dates) {
            let startDay;
            let endDay;
            if (dates.start) {
                /** Find start date and mark it as selected */
                startDay = calendarList.find((_day) => this._isSameDay(_day.date, dates.start));
                if (startDay &&
                    !startDay.blocked &&
                    !startDay.disabled &&
                    (typeof this.disableRangeStartFunction() !== 'function' ||
                        !this.disableRangeStartFunction()?.(startDay.date))) {
                    startDay.selected = true;
                    startDay.selectedFirst = true;
                }
            }
            if (dates.end) {
                /** Find end date and mark it as selected */
                endDay = calendarList.find((_day) => this._isSameDay(_day.date, dates.end));
                if (endDay &&
                    !endDay.blocked &&
                    !endDay.disabled &&
                    (typeof this.disableRangeEndFunction() !== 'function' ||
                        !this.disableRangeEndFunction()?.(endDay.date))) {
                    endDay.selected = true;
                    endDay.selectedLast = true;
                }
            }
            /** Verify if start day and end day is valid, otherwise don't put range selection */
            if (dates.start && dates.end) {
                /** Mark all days, which are between start and end date */
                calendarList
                    .filter((_day) => (_day.selectedRange = this._dateTimeAdapter.isBetween(_day.date, dates.start, dates.end)))
                    .forEach((_day) => (_day.selectedRange = true));
            }
        }
        this.refreshTabIndex(calendarList);
        /** Apply disabled state to days marked with passed function */
        if (this.disableFunction()) {
            calendarList.forEach((_day) => (_day.disabled = this.disableFunction()(_day.date)));
        }
        if ((this._selectCounter === 0 || this._selectCounter === 2) && this.disableRangeStartFunction()) {
            calendarList.forEach((_day) => (_day.disabled = _day.disabled || this.disableRangeStartFunction()(_day.date)));
        }
        else if (this._selectCounter === 1 && this.disableRangeEndFunction()) {
            calendarList.forEach((_day) => (_day.disabled = _day.disabled || this.disableRangeEndFunction()(_day.date)));
        }
    }
    /**
     * @hidden
     * Change properties of range days for multiple ranges.
     * This method is called to not rebuild the whole grid from scratch.
     * It just changes properties of newly selected/unselected days.
     */
    _changeSelectedMultipleRangeDays(datesArray, calendar) {
        // Reset changing properties
        calendar.forEach((_day) => {
            _day.selectedFirst = false;
            _day.selectedLast = false;
            _day.selectedRange = false;
            _day.selected = false;
            _day.isTabIndexed = false;
            _day.disabled = false;
            _day.hoverRange = false;
            _day.disabled = false;
        });
        datesArray.forEach((dates) => {
            if (dates) {
                let startDay;
                let endDay;
                if (dates.start) {
                    // Find start date and mark it as selected
                    startDay = calendar.find((_day) => this._isSameDay(_day.date, dates.start));
                    if (startDay) {
                        startDay.selectedFirst = true;
                        startDay.selected = true;
                    }
                }
                if (dates.end) {
                    // Find end date and mark it as selected
                    endDay = calendar.find((_day) => this._isSameDay(_day.date, dates.end));
                    if (endDay) {
                        endDay.selectedLast = true;
                        endDay.selected = true;
                    }
                }
                // Mark all days between start and end as selected range
                if (dates.start && dates.end) {
                    calendar.forEach((_day) => {
                        if (this._isDateInRange(_day.date, dates)) {
                            _day.selectedRange = true;
                            _day.selected = true;
                        }
                    });
                }
            }
        });
        this.refreshTabIndex(calendar);
        // Apply disabled state to days marked with passed function
        if (this.disableFunction()) {
            calendar.forEach((_day) => (_day.disabled = this.disableFunction()(_day.date)));
        }
        if ((this._selectMultipleCounter === 0 || this._selectMultipleCounter % 2 === 0) &&
            this.disableRangeStartFunction()) {
            calendar.forEach((_day) => (_day.disabled = _day.disabled || this.disableRangeStartFunction()(_day.date)));
        }
        else if (this._selectMultipleCounter % 2 === 1 && this.disableRangeEndFunction()) {
            calendar.forEach((_day) => (_day.disabled = _day.disabled || this.disableRangeEndFunction()(_day.date)));
        }
    }
    /** @hidden */
    refreshTabIndex(calendar) {
        calendar.forEach((_day) => (_day.isTabIndexed = false));
        const cell = this._getActiveCell(calendar.filter((_day) => _day.monthStatus === 'current'));
        cell && (cell.isTabIndexed = true);
    }
    /** @hidden */
    focusOnCellByIndex(index) {
        this._focusElementBySelector(`#${this._getCellIdByIndex(index)}`);
    }
    /**
     * @hidden
     * Check if dates are equal
     */
    _isSameDay(date1, date2) {
        return this._dateTimeAdapter.datesEqual(date1, date2);
    }
    /**
     * @hidden
     * Selects a single date and updates the selected date in single mode.
     * @param day The calendar day to be selected.
     */
    _selectSingleDate(day) {
        this._calendarDayList.forEach((_day) => (_day.selected = false));
        day.selected = true;
        this._selectedDate = day.date;
        this.selectedDateChange.emit(day.date);
    }
    /**
     * @hidden
     * Toggles the selection of a date in multi mode.
     * Adds the date if not selected, removes it if already selected.
     * @param day The calendar day to be toggled.
     */
    _toggleMultiDate(day) {
        const dateIndex = this._selectedMultipleDates.findIndex((d) => this._isSameDay(d, day.date));
        let newSelectedDates;
        if (dateIndex > -1) {
            newSelectedDates = this._selectedMultipleDates.filter((_, index) => index !== dateIndex);
            day.selected = false;
        }
        else {
            newSelectedDates = [...this._selectedMultipleDates, day.date];
            day.selected = true;
        }
        this._selectedMultipleDates = newSelectedDates;
        this.selectedMultipleDatesChange.emit(this._selectedMultipleDates);
    }
    /**
     * @hidden
     * Selects or updates the range of dates in range mode.
     * Handles the start and end dates and updates the selected range.
     * @param day The calendar day to be selected or updated in the range.
     */
    _selectRangeDate(day) {
        if (this._selectCounter === 0 || this._selectCounter === 2) {
            this._selectedRangeDate = { start: day.date, end: null };
            this.selectedRangeDateChange.emit(this.selectedRangeDate);
        }
        else if (this._selectCounter === 1) {
            this._selectedRangeDate = this._getOrderedRange(this.selectedRangeDate.start, day.date);
            this.selectedRangeDateChange.emit(this.selectedRangeDate);
        }
        this._changeSelectedRangeDays(this._selectedRangeDate, this._calendarDayList);
    }
    /**
     * @hidden
     * Selects or updates multiple ranges of dates in range mode.
     * Handles the start and end dates and updates the selected ranges.
     * @param day The calendar day to be selected or updated in the range.
     */
    _selectMultipleRangeDates(day) {
        let tempRanges = this._selectedMultipleDateRanges?.filter((range) => range.start || range.end) || [];
        // Handles the existing range by updating or merging it with the new day selection.
        tempRanges = this._handleExistingRange(tempRanges, day);
        if (this._selectMultipleCounter % 2 === 0) {
            // Start a new range
            this._newRange = { start: day.date, end: null };
        }
        else {
            // Check for reverse selection
            if (this._newRange &&
                this._newRange.start &&
                this._dateTimeAdapter.compareDate(this._newRange.start, day.date) > 0) {
                this._newRange = { start: day.date, end: this._newRange.start };
            }
            else if (this._newRange) {
                this._newRange.end = day.date;
            }
            if (this._newRange) {
                tempRanges.push(this._newRange);
            }
            this._newRange = null;
        }
        tempRanges = this._mergeOverlappingRanges(tempRanges);
        this._selectedMultipleDateRanges = tempRanges;
        // Check if all ranges have both start and end dates filled
        const allRangesComplete = this._selectedMultipleDateRanges.every((range) => range.start && range.end);
        if (allRangesComplete && tempRanges.length > 0) {
            this.selectedMultipleDateRangesChange.emit(this._selectedMultipleDateRanges);
        }
        // Update the calendar view
        this._changeSelectedMultipleRangeDays(this._selectedMultipleDateRanges, this._calendarDayList);
    }
    /**
     * Merges overlapping date ranges into a single range.
     *
     * @param ranges - An array of date ranges to be merged.
     * @returns An array of merged date ranges.
     */
    _mergeOverlappingRanges(ranges) {
        if (ranges.length <= 1) {
            return ranges;
        }
        ranges.sort((a, b) => this._dateTimeAdapter.compareDate(a.start, b.start));
        const mergedRanges = [];
        let currentRange = ranges[0];
        for (let i = 1; i < ranges.length; i++) {
            const nextRange = ranges[i];
            if (this._dateTimeAdapter.compareDate(currentRange.end, nextRange.start) >= 0) {
                currentRange = {
                    start: currentRange.start,
                    end: this._dateTimeAdapter.compareDate(currentRange.end, nextRange.end) >= 0
                        ? currentRange.end
                        : nextRange.end
                };
            }
            else {
                mergedRanges.push(currentRange);
                currentRange = nextRange;
            }
        }
        mergedRanges.push(currentRange);
        return mergedRanges;
    }
    /**
     * Handles the case where the selected day is part of an existing range.
     *
     * @param tempRanges - An array of date ranges to be checked.
     * @param day - The calendar day to be checked.
     * @returns An array of date ranges with the updated range if the selected day is part of an existing range.
     */
    _handleExistingRange(tempRanges, day) {
        if (tempRanges.length > 0) {
            const existingRangeIndex = tempRanges.findIndex((range) => this._isDateInRange(day.date, range));
            const existingRange = tempRanges[existingRangeIndex];
            if (existingRangeIndex !== -1 && existingRange.end) {
                tempRanges.splice(existingRangeIndex, 1);
            }
        }
        return tempRanges;
    }
    /**
     * @hidden
     * Checks if a date is within a given date range.
     * @param date The date to check.
     * @param range The date range.
     * @returns True if the date is in the range, false otherwise.
     */
    _isDateInRange(date, range) {
        return this._dateTimeAdapter.isBetween(date, range.start, range.end);
    }
    /**
     * @hidden
     * Orders the start and end dates for the range selection.
     * Ensures the start date is before or equal to the end date.
     * @param date1 The first date.
     * @param date2 The second date.
     * @returns An object containing the ordered start and end dates.
     */
    _getOrderedRange(date1, date2) {
        return this._dateTimeAdapter.compareDate(date1, date2) < 0
            ? { start: date1, end: date2 }
            : { start: date2, end: date1 };
    }
    /**
     * @hidden
     * Handles the hover effect for range selection.
     * Toggles the hover effect based on the selection state and event.
     * @param event Optional mouse event for handling hover effect.
     */
    _handleRangeHoverEffect(event) {
        if (this.allowMultipleSelection()) {
            if (this.calType() === CalendarTypeEnum.Range &&
                this.rangeHoverEffect() &&
                this._selectMultipleCounter === 1 &&
                event) {
                this._isOnRangePick = !this._isOnRangePick;
            }
            else {
                this._isOnRangePick = false;
            }
        }
        else {
            if (this.calType() === CalendarTypeEnum.Range &&
                this.rangeHoverEffect() &&
                this._selectCounter === 1 &&
                event) {
                this._isOnRangePick = !this._isOnRangePick;
            }
            else {
                this._isOnRangePick = false;
            }
        }
    }
    /**
     * Helper method to toggle the selection of a week.
     * @param selectedWeek Array of CalendarDay objects representing the week to be toggled.
     */
    toggleWeekSelection(selectedWeek) {
        const selectableDays = selectedWeek.filter((day) => !day.disabled);
        const isCurrentWeekSelected = selectableDays.every((day) => day.selected);
        if (!isCurrentWeekSelected) {
            selectedWeek.forEach((day) => {
                if (!day.disabled) {
                    day.selected = true;
                    if (!this._selectedMultipleDates.some((selectedDate) => this._isSameDay(selectedDate, day.date))) {
                        this._selectedMultipleDates.push(day.date);
                    }
                }
            });
        }
        else {
            selectedWeek.forEach((day) => {
                if (!day.disabled) {
                    day.selected = false;
                    this._selectedMultipleDates = this._selectedMultipleDates.filter((selectedDate) => !this._isSameDay(selectedDate, day.date));
                }
            });
        }
        this.selectedMultipleDatesChange.emit(this._selectedMultipleDates);
    }
    /**
     * @hidden
     * Computes the CSS class for each week day in calendar header based on whether the calendar type is 'multi'
     * and the date is not disabled.
     * Stores the computed classes in the weekHeaderClasses array.
     */
    _computeWeekHeaderClasses() {
        this._weekHeaderClasses = this._calendarDayList.map(() => this.calType() !== CalendarTypeEnum.Range && this.allowMultipleSelection() && this.disableFunction()
            ? 'event-enabled'
            : '');
    }
    /**
     * @hidden
     * Handles hover effect for single-range selection mode.
     * @param day The calendar day that is hovered.
     */
    _handleSingleRangeHover(day) {
        // Handle single range hover
        const start = this.selectedRangeDate?.start;
        if (this._isOnRangePick && start) {
            if (this._dateTimeAdapter.compareDate(day.date, start) < 0) {
                this._calendarDayList.forEach((_day) => {
                    _day.hoverRange =
                        this._dateTimeAdapter.compareDate(_day.date, day.date) > 0 &&
                            this._dateTimeAdapter.compareDate(_day.date, start) < 0;
                });
            }
            else {
                this._calendarDayList.forEach((_day) => {
                    _day.hoverRange =
                        this._dateTimeAdapter.compareDate(_day.date, day.date) < 0 &&
                            this._dateTimeAdapter.compareDate(_day.date, start) > 0;
                });
            }
        }
    }
    /**
     * @hidden
     * Handles hover effect for multi-range selection mode.
     * @param day The calendar day that is hovered.
     */
    _handleMultiRangeHover(day) {
        // Determine the start date from the most recent range with a null end date
        let startDate = this._newRange?.start;
        if (this._selectedMultipleDateRanges.length > 0) {
            // Find the most recent range with an end date of null
            const activeRanges = this._selectedMultipleDateRanges.filter((range) => range.end === null);
            if (activeRanges.length > 0) {
                const mostRecentRange = activeRanges[activeRanges.length - 1];
                startDate = mostRecentRange.start;
            }
        }
        if (startDate && startDate) {
            if (this._dateTimeAdapter.compareDate(day.date, startDate) < 0) {
                // Hovering backwards from the start date to the selected date
                this._calendarDayList.forEach((_day) => {
                    _day.hoverRange =
                        this._dateTimeAdapter.compareDate(_day.date, day.date) > 0 &&
                            this._dateTimeAdapter.compareDate(_day.date, startDate) < 0;
                });
            }
            else {
                // Hovering forwards from the start date to the selected date
                this._calendarDayList.forEach((_day) => {
                    _day.hoverRange =
                        this._dateTimeAdapter.compareDate(_day.date, day.date) < 0 &&
                            this._dateTimeAdapter.compareDate(_day.date, startDate) > 0;
                });
            }
        }
        else {
            // No start date, clear hover
            this._calendarDayList.forEach((_day) => {
                _day.hoverRange = false;
            });
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarDayViewComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: CalendarService }, { token: CalendarLegendFocusingService }, { token: DATE_TIME_FORMATS }, { token: i2.DatetimeAdapter }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CalendarDayViewComponent, isStandalone: true, selector: "fd-calendar-day-view", inputs: { currentlyDisplayed: { classPropertyName: "currentlyDisplayed", publicName: "currentlyDisplayed", isSignal: false, isRequired: false, transformFunction: null }, selectedDate: { classPropertyName: "selectedDate", publicName: "selectedDate", isSignal: false, isRequired: false, transformFunction: null }, selectedMultipleDates: { classPropertyName: "selectedMultipleDates", publicName: "selectedMultipleDates", isSignal: false, isRequired: false, transformFunction: null }, selectedRangeDate: { classPropertyName: "selectedRangeDate", publicName: "selectedRangeDate", isSignal: false, isRequired: false, transformFunction: null }, selectedMultipleDateRanges: { classPropertyName: "selectedMultipleDateRanges", publicName: "selectedMultipleDateRanges", isSignal: false, isRequired: false, transformFunction: null }, disableFunction: { classPropertyName: "disableFunction", publicName: "disableFunction", isSignal: true, isRequired: false, transformFunction: null }, disableRangeStartFunction: { classPropertyName: "disableRangeStartFunction", publicName: "disableRangeStartFunction", isSignal: true, isRequired: false, transformFunction: null }, disableRangeEndFunction: { classPropertyName: "disableRangeEndFunction", publicName: "disableRangeEndFunction", isSignal: true, isRequired: false, transformFunction: null }, startingDayOfWeek: { classPropertyName: "startingDayOfWeek", publicName: "startingDayOfWeek", isSignal: true, isRequired: false, transformFunction: null }, calType: { classPropertyName: "calType", publicName: "calType", isSignal: true, isRequired: false, transformFunction: null }, id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null }, associatedLegendId: { classPropertyName: "associatedLegendId", publicName: "associatedLegendId", isSignal: true, isRequired: false, transformFunction: null }, rangeHoverEffect: { classPropertyName: "rangeHoverEffect", publicName: "rangeHoverEffect", isSignal: true, isRequired: false, transformFunction: null }, markWeekends: { classPropertyName: "markWeekends", publicName: "markWeekends", isSignal: true, isRequired: false, transformFunction: null }, showWeekNumbers: { classPropertyName: "showWeekNumbers", publicName: "showWeekNumbers", isSignal: true, isRequired: false, transformFunction: null }, allowMultipleSelection: { classPropertyName: "allowMultipleSelection", publicName: "allowMultipleSelection", isSignal: true, isRequired: false, transformFunction: null }, focusEscapeFunction: { classPropertyName: "focusEscapeFunction", publicName: "focusEscapeFunction", isSignal: true, isRequired: false, transformFunction: null }, specialDaysRules: { classPropertyName: "specialDaysRules", publicName: "specialDaysRules", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { nextMonthSelect: "nextMonthSelect", previousMonthSelect: "previousMonthSelect", selectedDateChange: "selectedDateChange", selectedMultipleDatesChange: "selectedMultipleDatesChange", selectedRangeDateChange: "selectedRangeDateChange", selectedMultipleDateRangesChange: "selectedMultipleDateRangesChange", disableFunction: "disableFunctionChange", disableRangeStartFunction: "disableRangeStartFunctionChange", disableRangeEndFunction: "disableRangeEndFunctionChange", startingDayOfWeek: "startingDayOfWeekChange", calType: "calTypeChange", rangeHoverEffect: "rangeHoverEffectChange", allowMultipleSelection: "allowMultipleSelectionChange" }, host: { properties: { "attr.id": "viewId" }, classAttribute: "fd-calendar__dates" }, usesOnChanges: true, ngImport: i0, template: "<table\n    class=\"fd-calendar__content fd-calendar__content--dates\"\n    role=\"grid\"\n    [attr.aria-roledescription]=\"'coreCalendar.calendarDayViewDescription' | fdTranslate\"\n>\n    <thead class=\"fd-calendar__group\" role=\"rowgroup\">\n        <tr class=\"fd-calendar__row\" role=\"row\">\n            @if (showWeekNumbers()) {\n                <th\n                    class=\"fd-calendar__item fd-calendar__item--side-helper\"\n                    role=\"columnheader\"\n                    [attr.id]=\"_weekNumbersColumnHeaderId\"\n                    [attr.aria-label]=\"'coreCalendar.weekColumnLabel' | fdTranslate\"\n                ></th>\n            }\n            @for (day of shortWeekDays; track day + '' + i; let i = $index) {\n                <th\n                    class=\"fd-calendar__item fd-calendar__item--side-helper\"\n                    [ngClass]=\"_weekHeaderClasses[i]\"\n                    role=\"columnheader\"\n                    [attr.aria-label]=\"longWeekDays[i]\"\n                    (click)=\"handleWeekSelectionByIndex(i)\"\n                >\n                    <div class=\"fd-calendar__text-wrapper\">\n                        <span class=\"fd-calendar__text\">{{ day }}</span>\n                    </div>\n                </th>\n            }\n        </tr>\n    </thead>\n    <tbody class=\"fd-calendar__group\" role=\"rowgroup\">\n        @for (row of _dayViewGrid; track row + '' + rowIndex; let rowIndex = $index) {\n            <tr class=\"fd-calendar__row\" role=\"row\">\n                @if (showWeekNumbers()) {\n                    <th\n                        class=\"fd-calendar__item fd-calendar__item--side-helper\"\n                        [ngClass]=\"{ 'event-enabled': allowMultipleSelection() && calType() !== 'range' }\"\n                        role=\"rowheader\"\n                        scope=\"row\"\n                        [attr.data-fd-calendar-week]=\"_weeks[rowIndex]\"\n                        [attr.id]=\"viewId + '-week-' + _weeks[rowIndex]\"\n                        [attr.aria-labelledby]=\"\n                            _weekNumbersColumnHeaderId + ' ' + (viewId + '-week-' + _weeks[rowIndex])\n                        \"\n                        (click)=\"handleWeekSelectionByDays(row)\"\n                    >\n                        @if (_weeks && _weeks[rowIndex]) {\n                            <div class=\"fd-calendar__text-wrapper\">\n                                <span class=\"fd-calendar__text\">\n                                    {{ _weeks[rowIndex] }}\n                                </span>\n                            </div>\n                        }\n                    </th>\n                }\n                @for (cell of row; track cell + '' + cellIndex; let cellIndex = $index) {\n                    <td\n                        class=\"fd-calendar__item\"\n                        role=\"gridcell\"\n                        [class.fd-calendar__item--selected]=\"cell.selectedFirst || cell.selectedLast || cell.selected\"\n                        [class.fd-calendar__item--range]=\"\n                            (cell.selectedRange || cell.hoverRange) && !cell.selectedFirst && !cell.selectedLast\n                        \"\n                        [class.fd-calendar__item--today]=\"cell.current\"\n                        [class.fd-calendar__item--weekend]=\"\n                            cell.weekend && markWeekends() && cell.monthStatus === 'current'\n                        \"\n                        [class.fd-calendar__item--other]=\"cell.monthStatus !== 'current'\"\n                        [class.is-disabled]=\"cell.disabled\"\n                        [class]=\"\n                            cell.specialDayNumber && !cell.shouldHideSpecialDayMarker\n                                ? 'fd-calendar__item--legend-' + cell.specialDayNumber\n                                : ''\n                        \"\n                        [attr.id]=\"cell.id\"\n                        [attr.data-fd-calendar-date-day]=\"cell.label\"\n                        [attr.data-fd-calendar-day]=\"cell.index\"\n                        [attr.aria-selected]=\"cell.selected\"\n                        [attr.aria-disabled]=\"cell.disabled\"\n                        [attr.tabindex]=\"cell.isTabIndexed ? 0 : -1\"\n                        (click)=\"selectDate(cell, $event)\"\n                        (mouseenter)=\"_refreshHoverRange(cell)\"\n                        (keydown)=\"_onKeydownDayHandler($event, cell, _getIndex(rowIndex, cellIndex))\"\n                    >\n                        <div class=\"fd-calendar__text-wrapper\">\n                            <span\n                                class=\"fd-calendar__text\"\n                                role=\"button\"\n                                [attr.aria-labelledby]=\"\n                                    cell.id +\n                                    '-aria-label ' +\n                                    (cell.selectedFirst ? _dateRangeStartLabelId + ' ' : '') +\n                                    (cell.selectedLast ? _dateRangeEndLabelId + ' ' : '') +\n                                    (cell.current ? _todayLabelId + ' ' : '') +\n                                    (cell.selected && calType() === 'single' ? _selectedDateLabelId + ' ' : '') +\n                                    (cell.past ? _dateInPastLabelId : '')\n                                \"\n                                >{{ cell.label }}</span\n                            >\n                            <span hidden aria-hidden=\"true\" [attr.id]=\"cell.id + '-aria-label'\">\n                                {{ cell.ariaLabel }}\n                            </span>\n                        </div>\n                    </td>\n                }\n            </tr>\n        }\n        @if (_dayViewGrid.length <= 5) {\n            <tr class=\"fd-calendar__row\">\n                <td class=\"fd-calendar__item hidden-day\"></td>\n            </tr>\n        }\n        @if (_dayViewGrid.length === 4) {\n            <tr class=\"fd-calendar__row\">\n                <td class=\"fd-calendar__item hidden-day\"></td>\n            </tr>\n        }\n    </tbody>\n</table>\n<!-- Hidden elements for aria purposes -->\n<div hidden aria-hidden=\"true\">\n    <div [attr.id]=\"_todayLabelId\">{{ 'coreCalendar.todayLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_selectedDateLabelId\">{{ 'coreCalendar.dateSelectedLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_dateRangeStartLabelId\">{{ 'coreCalendar.rangeStartLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_dateRangeEndLabelId\">{{ 'coreCalendar.rangeEndLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_dateInPastLabelId\">{{ 'coreCalendar.dayInPastLabel' | fdTranslate }}</div>\n</div>\n", styles: [".hidden-day{visibility:hidden}.event-enabled{pointer-events:auto}\n"], dependencies: [{ kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }, { kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarDayViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-calendar-day-view', encapsulation: ViewEncapsulation.None, host: {
                        '[attr.id]': 'viewId',
                        class: 'fd-calendar__dates'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, imports: [FdTranslatePipe, NgClass], template: "<table\n    class=\"fd-calendar__content fd-calendar__content--dates\"\n    role=\"grid\"\n    [attr.aria-roledescription]=\"'coreCalendar.calendarDayViewDescription' | fdTranslate\"\n>\n    <thead class=\"fd-calendar__group\" role=\"rowgroup\">\n        <tr class=\"fd-calendar__row\" role=\"row\">\n            @if (showWeekNumbers()) {\n                <th\n                    class=\"fd-calendar__item fd-calendar__item--side-helper\"\n                    role=\"columnheader\"\n                    [attr.id]=\"_weekNumbersColumnHeaderId\"\n                    [attr.aria-label]=\"'coreCalendar.weekColumnLabel' | fdTranslate\"\n                ></th>\n            }\n            @for (day of shortWeekDays; track day + '' + i; let i = $index) {\n                <th\n                    class=\"fd-calendar__item fd-calendar__item--side-helper\"\n                    [ngClass]=\"_weekHeaderClasses[i]\"\n                    role=\"columnheader\"\n                    [attr.aria-label]=\"longWeekDays[i]\"\n                    (click)=\"handleWeekSelectionByIndex(i)\"\n                >\n                    <div class=\"fd-calendar__text-wrapper\">\n                        <span class=\"fd-calendar__text\">{{ day }}</span>\n                    </div>\n                </th>\n            }\n        </tr>\n    </thead>\n    <tbody class=\"fd-calendar__group\" role=\"rowgroup\">\n        @for (row of _dayViewGrid; track row + '' + rowIndex; let rowIndex = $index) {\n            <tr class=\"fd-calendar__row\" role=\"row\">\n                @if (showWeekNumbers()) {\n                    <th\n                        class=\"fd-calendar__item fd-calendar__item--side-helper\"\n                        [ngClass]=\"{ 'event-enabled': allowMultipleSelection() && calType() !== 'range' }\"\n                        role=\"rowheader\"\n                        scope=\"row\"\n                        [attr.data-fd-calendar-week]=\"_weeks[rowIndex]\"\n                        [attr.id]=\"viewId + '-week-' + _weeks[rowIndex]\"\n                        [attr.aria-labelledby]=\"\n                            _weekNumbersColumnHeaderId + ' ' + (viewId + '-week-' + _weeks[rowIndex])\n                        \"\n                        (click)=\"handleWeekSelectionByDays(row)\"\n                    >\n                        @if (_weeks && _weeks[rowIndex]) {\n                            <div class=\"fd-calendar__text-wrapper\">\n                                <span class=\"fd-calendar__text\">\n                                    {{ _weeks[rowIndex] }}\n                                </span>\n                            </div>\n                        }\n                    </th>\n                }\n                @for (cell of row; track cell + '' + cellIndex; let cellIndex = $index) {\n                    <td\n                        class=\"fd-calendar__item\"\n                        role=\"gridcell\"\n                        [class.fd-calendar__item--selected]=\"cell.selectedFirst || cell.selectedLast || cell.selected\"\n                        [class.fd-calendar__item--range]=\"\n                            (cell.selectedRange || cell.hoverRange) && !cell.selectedFirst && !cell.selectedLast\n                        \"\n                        [class.fd-calendar__item--today]=\"cell.current\"\n                        [class.fd-calendar__item--weekend]=\"\n                            cell.weekend && markWeekends() && cell.monthStatus === 'current'\n                        \"\n                        [class.fd-calendar__item--other]=\"cell.monthStatus !== 'current'\"\n                        [class.is-disabled]=\"cell.disabled\"\n                        [class]=\"\n                            cell.specialDayNumber && !cell.shouldHideSpecialDayMarker\n                                ? 'fd-calendar__item--legend-' + cell.specialDayNumber\n                                : ''\n                        \"\n                        [attr.id]=\"cell.id\"\n                        [attr.data-fd-calendar-date-day]=\"cell.label\"\n                        [attr.data-fd-calendar-day]=\"cell.index\"\n                        [attr.aria-selected]=\"cell.selected\"\n                        [attr.aria-disabled]=\"cell.disabled\"\n                        [attr.tabindex]=\"cell.isTabIndexed ? 0 : -1\"\n                        (click)=\"selectDate(cell, $event)\"\n                        (mouseenter)=\"_refreshHoverRange(cell)\"\n                        (keydown)=\"_onKeydownDayHandler($event, cell, _getIndex(rowIndex, cellIndex))\"\n                    >\n                        <div class=\"fd-calendar__text-wrapper\">\n                            <span\n                                class=\"fd-calendar__text\"\n                                role=\"button\"\n                                [attr.aria-labelledby]=\"\n                                    cell.id +\n                                    '-aria-label ' +\n                                    (cell.selectedFirst ? _dateRangeStartLabelId + ' ' : '') +\n                                    (cell.selectedLast ? _dateRangeEndLabelId + ' ' : '') +\n                                    (cell.current ? _todayLabelId + ' ' : '') +\n                                    (cell.selected && calType() === 'single' ? _selectedDateLabelId + ' ' : '') +\n                                    (cell.past ? _dateInPastLabelId : '')\n                                \"\n                                >{{ cell.label }}</span\n                            >\n                            <span hidden aria-hidden=\"true\" [attr.id]=\"cell.id + '-aria-label'\">\n                                {{ cell.ariaLabel }}\n                            </span>\n                        </div>\n                    </td>\n                }\n            </tr>\n        }\n        @if (_dayViewGrid.length <= 5) {\n            <tr class=\"fd-calendar__row\">\n                <td class=\"fd-calendar__item hidden-day\"></td>\n            </tr>\n        }\n        @if (_dayViewGrid.length === 4) {\n            <tr class=\"fd-calendar__row\">\n                <td class=\"fd-calendar__item hidden-day\"></td>\n            </tr>\n        }\n    </tbody>\n</table>\n<!-- Hidden elements for aria purposes -->\n<div hidden aria-hidden=\"true\">\n    <div [attr.id]=\"_todayLabelId\">{{ 'coreCalendar.todayLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_selectedDateLabelId\">{{ 'coreCalendar.dateSelectedLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_dateRangeStartLabelId\">{{ 'coreCalendar.rangeStartLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_dateRangeEndLabelId\">{{ 'coreCalendar.rangeEndLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_dateInPastLabelId\">{{ 'coreCalendar.dayInPastLabel' | fdTranslate }}</div>\n</div>\n", styles: [".hidden-day{visibility:hidden}.event-enabled{pointer-events:auto}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: CalendarService }, { type: CalendarLegendFocusingService }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DATE_TIME_FORMATS]
                }] }, { type: i2.DatetimeAdapter }], propDecorators: { currentlyDisplayed: [{
                type: Input
            }], selectedDate: [{
                type: Input
            }], selectedMultipleDates: [{
                type: Input
            }], selectedRangeDate: [{
                type: Input
            }], selectedMultipleDateRanges: [{
                type: Input
            }], nextMonthSelect: [{
                type: Output
            }], previousMonthSelect: [{
                type: Output
            }], selectedDateChange: [{
                type: Output
            }], selectedMultipleDatesChange: [{
                type: Output
            }], selectedRangeDateChange: [{
                type: Output
            }], selectedMultipleDateRangesChange: [{
                type: Output
            }] } });

/** Component representing the month view of the calendar. */
class CalendarMonthViewComponent {
    /** @hidden */
    constructor(_eRef, _changeDetectorRef, _calendarService, _dateTimeFormats, _dateTimeAdapter) {
        this._eRef = _eRef;
        this._changeDetectorRef = _changeDetectorRef;
        this._calendarService = _calendarService;
        this._dateTimeFormats = _dateTimeFormats;
        this._dateTimeAdapter = _dateTimeAdapter;
        /** An event fired when a new month is selected */
        this.monthClicked = new EventEmitter();
        /** Event thrown every time selected first or last date in range mode is changed */
        this.selectedRangeDateChange = new EventEmitter();
        /**
         * Whether user wants to mark month cells on hover.
         * Works only on range mode, when start month is selected.
         */
        this.rangeHoverEffect = false;
        /**
         * @hidden
         * A number offset used to achieve the 1-12 representation of the calendar
         */
        this._monthOffset = 1;
        /** @hidden */
        this._amountOfColPerRow = 3;
        /** @hidden */
        this._amountOfRows = 4;
        /**
         * @hidden
         */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._initiated = false;
        this._isOnRangePick = false;
    }
    /** @hidden */
    ngOnInit() {
        this._initiated = true;
        this._setupKeyboardService();
        this._constructMonthGrid();
        this._dateTimeAdapter.localeChanges.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._constructMonthGrid();
            this._changeDetectorRef.markForCheck();
        });
    }
    /** @hidden */
    ngOnChanges(changes) {
        if (this._initiated && ('monthSelected' in changes || 'year' in changes || 'id' in changes)) {
            this._constructMonthGrid();
        }
    }
    /** Get a number (1-12) representing the current month  */
    get currentMonth() {
        return this._dateTimeAdapter.getMonth(this._dateTimeAdapter.today());
    }
    /**  Getter for the private class member _monthOffset */
    get monthOffset() {
        return this._monthOffset;
    }
    /** View ID */
    get viewId() {
        return this.id + '-month-view';
    }
    /**
     * @hidden
     * Today cell label ID
     */
    get _todayLabelId() {
        return this.viewId + '-today-label';
    }
    /**
     * @hidden
     * Selected date label ID
     */
    get _selectedDateLabelId() {
        return this.viewId + '-selected-date-label';
    }
    /** The currently selected FdDates model start and end in range mode. */
    set selectedRangeDate(dateRange) {
        if (dateRange &&
            this.selectedRangeDate &&
            this._isSameDate(dateRange.start, this.selectedRangeDate.start) &&
            this._isSameDate(dateRange.end, this.selectedRangeDate.end)) {
            return;
        }
        this._selectedRangeDate = dateRange;
        if (this._calendarMonthListGrid) {
            this._changeSelectedRangeMonths(dateRange, this._getMonthList());
        }
    }
    get selectedRangeDate() {
        return this._selectedRangeDate;
    }
    /**
     * @hidden
     *  Amount of selected months
     *  0, when there is no month selected, or start month is invalid,
     *  1, when there is only valid start month, or end month is same as start month,
     *  2, when both dates are valid
     */
    get _selectCounter() {
        if (!this.selectedRangeDate || !this._dateTimeAdapter.isValid(this.selectedRangeDate.start)) {
            return 0;
        }
        if (this.selectedRangeDate.start &&
            (!this._dateTimeAdapter.isValid(this.selectedRangeDate.end) ||
                this._isSameDate(this.selectedRangeDate.start, this.selectedRangeDate.end))) {
            return 1;
        }
        if (this._dateTimeAdapter.isValid(this.selectedRangeDate.start) &&
            this._dateTimeAdapter.isValid(this.selectedRangeDate.end)) {
            return 2;
        }
        return 0;
    }
    /**
     * @hidden
     * Method for handling the keyboard events (a11y)
     */
    _onKeydownMonthHandler(event, index) {
        this._calendarService.onKeydownHandler(event, index);
    }
    /**
     * @hidden
     * Method that allows to focus elements inside this component
     */
    _focusElementBySelector(elementSelector) {
        const elementToFocus = this._eRef.nativeElement.querySelector(elementSelector);
        if (elementToFocus?.focus) {
            elementToFocus.focus();
        }
    }
    /**
     * @hidden
     * Method returning id of month cell
     */
    _getIndex(rowIndex, colIndex) {
        return this._calendarService.getId(rowIndex, colIndex);
    }
    /**
     * @hidden
     * @param index month grid cell index
     */
    _getId(index) {
        return this.viewId + '-month-' + index;
    }
    /**
     * @hidden
     * Method that checks if this is current month
     */
    _isCurrent(id) {
        return id + this._monthOffset === this.currentMonth;
    }
    /**
     * @hidden
     * Method that check if this is selected month
     */
    _isSelected(id) {
        return id + this._monthOffset === this.monthSelected;
    }
    /** Method for handling the mouse click event when a month is selected  */
    selectMonth(monthCell, event) {
        if (event) {
            event.stopPropagation();
            event.preventDefault();
        }
        this.monthSelected = monthCell.month;
        this.monthClicked.emit(this.monthSelected);
        // when date range start date is selected start the hover effect between the date range
        if (this.isDateRangeMonthYearFormat) {
            this._selectRangeDate(monthCell);
            this._handleRangeHoverEffect(event);
        }
    }
    /**
     * Set focus on month cell.
     * It can be a selected cell, current month cell or first cell in the list
     */
    setFocusOnCell() {
        const cellToFocus = new DefaultCalendarActiveCellStrategy().getActiveCell(this._getMonthList());
        if (!cellToFocus?.id) {
            return;
        }
        this._focusElementBySelector(`#${cellToFocus.id}`);
    }
    /**
     * @hidden
     * Handles hover effect for range selection mode.
     * @param month The calendar month that is hovered.
     */
    _handleRangeHover(month) {
        // Handle range hover
        const start = this.selectedRangeDate?.start;
        if (this._isOnRangePick && start) {
            if (this._dateTimeAdapter.compareDate(month.date, start) < 0) {
                this._getMonthList().forEach((_month) => {
                    _month.hoverRange =
                        this._dateTimeAdapter.compareDate(_month.date, month.date) > 0 &&
                            this._dateTimeAdapter.compareDate(_month.date, start) < 0;
                });
            }
            else {
                this._getMonthList().forEach((_month) => {
                    _month.hoverRange =
                        this._dateTimeAdapter.compareDate(_month.date, month.date) < 0 &&
                            this._dateTimeAdapter.compareDate(_month.date, start) > 0;
                });
            }
        }
    }
    /**
     * @hidden
     * Handles the hover effect for range selection.
     * Toggles the hover effect based on the selection state and event.
     * @param event Optional mouse event for handling hover effect.
     */
    _handleRangeHoverEffect(event) {
        if (this.isDateRangeMonthYearFormat && this.rangeHoverEffect && this._selectCounter === 1 && event) {
            this._isOnRangePick = !this._isOnRangePick;
        }
        else {
            this._isOnRangePick = false;
        }
    }
    /**
     * @hidden
     * Selects or updates the range of dates in range mode.
     * Handles the start and end dates and updates the selected range.
     * @param month The calendar month to be selected or updated in the range.
     */
    _selectRangeDate(month) {
        if (this._selectCounter === 0 || this._selectCounter === 2) {
            this._selectedRangeDate = { start: month.date, end: null };
            this.selectedRangeDateChange.emit(this.selectedRangeDate);
        }
        else if (this._selectCounter === 1) {
            this._selectedRangeDate = this._getOrderedRange(this.selectedRangeDate.start, month.date);
            this.selectedRangeDateChange.emit(this.selectedRangeDate);
        }
        this._changeSelectedRangeMonths(this._selectedRangeDate, this._getMonthList());
    }
    /**
     * @hidden
     * Orders the start and end dates for the range selection.
     * Ensures the start date is before or equal to the end date.
     * @param date1 The first date.
     * @param date2 The second date.
     * @returns An object containing the ordered start and end dates.
     */
    _getOrderedRange(date1, date2) {
        return this._dateTimeAdapter.compareDate(date1, date2) < 0
            ? { start: date1, end: date2 }
            : { start: date2, end: date1 };
    }
    /**
     * @hidden
     * Change properties of range months, this method is called, to not rebuild whole grid from scratch,
     * it just changes properties of newly selected/unselected months.
     */
    _changeSelectedRangeMonths(dates, calendar) {
        /** Pull list of calendar month */
        const calendarList = calendar;
        /** Reset changing properties */
        calendarList.forEach((_month) => (_month.selectedFirst =
            _month.selectedLast =
                _month.selected =
                    _month.disabled =
                        _month.hoverRange =
                            _month.selectedRange =
                                false));
        if (dates) {
            let startMonth;
            let endMonth;
            if (dates.start) {
                /** Find start month and mark it as selected */
                startMonth = calendarList.find((_month) => this._isSameDate(_month.date, dates.start));
                if (startMonth) {
                    startMonth.selected = true;
                    startMonth.selectedFirst = true;
                }
            }
            if (dates.end) {
                /** Find end month and mark it as selected */
                endMonth = calendarList.find((_month) => this._isSameDate(_month.date, dates.end));
                if (endMonth) {
                    endMonth.selected = true;
                    endMonth.selectedLast = true;
                }
            }
            /** Verify if start month and end month is valid, otherwise don't put range selection */
            if (dates.start && dates.end) {
                /** Mark all months, which are between start and end date */
                calendarList
                    .filter((_month) => (_month.selectedRange = this._dateTimeAdapter.isBetween(_month.date, dates.start, dates.end)))
                    .forEach((_month) => (_month.selectedRange = true));
            }
        }
    }
    /**
     * @hidden
     * Check if dates are equal
     */
    _isSameDate(date1, date2) {
        return this._dateTimeAdapter.datesEqual(date1, date2);
    }
    /**
     * @hidden
     * Method that create month grid with required meta data
     */
    _constructMonthGrid() {
        const monthNames = this.isDateRangeMonthYearFormat
            ? this._dateTimeAdapter.getMonthNames('long')
            : this._dateTimeAdapter.getMonthNames('short');
        const monthList = monthNames.map((monthName, index) => {
            const month = index + this.monthOffset;
            return {
                date: this._dateTimeAdapter.createDate(this.year, month),
                month,
                label: monthName,
                ariaLabel: this._dateTimeAdapter.format(this._dateTimeAdapter.createDate(this.year, month, 1), this._dateTimeFormats.display.monthA11yLabel),
                index,
                selected: month === this.monthSelected,
                current: month === this.currentMonth,
                tabIndex: month === this.monthSelected ? 0 : -1
            };
        });
        // if the date range is selected
        if (this.isDateRangeMonthYearFormat) {
            this._changeSelectedRangeMonths(this._selectedRangeDate, monthList);
        }
        this._calendarMonthListGrid = [];
        /** Creating 2d grid */
        while (monthList.length) {
            this._calendarMonthListGrid.push(monthList.splice(0, this._amountOfColPerRow));
        }
        this._calendarMonthListGrid.forEach((row, rowIndex) => {
            row.forEach((monthCell, colIndex) => {
                monthCell.id = this._getId(this._getIndex(rowIndex, colIndex));
            });
        });
        this._changeDetectorRef.markForCheck();
    }
    /**
     * @hidden
     * Method to put configuration and listeners on calendar keyboard service
     */
    _setupKeyboardService() {
        this._calendarService.rowAmount = this._amountOfRows;
        this._calendarService.colAmount = this._amountOfColPerRow;
        this._calendarService.focusEscapeFunction = this.focusEscapeFunction;
        this._calendarService.onFocusIdChange.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((index) => {
            this._handleRangeHover(this._getMonthList()[index]);
            this._focusOnCellByIndex(index);
        });
        this._calendarService.onKeySelect
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe(({ index, event }) => this.selectMonth(this._getMonthList()[index], event));
    }
    /**
     * @hidden
     * Returns transformed 1d array from 2d month grid.
     */
    _getMonthList() {
        return [].concat(...this._calendarMonthListGrid);
    }
    /** @hidden */
    _focusOnCellByIndex(index) {
        this._focusElementBySelector(`#${this._getId(index)}`);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarMonthViewComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: CalendarService }, { token: DATE_TIME_FORMATS }, { token: i2.DatetimeAdapter }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CalendarMonthViewComponent, isStandalone: true, selector: "fd-calendar-month-view", inputs: { id: "id", monthSelected: "monthSelected", focusEscapeFunction: "focusEscapeFunction", year: "year", isDateRangeMonthYearFormat: "isDateRangeMonthYearFormat", rangeHoverEffect: "rangeHoverEffect", selectedRangeDate: "selectedRangeDate" }, outputs: { monthClicked: "monthClicked", selectedRangeDateChange: "selectedRangeDateChange" }, host: { properties: { "attr.id": "viewId" } }, usesOnChanges: true, ngImport: i0, template: "<table\n    class=\"fd-calendar__content fd-calendar__content--months\"\n    role=\"grid\"\n    [attr.aria-roledescription]=\"'coreCalendar.calendarMonthViewDescription' | fdTranslate\"\n>\n    <tbody class=\"fd-calendar__group\" role=\"rowgroup\">\n        @for (colMonths of _calendarMonthListGrid; track colMonths + '' + rowIndex; let rowIndex = $index) {\n            <tr class=\"fd-calendar__row\" role=\"row\">\n                @for (monthCell of colMonths; track monthCell + '' + colIndex; let colIndex = $index) {\n                    <td\n                        class=\"fd-calendar__my-item\"\n                        role=\"gridcell\"\n                        [class.fd-calendar__my-item--current]=\"monthCell.current\"\n                        [class.is-active]=\"monthCell.selected\"\n                        [attr.tabIndex]=\"monthCell.tabIndex\"\n                        [attr.id]=\"monthCell.id\"\n                        [attr.aria-selected]=\"monthCell.selected\"\n                        [attr.aria-disabled]=\"monthCell.disabled\"\n                        [attr.data-fd-calendar-month]=\"monthCell.month\"\n                        (keydown)=\"_onKeydownMonthHandler($event, monthCell.index)\"\n                        (mouseenter)=\"_handleRangeHover(monthCell)\"\n                        (click)=\"selectMonth(monthCell, $event)\"\n                    >\n                        <button\n                            fd-button\n                            fdType=\"transparent\"\n                            [class.fd-button--toggled]=\"\n                                monthCell.selectedRange ||\n                                monthCell.hoverRange ||\n                                monthCell.selectedFirst ||\n                                monthCell.selectedLast\n                            \"\n                            class=\"fd-calendar__my-item-button\"\n                            [class.is-active]=\"monthCell.current\"\n                            tabindex=\"-1\"\n                        >\n                            <span\n                                class=\"fd-calendar__text\"\n                                [attr.aria-labelledby]=\"\n                                    monthCell.id +\n                                    '-aria-label ' +\n                                    (monthCell.current ? _todayLabelId + ' ' : '') +\n                                    (monthCell.selected ? _selectedDateLabelId : '')\n                                \"\n                            >\n                                {{ monthCell.label }}\n                            </span>\n                        </button>\n                        <span hidden aria-hidden=\"true\" [attr.id]=\"monthCell.id + '-aria-label'\">\n                            {{ monthCell.ariaLabel }}\n                        </span>\n                    </td>\n                }\n            </tr>\n        }\n    </tbody>\n</table>\n<!-- Hidden elements for aria purposes -->\n<div hidden aria-hidden=\"true\">\n    <div [attr.id]=\"_todayLabelId\">{{ 'coreCalendar.todayLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_selectedDateLabelId\">{{ 'coreCalendar.dateSelectedLabel' | fdTranslate }}</div>\n</div>\n", styles: [""], dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarMonthViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-calendar-month-view', encapsulation: ViewEncapsulation.None, host: {
                        '[attr.id]': 'viewId'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, imports: [ButtonComponent, FdTranslatePipe], template: "<table\n    class=\"fd-calendar__content fd-calendar__content--months\"\n    role=\"grid\"\n    [attr.aria-roledescription]=\"'coreCalendar.calendarMonthViewDescription' | fdTranslate\"\n>\n    <tbody class=\"fd-calendar__group\" role=\"rowgroup\">\n        @for (colMonths of _calendarMonthListGrid; track colMonths + '' + rowIndex; let rowIndex = $index) {\n            <tr class=\"fd-calendar__row\" role=\"row\">\n                @for (monthCell of colMonths; track monthCell + '' + colIndex; let colIndex = $index) {\n                    <td\n                        class=\"fd-calendar__my-item\"\n                        role=\"gridcell\"\n                        [class.fd-calendar__my-item--current]=\"monthCell.current\"\n                        [class.is-active]=\"monthCell.selected\"\n                        [attr.tabIndex]=\"monthCell.tabIndex\"\n                        [attr.id]=\"monthCell.id\"\n                        [attr.aria-selected]=\"monthCell.selected\"\n                        [attr.aria-disabled]=\"monthCell.disabled\"\n                        [attr.data-fd-calendar-month]=\"monthCell.month\"\n                        (keydown)=\"_onKeydownMonthHandler($event, monthCell.index)\"\n                        (mouseenter)=\"_handleRangeHover(monthCell)\"\n                        (click)=\"selectMonth(monthCell, $event)\"\n                    >\n                        <button\n                            fd-button\n                            fdType=\"transparent\"\n                            [class.fd-button--toggled]=\"\n                                monthCell.selectedRange ||\n                                monthCell.hoverRange ||\n                                monthCell.selectedFirst ||\n                                monthCell.selectedLast\n                            \"\n                            class=\"fd-calendar__my-item-button\"\n                            [class.is-active]=\"monthCell.current\"\n                            tabindex=\"-1\"\n                        >\n                            <span\n                                class=\"fd-calendar__text\"\n                                [attr.aria-labelledby]=\"\n                                    monthCell.id +\n                                    '-aria-label ' +\n                                    (monthCell.current ? _todayLabelId + ' ' : '') +\n                                    (monthCell.selected ? _selectedDateLabelId : '')\n                                \"\n                            >\n                                {{ monthCell.label }}\n                            </span>\n                        </button>\n                        <span hidden aria-hidden=\"true\" [attr.id]=\"monthCell.id + '-aria-label'\">\n                            {{ monthCell.ariaLabel }}\n                        </span>\n                    </td>\n                }\n            </tr>\n        }\n    </tbody>\n</table>\n<!-- Hidden elements for aria purposes -->\n<div hidden aria-hidden=\"true\">\n    <div [attr.id]=\"_todayLabelId\">{{ 'coreCalendar.todayLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_selectedDateLabelId\">{{ 'coreCalendar.dateSelectedLabel' | fdTranslate }}</div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: CalendarService }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DATE_TIME_FORMATS]
                }] }, { type: i2.DatetimeAdapter }], propDecorators: { id: [{
                type: Input
            }], monthSelected: [{
                type: Input
            }], focusEscapeFunction: [{
                type: Input
            }], year: [{
                type: Input
            }], isDateRangeMonthYearFormat: [{
                type: Input
            }], monthClicked: [{
                type: Output
            }], selectedRangeDateChange: [{
                type: Output
            }], rangeHoverEffect: [{
                type: Input
            }], selectedRangeDate: [{
                type: Input
            }] } });

/** Component representing the YearView of the Calendar Component. */
class CalendarYearViewComponent {
    /** View ID */
    get viewId() {
        return this.id + '-year-view';
    }
    /**
     * @hidden
     * Today cell label ID
     */
    get _todayLabelId() {
        return this.viewId + '-today-label';
    }
    /**
     * @hidden
     * Selected date label ID
     */
    get _selectedDateLabelId() {
        return this.viewId + '-selected-date-label';
    }
    /** @hidden */
    constructor(_eRef, _changeDetectorRef, _calendarService, _dateTimeAdapter, _dateTimeFormats) {
        this._eRef = _eRef;
        this._changeDetectorRef = _changeDetectorRef;
        this._calendarService = _calendarService;
        this._dateTimeAdapter = _dateTimeAdapter;
        this._dateTimeFormats = _dateTimeFormats;
        /**
         * Whether user wants to mark year cells on hover.
         * Works only on range mode, when start year is selected.
         */
        this.rangeHoverEffect = false;
        /** Event fired when a year is selected. */
        this.yearClicked = new EventEmitter();
        /** Event thrown every time selected first or last date in range mode is changed */
        this.selectedRangeDateChange = new EventEmitter();
        /**
         * @hidden
         */
        this._destroyRef = inject(DestroyRef);
        /** @hidden */
        this._initiated = false;
        /** @hidden */
        this._isOnRangePick = false;
        // default values
        this._currentYear = _dateTimeAdapter.getYear(_dateTimeAdapter.today());
        this._firstYearInList = this._currentYear;
    }
    /** @hidden */
    ngOnInit() {
        this._initiated = true;
        this._setupKeyboardService();
        this._firstYearInList = this.yearSelected;
        this._constructYearGrid();
        this._dateTimeAdapter.localeChanges.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._constructYearGrid();
            this._changeDetectorRef.markForCheck();
        });
    }
    /** @hidden */
    ngOnChanges(changes) {
        if (this._initiated && ('yearViewGrid' in changes || 'yearSelected' in changes || 'id' in changes)) {
            this._constructYearGrid();
        }
    }
    /** The currently selected FdDates model start and end in range mode. */
    set selectedRangeDate(dateRange) {
        if (dateRange &&
            this.selectedRangeDate &&
            this._isSameDate(dateRange.start, this.selectedRangeDate.start) &&
            this._isSameDate(dateRange.end, this.selectedRangeDate.end)) {
            return;
        }
        this._selectedRangeDate = dateRange;
        if (this._calendarYearListGrid) {
            this._changeSelectedRangeYears(dateRange, this._getYearList());
        }
    }
    get selectedRangeDate() {
        return this._selectedRangeDate;
    }
    /**
     * @hidden
     *  Amount of selected years
     *  0, when there is no year selected, or start year is invalid,
     *  1, when there is only valid start year, or end year is same as start year,
     *  2, when both dates are valid
     */
    get _selectCounter() {
        if (!this.selectedRangeDate || !this._dateTimeAdapter.isValid(this.selectedRangeDate.start)) {
            return 0;
        }
        if (this.selectedRangeDate.start &&
            (!this._dateTimeAdapter.isValid(this.selectedRangeDate.end) ||
                this._isSameDate(this.selectedRangeDate.start, this.selectedRangeDate.end))) {
            return 1;
        }
        if (this._dateTimeAdapter.isValid(this.selectedRangeDate.start) &&
            this._dateTimeAdapter.isValid(this.selectedRangeDate.end)) {
            return 2;
        }
        return 0;
    }
    /** Method used to load the previous {{col * row}} years to be displayed. */
    loadNextYearList() {
        this._firstYearInList += this._getAmountOfYearsShownAtOnce();
        this._constructYearGrid();
    }
    /** Method used to load the next {{col * row}} years to be displayed. */
    loadPreviousYearList() {
        this._firstYearInList -= this._getAmountOfYearsShownAtOnce();
        this._constructYearGrid();
    }
    /** Method that sends the year to the parent component when it is clicked. */
    selectYear(selectedYear, event) {
        if (event) {
            event.stopPropagation();
        }
        this.yearSelected = selectedYear.year;
        this.yearClicked.emit(this.yearSelected);
        if (this.isDateRangeYearFormat) {
            this._selectRangeDate(selectedYear);
            this._handleRangeHoverEffect(event);
        }
    }
    /**
     * Set focus on month cell.
     * It can be a selected cell, current month cell or first cell in the list
     */
    setFocusOnCell() {
        const cellToFocus = new DefaultCalendarActiveCellStrategy().getActiveCell(this._getYearList());
        if (!cellToFocus?.id) {
            return;
        }
        this._focusElementBySelector(`#${cellToFocus.id}`);
    }
    /**
     * @hidden
     * Method for handling the keyboard navigation.
     */
    _onKeydownYearHandler(event, index) {
        this._calendarService.onKeydownHandler(event, index);
    }
    /**
     * @hidden
     * Method that allows to focus elements inside this component
     */
    _focusElementBySelector(elementSelector) {
        const elementToFocus = this._eRef.nativeElement.querySelector(elementSelector);
        if (elementToFocus?.focus) {
            elementToFocus.focus();
        }
    }
    /**
     * @hidden
     * Standardized method to calculate grid [x][y] to index number of flatten list
     */
    _getIndex(rowIndex, colIndex) {
        return this._calendarService.getId(rowIndex, colIndex);
    }
    /**
     * @hidden
     * Get grid cell id be index
     * @param index
     */
    _getId(index) {
        return this.viewId + '-year-' + index;
    }
    /**
     * @hidden
     * Handles hover effect for range selection mode.
     * @param year The calendar year that is hovered.
     */
    _handleRangeHover(year) {
        // Handle range hover
        const start = this.selectedRangeDate?.start;
        if (this._isOnRangePick && start) {
            if (this._dateTimeAdapter.compareDate(year.date, start) < 0) {
                this._getYearList().forEach((_year) => {
                    _year.hoverRange =
                        this._dateTimeAdapter.compareDate(_year.date, year.date) > 0 &&
                            this._dateTimeAdapter.compareDate(_year.date, start) < 0;
                });
            }
            else {
                this._getYearList().forEach((_year) => {
                    _year.hoverRange =
                        this._dateTimeAdapter.compareDate(_year.date, year.date) < 0 &&
                            this._dateTimeAdapter.compareDate(_year.date, start) > 0;
                });
            }
        }
    }
    /**
     * @hidden
     * Method that returns active cell, which means:
     * if there is any selected year, return selected year
     * if there is no selected year, but there is current year, return current year
     * if there is no current year, or selected, return first one
     */
    _getActiveYear() {
        const selectedYearCell = this._getYearList().find(({ year }) => year === this.yearSelected);
        if (selectedYearCell) {
            return selectedYearCell.year;
        }
        const currentYearCell = this._getYearList().find(({ year }) => year === this._currentYear);
        if (currentYearCell) {
            return currentYearCell.year;
        }
        return this._calendarYearListGrid[0][0].year;
    }
    /** @hidden */
    _constructYearGrid() {
        const displayedYearsAmount = this.yearViewGrid.cols * this.yearViewGrid.rows;
        const calendarYearList = [];
        this._calendarYearListGrid = [];
        for (let x = 0; x < displayedYearsAmount; ++x) {
            const year = this._firstYearInList + x;
            calendarYearList.push({
                date: this._dateTimeAdapter.createDate(year),
                year,
                label: this._getYearName(year),
                ariaLabel: this._getAriaYearName(year),
                selected: year === this.yearSelected,
                current: year === this._currentYear,
                index: x
            });
        }
        // if the date range is selected
        if (this.isDateRangeYearFormat) {
            this._changeSelectedRangeYears(this._selectedRangeDate, calendarYearList);
        }
        /** Creating 2d grid */
        while (calendarYearList.length) {
            this._calendarYearListGrid.push(calendarYearList.splice(0, this.yearViewGrid.cols));
        }
        this._activeYear = this._getActiveYear();
        this._calendarYearListGrid.forEach((row, rowIndex) => {
            row.forEach((cell, colIndex) => {
                cell.id = this._getId(this._getIndex(rowIndex, colIndex));
                cell.tabIndex = cell.year === this._activeYear ? 0 : -1;
            });
        });
        this._changeDetectorRef.markForCheck();
    }
    /**
     * @hidden
     * Handles the hover effect for range selection.
     * Toggles the hover effect based on the selection state and event.
     * @param event Optional mouse event for handling hover effect.
     */
    _handleRangeHoverEffect(event) {
        if (this.isDateRangeYearFormat && this.rangeHoverEffect && this._selectCounter === 1 && event) {
            this._isOnRangePick = !this._isOnRangePick;
        }
        else {
            this._isOnRangePick = false;
        }
    }
    /**
     * @hidden
     * Change properties of range years, this method is called, to not rebuild whole grid from scratch,
     * it just changes properties of newly selected/unselected years.
     */
    _changeSelectedRangeYears(dates, calendar) {
        /** Pull list of calendar year */
        const calendarList = calendar;
        /** Reset changing properties */
        calendarList.forEach((_year) => (_year.selectedFirst =
            _year.selectedLast =
                _year.selected =
                    _year.disabled =
                        _year.hoverRange =
                            _year.selectedRange =
                                false));
        if (dates) {
            let startYear;
            let endYear;
            if (dates.start) {
                /** Find start year and mark it as selected */
                startYear = calendarList.find((_year) => this._isSameDate(_year.date, dates.start));
                if (startYear) {
                    startYear.selected = true;
                    startYear.selectedFirst = true;
                }
            }
            if (dates.end) {
                /** Find end year and mark it as selected */
                endYear = calendarList.find((_year) => this._isSameDate(_year.date, dates.end));
                if (endYear) {
                    endYear.selected = true;
                    endYear.selectedLast = true;
                }
            }
            /** Verify if start year and end year is valid, otherwise don't put range selection */
            if (dates.start && dates.end) {
                /** Mark all years, which are between start and end date */
                calendarList
                    .filter((_year) => (_year.selectedRange = this._dateTimeAdapter.isBetween(_year.date, dates.start, dates.end)))
                    .forEach((_year) => (_year.selectedRange = true));
            }
        }
    }
    /**
     * @hidden
     * Check if dates are equal
     */
    _isSameDate(date1, date2) {
        return this._dateTimeAdapter.datesEqual(date1, date2);
    }
    /**
     * @hidden
     * Selects or updates the range of years in range mode.
     * Handles the start and end years and updates the selected range.
     * @param year The calendar year to be selected or updated in the range.
     */
    _selectRangeDate(year) {
        if (this._selectCounter === 0 || this._selectCounter === 2) {
            this._selectedRangeDate = { start: year.date, end: null };
            this.selectedRangeDateChange.emit(this.selectedRangeDate);
        }
        else if (this._selectCounter === 1) {
            this._selectedRangeDate = this._getOrderedRange(this.selectedRangeDate.start, year.date);
            this.selectedRangeDateChange.emit(this.selectedRangeDate);
        }
        this._changeSelectedRangeYears(this._selectedRangeDate, this._getYearList());
    }
    /**
     * @hidden
     * Orders the start and end dates for the range selection.
     * Ensures the start date is before or equal to the end date.
     * @param date1 The first date.
     * @param date2 The second date.
     * @returns An object containing the ordered start and end dates.
     */
    _getOrderedRange(date1, date2) {
        return this._dateTimeAdapter.compareDate(date1, date2) < 0
            ? { start: date1, end: date2 }
            : { start: date2, end: date1 };
    }
    /**
     * @hidden
     * Returns year name as a string.
     */
    _getYearName(year) {
        const formatted = this._dateTimeAdapter.getYearName(this._dateTimeAdapter.createDate(year, 1, 1));
        return this._getYearString(year, formatted);
    }
    /**
     * @hidden
     * Returns aria year name as a string.
     */
    _getAriaYearName(year) {
        const formatted = this._dateTimeAdapter.format(this._dateTimeAdapter.createDate(year, 1, 1), this._dateTimeFormats.display.yearA11yLabel);
        return this._getYearString(year, formatted);
    }
    /**
     * @hidden
     * Returns year name taking into account yearMapping.
     */
    _getYearString(year, defaultStr) {
        if (typeof this.yearViewGrid.yearMapping === 'function') {
            return this.yearViewGrid.yearMapping(year);
        }
        return defaultStr;
    }
    /**
     * @hidden
     * Returns transformed 1d array from 2d year grid.
     */
    _getYearList() {
        return [].concat(...this._calendarYearListGrid);
    }
    /**
     * @hidden
     * Amount of years displayed in year view
     */
    _getAmountOfYearsShownAtOnce() {
        return this.yearViewGrid.rows * this.yearViewGrid.cols;
    }
    /**
     * @hidden
     * Method to put configuration and listeners on calendar keyboard service
     */
    _setupKeyboardService() {
        this._calendarService.colAmount = this.yearViewGrid.cols;
        this._calendarService.rowAmount = this.yearViewGrid.rows;
        this._calendarService.focusEscapeFunction = this.focusEscapeFunction;
        this._calendarService.onFocusIdChange.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((index) => {
            this._handleRangeHover(this._getYearList()[index]);
            this._focusOnCellByIndex(index);
        });
        this._calendarService.onKeySelect.pipe(takeUntilDestroyed(this._destroyRef)).subscribe(({ index, event }) => {
            this.selectYear(this._getYearList()[index], event);
            this._focusOnCellByIndex(index);
        });
        this._calendarService.onListStartApproach.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((index) => {
            this.loadPreviousYearList();
            this._changeDetectorRef.detectChanges();
            this._focusOnCellByIndex(index);
        });
        this._calendarService.onListEndApproach.pipe(takeUntilDestroyed(this._destroyRef)).subscribe((index) => {
            this.loadNextYearList();
            this._changeDetectorRef.detectChanges();
            this._focusOnCellByIndex(index);
        });
    }
    /** @hidden */
    _focusOnCellByIndex(index) {
        this._focusElementBySelector(`#${this._getId(index)}`);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarYearViewComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: CalendarService }, { token: i2.DatetimeAdapter }, { token: DATE_TIME_FORMATS }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CalendarYearViewComponent, isStandalone: true, selector: "fd-calendar-year-view", inputs: { id: "id", focusEscapeFunction: "focusEscapeFunction", yearSelected: "yearSelected", yearViewGrid: "yearViewGrid", isDateRangeYearFormat: "isDateRangeYearFormat", rangeHoverEffect: "rangeHoverEffect", selectedRangeDate: "selectedRangeDate" }, outputs: { yearClicked: "yearClicked", selectedRangeDateChange: "selectedRangeDateChange" }, host: { properties: { "attr.id": "viewId" } }, usesOnChanges: true, ngImport: i0, template: "<table\n    class=\"fd-calendar__content fd-calendar__content--years\"\n    role=\"grid\"\n    [attr.aria-roledescription]=\"'coreCalendar.calendarYearsViewDescription' | fdTranslate\"\n>\n    <tbody class=\"fd-calendar__group\" role=\"rowgroup\">\n        @for (colYears of _calendarYearListGrid; track colYears + '' + rowIndex; let rowIndex = $index) {\n            <tr class=\"fd-calendar__row\" role=\"row\">\n                @for (yearCell of colYears; track yearCell + '' + colIndex; let colIndex = $index) {\n                    <td\n                        class=\"fd-calendar__my-item\"\n                        role=\"gridcell\"\n                        [class.fd-calendar__my-item--current]=\"yearCell.current\"\n                        [class.is-active]=\"yearCell.selected\"\n                        [attr.id]=\"yearCell.id\"\n                        [attr.tabindex]=\"yearCell.tabIndex\"\n                        [attr.aria-selected]=\"yearCell.selected\"\n                        [attr.aria-disabled]=\"yearCell.disabled\"\n                        [attr.data-fd-calendar-year]=\"yearCell.year\"\n                        (keydown)=\"_onKeydownYearHandler($event, yearCell.index)\"\n                        (mouseenter)=\"_handleRangeHover(yearCell)\"\n                        (click)=\"selectYear(yearCell, $event)\"\n                    >\n                        <button\n                            fd-button\n                            fdType=\"transparent\"\n                            [class.fd-button--toggled]=\"\n                                yearCell.selectedRange ||\n                                yearCell.hoverRange ||\n                                yearCell.selectedFirst ||\n                                yearCell.selectedLast\n                            \"\n                            class=\"fd-calendar__my-item-button\"\n                            [class.is-active]=\"yearCell.current\"\n                            tabindex=\"-1\"\n                        >\n                            <span\n                                class=\"fd-calendar__text\"\n                                [attr.aria-labelledby]=\"\n                                    yearCell.id +\n                                    '-aria-label ' +\n                                    (yearCell.current ? _todayLabelId + ' ' : '') +\n                                    (yearCell.selected ? _selectedDateLabelId : '')\n                                \"\n                            >\n                                {{ yearCell.label }}\n                            </span>\n                        </button>\n                        <span hidden aria-hidden=\"true\" [attr.id]=\"yearCell.id + '-aria-label'\">\n                            {{ yearCell.ariaLabel }}\n                        </span>\n                    </td>\n                }\n            </tr>\n        }\n    </tbody>\n</table>\n<!-- Hidden elements for aria purposes -->\n<div hidden aria-hidden=\"true\">\n    <div [attr.id]=\"_todayLabelId\">{{ 'coreCalendar.todayLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_selectedDateLabelId\">{{ 'coreCalendar.dateSelectedLabel' | fdTranslate }}</div>\n</div>\n", styles: [""], dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarYearViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-calendar-year-view', encapsulation: ViewEncapsulation.None, host: {
                        '[attr.id]': 'viewId'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, imports: [ButtonComponent, FdTranslatePipe], template: "<table\n    class=\"fd-calendar__content fd-calendar__content--years\"\n    role=\"grid\"\n    [attr.aria-roledescription]=\"'coreCalendar.calendarYearsViewDescription' | fdTranslate\"\n>\n    <tbody class=\"fd-calendar__group\" role=\"rowgroup\">\n        @for (colYears of _calendarYearListGrid; track colYears + '' + rowIndex; let rowIndex = $index) {\n            <tr class=\"fd-calendar__row\" role=\"row\">\n                @for (yearCell of colYears; track yearCell + '' + colIndex; let colIndex = $index) {\n                    <td\n                        class=\"fd-calendar__my-item\"\n                        role=\"gridcell\"\n                        [class.fd-calendar__my-item--current]=\"yearCell.current\"\n                        [class.is-active]=\"yearCell.selected\"\n                        [attr.id]=\"yearCell.id\"\n                        [attr.tabindex]=\"yearCell.tabIndex\"\n                        [attr.aria-selected]=\"yearCell.selected\"\n                        [attr.aria-disabled]=\"yearCell.disabled\"\n                        [attr.data-fd-calendar-year]=\"yearCell.year\"\n                        (keydown)=\"_onKeydownYearHandler($event, yearCell.index)\"\n                        (mouseenter)=\"_handleRangeHover(yearCell)\"\n                        (click)=\"selectYear(yearCell, $event)\"\n                    >\n                        <button\n                            fd-button\n                            fdType=\"transparent\"\n                            [class.fd-button--toggled]=\"\n                                yearCell.selectedRange ||\n                                yearCell.hoverRange ||\n                                yearCell.selectedFirst ||\n                                yearCell.selectedLast\n                            \"\n                            class=\"fd-calendar__my-item-button\"\n                            [class.is-active]=\"yearCell.current\"\n                            tabindex=\"-1\"\n                        >\n                            <span\n                                class=\"fd-calendar__text\"\n                                [attr.aria-labelledby]=\"\n                                    yearCell.id +\n                                    '-aria-label ' +\n                                    (yearCell.current ? _todayLabelId + ' ' : '') +\n                                    (yearCell.selected ? _selectedDateLabelId : '')\n                                \"\n                            >\n                                {{ yearCell.label }}\n                            </span>\n                        </button>\n                        <span hidden aria-hidden=\"true\" [attr.id]=\"yearCell.id + '-aria-label'\">\n                            {{ yearCell.ariaLabel }}\n                        </span>\n                    </td>\n                }\n            </tr>\n        }\n    </tbody>\n</table>\n<!-- Hidden elements for aria purposes -->\n<div hidden aria-hidden=\"true\">\n    <div [attr.id]=\"_todayLabelId\">{{ 'coreCalendar.todayLabel' | fdTranslate }}</div>\n    <div [attr.id]=\"_selectedDateLabelId\">{{ 'coreCalendar.dateSelectedLabel' | fdTranslate }}</div>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: CalendarService }, { type: i2.DatetimeAdapter }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DATE_TIME_FORMATS]
                }] }], propDecorators: { id: [{
                type: Input
            }], focusEscapeFunction: [{
                type: Input
            }], yearSelected: [{
                type: Input
            }], yearViewGrid: [{
                type: Input
            }], isDateRangeYearFormat: [{
                type: Input
            }], rangeHoverEffect: [{
                type: Input
            }], yearClicked: [{
                type: Output
            }], selectedRangeDateChange: [{
                type: Output
            }], selectedRangeDate: [{
                type: Input
            }] } });

/** Create an Error to be thrown when attempting to use an invalid date implementation. */
function createMissingDateImplementationError(provider) {
    return Error(`Calendar: No provider found for ${provider}. You must import one of the following ` +
        `modules at your application root: FdDatetimeModule, or provide a ` +
        `custom implementation.`);
}

/**
 * Provides i18n support for labels inside the calendar component.
 * @deprecated use i18n `coreCalendar` key instead
 */
class CalendarI18nLabels {
    constructor() {
        /** This is event that should be called, when labels are changed, to let component detect an changes. */
        this.labelsChange = new Subject();
        /** Year selection aria label. Used on the button to navigate to the years view. */
        this.yearSelectionLabel = FD_LANGUAGE_ENGLISH.coreCalendar.yearSelectionLabel;
        /** Years range selection aria label. Used on the button to navigate to the years range view. */
        this.yearsRangeSelectionLabel = FD_LANGUAGE_ENGLISH.coreCalendar.yearsRangeSelectionLabel;
        /** Month selection aria label. Used on the button to navigate to the months view. */
        this.monthSelectionLabel = FD_LANGUAGE_ENGLISH.coreCalendar.monthSelectionLabel;
        /** Day selection aria label. Used on the button to navigate to the day view. */
        this.dateSelectionLabel = FD_LANGUAGE_ENGLISH.coreCalendar.dateSelectionLabel;
        /** Previous year aria label. Used on the button to switch to a previous year in the years view. */
        this.previousYearLabel = FD_LANGUAGE_ENGLISH.coreCalendar.previousYearLabel;
        /** Next year aria label. Used on the button to switch to a next year in the years view. */
        this.nextYearLabel = FD_LANGUAGE_ENGLISH.coreCalendar.nextYearLabel;
        /** Previous month aria label. Used on the button to switch to a previous month in the months view. */
        this.previousMonthLabel = FD_LANGUAGE_ENGLISH.coreCalendar.previousMonthLabel;
        /** Next month aria label. Used on the button to switch to a next month in the months view. */
        this.nextMonthLabel = FD_LANGUAGE_ENGLISH.coreCalendar.nextMonthLabel;
        /** Week number column label */
        this.weekColumnLabel = FD_LANGUAGE_ENGLISH.coreCalendar.weekColumnLabel;
        /** Selected date label. Used on the selected day/month/year cell. */
        this.dateSelectedLabel = FD_LANGUAGE_ENGLISH.coreCalendar.dateSelectedLabel;
        /** Is used to describe present date */
        this.todayLabel = FD_LANGUAGE_ENGLISH.coreCalendar.todayLabel;
        /** Range start label. Used for date range selection */
        this.rangeStartLabel = FD_LANGUAGE_ENGLISH.coreCalendar.rangeStartLabel;
        /** Range end label. Used for date range selection */
        this.rangeEndLabel = FD_LANGUAGE_ENGLISH.coreCalendar.rangeEndLabel;
        /** Past days aria label. Used when days in the past are accessed */
        this.dayInPastLabel = FD_LANGUAGE_ENGLISH.coreCalendar.dayInPastLabel;
        /** Past days aria label. Used when days in the past are accessed */
        this.closeCalendarLabel = FD_LANGUAGE_ENGLISH.coreCalendar.closeCalendarLabel;
        /** Calendar day view aria role description. */
        this.calendarDayViewDescription = FD_LANGUAGE_ENGLISH.coreCalendar.calendarDayViewDescription;
        /** Calendar month view aria role description. */
        this.calendarMonthViewDescription = FD_LANGUAGE_ENGLISH.coreCalendar.calendarMonthViewDescription;
        /** Calendar years view aria role description. */
        this.calendarYearsViewDescription = FD_LANGUAGE_ENGLISH.coreCalendar.calendarYearsViewDescription;
        /** Calendar years range view aria role description. */
        this.calendarYearsRangeViewDescription = FD_LANGUAGE_ENGLISH.coreCalendar.calendarYearsRangeViewDescription;
    }
}

/**
 * Use deprecated `CalendarI18nLabels` to patch `FD_LANGUAGE` observable
 */
function patchDeprecatedI18nLabels() {
    const deprecatedSymbol = inject(CalendarI18nLabels, { optional: true });
    if (deprecatedSymbol) {
        return inject(FD_LANGUAGE, { skipSelf: true }).pipe(switchMap((existingLang) => deprecatedSymbol.labelsChange.pipe(startWith(null), map(() => existingLang))), map((existingLang) => ({
            ...existingLang,
            coreCalendar: {
                ...existingLang.coreCalendar,
                ...deprecatedSymbol
            }
        })));
    }
    return inject(FD_LANGUAGE, { skipSelf: true });
}

let calendarUniqueId = 0;
/**
 * Months: 1 = January, 12 = december.
 * Days: 1 = Sunday, 7 = Saturday
 *
 * Calendar component used for selecting dates, typically used by the DatePicker and DateTimePicker components.
 * Supports the Angular forms module, enabling form validity, ngModel, etc.
 * ```html
 * <fd-calendar></fd-calendar>
 * ```
 *
 */
class CalendarComponent {
    /** @hidden */
    constructor(_elementRef, _changeDetectorRef, _contentDensityObserver, 
    // Use @Optional to avoid angular injection error message and throw our own which is more precise one
    _dateTimeAdapter, _dateTimeFormats) {
        this._elementRef = _elementRef;
        this._changeDetectorRef = _changeDetectorRef;
        this._dateTimeAdapter = _dateTimeAdapter;
        this._dateTimeFormats = _dateTimeFormats;
        /** The currently selected date model with multiple ranges. */
        this.selectedMultipleDateRanges = [];
        /**
         * Whether user wants to mark sunday/saturday with `fd-calendar__item--weekend` class
         */
        this.markWeekends = true;
        /**
         * Whether user wants to show week numbers next to days
         */
        this.showWeekNumbers = false;
        /**
         * Whether the user wants to select multiple days or multiple range dates.
         * If `displayWeekNumbers` is true, the user can click on the week number to mark the related row.
         * The user can click on week days to mark the related column.
         * Note: Clickable selection for week row or column does not work for range selections.
         */
        this.allowMultipleSelection = false;
        /** Whether calendar is used inside mobile in landscape mode, it also adds close button on right side */
        this.mobileLandscape = false;
        /** Whether calendar is used inside mobile in portrait mode */
        this.mobilePortrait = false;
        /** Actually shown active view one of 'day' | 'month' | 'year' */
        this.activeView = FdCalendarViewEnum.Day;
        /**
         * The type of calendar
         * 'single' for single date selection
         * 'range' for a range of dates.
         */
        this.calType = CalendarTypeEnum.Single;
        /** Id of the calendar. If none is provided, one will be generated. */
        this.id = 'fd-calendar-' + calendarUniqueId++;
        /**
         * Special days mark, it can be used by passing array of object with
         * Special day number, list 1-20 [class:`fd-calendar__item--legend-{{number}}`] is available there:
         * https://sap.github.io/fundamental-styles/components/calendar.html calendar special days section
         * Rule accepts method with D object as a parameter. ex:
         * `rule: (fdDate: D) => fdDate.getDay() === 1`, which will mark all sundays as special day.
         */
        this.specialDaysRules = [];
        /**
         * Object to customize year grid,
         * Row, Columns and method to display year can be modified
         */
        this.yearGrid = {
            rows: 4,
            cols: 5
        };
        /**
         * Object to customize aggregated year grid,
         * Row, Columns and method to display year can be modified
         */
        this.aggregatedYearGrid = {
            rows: 4,
            cols: 3
        };
        /**
         * Whether user wants to mark day cells on hover.
         * Works only on range mode, when start date is selected on Day View.
         */
        this.rangeHoverEffect = false;
        /** Whether to pick the date range in month or year or days format
         * Day format will have a month and year including day
         * Month format will have year including month
         * Year format will have just year
         * Values can be 'month' for Month format, 'year' for Year format or nothing for day format
         */
        this.dateRangeFormat = '';
        /** Event thrown every time active view is changed */
        this.activeViewChange = new EventEmitter();
        /** Event thrown every time selected date in single mode is changed */
        this.selectedDateChange = new EventEmitter();
        /** Event thrown every time the selected dates in multiple mode are changed. */
        this.selectedMultipleDatesChange = new EventEmitter();
        /** Event thrown every time selected first or last date in range mode is changed */
        this.selectedRangeDateChange = new EventEmitter();
        /** Event thrown every time the first or last date in multiple range mode is changed. */
        this.selectedMultipleDateRangesChange = new EventEmitter();
        /** Event thrown every time when value is overwritten from outside and throw back isValid */
        this.isValidDateChange = new EventEmitter();
        /** Event thrown every time when calendar should be closed */
        this.closeCalendar = new EventEmitter();
        /** Event thrown, when close button is clicked */
        this.closeClicked = new EventEmitter();
        /** @hidden */
        this._subscriptions = new Subscription();
        /** That allows to define function that should happen, when focus should normally escape of component */
        this.escapeFocusFunction = (event) => {
            event?.preventDefault();
            this._calendarHeaderComponent?.focus();
        };
        /**
         * Function used to disable certain dates in the calendar.
         */
        this.disableFunction = () => false;
        /**
         * Function used to disable certain dates in the calendar for the range start selection.
         */
        this.disableRangeStartFunction = () => false;
        /**
         * Function used to disable certain dates in the calendar for the range end selection.
         */
        this.disableRangeEndFunction = () => false;
        /** @hidden */
        this.onChange = () => { };
        /** @hidden */
        this.onTouched = () => { };
        if (!this._dateTimeAdapter) {
            throw createMissingDateImplementationError('DateTimeAdapter');
        }
        if (!this._dateTimeFormats) {
            throw createMissingDateImplementationError('DATE_TIME_FORMATS');
        }
        _contentDensityObserver.subscribe();
        // set default value
        this._adapterStartingDayOfWeek = (this._dateTimeAdapter.getFirstDayOfWeek() + 1);
        this.selectedDate = this._dateTimeAdapter.today();
        this._changeDetectorRef.markForCheck();
        this._listenToLocaleChanges();
    }
    /** @hidden */
    focusOut(event) {
        if (!this._elementRef.nativeElement.contains(event.relatedTarget)) {
            this.onTouched();
        }
    }
    /** @hidden */
    ngOnInit() {
        this._prepareDisplayedView();
    }
    /** @hidden */
    ngOnChanges(changes) {
        if ('nextButtonDisableFunction' in changes ||
            'previousButtonDisableFunction' in changes ||
            '_currentlyDisplayed' in changes) {
            this._setNavigationButtonsStates();
        }
    }
    /** @hidden */
    getWeekStartDay() {
        return this.startingDayOfWeek === undefined ? this._adapterStartingDayOfWeek : this.startingDayOfWeek;
    }
    /** @hidden */
    ngOnDestroy() {
        this._subscriptions.unsubscribe();
    }
    /**
     * @hidden
     * Function that provides support for ControlValueAccessor that allows to use [(ngModel)] or forms.
     */
    writeValue(selected) {
        let valid = true;
        const isValidDate = (date) => date != null && this._dateTimeAdapter.isValid(date);
        const isValidRange = (range) => range != null && isValidDate(range.start) && isValidDate(range.end);
        if (this.allowMultipleSelection) {
            if (this.calType === CalendarTypeEnum.Single) {
                const dates = Array.isArray(selected) ? selected : [selected];
                valid = dates.every(isValidDate);
                this.selectedMultipleDates = dates;
            }
            else if (this.calType === CalendarTypeEnum.Range) {
                const ranges = Array.isArray(selected) ? selected : [];
                valid = ranges.every(isValidRange);
                this.selectedMultipleDateRanges = ranges.map((range) => ({
                    start: range?.start || null,
                    end: range?.end || null
                }));
            }
        }
        else {
            if (this.calType === CalendarTypeEnum.Single) {
                valid = isValidDate(selected);
                this.selectedDate = selected;
            }
            else if (this.calType === CalendarTypeEnum.Range) {
                const range = selected;
                valid = range && isValidRange(range);
                this.selectedRangeDate = range
                    ? { start: range.start || null, end: range.end || null }
                    : {
                        start: null,
                        end: null
                    };
            }
        }
        if (valid) {
            this._prepareDisplayedView();
        }
        this._changeDetectorRef.detectChanges();
        this.isValidDateChange.emit(valid);
    }
    /**
     * @hidden
     * Function that implements Validator Interface, adds validation support for forms
     */
    validate() {
        return this.isModelValid()
            ? null
            : {
                dateValidation: {
                    valid: false
                }
            };
    }
    /** @hidden */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /** @hidden */
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    /**
     * Method that handle active view change and throws event.
     *
     * Fired by calendar header component.
     */
    handleActiveViewChange(activeView) {
        if (activeView === this.activeView) {
            return;
        }
        this.activeView = activeView;
        this.activeViewChange.emit(activeView);
        if (activeView === FdCalendarViewEnum.Month) {
            this.onMonthViewSelected();
        }
        if (activeView === FdCalendarViewEnum.Year) {
            this.onYearViewSelected();
        }
        if (activeView === FdCalendarViewEnum.AggregatedYear) {
            this.onYearsRangeViewSelected();
        }
        this._setNavigationButtonsStates();
    }
    /**
     * @hidden
     * Method that is triggered by events from day view component, when there is selected single date changed
     */
    selectedDateChanged(date) {
        this.selectedDate = date;
        this._setNavigationButtonsStates();
        this.onChange(date);
        this.selectedDateChange.emit(date);
        this.closeCalendar.emit();
    }
    /**
     * @hidden
     * Method that is triggered by events from day view component, when there is selected multi date changed
     */
    selectedMultipleDatesChanged(date) {
        this.selectedMultipleDates = date;
        this._setNavigationButtonsStates();
        this.onChange(date);
        this.selectedMultipleDatesChange.emit(date);
        this.closeCalendar.emit();
    }
    /**
     * @hidden
     * Method that is triggered by events from day view component, when there is selected range date changed
     */
    selectedRangeDateChanged(dates) {
        if (dates) {
            this.selectedRangeDate = { start: dates.start, end: dates.end };
            this.selectedRangeDateChange.emit(this.selectedRangeDate);
            this.onChange(this.selectedRangeDate);
            this.closeCalendar.emit();
        }
    }
    /**
     * @hidden
     * Method that is triggered by events from day view component, when there is selected range date changed
     */
    selectedMultipleDateRangesChanged(dates) {
        if (dates) {
            this.selectedMultipleDateRanges = dates;
            this.selectedMultipleDateRangesChange.emit(this.selectedMultipleDateRanges);
            this.onChange(this.selectedMultipleDateRanges);
            this.closeCalendar.emit();
        }
    }
    /** Function that handles next arrow icon click, depending on current view it changes month, year or list of years */
    handleNextArrowClick() {
        switch (this.activeView) {
            case FdCalendarViewEnum.Day:
                this.displayNextMonth();
                break;
            case FdCalendarViewEnum.Month:
                this.displayNextYear();
                break;
            case FdCalendarViewEnum.Year:
                this.displayNextYearList();
                break;
            case FdCalendarViewEnum.AggregatedYear:
                this.displayNextYearsList();
                break;
        }
        this._setNavigationButtonsStates();
    }
    /** Function that handles previous arrow icon click, depending on current view it changes month, year or list of years */
    handlePreviousArrowClick() {
        switch (this.activeView) {
            case FdCalendarViewEnum.Day:
                this.displayPreviousMonth();
                break;
            case FdCalendarViewEnum.Month:
                this.displayPreviousYear();
                break;
            case FdCalendarViewEnum.Year:
                this.displayPreviousYearList();
                break;
            case FdCalendarViewEnum.AggregatedYear:
                this.displayPreviousYearsList();
                break;
        }
        this._setNavigationButtonsStates();
    }
    /** Function that allows to switch actual view to next month */
    displayNextMonth() {
        if (this._currentlyDisplayed.month === 12) {
            this._currentlyDisplayed = { year: this._currentlyDisplayed.year + 1, month: 1 };
        }
        else {
            this._currentlyDisplayed = {
                year: this._currentlyDisplayed.year,
                month: this._currentlyDisplayed.month + 1
            };
        }
    }
    /** Function that allows to switch actual view to previous month */
    displayPreviousMonth() {
        if (this._currentlyDisplayed.month <= 1) {
            this._currentlyDisplayed = { year: this._currentlyDisplayed.year - 1, month: 12 };
        }
        else {
            this._currentlyDisplayed = {
                year: this._currentlyDisplayed.year,
                month: this._currentlyDisplayed.month - 1
            };
        }
    }
    /** Function that allows to switch actual view to next year */
    displayNextYear() {
        this._currentlyDisplayed = { month: this._currentlyDisplayed.month, year: this._currentlyDisplayed.year + 1 };
    }
    /** Function that allows to switch actual view to previous year */
    displayPreviousYear() {
        this._currentlyDisplayed = { month: this._currentlyDisplayed.month, year: this._currentlyDisplayed.year - 1 };
    }
    /** Function that allows to switch actually displayed list of year to next year list*/
    displayNextYearList() {
        this._yearViewComponent.loadNextYearList();
        this._currentlyDisplayed = {
            month: this._currentlyDisplayed.month,
            year: this._yearViewComponent._firstYearInList
        };
    }
    /** Function that allows to switch actually displayed list of year to previous year list*/
    displayPreviousYearList() {
        this._yearViewComponent.loadPreviousYearList();
        this._currentlyDisplayed = {
            month: this._currentlyDisplayed.month,
            year: this._yearViewComponent._firstYearInList
        };
    }
    /** Function that allows to switch actually displayed list of year to next year list*/
    displayNextYearsList() {
        this._aggregatedYearViewComponent.loadNextYearsList();
    }
    /** Function that allows to switch actually displayed list of year to previous year list*/
    displayPreviousYearsList() {
        this._aggregatedYearViewComponent.loadPreviousYearsList();
    }
    /**
     * Function that allows to change currently displayed month/year configuration,
     * which are connected to days displayed
     */
    setCurrentlyDisplayed(date) {
        if (this._dateTimeAdapter.isValid(date)) {
            this._currentlyDisplayed = {
                month: this._dateTimeAdapter.getMonth(date),
                year: this._dateTimeAdapter.getYear(date)
            };
        }
    }
    /**
     * Set initial focus on one of the calendar's element
     */
    initialFocus() {
        this._getActiveFocusableView()?.setFocusOnCell();
    }
    /**
     * @hidden
     * Function that handles changes from month view child component, changes actual view and changes currently displayed month
     */
    handleMonthViewChange(month) {
        this._currentlyDisplayed = { month, year: this._currentlyDisplayed.year };
        // if mm/yyyy format date is not enabled then only show days view
        if (!this.isDateRangeMonthFormat()) {
            this.activeView = FdCalendarViewEnum.Day;
            this.onDaysViewSelected();
        }
        this.activeViewChange.emit(this.activeView);
    }
    /** Select year */
    selectedYear(yearSelected) {
        this._currentlyDisplayed.year = yearSelected;
        // if month format date range is enabled then on selecting year show month view else show days view
        // if year format date range is enabled then view remains same on selecting year
        if (this.isDateRangeMonthFormat()) {
            this.activeView = FdCalendarViewEnum.Month;
            this.onMonthViewSelected();
        }
        else if (this.isDateRangeYearFormat()) {
            this.activeView = FdCalendarViewEnum.Year;
            this.onYearViewSelected();
        }
        else {
            this.activeView = FdCalendarViewEnum.Day;
            this.onDaysViewSelected();
        }
    }
    /** Select year range */
    selectedYears(yearsSelected) {
        this.activeView = FdCalendarViewEnum.Year;
        this._currentlyDisplayed = {
            ...this._currentlyDisplayed,
            year: yearsSelected.startYear
        };
        this.onYearViewSelected();
    }
    /** @hidden */
    onDaysViewSelected() {
        this._changeDetectorRef.detectChanges();
        this._dayViewComponent?.setFocusOnCell();
    }
    /** @hidden */
    onMonthViewSelected() {
        this._changeDetectorRef.detectChanges();
        this._monthViewComponent?.setFocusOnCell();
    }
    /** @hidden */
    onYearViewSelected() {
        this._changeDetectorRef.detectChanges();
        this._yearViewComponent?.setFocusOnCell();
    }
    /** @hidden */
    onYearsRangeViewSelected() {
        this._changeDetectorRef.detectChanges();
        this._aggregatedYearViewComponent?.setFocusOnCell();
    }
    /** Method that provides information if model selected date/dates have properly types and are valid */
    isModelValid() {
        if (this.allowMultipleSelection) {
            if (this.calType === CalendarTypeEnum.Single) {
                return (this.selectedMultipleDates &&
                    this.selectedMultipleDates.every((d) => this._dateTimeAdapter.isValid(d)));
            }
            if (this.calType === CalendarTypeEnum.Range) {
                return (this.selectedMultipleDateRanges &&
                    this.selectedMultipleDateRanges.every((dr) => this._dateTimeAdapter.isValid(dr.start)) &&
                    this.selectedMultipleDateRanges.every((dr) => this._dateTimeAdapter.isValid(dr.end)));
            }
        }
        else {
            if (this.calType === CalendarTypeEnum.Single) {
                return this._dateTimeAdapter.isValid(this.selectedDate);
            }
            if (this.calType === CalendarTypeEnum.Range) {
                return (this.selectedRangeDate &&
                    this._dateTimeAdapter.isValid(this.selectedRangeDate.start) &&
                    this._dateTimeAdapter.isValid(this.selectedRangeDate.end));
            }
        }
        return false;
    }
    /** Whether the date range format is month */
    isDateRangeMonthFormat() {
        return this.dateRangeFormat === 'month';
    }
    /** Whether the date range format is year */
    isDateRangeYearFormat() {
        return this.dateRangeFormat === 'year';
    }
    /** @hidden */
    _listenToLocaleChanges() {
        this._subscriptions.add(this._dateTimeAdapter.localeChanges.subscribe(() => {
            this._adapterStartingDayOfWeek = (this._dateTimeAdapter.getFirstDayOfWeek() + 1);
            this._changeDetectorRef.markForCheck();
        }));
    }
    /**
     * @hidden
     * Method that sets up the currently displayed variables, like shown month and year.
     * Day grid is based on currently displayed month and year
     */
    _prepareDisplayedView() {
        const { selectedDate, selectedRangeDate, selectedMultipleDates, selectedMultipleDateRanges } = this;
        if (this.calType === CalendarTypeEnum.Single &&
            this._dateTimeAdapter.isValid(selectedDate) &&
            !this.allowMultipleSelection) {
            this._setCurrentlyDisplayed(selectedDate);
        }
        else if (selectedMultipleDates?.length > 0 && this.allowMultipleSelection) {
            this._setCurrentlyDisplayed(selectedMultipleDates[0]);
        }
        else if (selectedRangeDate?.start && !this.allowMultipleSelection) {
            this._setCurrentlyDisplayed(selectedRangeDate.start);
        }
        else if (selectedRangeDate?.end && !this.allowMultipleSelection) {
            this._setCurrentlyDisplayed(selectedRangeDate.end);
        }
        else if (selectedMultipleDateRanges?.length > 0 &&
            selectedMultipleDateRanges[0].start &&
            this.allowMultipleSelection) {
            this._setCurrentlyDisplayed(selectedMultipleDateRanges[0].start);
        }
        else if (selectedMultipleDateRanges?.length > 0 &&
            selectedMultipleDateRanges[0].end &&
            this.allowMultipleSelection) {
            this._setCurrentlyDisplayed(selectedMultipleDateRanges[0].end);
        }
        else {
            const today = this._dateTimeAdapter.today();
            this._setCurrentlyDisplayed(today);
        }
    }
    /** @hidden */
    _setCurrentlyDisplayed(date) {
        this._currentlyDisplayed = {
            year: this._dateTimeAdapter.getYear(date),
            month: this._dateTimeAdapter.getMonth(date)
        };
    }
    /** @hidden */
    _getActiveFocusableView() {
        switch (this.activeView) {
            case FdCalendarViewEnum.Day:
                return this._dayViewComponent;
            case FdCalendarViewEnum.Month:
                return this._monthViewComponent;
            case FdCalendarViewEnum.Year:
                return this._yearViewComponent;
            case FdCalendarViewEnum.AggregatedYear:
                return this._aggregatedYearViewComponent;
            default:
                return null;
        }
    }
    /** @hidden */
    _setNavigationButtonsStates() {
        this.previousButtonDisabled = this._isNavigationButtonDisabled(this.previousButtonDisableFunction);
        this.nextButtonDisabled = this._isNavigationButtonDisabled(this.nextButtonDisableFunction);
        this._changeDetectorRef.markForCheck();
    }
    /** @hidden */
    _isNavigationButtonDisabled(disableFunction) {
        return (typeof disableFunction === 'function' &&
            disableFunction(this.selectedDate, this._currentlyDisplayed, this.activeView));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: i1$1.ContentDensityObserver }, { token: i2.DatetimeAdapter, optional: true }, { token: DATE_TIME_FORMATS, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CalendarComponent, isStandalone: true, selector: "fd-calendar", inputs: { selectedDate: "selectedDate", selectedMultipleDates: "selectedMultipleDates", selectedRangeDate: "selectedRangeDate", selectedMultipleDateRanges: "selectedMultipleDateRanges", markWeekends: "markWeekends", showWeekNumbers: "showWeekNumbers", allowMultipleSelection: "allowMultipleSelection", mobileLandscape: "mobileLandscape", mobilePortrait: "mobilePortrait", activeView: "activeView", startingDayOfWeek: "startingDayOfWeek", calType: "calType", id: "id", specialDaysRules: "specialDaysRules", yearGrid: "yearGrid", aggregatedYearGrid: "aggregatedYearGrid", rangeHoverEffect: "rangeHoverEffect", dateRangeFormat: "dateRangeFormat", previousButtonDisableFunction: "previousButtonDisableFunction", nextButtonDisableFunction: "nextButtonDisableFunction", associatedLegendId: "associatedLegendId", escapeFocusFunction: "escapeFocusFunction", disableFunction: "disableFunction", disableRangeStartFunction: "disableRangeStartFunction", disableRangeEndFunction: "disableRangeEndFunction" }, outputs: { activeViewChange: "activeViewChange", selectedDateChange: "selectedDateChange", selectedMultipleDatesChange: "selectedMultipleDatesChange", selectedRangeDateChange: "selectedRangeDateChange", selectedMultipleDateRangesChange: "selectedMultipleDateRangesChange", isValidDateChange: "isValidDateChange", closeCalendar: "closeCalendar", closeClicked: "closeClicked" }, host: { listeners: { "focusout": "focusOut($event)" }, properties: { "attr.id": "id", "class.fd-calendar--mobile-landscape": "this.mobileLandscape", "class.fd-calendar--mobile-portrait": "this.mobilePortrait" }, classAttribute: "fd-calendar fd-has-display-block" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => CalendarComponent),
                multi: true
            },
            {
                provide: NG_VALIDATORS,
                useExisting: forwardRef(() => CalendarComponent),
                multi: true
            },
            CalendarService,
            contentDensityObserverProviders(),
            {
                provide: FD_LANGUAGE,
                useFactory: patchDeprecatedI18nLabels
            }
        ], viewQueries: [{ propertyName: "_dayViewComponent", first: true, predicate: CalendarDayViewComponent, descendants: true }, { propertyName: "_monthViewComponent", first: true, predicate: CalendarMonthViewComponent, descendants: true }, { propertyName: "_yearViewComponent", first: true, predicate: CalendarYearViewComponent, descendants: true }, { propertyName: "_aggregatedYearViewComponent", first: true, predicate: CalendarAggregatedYearViewComponent, descendants: true }, { propertyName: "_calendarHeaderComponent", first: true, predicate: CalendarHeaderComponent, descendants: true }], usesOnChanges: true, ngImport: i0, template: "<fd-calendar-header\n    [currentlyDisplayed]=\"_currentlyDisplayed\"\n    [activeView]=\"activeView\"\n    [id]=\"id\"\n    [calendarYearGrid]=\"yearGrid\"\n    (closeClicked)=\"closeClicked.emit()\"\n    (nextClicked)=\"handleNextArrowClick()\"\n    (previousClicked)=\"handlePreviousArrowClick()\"\n    [previousButtonDisabled]=\"previousButtonDisabled\"\n    [nextButtonDisabled]=\"nextButtonDisabled\"\n    (activeViewChange)=\"handleActiveViewChange($event)\"\n></fd-calendar-header>\n@if (_currentlyDisplayed) {\n    @if (activeView === 'day') {\n        <fd-calendar-day-view\n            [selectedDate]=\"selectedDate\"\n            [selectedMultipleDates]=\"selectedMultipleDates\"\n            [selectedRangeDate]=\"selectedRangeDate\"\n            [selectedMultipleDateRanges]=\"selectedMultipleDateRanges\"\n            (selectedDateChange)=\"selectedDateChanged($event)\"\n            (selectedMultipleDatesChange)=\"selectedMultipleDatesChanged($event)\"\n            (selectedRangeDateChange)=\"selectedRangeDateChanged($event)\"\n            (selectedMultipleDateRangesChange)=\"selectedMultipleDateRangesChanged($event)\"\n            [showWeekNumbers]=\"showWeekNumbers\"\n            [allowMultipleSelection]=\"allowMultipleSelection\"\n            [markWeekends]=\"markWeekends\"\n            [currentlyDisplayed]=\"_currentlyDisplayed\"\n            [startingDayOfWeek]=\"getWeekStartDay()\"\n            [disableFunction]=\"disableFunction\"\n            [disableRangeEndFunction]=\"disableRangeEndFunction\"\n            [disableRangeStartFunction]=\"disableRangeStartFunction\"\n            [calType]=\"calType\"\n            [id]=\"id\"\n            [rangeHoverEffect]=\"rangeHoverEffect\"\n            [specialDaysRules]=\"specialDaysRules\"\n            [focusEscapeFunction]=\"escapeFocusFunction\"\n            (nextMonthSelect)=\"displayNextMonth()\"\n            (previousMonthSelect)=\"displayPreviousMonth()\"\n            [associatedLegendId]=\"associatedLegendId\"\n        ></fd-calendar-day-view>\n    } @else if (activeView === 'month') {\n        <fd-calendar-month-view\n            [monthSelected]=\"_currentlyDisplayed.month\"\n            [year]=\"_currentlyDisplayed.year\"\n            [id]=\"id\"\n            [focusEscapeFunction]=\"escapeFocusFunction\"\n            [isDateRangeMonthYearFormat]=\"isDateRangeMonthFormat()\"\n            [selectedRangeDate]=\"selectedRangeDate\"\n            [rangeHoverEffect]=\"rangeHoverEffect\"\n            (selectedRangeDateChange)=\"selectedRangeDateChanged($event)\"\n            (monthClicked)=\"handleMonthViewChange($event)\"\n        ></fd-calendar-month-view>\n    } @else if (activeView === 'year') {\n        <fd-calendar-year-view\n            [yearSelected]=\"_currentlyDisplayed.year\"\n            [yearViewGrid]=\"yearGrid\"\n            [id]=\"id\"\n            [focusEscapeFunction]=\"escapeFocusFunction\"\n            [isDateRangeYearFormat]=\"isDateRangeYearFormat()\"\n            [selectedRangeDate]=\"selectedRangeDate\"\n            [rangeHoverEffect]=\"rangeHoverEffect\"\n            (selectedRangeDateChange)=\"selectedRangeDateChanged($event)\"\n            (yearClicked)=\"selectedYear($event)\"\n        >\n        </fd-calendar-year-view>\n    } @else if (activeView === 'aggregatedYear') {\n        <fd-calendar-aggregated-year-view\n            (yearsClicked)=\"selectedYears($event)\"\n            [yearSelected]=\"_currentlyDisplayed.year\"\n            [yearViewGrid]=\"yearGrid\"\n            [aggregatedYearsViewGrid]=\"aggregatedYearGrid\"\n            [id]=\"id\"\n            [focusEscapeFunction]=\"escapeFocusFunction\"\n        >\n        </fd-calendar-aggregated-year-view>\n    }\n}\n", styles: [".fd-calendar .fd-calendar__my-item,.fd-calendar__item{background-color:var(--fdCalendar_Item_Background);border:0;border-radius:var(--fdCalendar_Border_Radius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-block:var(--fdCalendar_Item_Spacing);margin-inline:0;margin-inline:var(--fdCalendar_Item_Spacing);min-width:var(--fdCalendar_Item_Width);overflow:hidden;padding-block:0;padding-inline:0;position:relative;-webkit-box-flex:1;border:var(--fdCalendar_Item_Border);cursor:pointer;display:inline-block;-ms-flex:1 1 calc(var(--fdCalendar_Item_Current_Border_Width)*2 + var(--fdCalendar_Item_Spacing)*2);flex:1 1 calc(var(--fdCalendar_Item_Current_Border_Width)*2 + var(--fdCalendar_Item_Spacing)*2)}.fd-calendar .fd-calendar__my-item:after,.fd-calendar .fd-calendar__my-item:before,.fd-calendar__item:after,.fd-calendar__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}[class*=fd-calendar__item--legend-]:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{border-bottom:none;border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:0;content:\"\";height:.3125rem;left:0;position:absolute;right:0;width:100%}[class*=fd-calendar__item--legend-]:not(.fd-calendar__item--today).is-focus,[class*=fd-calendar__item--legend-]:not(.fd-calendar__item--today):focus{z-index:5}[class*=fd-calendar__item--legend-]:not(.fd-calendar__item--today).is-focus .fd-calendar__text-wrapper:after,[class*=fd-calendar__item--legend-]:not(.fd-calendar__item--today):focus .fd-calendar__text-wrapper:after{z-index:var(--fdCalendar_Text_Wrapper_After_Z)}.fd-calendar__item--today[class*=fd-calendar__item--legend-].is-focus,.fd-calendar__item--today[class*=fd-calendar__item--legend-]:focus{z-index:5}.fd-calendar__item--today[class*=fd-calendar__item--legend-].is-focus .fd-calendar__text-wrapper:after,.fd-calendar__item--today[class*=fd-calendar__item--legend-]:focus .fd-calendar__text-wrapper:after{border-bottom:none}.fd-calendar__item--today[class*=fd-calendar__item--legend-].is-focus .fd-calendar__text:after,.fd-calendar__item--today[class*=fd-calendar__item--legend-]:focus .fd-calendar__text:after{bottom:0;content:\"\";height:.1875rem;left:0;position:absolute;right:0;width:100%}.fd-calendar__item--today[class*=fd-calendar__item--legend-] .fd-calendar__text-wrapper:after{border-radius:.3125rem;bottom:.0625rem;content:\"\";height:.5rem;left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today[class*=fd-calendar__item--legend-][dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today[class*=fd-calendar__item--legend-] .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-1:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor1);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor1)}.fd-calendar__item--legend-1:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-1:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-1.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-1:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-1.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-1:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor1);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor1)}.fd-calendar__item--today.fd-calendar__item--legend-1 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor1);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-1[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-1 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-2:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor2);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor2)}.fd-calendar__item--legend-2:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-2:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-2.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-2:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-2.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-2:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor2);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor2)}.fd-calendar__item--today.fd-calendar__item--legend-2 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor2);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-2[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-2 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-3:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor3);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor3)}.fd-calendar__item--legend-3:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-3:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-3.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-3:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-3.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-3:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor3);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor3)}.fd-calendar__item--today.fd-calendar__item--legend-3 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor3);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-3[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-3 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-4:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor4);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor4)}.fd-calendar__item--legend-4:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-4:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-4.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-4:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-4.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-4:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor4);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor4)}.fd-calendar__item--today.fd-calendar__item--legend-4 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor4);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-4[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-4 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-5:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor5);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor5)}.fd-calendar__item--legend-5:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-5:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-5.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-5:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-5.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-5:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor5);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor5)}.fd-calendar__item--today.fd-calendar__item--legend-5 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor5);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-5[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-5 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-6:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor6);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor6)}.fd-calendar__item--legend-6:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-6:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-6.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-6:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-6.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-6:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor6);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor6)}.fd-calendar__item--today.fd-calendar__item--legend-6 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor6);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-6[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-6 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-7:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor7);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor7)}.fd-calendar__item--legend-7:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-7:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-7.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-7:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-7.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-7:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor7);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor7)}.fd-calendar__item--today.fd-calendar__item--legend-7 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor7);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-7[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-7 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-8:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor8);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor8)}.fd-calendar__item--legend-8:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-8:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-8.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-8:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-8.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-8:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor8);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor8)}.fd-calendar__item--today.fd-calendar__item--legend-8 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor8);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-8[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-8 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-9:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor9);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor9)}.fd-calendar__item--legend-9:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-9:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-9.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-9:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-9.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-9:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor9);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor9)}.fd-calendar__item--today.fd-calendar__item--legend-9 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor9);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-9[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-9 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-10:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor10);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor10)}.fd-calendar__item--legend-10:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-10:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-10.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-10:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-10.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-10:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor10);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor10)}.fd-calendar__item--today.fd-calendar__item--legend-10 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor10);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-10[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-10 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-11:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor11);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor11)}.fd-calendar__item--legend-11:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-11:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-11.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-11:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-11.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-11:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor11);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor11)}.fd-calendar__item--today.fd-calendar__item--legend-11 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor11);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-11[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-11 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-12:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor12);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor12)}.fd-calendar__item--legend-12:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-12:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-12.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-12:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-12.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-12:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor12);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor12)}.fd-calendar__item--today.fd-calendar__item--legend-12 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor12);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-12[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-12 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-13:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor13);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor13)}.fd-calendar__item--legend-13:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-13:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-13.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-13:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-13.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-13:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor13);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor13)}.fd-calendar__item--today.fd-calendar__item--legend-13 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor13);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-13[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-13 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-14:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor14);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor14)}.fd-calendar__item--legend-14:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-14:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-14.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-14:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-14.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-14:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor14);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor14)}.fd-calendar__item--today.fd-calendar__item--legend-14 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor14);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-14[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-14 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-15:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor15);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor15)}.fd-calendar__item--legend-15:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-15:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-15.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-15:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-15.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-15:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor15);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor15)}.fd-calendar__item--today.fd-calendar__item--legend-15 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor15);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-15[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-15 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-16:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor16);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor16)}.fd-calendar__item--legend-16:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-16:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-16.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-16:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-16.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-16:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor16);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor16)}.fd-calendar__item--today.fd-calendar__item--legend-16 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor16);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-16[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-16 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-17:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor17);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor17)}.fd-calendar__item--legend-17:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-17:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-17.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-17:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-17.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-17:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor17);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor17)}.fd-calendar__item--today.fd-calendar__item--legend-17 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor17);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-17[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-17 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-18:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor18);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor18)}.fd-calendar__item--legend-18:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-18:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-18.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-18:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-18.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-18:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor18);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor18)}.fd-calendar__item--today.fd-calendar__item--legend-18 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor18);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-18[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-18 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-19:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor19);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor19)}.fd-calendar__item--legend-19:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-19:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-19.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-19:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-19.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-19:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor19);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor19)}.fd-calendar__item--today.fd-calendar__item--legend-19 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor19);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-19[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-19 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-20:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor20);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor20)}.fd-calendar__item--legend-20:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-20:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-20.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-20:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-20.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-20:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor20);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor20)}.fd-calendar__item--today.fd-calendar__item--legend-20 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor20);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-20[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-20 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar{--fdCalendar_Item_Width:2rem;--fdCalendar_Item_Height:2.75rem;--fdCalendar_Padding:.5rem;--fdCalendar_Background:var(--sapList_Background);--fdCalendar_Width:calc(var(--fdCalendar_Item_Width)*8 + var(--fdCalendar_Padding)*2 + var(--fdCalendar_Item_Spacing)*16);--fdCalendar_Action_Padding:.25rem;--fdCalendar_Action_Width:auto;--fdCalendar_Button_Horizontal_Space:.25rem;--fdCalendar_Item_Spacing:.0625rem;--fdCalendar_Item_Background:var(--sapLegend_WorkingBackground);--fdCalendar_Item_Helper_Height:1.875rem;--fdCalendar_Item_Font_Size:var(--sapFontSize);--fdCalendar_Item_Border:0;--fdCalendar_Item_Current_Border_Width:.125rem;--fdCalendar_Item_Text_Color:var(--sapTextColor);--fdCalendar_Item_Text_Height:2.125rem;background-color:var(--fdCalendar_Background);border:0;border-radius:var(--fdCalendar_Border_Radius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:var(--fdCalendar_Padding);padding-inline:0;padding-inline:var(--fdCalendar_Padding);width:var(--fdCalendar_Width)}.fd-calendar:after,.fd-calendar:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__navigation{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:var(--fdCalendar_Button_Horizontal_Space);padding-inline:0;position:relative;width:100%;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.fd-calendar__navigation:after,.fd-calendar__navigation:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__action{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1}.fd-calendar__action:after,.fd-calendar__action:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__action:not(:last-child,:first-child){margin-inline:var(--fdCalendar_Action_Padding)}.fd-calendar__action:first-child{-webkit-margin-end:var(--fdCalendar_Action_Padding);margin-inline-end:var(--fdCalendar_Action_Padding)}.fd-calendar__action:last-child{-webkit-margin-start:var(--fdCalendar_Action_Padding);margin-inline-start:var(--fdCalendar_Action_Padding)}.fd-calendar__action>[type=button]{width:100%}.fd-calendar__action--arrow-left,.fd-calendar__action--arrow-right{-webkit-box-flex:0;-ms-flex-positive:0;flex-grow:0;width:var(--fdCalendar_Action_Width)}.fd-calendar__action--arrow-left+.fd-calendar__action--arrow-right{-webkit-margin-start:auto;margin-inline-start:auto}.fd-calendar__action [class*=sap-icon][dir=rtl],[dir=rtl] .fd-calendar__action [class*=sap-icon]{-webkit-transform:scaleX(-1);transform:scaleX(-1)}.fd-calendar__text-wrapper{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:100%}.fd-calendar__text-wrapper:after,.fd-calendar__text-wrapper:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__item{height:var(--fdCalendar_Item_Height)}.fd-calendar__item.is-hover,.fd-calendar__item:hover{--fdCalendar_Item_Background:var(--sapList_Hover_Background)}.fd-calendar__item.is-disabled,.fd-calendar__item:disabled,.fd-calendar__item[aria-disabled=true]{opacity:.4;pointer-events:none}.fd-calendar__item--weekend{--fdCalendar_Item_Background:var(--sapLegend_NonWorkingBackground)}.fd-calendar__item--weekend.is-hover,.fd-calendar__item--weekend:hover{--fdCalendar_Item_Background:var(--sapList_Hover_Background);-webkit-filter:brightness(1.05);filter:brightness(1.05)}.fd-calendar__item--other{--fdCalendar_Item_Background:var(--fdCalendar_Background)}.fd-calendar__item--other.is-hover,.fd-calendar__item--other:hover{--fdCalendar_Item_Background:var(--sapList_Hover_Background)}.fd-calendar__item--other .fd-calendar__text{--fdCalendar_Item_Text_Color:var(--sapContent_LabelColor)}.fd-calendar__item--selected{--fdCalendar_Item_Background:var(--sapContent_Selected_Background);--fdCalendar_Item_Border:var(--fdCalendar_Active_Item_Border)}.fd-calendar__item--selected.is-hover,.fd-calendar__item--selected:hover{--fdCalendar_Item_Background:var(--fdCalendar_Item_Active_Background_Hover)}.fd-calendar__item--selected .fd-calendar__text{--fdCalendar_Item_Text_Color:var(--sapContent_Selected_TextColor);font-family:var(--fdCalendar_Active_Item_Font_Weight)}.fd-calendar__item--range{--fdCalendar_Item_Border:var(--fdCalendar_Active_Item_Border);--fdCalendar_Item_Background:var(--sapList_SelectionBackgroundColor)}.fd-calendar__item--range.is-hover,.fd-calendar__item--range:hover{--fdCalendar_Item_Background:var(--sapList_Hover_SelectionBackground)}.fd-calendar__item--today.fd-calendar__item--range:after,.fd-calendar__item--today.fd-calendar__item--selected:after{border:.0625rem solid var(--sapList_SelectionBorderColor);border-radius:var(--fdCalendar_Item_Today_Selected_Bottom_Radius);bottom:.0625rem;content:\"\";height:calc(100% - .125rem);left:.0625rem;position:absolute;top:.0625rem;width:calc(100% - .125rem)}.fd-calendar__item--today{--fdCalendar_Item_Border:solid .125rem var(--sapLegend_CurrentDateTime);-webkit-box-shadow:0 0 0 .0625rem var(--sapList_Background) inset;box-shadow:0 0 0 .0625rem var(--sapList_Background) inset;position:relative}.fd-calendar__item--today:after{border-radius:.3125rem;bottom:.0625rem;content:\"\";height:calc(100% - .125rem);left:.0625rem;position:absolute;top:.0625rem;width:calc(100% - .125rem)}.fd-calendar__item.fd-calendar__item--selected.is-focus,.fd-calendar__item.fd-calendar__item--selected:focus{z-index:5}.fd-calendar__item.fd-calendar__item--selected.is-focus .fd-calendar__text-wrapper,.fd-calendar__item.fd-calendar__item--selected:focus .fd-calendar__text-wrapper{border:var(--fdCalendar_Item_Text_Active_Focus)}.fd-calendar__item:focus-visible{outline:none}.fd-calendar__item.is-focus,.fd-calendar__item:focus{z-index:5}.fd-calendar__item.is-focus .fd-calendar__text-wrapper,.fd-calendar__item:focus .fd-calendar__text-wrapper{border:var(--fdCalendar_Text_Wrapper_Border);-webkit-box-sizing:var(--fdCalendar_Text_Wrapper_Box_Sizing);box-sizing:var(--fdCalendar_Text_Wrapper_Box_Sizing);height:var(--fdCalendar_Text_Wrapper_Height);margin-block:var(--fdCalendar_Text_Wrapper_Margin);margin-inline:var(--fdCalendar_Text_Wrapper_Margin)}.fd-calendar__item.is-focus .fd-calendar__text,.fd-calendar__item:focus .fd-calendar__text{border:var(--fdCalendar_Text_Border_Focus)}.fd-calendar__item--side-helper{-ms-flex-item-align:center;align-self:center;pointer-events:none;--fdCalendar_Item_Height:var(--fdCalendar_Item_Side_Helper,var(--fdCalendar_Item_Helper_Height));--fdCalendar_Item_Background:var(--sapList_Background)}.fd-calendar__item--side-helper .fd-calendar__text{--fdCalendar_Item_Text_Color:var(--sapContent_LabelColor);--fdCalendar_Item_Font_Size:var(--sapFontSmallSize)}.fd-calendar .fd-calendar__my-item{max-height:var(--fdCalendar_Item_Height)}.fd-calendar .fd-calendar__my-item-button{min-width:100%;padding-block:0;padding-inline:0}.fd-calendar .fd-calendar__my-item .fd-calendar__text{color:inherit}.fd-calendar__content{border:0;border-spacing:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:table;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%}.fd-calendar__content:after,.fd-calendar__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__content--months,.fd-calendar__content--years{-webkit-padding-before:var(--fdCalendar_Item_Helper_Height);padding-block-start:var(--fdCalendar_Item_Helper_Height);--fdCalendar_Item_Background:transparent}.fd-calendar__content--screen-reader-only{position:absolute;clip:rect(0 0 0 0);border:0;height:1px;margin-block:-1px;margin-inline:-1px;overflow:hidden;padding-block:0;padding-inline:0;white-space:nowrap;width:1px}.fd-calendar__group{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:table-row-group;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-calendar__group:after,.fd-calendar__group:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__row{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-calendar__row:after,.fd-calendar__row:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;border-radius:.1875rem;color:var(--fdCalendar_Item_Text_Color);font-size:var(--fdCalendar_Item_Font_Size);height:var(--fdCalendar_Item_Text_Height);min-width:1.375rem;text-shadow:var(--fdCalendar_Text_Shadow);-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;max-width:calc(100% - .7rem);position:relative}.fd-calendar__text:after,.fd-calendar__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__text.is-focus,.fd-calendar__text:focus{border:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);z-index:5}.fd-calendar[class*=-compact],.fd-calendar[class*=-condensed],[class*=-compact] .fd-calendar:not([class*=-cozy]),[class*=-condensed] .fd-calendar:not([class*=-cozy]){--fdCalendar_Width:calc(var(--fdCalendar_Action_Width)*8 + var(--fdCalendar_Padding)*2 + var(--fdCalendar_Item_Spacing)*16);--fdCalendar_Padding:.5rem;--fdCalendar_Item_Text_Height:1.375rem;--fdCalendar_Item_Height:2rem;--fdCalendar_Button_Horizontal_Space:.1875rem;--fdCalendar_Action_Width:2rem;--fdCalendar_Item_Width:var(--fdCalendar_Action_Width)}.fd-calendar--mobile-landscape,.fd-calendar--mobile-portrait{height:100%;width:100%}.fd-calendar--mobile-landscape{--fdCalendar_Padding:0;--fdCalendar_Item_Side_Helper:1.625rem}.fd-calendar--mobile-landscape .fd-calendar__navigation--main{max-width:20rem}.fd-calendar--mobile-portrait{--fdCalendar_Padding:0;-webkit-padding-before:1rem;padding-block-start:1rem}.fd-calendar-legend{background:var(--sapList_Background);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);-webkit-column-width:var(--fdCalendar_Legend_Column_Width,7.5rem);-moz-column-width:var(--fdCalendar_Legend_Column_Width,7.5rem);column-width:var(--fdCalendar_Legend_Column_Width,7.5rem);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:.5rem;padding-inline:0;padding-inline:.5rem}.fd-calendar-legend:after,.fd-calendar-legend:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar-legend--auto-column{--fdCalendar_Legend_Column_Width:auto}.fd-calendar-legend__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;border-radius:.25rem;-ms-flex-direction:row;flex-direction:row;gap:.5rem;min-width:7.5rem;padding-block:var(--fdCalendar_Legend_Item_Padding,.25rem);padding-inline:var(--fdCalendar_Legend_Item_Padding,.25rem)}.fd-calendar-legend__item:after,.fd-calendar-legend__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar-legend__item.is-focus,.fd-calendar-legend__item:focus{z-index:5}.fd-calendar-legend__item.is-active,.fd-calendar-legend__item.is-focus,.fd-calendar-legend__item:active,.fd-calendar-legend__item:focus{-webkit-box-shadow:0 0 0 var(--sapContent_FocusWidth) var(--sapContent_FocusColor) inset;box-shadow:0 0 0 var(--sapContent_FocusWidth) var(--sapContent_FocusColor) inset}.fd-calendar-legend__item--appointment{--fdCalendar_Legend_Marker_Border_Radius:1rem}.fd-calendar-legend__item--today{--fdCalendar_Legend_Marker_Border_Width:.125rem;--fdCalendar_Legend_Marker_Background:var(--sapList_Background);--fdCalendar_Legend_Marker_Border_Color:var(--sapLegend_CurrentDateTime)}.fd-calendar-legend__item--selected{--fdCalendar_Legend_Marker_Background:var(--sapSelectedColor)}.fd-calendar-legend__item--work{--fdCalendar_Legend_Marker_Background:var(--sapLegend_WorkingBackground)}.fd-calendar-legend__item--non-work{--fdCalendar_Legend_Marker_Background:var(--sapLegend_NonWorkingBackground)}.fd-calendar-legend__item--placeholder-1{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor1)}.fd-calendar-legend__item--placeholder-2{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor2)}.fd-calendar-legend__item--placeholder-3{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor3)}.fd-calendar-legend__item--placeholder-4{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor4)}.fd-calendar-legend__item--placeholder-5{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor5)}.fd-calendar-legend__item--placeholder-6{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor6)}.fd-calendar-legend__item--placeholder-7{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor7)}.fd-calendar-legend__item--placeholder-8{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor8)}.fd-calendar-legend__item--placeholder-9{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor9)}.fd-calendar-legend__item--placeholder-10{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor10)}.fd-calendar-legend__item--placeholder-11{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor11)}.fd-calendar-legend__item--placeholder-12{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor12)}.fd-calendar-legend__item--placeholder-13{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor13)}.fd-calendar-legend__item--placeholder-14{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor14)}.fd-calendar-legend__item--placeholder-15{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor15)}.fd-calendar-legend__item--placeholder-16{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor16)}.fd-calendar-legend__item--placeholder-17{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor17)}.fd-calendar-legend__item--placeholder-18{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor18)}.fd-calendar-legend__item--placeholder-19{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor19)}.fd-calendar-legend__item--placeholder-20{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor20)}.fd-calendar-legend__marker{background:var(--fdCalendar_Legend_Marker_Background,var(--sapList_Background));border:0;border-color:var(--fdCalendar_Legend_Marker_Border_Color,var(--sapContent_ForegroundBorderColor));border-radius:var(--fdCalendar_Legend_Marker_Border_Radius,0);border-style:solid;border-width:var(--fdCalendar_Legend_Marker_Border_Width,.0625rem);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:1rem;line-height:normal;margin-block:0;margin-inline:0;max-height:1rem;max-width:1rem;min-height:1rem;min-width:1rem;padding-block:0;padding-inline:0;width:1rem}.fd-calendar-legend__marker:after,.fd-calendar-legend__marker:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar-legend__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontSmallSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;vertical-align:middle;white-space:pre-line}.fd-calendar-legend__text:after,.fd-calendar-legend__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar-legend[class*=-compact],.fd-calendar-legend[class*=-condensed],[class*=-compact] .fd-calendar-legend:not([class*=-cozy]),[class*=-condensed] .fd-calendar-legend:not([class*=-cozy]){--fdCalendar_Legend_Item_Padding:.125rem}.fd-has-display-block{display:block}.fd-calendar__text{max-width:calc(100% - .375rem)}\n/*! Bundled license information:\n\nfundamental-styles/dist/calendar.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "ngmodule", type: ContentDensityModule }, { kind: "component", type: CalendarHeaderComponent, selector: "fd-calendar-header", inputs: ["activeView", "currentlyDisplayed", "previousButtonDisabled", "nextButtonDisabled", "calendarYearGrid", "id", "mobileLandscape"], outputs: ["activeViewChange", "previousClicked", "nextClicked"] }, { kind: "component", type: CalendarDayViewComponent, selector: "fd-calendar-day-view", inputs: ["currentlyDisplayed", "selectedDate", "selectedMultipleDates", "selectedRangeDate", "selectedMultipleDateRanges", "disableFunction", "disableRangeStartFunction", "disableRangeEndFunction", "startingDayOfWeek", "calType", "id", "associatedLegendId", "rangeHoverEffect", "markWeekends", "showWeekNumbers", "allowMultipleSelection", "focusEscapeFunction", "specialDaysRules"], outputs: ["nextMonthSelect", "previousMonthSelect", "selectedDateChange", "selectedMultipleDatesChange", "selectedRangeDateChange", "selectedMultipleDateRangesChange", "disableFunctionChange", "disableRangeStartFunctionChange", "disableRangeEndFunctionChange", "startingDayOfWeekChange", "calTypeChange", "rangeHoverEffectChange", "allowMultipleSelectionChange"] }, { kind: "component", type: CalendarMonthViewComponent, selector: "fd-calendar-month-view", inputs: ["id", "monthSelected", "focusEscapeFunction", "year", "isDateRangeMonthYearFormat", "rangeHoverEffect", "selectedRangeDate"], outputs: ["monthClicked", "selectedRangeDateChange"] }, { kind: "component", type: CalendarYearViewComponent, selector: "fd-calendar-year-view", inputs: ["id", "focusEscapeFunction", "yearSelected", "yearViewGrid", "isDateRangeYearFormat", "rangeHoverEffect", "selectedRangeDate"], outputs: ["yearClicked", "selectedRangeDateChange"] }, { kind: "component", type: CalendarAggregatedYearViewComponent, selector: "fd-calendar-aggregated-year-view", inputs: ["id", "focusEscapeFunction", "yearSelected", "aggregatedYearsViewGrid", "yearViewGrid"], outputs: ["yearsClicked"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-calendar', encapsulation: ViewEncapsulation.None, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => CalendarComponent),
                            multi: true
                        },
                        {
                            provide: NG_VALIDATORS,
                            useExisting: forwardRef(() => CalendarComponent),
                            multi: true
                        },
                        CalendarService,
                        contentDensityObserverProviders(),
                        {
                            provide: FD_LANGUAGE,
                            useFactory: patchDeprecatedI18nLabels
                        }
                    ], host: {
                        '[attr.id]': 'id',
                        class: 'fd-calendar fd-has-display-block'
                    }, changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        ContentDensityModule,
                        CalendarHeaderComponent,
                        CalendarDayViewComponent,
                        CalendarMonthViewComponent,
                        CalendarYearViewComponent,
                        CalendarAggregatedYearViewComponent
                    ], template: "<fd-calendar-header\n    [currentlyDisplayed]=\"_currentlyDisplayed\"\n    [activeView]=\"activeView\"\n    [id]=\"id\"\n    [calendarYearGrid]=\"yearGrid\"\n    (closeClicked)=\"closeClicked.emit()\"\n    (nextClicked)=\"handleNextArrowClick()\"\n    (previousClicked)=\"handlePreviousArrowClick()\"\n    [previousButtonDisabled]=\"previousButtonDisabled\"\n    [nextButtonDisabled]=\"nextButtonDisabled\"\n    (activeViewChange)=\"handleActiveViewChange($event)\"\n></fd-calendar-header>\n@if (_currentlyDisplayed) {\n    @if (activeView === 'day') {\n        <fd-calendar-day-view\n            [selectedDate]=\"selectedDate\"\n            [selectedMultipleDates]=\"selectedMultipleDates\"\n            [selectedRangeDate]=\"selectedRangeDate\"\n            [selectedMultipleDateRanges]=\"selectedMultipleDateRanges\"\n            (selectedDateChange)=\"selectedDateChanged($event)\"\n            (selectedMultipleDatesChange)=\"selectedMultipleDatesChanged($event)\"\n            (selectedRangeDateChange)=\"selectedRangeDateChanged($event)\"\n            (selectedMultipleDateRangesChange)=\"selectedMultipleDateRangesChanged($event)\"\n            [showWeekNumbers]=\"showWeekNumbers\"\n            [allowMultipleSelection]=\"allowMultipleSelection\"\n            [markWeekends]=\"markWeekends\"\n            [currentlyDisplayed]=\"_currentlyDisplayed\"\n            [startingDayOfWeek]=\"getWeekStartDay()\"\n            [disableFunction]=\"disableFunction\"\n            [disableRangeEndFunction]=\"disableRangeEndFunction\"\n            [disableRangeStartFunction]=\"disableRangeStartFunction\"\n            [calType]=\"calType\"\n            [id]=\"id\"\n            [rangeHoverEffect]=\"rangeHoverEffect\"\n            [specialDaysRules]=\"specialDaysRules\"\n            [focusEscapeFunction]=\"escapeFocusFunction\"\n            (nextMonthSelect)=\"displayNextMonth()\"\n            (previousMonthSelect)=\"displayPreviousMonth()\"\n            [associatedLegendId]=\"associatedLegendId\"\n        ></fd-calendar-day-view>\n    } @else if (activeView === 'month') {\n        <fd-calendar-month-view\n            [monthSelected]=\"_currentlyDisplayed.month\"\n            [year]=\"_currentlyDisplayed.year\"\n            [id]=\"id\"\n            [focusEscapeFunction]=\"escapeFocusFunction\"\n            [isDateRangeMonthYearFormat]=\"isDateRangeMonthFormat()\"\n            [selectedRangeDate]=\"selectedRangeDate\"\n            [rangeHoverEffect]=\"rangeHoverEffect\"\n            (selectedRangeDateChange)=\"selectedRangeDateChanged($event)\"\n            (monthClicked)=\"handleMonthViewChange($event)\"\n        ></fd-calendar-month-view>\n    } @else if (activeView === 'year') {\n        <fd-calendar-year-view\n            [yearSelected]=\"_currentlyDisplayed.year\"\n            [yearViewGrid]=\"yearGrid\"\n            [id]=\"id\"\n            [focusEscapeFunction]=\"escapeFocusFunction\"\n            [isDateRangeYearFormat]=\"isDateRangeYearFormat()\"\n            [selectedRangeDate]=\"selectedRangeDate\"\n            [rangeHoverEffect]=\"rangeHoverEffect\"\n            (selectedRangeDateChange)=\"selectedRangeDateChanged($event)\"\n            (yearClicked)=\"selectedYear($event)\"\n        >\n        </fd-calendar-year-view>\n    } @else if (activeView === 'aggregatedYear') {\n        <fd-calendar-aggregated-year-view\n            (yearsClicked)=\"selectedYears($event)\"\n            [yearSelected]=\"_currentlyDisplayed.year\"\n            [yearViewGrid]=\"yearGrid\"\n            [aggregatedYearsViewGrid]=\"aggregatedYearGrid\"\n            [id]=\"id\"\n            [focusEscapeFunction]=\"escapeFocusFunction\"\n        >\n        </fd-calendar-aggregated-year-view>\n    }\n}\n", styles: [".fd-calendar .fd-calendar__my-item,.fd-calendar__item{background-color:var(--fdCalendar_Item_Background);border:0;border-radius:var(--fdCalendar_Border_Radius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-block:var(--fdCalendar_Item_Spacing);margin-inline:0;margin-inline:var(--fdCalendar_Item_Spacing);min-width:var(--fdCalendar_Item_Width);overflow:hidden;padding-block:0;padding-inline:0;position:relative;-webkit-box-flex:1;border:var(--fdCalendar_Item_Border);cursor:pointer;display:inline-block;-ms-flex:1 1 calc(var(--fdCalendar_Item_Current_Border_Width)*2 + var(--fdCalendar_Item_Spacing)*2);flex:1 1 calc(var(--fdCalendar_Item_Current_Border_Width)*2 + var(--fdCalendar_Item_Spacing)*2)}.fd-calendar .fd-calendar__my-item:after,.fd-calendar .fd-calendar__my-item:before,.fd-calendar__item:after,.fd-calendar__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}[class*=fd-calendar__item--legend-]:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{border-bottom:none;border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:0;content:\"\";height:.3125rem;left:0;position:absolute;right:0;width:100%}[class*=fd-calendar__item--legend-]:not(.fd-calendar__item--today).is-focus,[class*=fd-calendar__item--legend-]:not(.fd-calendar__item--today):focus{z-index:5}[class*=fd-calendar__item--legend-]:not(.fd-calendar__item--today).is-focus .fd-calendar__text-wrapper:after,[class*=fd-calendar__item--legend-]:not(.fd-calendar__item--today):focus .fd-calendar__text-wrapper:after{z-index:var(--fdCalendar_Text_Wrapper_After_Z)}.fd-calendar__item--today[class*=fd-calendar__item--legend-].is-focus,.fd-calendar__item--today[class*=fd-calendar__item--legend-]:focus{z-index:5}.fd-calendar__item--today[class*=fd-calendar__item--legend-].is-focus .fd-calendar__text-wrapper:after,.fd-calendar__item--today[class*=fd-calendar__item--legend-]:focus .fd-calendar__text-wrapper:after{border-bottom:none}.fd-calendar__item--today[class*=fd-calendar__item--legend-].is-focus .fd-calendar__text:after,.fd-calendar__item--today[class*=fd-calendar__item--legend-]:focus .fd-calendar__text:after{bottom:0;content:\"\";height:.1875rem;left:0;position:absolute;right:0;width:100%}.fd-calendar__item--today[class*=fd-calendar__item--legend-] .fd-calendar__text-wrapper:after{border-radius:.3125rem;bottom:.0625rem;content:\"\";height:.5rem;left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today[class*=fd-calendar__item--legend-][dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today[class*=fd-calendar__item--legend-] .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-1:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor1);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor1)}.fd-calendar__item--legend-1:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-1:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-1.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-1:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-1.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-1:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor1);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor1)}.fd-calendar__item--today.fd-calendar__item--legend-1 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor1);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-1[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-1 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-2:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor2);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor2)}.fd-calendar__item--legend-2:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-2:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-2.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-2:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-2.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-2:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor2);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor2)}.fd-calendar__item--today.fd-calendar__item--legend-2 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor2);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-2[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-2 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-3:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor3);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor3)}.fd-calendar__item--legend-3:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-3:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-3.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-3:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-3.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-3:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor3);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor3)}.fd-calendar__item--today.fd-calendar__item--legend-3 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor3);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-3[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-3 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-4:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor4);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor4)}.fd-calendar__item--legend-4:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-4:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-4.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-4:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-4.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-4:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor4);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor4)}.fd-calendar__item--today.fd-calendar__item--legend-4 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor4);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-4[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-4 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-5:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor5);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor5)}.fd-calendar__item--legend-5:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-5:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-5.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-5:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-5.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-5:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor5);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor5)}.fd-calendar__item--today.fd-calendar__item--legend-5 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor5);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-5[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-5 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-6:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor6);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor6)}.fd-calendar__item--legend-6:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-6:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-6.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-6:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-6.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-6:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor6);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor6)}.fd-calendar__item--today.fd-calendar__item--legend-6 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor6);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-6[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-6 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-7:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor7);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor7)}.fd-calendar__item--legend-7:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-7:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-7.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-7:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-7.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-7:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor7);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor7)}.fd-calendar__item--today.fd-calendar__item--legend-7 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor7);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-7[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-7 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-8:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor8);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor8)}.fd-calendar__item--legend-8:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-8:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-8.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-8:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-8.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-8:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor8);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor8)}.fd-calendar__item--today.fd-calendar__item--legend-8 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor8);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-8[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-8 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-9:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor9);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor9)}.fd-calendar__item--legend-9:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-9:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-9.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-9:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-9.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-9:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor9);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor9)}.fd-calendar__item--today.fd-calendar__item--legend-9 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor9);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-9[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-9 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-10:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor10);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor10)}.fd-calendar__item--legend-10:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-10:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-10.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-10:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-10.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-10:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor10);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor10)}.fd-calendar__item--today.fd-calendar__item--legend-10 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor10);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-10[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-10 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-11:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor11);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor11)}.fd-calendar__item--legend-11:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-11:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-11.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-11:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-11.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-11:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor11);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor11)}.fd-calendar__item--today.fd-calendar__item--legend-11 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor11);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-11[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-11 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-12:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor12);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor12)}.fd-calendar__item--legend-12:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-12:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-12.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-12:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-12.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-12:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor12);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor12)}.fd-calendar__item--today.fd-calendar__item--legend-12 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor12);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-12[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-12 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-13:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor13);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor13)}.fd-calendar__item--legend-13:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-13:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-13.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-13:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-13.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-13:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor13);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor13)}.fd-calendar__item--today.fd-calendar__item--legend-13 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor13);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-13[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-13 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-14:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor14);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor14)}.fd-calendar__item--legend-14:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-14:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-14.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-14:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-14.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-14:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor14);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor14)}.fd-calendar__item--today.fd-calendar__item--legend-14 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor14);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-14[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-14 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-15:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor15);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor15)}.fd-calendar__item--legend-15:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-15:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-15.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-15:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-15.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-15:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor15);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor15)}.fd-calendar__item--today.fd-calendar__item--legend-15 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor15);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-15[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-15 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-16:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor16);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor16)}.fd-calendar__item--legend-16:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-16:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-16.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-16:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-16.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-16:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor16);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor16)}.fd-calendar__item--today.fd-calendar__item--legend-16 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor16);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-16[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-16 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-17:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor17);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor17)}.fd-calendar__item--legend-17:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-17:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-17.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-17:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-17.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-17:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor17);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor17)}.fd-calendar__item--today.fd-calendar__item--legend-17 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor17);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-17[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-17 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-18:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor18);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor18)}.fd-calendar__item--legend-18:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-18:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-18.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-18:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-18.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-18:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor18);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor18)}.fd-calendar__item--today.fd-calendar__item--legend-18 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor18);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-18[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-18 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-19:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor19);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor19)}.fd-calendar__item--legend-19:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-19:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-19.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-19:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-19.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-19:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor19);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor19)}.fd-calendar__item--today.fd-calendar__item--legend-19 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor19);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-19[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-19 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar__item--legend-20:not(.fd-calendar__item--today) .fd-calendar__text-wrapper:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor20);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor20)}.fd-calendar__item--legend-20:not(.fd-calendar__item--today).fd-calendar__item--range .fd-calendar__text-wrapper:after,.fd-calendar__item--legend-20:not(.fd-calendar__item--today).fd-calendar__item--selected .fd-calendar__text-wrapper:after{height:var(--fdCalendar_Item_Selected_Legend_Height)}.fd-calendar__item--today.fd-calendar__item--legend-20.is-focus,.fd-calendar__item--today.fd-calendar__item--legend-20:focus{z-index:5}.fd-calendar__item--today.fd-calendar__item--legend-20.is-focus .fd-calendar__text:after,.fd-calendar__item--today.fd-calendar__item--legend-20:focus .fd-calendar__text:after{-webkit-box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor20);box-shadow:inset 0 calc(var(--fdCalendar_Special_Day_Marker_Height)*-1) 0 var(--sapLegendColor20)}.fd-calendar__item--today.fd-calendar__item--legend-20 .fd-calendar__text-wrapper:after{border-bottom:.25rem solid var(--sapLegendColor20);border-radius:0 0 var(--fdCalendar_Item_Legend_Bottom_Border_Radius) var(--fdCalendar_Item_Legend_Bottom_Border_Radius);border-top:var(--fdCalendar_Item_Legend_Top_Border);bottom:.0625rem;content:\"\";height:var(--fdCalendar_Item_Text_Wrapper_Height);left:.0625rem;position:absolute;right:0;width:calc(100% - .125rem)}.fd-calendar__item--today.fd-calendar__item--legend-20[dir=rtl] .fd-calendar__text-wrapper:after,[dir=rtl] .fd-calendar__item--today.fd-calendar__item--legend-20 .fd-calendar__text-wrapper:after{left:0;right:.0625rem}.fd-calendar{--fdCalendar_Item_Width:2rem;--fdCalendar_Item_Height:2.75rem;--fdCalendar_Padding:.5rem;--fdCalendar_Background:var(--sapList_Background);--fdCalendar_Width:calc(var(--fdCalendar_Item_Width)*8 + var(--fdCalendar_Padding)*2 + var(--fdCalendar_Item_Spacing)*16);--fdCalendar_Action_Padding:.25rem;--fdCalendar_Action_Width:auto;--fdCalendar_Button_Horizontal_Space:.25rem;--fdCalendar_Item_Spacing:.0625rem;--fdCalendar_Item_Background:var(--sapLegend_WorkingBackground);--fdCalendar_Item_Helper_Height:1.875rem;--fdCalendar_Item_Font_Size:var(--sapFontSize);--fdCalendar_Item_Border:0;--fdCalendar_Item_Current_Border_Width:.125rem;--fdCalendar_Item_Text_Color:var(--sapTextColor);--fdCalendar_Item_Text_Height:2.125rem;background-color:var(--fdCalendar_Background);border:0;border-radius:var(--fdCalendar_Border_Radius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:var(--fdCalendar_Padding);padding-inline:0;padding-inline:var(--fdCalendar_Padding);width:var(--fdCalendar_Width)}.fd-calendar:after,.fd-calendar:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__navigation{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:var(--fdCalendar_Button_Horizontal_Space);padding-inline:0;position:relative;width:100%;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.fd-calendar__navigation:after,.fd-calendar__navigation:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__action{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1}.fd-calendar__action:after,.fd-calendar__action:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__action:not(:last-child,:first-child){margin-inline:var(--fdCalendar_Action_Padding)}.fd-calendar__action:first-child{-webkit-margin-end:var(--fdCalendar_Action_Padding);margin-inline-end:var(--fdCalendar_Action_Padding)}.fd-calendar__action:last-child{-webkit-margin-start:var(--fdCalendar_Action_Padding);margin-inline-start:var(--fdCalendar_Action_Padding)}.fd-calendar__action>[type=button]{width:100%}.fd-calendar__action--arrow-left,.fd-calendar__action--arrow-right{-webkit-box-flex:0;-ms-flex-positive:0;flex-grow:0;width:var(--fdCalendar_Action_Width)}.fd-calendar__action--arrow-left+.fd-calendar__action--arrow-right{-webkit-margin-start:auto;margin-inline-start:auto}.fd-calendar__action [class*=sap-icon][dir=rtl],[dir=rtl] .fd-calendar__action [class*=sap-icon]{-webkit-transform:scaleX(-1);transform:scaleX(-1)}.fd-calendar__text-wrapper{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:100%}.fd-calendar__text-wrapper:after,.fd-calendar__text-wrapper:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__item{height:var(--fdCalendar_Item_Height)}.fd-calendar__item.is-hover,.fd-calendar__item:hover{--fdCalendar_Item_Background:var(--sapList_Hover_Background)}.fd-calendar__item.is-disabled,.fd-calendar__item:disabled,.fd-calendar__item[aria-disabled=true]{opacity:.4;pointer-events:none}.fd-calendar__item--weekend{--fdCalendar_Item_Background:var(--sapLegend_NonWorkingBackground)}.fd-calendar__item--weekend.is-hover,.fd-calendar__item--weekend:hover{--fdCalendar_Item_Background:var(--sapList_Hover_Background);-webkit-filter:brightness(1.05);filter:brightness(1.05)}.fd-calendar__item--other{--fdCalendar_Item_Background:var(--fdCalendar_Background)}.fd-calendar__item--other.is-hover,.fd-calendar__item--other:hover{--fdCalendar_Item_Background:var(--sapList_Hover_Background)}.fd-calendar__item--other .fd-calendar__text{--fdCalendar_Item_Text_Color:var(--sapContent_LabelColor)}.fd-calendar__item--selected{--fdCalendar_Item_Background:var(--sapContent_Selected_Background);--fdCalendar_Item_Border:var(--fdCalendar_Active_Item_Border)}.fd-calendar__item--selected.is-hover,.fd-calendar__item--selected:hover{--fdCalendar_Item_Background:var(--fdCalendar_Item_Active_Background_Hover)}.fd-calendar__item--selected .fd-calendar__text{--fdCalendar_Item_Text_Color:var(--sapContent_Selected_TextColor);font-family:var(--fdCalendar_Active_Item_Font_Weight)}.fd-calendar__item--range{--fdCalendar_Item_Border:var(--fdCalendar_Active_Item_Border);--fdCalendar_Item_Background:var(--sapList_SelectionBackgroundColor)}.fd-calendar__item--range.is-hover,.fd-calendar__item--range:hover{--fdCalendar_Item_Background:var(--sapList_Hover_SelectionBackground)}.fd-calendar__item--today.fd-calendar__item--range:after,.fd-calendar__item--today.fd-calendar__item--selected:after{border:.0625rem solid var(--sapList_SelectionBorderColor);border-radius:var(--fdCalendar_Item_Today_Selected_Bottom_Radius);bottom:.0625rem;content:\"\";height:calc(100% - .125rem);left:.0625rem;position:absolute;top:.0625rem;width:calc(100% - .125rem)}.fd-calendar__item--today{--fdCalendar_Item_Border:solid .125rem var(--sapLegend_CurrentDateTime);-webkit-box-shadow:0 0 0 .0625rem var(--sapList_Background) inset;box-shadow:0 0 0 .0625rem var(--sapList_Background) inset;position:relative}.fd-calendar__item--today:after{border-radius:.3125rem;bottom:.0625rem;content:\"\";height:calc(100% - .125rem);left:.0625rem;position:absolute;top:.0625rem;width:calc(100% - .125rem)}.fd-calendar__item.fd-calendar__item--selected.is-focus,.fd-calendar__item.fd-calendar__item--selected:focus{z-index:5}.fd-calendar__item.fd-calendar__item--selected.is-focus .fd-calendar__text-wrapper,.fd-calendar__item.fd-calendar__item--selected:focus .fd-calendar__text-wrapper{border:var(--fdCalendar_Item_Text_Active_Focus)}.fd-calendar__item:focus-visible{outline:none}.fd-calendar__item.is-focus,.fd-calendar__item:focus{z-index:5}.fd-calendar__item.is-focus .fd-calendar__text-wrapper,.fd-calendar__item:focus .fd-calendar__text-wrapper{border:var(--fdCalendar_Text_Wrapper_Border);-webkit-box-sizing:var(--fdCalendar_Text_Wrapper_Box_Sizing);box-sizing:var(--fdCalendar_Text_Wrapper_Box_Sizing);height:var(--fdCalendar_Text_Wrapper_Height);margin-block:var(--fdCalendar_Text_Wrapper_Margin);margin-inline:var(--fdCalendar_Text_Wrapper_Margin)}.fd-calendar__item.is-focus .fd-calendar__text,.fd-calendar__item:focus .fd-calendar__text{border:var(--fdCalendar_Text_Border_Focus)}.fd-calendar__item--side-helper{-ms-flex-item-align:center;align-self:center;pointer-events:none;--fdCalendar_Item_Height:var(--fdCalendar_Item_Side_Helper,var(--fdCalendar_Item_Helper_Height));--fdCalendar_Item_Background:var(--sapList_Background)}.fd-calendar__item--side-helper .fd-calendar__text{--fdCalendar_Item_Text_Color:var(--sapContent_LabelColor);--fdCalendar_Item_Font_Size:var(--sapFontSmallSize)}.fd-calendar .fd-calendar__my-item{max-height:var(--fdCalendar_Item_Height)}.fd-calendar .fd-calendar__my-item-button{min-width:100%;padding-block:0;padding-inline:0}.fd-calendar .fd-calendar__my-item .fd-calendar__text{color:inherit}.fd-calendar__content{border:0;border-spacing:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:table;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%}.fd-calendar__content:after,.fd-calendar__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__content--months,.fd-calendar__content--years{-webkit-padding-before:var(--fdCalendar_Item_Helper_Height);padding-block-start:var(--fdCalendar_Item_Helper_Height);--fdCalendar_Item_Background:transparent}.fd-calendar__content--screen-reader-only{position:absolute;clip:rect(0 0 0 0);border:0;height:1px;margin-block:-1px;margin-inline:-1px;overflow:hidden;padding-block:0;padding-inline:0;white-space:nowrap;width:1px}.fd-calendar__group{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:table-row-group;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-calendar__group:after,.fd-calendar__group:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__row{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-calendar__row:after,.fd-calendar__row:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;border-radius:.1875rem;color:var(--fdCalendar_Item_Text_Color);font-size:var(--fdCalendar_Item_Font_Size);height:var(--fdCalendar_Item_Text_Height);min-width:1.375rem;text-shadow:var(--fdCalendar_Text_Shadow);-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;max-width:calc(100% - .7rem);position:relative}.fd-calendar__text:after,.fd-calendar__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar__text.is-focus,.fd-calendar__text:focus{border:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);z-index:5}.fd-calendar[class*=-compact],.fd-calendar[class*=-condensed],[class*=-compact] .fd-calendar:not([class*=-cozy]),[class*=-condensed] .fd-calendar:not([class*=-cozy]){--fdCalendar_Width:calc(var(--fdCalendar_Action_Width)*8 + var(--fdCalendar_Padding)*2 + var(--fdCalendar_Item_Spacing)*16);--fdCalendar_Padding:.5rem;--fdCalendar_Item_Text_Height:1.375rem;--fdCalendar_Item_Height:2rem;--fdCalendar_Button_Horizontal_Space:.1875rem;--fdCalendar_Action_Width:2rem;--fdCalendar_Item_Width:var(--fdCalendar_Action_Width)}.fd-calendar--mobile-landscape,.fd-calendar--mobile-portrait{height:100%;width:100%}.fd-calendar--mobile-landscape{--fdCalendar_Padding:0;--fdCalendar_Item_Side_Helper:1.625rem}.fd-calendar--mobile-landscape .fd-calendar__navigation--main{max-width:20rem}.fd-calendar--mobile-portrait{--fdCalendar_Padding:0;-webkit-padding-before:1rem;padding-block-start:1rem}.fd-calendar-legend{background:var(--sapList_Background);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);-webkit-column-width:var(--fdCalendar_Legend_Column_Width,7.5rem);-moz-column-width:var(--fdCalendar_Legend_Column_Width,7.5rem);column-width:var(--fdCalendar_Legend_Column_Width,7.5rem);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:.5rem;padding-inline:0;padding-inline:.5rem}.fd-calendar-legend:after,.fd-calendar-legend:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar-legend--auto-column{--fdCalendar_Legend_Column_Width:auto}.fd-calendar-legend__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;border-radius:.25rem;-ms-flex-direction:row;flex-direction:row;gap:.5rem;min-width:7.5rem;padding-block:var(--fdCalendar_Legend_Item_Padding,.25rem);padding-inline:var(--fdCalendar_Legend_Item_Padding,.25rem)}.fd-calendar-legend__item:after,.fd-calendar-legend__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar-legend__item.is-focus,.fd-calendar-legend__item:focus{z-index:5}.fd-calendar-legend__item.is-active,.fd-calendar-legend__item.is-focus,.fd-calendar-legend__item:active,.fd-calendar-legend__item:focus{-webkit-box-shadow:0 0 0 var(--sapContent_FocusWidth) var(--sapContent_FocusColor) inset;box-shadow:0 0 0 var(--sapContent_FocusWidth) var(--sapContent_FocusColor) inset}.fd-calendar-legend__item--appointment{--fdCalendar_Legend_Marker_Border_Radius:1rem}.fd-calendar-legend__item--today{--fdCalendar_Legend_Marker_Border_Width:.125rem;--fdCalendar_Legend_Marker_Background:var(--sapList_Background);--fdCalendar_Legend_Marker_Border_Color:var(--sapLegend_CurrentDateTime)}.fd-calendar-legend__item--selected{--fdCalendar_Legend_Marker_Background:var(--sapSelectedColor)}.fd-calendar-legend__item--work{--fdCalendar_Legend_Marker_Background:var(--sapLegend_WorkingBackground)}.fd-calendar-legend__item--non-work{--fdCalendar_Legend_Marker_Background:var(--sapLegend_NonWorkingBackground)}.fd-calendar-legend__item--placeholder-1{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor1)}.fd-calendar-legend__item--placeholder-2{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor2)}.fd-calendar-legend__item--placeholder-3{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor3)}.fd-calendar-legend__item--placeholder-4{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor4)}.fd-calendar-legend__item--placeholder-5{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor5)}.fd-calendar-legend__item--placeholder-6{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor6)}.fd-calendar-legend__item--placeholder-7{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor7)}.fd-calendar-legend__item--placeholder-8{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor8)}.fd-calendar-legend__item--placeholder-9{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor9)}.fd-calendar-legend__item--placeholder-10{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor10)}.fd-calendar-legend__item--placeholder-11{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor11)}.fd-calendar-legend__item--placeholder-12{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor12)}.fd-calendar-legend__item--placeholder-13{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor13)}.fd-calendar-legend__item--placeholder-14{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor14)}.fd-calendar-legend__item--placeholder-15{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor15)}.fd-calendar-legend__item--placeholder-16{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor16)}.fd-calendar-legend__item--placeholder-17{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor17)}.fd-calendar-legend__item--placeholder-18{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor18)}.fd-calendar-legend__item--placeholder-19{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor19)}.fd-calendar-legend__item--placeholder-20{--fdCalendar_Legend_Marker_Background:var(--sapLegendColor20)}.fd-calendar-legend__marker{background:var(--fdCalendar_Legend_Marker_Background,var(--sapList_Background));border:0;border-color:var(--fdCalendar_Legend_Marker_Border_Color,var(--sapContent_ForegroundBorderColor));border-radius:var(--fdCalendar_Legend_Marker_Border_Radius,0);border-style:solid;border-width:var(--fdCalendar_Legend_Marker_Border_Width,.0625rem);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:1rem;line-height:normal;margin-block:0;margin-inline:0;max-height:1rem;max-width:1rem;min-height:1rem;min-width:1rem;padding-block:0;padding-inline:0;width:1rem}.fd-calendar-legend__marker:after,.fd-calendar-legend__marker:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar-legend__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontSmallSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;vertical-align:middle;white-space:pre-line}.fd-calendar-legend__text:after,.fd-calendar-legend__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-calendar-legend[class*=-compact],.fd-calendar-legend[class*=-condensed],[class*=-compact] .fd-calendar-legend:not([class*=-cozy]),[class*=-condensed] .fd-calendar-legend:not([class*=-cozy]){--fdCalendar_Legend_Item_Padding:.125rem}.fd-has-display-block{display:block}.fd-calendar__text{max-width:calc(100% - .375rem)}\n/*! Bundled license information:\n\nfundamental-styles/dist/calendar.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i1$1.ContentDensityObserver }, { type: i2.DatetimeAdapter, decorators: [{
                    type: Optional
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [DATE_TIME_FORMATS]
                }] }], propDecorators: { selectedDate: [{
                type: Input
            }], selectedMultipleDates: [{
                type: Input
            }], selectedRangeDate: [{
                type: Input
            }], selectedMultipleDateRanges: [{
                type: Input
            }], markWeekends: [{
                type: Input
            }], showWeekNumbers: [{
                type: Input
            }], allowMultipleSelection: [{
                type: Input
            }], mobileLandscape: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.fd-calendar--mobile-landscape']
            }], mobilePortrait: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['class.fd-calendar--mobile-portrait']
            }], activeView: [{
                type: Input
            }], startingDayOfWeek: [{
                type: Input
            }], calType: [{
                type: Input
            }], id: [{
                type: Input
            }], specialDaysRules: [{
                type: Input
            }], yearGrid: [{
                type: Input
            }], aggregatedYearGrid: [{
                type: Input
            }], rangeHoverEffect: [{
                type: Input
            }], dateRangeFormat: [{
                type: Input
            }], activeViewChange: [{
                type: Output
            }], selectedDateChange: [{
                type: Output
            }], selectedMultipleDatesChange: [{
                type: Output
            }], selectedRangeDateChange: [{
                type: Output
            }], selectedMultipleDateRangesChange: [{
                type: Output
            }], isValidDateChange: [{
                type: Output
            }], closeCalendar: [{
                type: Output
            }], closeClicked: [{
                type: Output
            }], _dayViewComponent: [{
                type: ViewChild,
                args: [CalendarDayViewComponent]
            }], _monthViewComponent: [{
                type: ViewChild,
                args: [CalendarMonthViewComponent]
            }], _yearViewComponent: [{
                type: ViewChild,
                args: [CalendarYearViewComponent]
            }], _aggregatedYearViewComponent: [{
                type: ViewChild,
                args: [CalendarAggregatedYearViewComponent]
            }], _calendarHeaderComponent: [{
                type: ViewChild,
                args: [CalendarHeaderComponent]
            }], previousButtonDisableFunction: [{
                type: Input
            }], nextButtonDisableFunction: [{
                type: Input
            }], associatedLegendId: [{
                type: Input
            }], escapeFocusFunction: [{
                type: Input
            }], disableFunction: [{
                type: Input
            }], disableRangeStartFunction: [{
                type: Input
            }], disableRangeEndFunction: [{
                type: Input
            }], focusOut: [{
                type: HostListener,
                args: ['focusout', ['$event']]
            }] } });

class CalendarModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: CalendarModule, imports: [CalendarComponent,
            CalendarHeaderComponent,
            CalendarDayViewComponent,
            CalendarMonthViewComponent,
            CalendarYearViewComponent,
            CalendarAggregatedYearViewComponent,
            CalendarCloseButtonDirective], exports: [CalendarComponent,
            CalendarDayViewComponent,
            CalendarHeaderComponent,
            CalendarYearViewComponent,
            CalendarMonthViewComponent,
            CalendarAggregatedYearViewComponent,
            CalendarCloseButtonDirective,
            ContentDensityModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarModule, imports: [CalendarComponent,
            CalendarHeaderComponent,
            CalendarMonthViewComponent,
            CalendarYearViewComponent,
            CalendarAggregatedYearViewComponent, ContentDensityModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CalendarModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CalendarComponent,
                        CalendarHeaderComponent,
                        CalendarDayViewComponent,
                        CalendarMonthViewComponent,
                        CalendarYearViewComponent,
                        CalendarAggregatedYearViewComponent,
                        CalendarCloseButtonDirective
                    ],
                    exports: [
                        CalendarComponent,
                        CalendarDayViewComponent,
                        CalendarHeaderComponent,
                        CalendarYearViewComponent,
                        CalendarMonthViewComponent,
                        CalendarAggregatedYearViewComponent,
                        CalendarCloseButtonDirective,
                        ContentDensityModule
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { CalendarAggregatedYearViewComponent, CalendarCloseButtonDirective, CalendarComponent, CalendarDayViewComponent, CalendarHeaderComponent, CalendarI18nLabels, CalendarLegendComponent, CalendarModule, CalendarMonthViewComponent, CalendarService, CalendarTypeEnum, CalendarYearViewComponent, DateRange, FdCalendarViewEnum };
//# sourceMappingURL=fundamental-ngx-core-calendar.mjs.map
