import * as i0 from '@angular/core';
import { InjectionToken, input, EventEmitter, inject, ElementRef, signal, computed, HostListener, Input, Directive, contentChildren, DestroyRef, ContentChildren, Output, contentChild, model, forwardRef, ChangeDetectionStrategy, ViewEncapsulation, Component, booleanAttribute, HostBinding, NgModule } from '@angular/core';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import * as i1 from '@fundamental-ngx/cdk/utils';
import { destroyObservable, KeyboardSupportService, applyCssClass } from '@fundamental-ngx/cdk/utils';
import { Subject, startWith, merge, map, takeUntil, Subscription, tap } from 'rxjs';
import { coerceNumberProperty } from '@angular/cdk/coercion';
import { __decorate, __metadata } from 'tslib';
import * as i1$1 from '@fundamental-ngx/core/content-density';
import { contentDensityObserverProviders, ContentDensityModule } from '@fundamental-ngx/core/content-density';
import { ObjectStatusComponent, buildObjectStatusCssClasses } from '@fundamental-ngx/core/object-status';
import { NgTemplateOutlet } from '@angular/common';
import { FD_AVATAR_COMPONENT } from '@fundamental-ngx/core/avatar';

const FD_CARD = new InjectionToken('FdCardComponent');
const FD_CARD_MAIN_HEADER = new InjectionToken('FdCardMainHeaderComponent');
const FD_CARD_TITLE = new InjectionToken('FdCardTitleDirective');
const FD_CARD_SUBTITLE = new InjectionToken('FdCardSubtitleDirective');
const FD_CARD_SECOND_SUBTITLE = new InjectionToken('FdCardSecondSubtitleDirective');
const FD_CARD_COUNTER = new InjectionToken('FdCardCounterDirective');
const FD_CARD_HEADER_ACTION = new InjectionToken('FdCardHeaderActionDirective');
const FD_CARD_KPI_HEADER = new InjectionToken('FdCardKpiHeaderComponent');
const FD_CARD_MEDIA_HEADING = new InjectionToken('FdCardMediaHeadingComponent');

class CardFocusItem {
    constructor() {
        /**
         * value of the list item.
         */
        this.value = input();
        /**
         * @hidden
         * implementation of KeyboardSupportItemInterface
         */
        this.keyDown = new EventEmitter();
        /** @hidden */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this._focused$ = new Subject();
        /** @hidden */
        this._clicked$ = new Subject();
        /** @hidden */
        this._isFirstItem$ = signal(false);
        /** @hidden */
        this._tabIndex$ = signal(undefined);
        /** @hidden */
        this._normalizedTabIndex$ = computed(() => {
            if (this._isFirstItem$() && isNaN(this._tabIndex$())) {
                return 0;
            }
            return this._tabIndex$() ?? -1;
        });
    }
    /**
     * tab index attribute
     */
    set tabindex(value) {
        this._tabIndex$.set(coerceNumberProperty(value, -1));
    }
    get tabindex() {
        return this._normalizedTabIndex$();
    }
    /** @hidden */
    onFocus(event) {
        this._focused$.next({
            focusedWithin: event.target !== this.elementRef?.nativeElement
        });
    }
    /** @hidden */
    click() {
        this.elementRef?.nativeElement?.click();
    }
    /** @hidden */
    focus() {
        this.elementRef?.nativeElement?.focus();
    }
    /** @hidden */
    setIsFirst(value) {
        this._isFirstItem$.set(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardFocusItem, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.2", type: CardFocusItem, isStandalone: true, inputs: { tabindex: { classPropertyName: "tabindex", publicName: "tabindex", isSignal: false, isRequired: false, transformFunction: null }, value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null } }, host: { listeners: { "focusin": "onFocus($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardFocusItem, decorators: [{
            type: Directive
        }], propDecorators: { tabindex: [{
                type: Input
            }], onFocus: [{
                type: HostListener,
                args: ['focusin', ['$event']]
            }] } });

class CardListDirective {
    /** @hidden */
    constructor(_keyboardSupportService) {
        this._keyboardSupportService = _keyboardSupportService;
        /**
         * an event thrown, when focus escapes the list
         */
        this.focusEscapeList = new EventEmitter();
        /**
         * whether internal keyboard support should be enabled.
         * default: true
         */
        this.keyboardSupport = input(true);
        /**
         * aria-roledescription for the Card list
         * default: 'Card Container'
         */
        this.ariaRoleDescription = input('Card Container');
        /**
         * aria-label for the Card list
         */
        this.ariaLabel = input();
        /** @hidden */
        this._cards = contentChildren(FD_CARD);
        /**
         * an RxJS Subject that will kill the data stream upon component’s destruction
         * for unsubscribing
         */
        this._destroyRef = inject(DestroyRef);
        /**
         * an RxJS Subject that will kill the data stream upon queryList changes
         * for unsubscribing
         */
        this._onRefresh$ = new Subject();
    }
    /** @hidden */
    keyDownHandler(event) {
        if (this.keyboardSupport()) {
            this._keyboardSupportService.onKeyDown(event);
        }
    }
    /** Set fake focus on element with passed index */
    setItemActive(index, updateOnly = false) {
        if (updateOnly) {
            this._keyboardSupportService.keyManager.updateActiveItem(index);
        }
        else {
            this._keyboardSupportService.keyManager.setActiveItem(index);
        }
    }
    /**
     * @returns Currently active list item.
     */
    getActiveItem() {
        return this._keyboardSupportService.keyManager.activeItem;
    }
    /** @hidden */
    ngOnInit() {
        this._listenOnListFocusEscape();
        this._cards().forEach((card, index) => {
            card.ariaPosinset.set(++index);
            card.ariaSetsize.set(this._cards().length);
        });
    }
    /** @hidden */
    ngAfterContentInit() {
        this._keyboardSupportService.setKeyboardService(this._focusItems, false, false);
        this._listenOnQueryChange();
    }
    /** @hidden */
    ngOnDestroy() {
        this._onRefresh$.next();
        this._onRefresh$.complete();
    }
    /** @hidden */
    _listenOnQueryChange() {
        this._focusItems.changes.pipe(startWith(0), takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._listenOnItemsClick();
        });
    }
    /** @hidden */
    _listenOnItemsClick() {
        this._onRefresh$.next();
        if (!this.keyboardSupport) {
            return;
        }
        const completion$ = merge(this._onRefresh$, destroyObservable(this._destroyRef));
        const interactionChangesIndexes = this._focusItems.map((item, index) => merge(item._clicked$.pipe(map(() => ({ index, updateOnly: false }))), item._focused$.pipe(map(({ focusedWithin }) => ({ index, updateOnly: focusedWithin })))));
        merge(...interactionChangesIndexes)
            .pipe(takeUntil(completion$))
            .subscribe(({ index, updateOnly }) => this.setItemActive(index, updateOnly));
    }
    /** @hidden */
    _listenOnListFocusEscape() {
        this._keyboardSupportService.focusEscapeList
            .pipe(takeUntilDestroyed(this._destroyRef))
            .subscribe((direction) => this.focusEscapeList.emit(direction));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardListDirective, deps: [{ token: i1.KeyboardSupportService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.2.0", version: "20.0.2", type: CardListDirective, isStandalone: true, selector: "[fd-card-list]", inputs: { keyboardSupport: { classPropertyName: "keyboardSupport", publicName: "keyboardSupport", isSignal: true, isRequired: false, transformFunction: null }, ariaRoleDescription: { classPropertyName: "ariaRoleDescription", publicName: "ariaRoleDescription", isSignal: true, isRequired: false, transformFunction: null }, ariaLabel: { classPropertyName: "ariaLabel", publicName: "ariaLabel", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { focusEscapeList: "focusEscapeList" }, host: { attributes: { "role": "list" }, listeners: { "keydown": "keyDownHandler($event)" }, properties: { "attr.aria-roledescription": "ariaRoleDescription()", "attr.aria-label": "ariaLabel()" } }, providers: [KeyboardSupportService], queries: [{ propertyName: "_cards", predicate: FD_CARD, isSignal: true }, { propertyName: "_focusItems", predicate: CardFocusItem }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardListDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-list]',
                    standalone: true,
                    host: {
                        role: 'list',
                        '[attr.aria-roledescription]': 'ariaRoleDescription()',
                        '[attr.aria-label]': 'ariaLabel()'
                    },
                    providers: [KeyboardSupportService]
                }]
        }], ctorParameters: () => [{ type: i1.KeyboardSupportService }], propDecorators: { focusEscapeList: [{
                type: Output
            }], _focusItems: [{
                type: ContentChildren,
                args: [CardFocusItem]
            }], keyDownHandler: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }] } });

const CLASS_NAME = {
    card: 'fd-card',
    cardHeader: 'fd-card__header',
    cardHeaderNonInteractive: 'fd-card__header--non-interactive',
    cardTitle: 'fd-card__title',
    cardSubtitle: 'fd-card__subtitle',
    cardSecondSubtitle: 'fd-card__second-subtitle',
    cardAnalyticalArea: 'fd-card__analytics-area',
    cardAnalytics: 'fd-card__analytics',
    cardAnalyticsText: 'fd-card__analytics-text',
    cardAnalyticsContent: 'fd-card__analytics-content',
    cardAnalyticsKpiValue: 'fd-numeric-content__kpi',
    cardAnalyticsScaleIcon: 'fd-numeric-content__scale-arrow',
    cardAnalyticsScaleText: 'fd-numeric-content__scale-text',
    cardCounter: 'fd-card__counter',
    cardBadge: 'fd-card__badge',
    cardContent: 'fd-card__content',
    cardFooter: 'fd-card__footer',
    cardLoader: 'fd-card__loader'
};

const buildModifierClassName = (className) => `${CLASS_NAME.card}--${className}`;
const getCardModifierClassNameByCardType = (cardType) => {
    switch (cardType) {
        case 'standard':
        case 'component':
        case 'list':
        case 'banner':
        case 'analytical':
        case 'table':
        case 'object':
            return buildModifierClassName(cardType);
        default:
            return '';
    }
};
/** @hidden */
function isTruthy(value) {
    return !!value;
}

let cardId = 0;
class CardComponent extends CardFocusItem {
    /** @hidden */
    constructor(elementRef, _contentDensityObserver) {
        super();
        this.elementRef = elementRef;
        this._contentDensityObserver = _contentDensityObserver;
        /** @hidden */
        this.cardTitle = contentChild(FD_CARD_TITLE);
        /** @hidden */
        this.cardMediaHeading = contentChild(FD_CARD_MEDIA_HEADING);
        /**
         * text for the card badge
         */
        this.badge = input();
        /**
         * icon/glyph for the card badge
         */
        this.badgeIcon = input();
        /**
         * Indication color for the card badge
         * Possible values: integers from 1 to 10
         */
        this.badgeColor = input();
        /**
         * Whether to use secondary set of indication colors for the card badge
         * Default value: false
         */
        this.badgeColorSecondary = input(false);
        /**
         * Color status for the card badge
         * Possible values: 'negative' | 'critical' | 'positive' | 'informative' | 'neutral'
         * Default value: null
         */
        this.badgeStatus = input();
        /**
         * aria-label for the card badge
         * Default value: null
         */
        this.badgeAriaLabel = input();
        /**
         * text for the card second badge
         */
        this.secondBadge = input();
        /**
         * icon/glyph for the card second badge
         */
        this.secondBadgeIcon = input();
        /**
         * Indication color for the card second badge
         * Possible values: integers from 1 to 10
         */
        this.secondBadgeColor = input();
        /**
         * Whether to use secondary set of indication colors for the card second badge
         * Default value: false
         */
        this.secondBadgeColorSecondary = input(false);
        /**
         * Color status for the card second badge
         * Possible values: 'negative' | 'critical' | 'positive' | 'informative' | 'neutral'
         * Default value: null
         */
        this.secondBadgeStatus = input();
        /**
         * aria-label for the card second badge
         * Default value: null
         */
        this.secondBadgeAriaLabel = input();
        /**
         * whether the card is in loading state
         * default: false
         */
        this.isLoading = input(false);
        /**
         * set the Caard type
         * options: 'object' | 'standard' | 'component' | 'analytical' | 'list' | 'table' | 'quickView' | 'linkList' | 'banner'
         * default: 'standard'
         *
         */
        this.cardType = input('standard');
        /**
         * card id
         * if not set, a default value is provided
         */
        this.id = input('fd-card-id-' + cardId++);
        /**
         * card aria-roledescription
         * default: 'Card'
         */
        this.ariaRoledescription = input('Card');
        /**
         * card aria-description
         * default: 'Activate for action or navigation'
         */
        this.ariaDescription = input('Activate for action or navigation');
        /**
         * card aria-label
         * used when there's no title describing the card
         */
        this.ariaLabel = input();
        /**
         * card role
         * default: 'region'
         */
        this.role = input('region');
        /**
         * whether the card is interactive
         * default: false
         */
        this.interactive = input(false);
        /**
         * whether the card is selected
         * default: false
         */
        this.selected = input(false);
        /**
         * value for aria-posinset
         */
        this.ariaPosinset = model();
        /**
         * value for aria-setsize
         */
        this.ariaSetsize = model();
        /**
         * @hidden
         * Implementation of KeyboardSupportItemInterface
         */
        this.keyDown = new EventEmitter();
        /** @hidden */
        this._subscriptions = new Subscription();
        _contentDensityObserver.subscribe();
    }
    /** @hidden */
    keydownHandler(event) {
        this.keyDown.emit(event);
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.card, this.cardType() ? getCardModifierClassNameByCardType(this.cardType()) : ''];
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnDestroy() {
        this._subscriptions.unsubscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardComponent, deps: [{ token: i0.ElementRef }, { token: i1$1.ContentDensityObserver }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CardComponent, isStandalone: true, selector: "fd-card", inputs: { badge: { classPropertyName: "badge", publicName: "badge", isSignal: true, isRequired: false, transformFunction: null }, badgeIcon: { classPropertyName: "badgeIcon", publicName: "badgeIcon", isSignal: true, isRequired: false, transformFunction: null }, badgeColor: { classPropertyName: "badgeColor", publicName: "badgeColor", isSignal: true, isRequired: false, transformFunction: null }, badgeColorSecondary: { classPropertyName: "badgeColorSecondary", publicName: "badgeColorSecondary", isSignal: true, isRequired: false, transformFunction: null }, badgeStatus: { classPropertyName: "badgeStatus", publicName: "badgeStatus", isSignal: true, isRequired: false, transformFunction: null }, badgeAriaLabel: { classPropertyName: "badgeAriaLabel", publicName: "badgeAriaLabel", isSignal: true, isRequired: false, transformFunction: null }, secondBadge: { classPropertyName: "secondBadge", publicName: "secondBadge", isSignal: true, isRequired: false, transformFunction: null }, secondBadgeIcon: { classPropertyName: "secondBadgeIcon", publicName: "secondBadgeIcon", isSignal: true, isRequired: false, transformFunction: null }, secondBadgeColor: { classPropertyName: "secondBadgeColor", publicName: "secondBadgeColor", isSignal: true, isRequired: false, transformFunction: null }, secondBadgeColorSecondary: { classPropertyName: "secondBadgeColorSecondary", publicName: "secondBadgeColorSecondary", isSignal: true, isRequired: false, transformFunction: null }, secondBadgeStatus: { classPropertyName: "secondBadgeStatus", publicName: "secondBadgeStatus", isSignal: true, isRequired: false, transformFunction: null }, secondBadgeAriaLabel: { classPropertyName: "secondBadgeAriaLabel", publicName: "secondBadgeAriaLabel", isSignal: true, isRequired: false, transformFunction: null }, isLoading: { classPropertyName: "isLoading", publicName: "isLoading", isSignal: true, isRequired: false, transformFunction: null }, cardType: { classPropertyName: "cardType", publicName: "cardType", isSignal: true, isRequired: false, transformFunction: null }, id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null }, ariaRoledescription: { classPropertyName: "ariaRoledescription", publicName: "ariaRoledescription", isSignal: true, isRequired: false, transformFunction: null }, ariaDescription: { classPropertyName: "ariaDescription", publicName: "ariaDescription", isSignal: true, isRequired: false, transformFunction: null }, ariaLabel: { classPropertyName: "ariaLabel", publicName: "ariaLabel", isSignal: true, isRequired: false, transformFunction: null }, role: { classPropertyName: "role", publicName: "role", isSignal: true, isRequired: false, transformFunction: null }, interactive: { classPropertyName: "interactive", publicName: "interactive", isSignal: true, isRequired: false, transformFunction: null }, selected: { classPropertyName: "selected", publicName: "selected", isSignal: true, isRequired: false, transformFunction: null }, ariaPosinset: { classPropertyName: "ariaPosinset", publicName: "ariaPosinset", isSignal: true, isRequired: false, transformFunction: null }, ariaSetsize: { classPropertyName: "ariaSetsize", publicName: "ariaSetsize", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { ariaPosinset: "ariaPosinsetChange", ariaSetsize: "ariaSetsizeChange" }, host: { listeners: { "keydown": "keydownHandler($event)" }, properties: { "attr.id": "id()", "attr.role": "role()", "attr.aria-description": "role() === \"listitem\" ? ariaDescription() : null", "attr.aria-roledescription": "ariaRoledescription()", "attr.aria-labelledby": "cardTitle()?.id() || cardMediaHeading()?.id()", "attr.aria-label": "ariaLabel()", "attr.aria-selected": "selected()", "class.fd-card--interactive": "interactive()", "tabindex": "role() === \"listitem\" ? 0 : -1", "attr.aria-posinset": "role() === \"listitem\" ? ariaPosinset() : null", "attr.aria-setsize": "role() === \"listitem\" ? ariaSetsize() : null" } }, providers: [
            contentDensityObserverProviders(),
            {
                provide: FD_CARD,
                useExisting: forwardRef(() => CardComponent)
            },
            {
                provide: CardFocusItem,
                useExisting: forwardRef(() => CardComponent)
            }
        ], queries: [{ propertyName: "cardTitle", first: true, predicate: FD_CARD_TITLE, descendants: true, isSignal: true }, { propertyName: "cardMediaHeading", first: true, predicate: FD_CARD_MEDIA_HEADING, descendants: true, isSignal: true }], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "@if (!isLoading()) {\n    <!-- Badge -->\n\n    @if (badge() || badgeIcon() || secondBadge() || secondBadgeIcon()) {\n        <div class=\"fd-card__badge-container\">\n            @if (badge() || badgeIcon()) {\n                <span\n                    fd-object-status\n                    [inverted]=\"true\"\n                    class=\"fd-card__badge\"\n                    [glyph]=\"badgeIcon()\"\n                    [status]=\"badgeStatus()\"\n                    [indicationColor]=\"badgeColor()\"\n                    [secondaryIndication]=\"badgeColorSecondary()\"\n                    [label]=\"badge()\"\n                    [attr.aria-label]=\"badgeAriaLabel()\"\n                >\n                </span>\n            }\n\n            @if (secondBadge() || secondBadgeIcon()) {\n                <span\n                    fd-object-status\n                    [inverted]=\"true\"\n                    class=\"fd-card__badge\"\n                    [glyph]=\"secondBadgeIcon()\"\n                    [status]=\"secondBadgeStatus()\"\n                    [indicationColor]=\"secondBadgeColor()\"\n                    [secondaryIndication]=\"secondBadgeColorSecondary()\"\n                    [label]=\"secondBadge()\"\n                    [attr.aria-label]=\"secondBadgeAriaLabel()\"\n                >\n                </span>\n            }\n        </div>\n    }\n\n    <!-- Header and Content -->\n    <ng-content></ng-content>\n    <!-- Footer -->\n    <ng-content select=\"fd-card-footer\"></ng-content>\n} @else {\n    <ng-content select=\"fd-card-loader\"></ng-content>\n}\n<!-- Loader -->\n", styles: ["@charset \"UTF-8\";.fd-numeric-content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:3rem;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%}.fd-numeric-content:after,.fd-numeric-content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__kpi-container,.fd-numeric-content__launch-icon-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:100%;overflow:hidden;-webkit-padding-before:.125rem;padding-block-start:.125rem;-webkit-margin-end:.375rem;margin-inline-end:.375rem}.fd-numeric-content__kpi-container:after,.fd-numeric-content__kpi-container:before,.fd-numeric-content__launch-icon-container:after,.fd-numeric-content__launch-icon-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__kpi-container:first-child:last-child,.fd-numeric-content__launch-icon-container:first-child:last-child{margin-block:0;margin-inline:0}.fd-numeric-content__launch-icon-container{max-width:1.75rem;min-width:1.75rem;width:1.75rem}.fd-numeric-content__scale-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:100%;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-block:.5rem .375rem;padding-inline:0}.fd-numeric-content__scale-container:after,.fd-numeric-content__scale-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__scale-container:first-child:last-child{margin-block:0;margin-inline:0}.fd-numeric-content__launch-icon [class*=sap-icon],.fd-numeric-content__launch-icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;color:var(--sapTile_IconColor);font-size:inherit;font-size:1.75rem;line-height:1;line-height:normal}.fd-numeric-content__kpi{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapNeutralTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:2.25rem;font-weight:400;font-weight:lighter;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-numeric-content__kpi:after,.fd-numeric-content__kpi:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__kpi--positive{color:var(--sapPositiveTextColor)}.fd-numeric-content__kpi--critical{color:var(--sapCriticalTextColor)}.fd-numeric-content__kpi--negative{color:var(--sapNegativeTextColor)}.fd-numeric-content__kpi--informative{color:var(--sapInformativeTextColor)}.fd-numeric-content__scale{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-numeric-content__scale:after,.fd-numeric-content__scale:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__scale-arrow [class*=sap-icon],.fd-numeric-content__scale-arrow[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;color:var(--sapNeutralTextColor);font-size:inherit;font-size:.875rem;line-height:1;line-height:normal}.fd-numeric-content__scale-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapNeutralTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:.875rem;font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-numeric-content__scale-text:after,.fd-numeric-content__scale-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__scale--positive .fd-numeric-content__scale-arrow [class*=sap-icon],.fd-numeric-content__scale--positive .fd-numeric-content__scale-arrow[class*=sap-icon],.fd-numeric-content__scale--positive .fd-numeric-content__scale-text{color:var(--sapPositiveTextColor)}.fd-numeric-content__scale--critical .fd-numeric-content__scale-arrow [class*=sap-icon],.fd-numeric-content__scale--critical .fd-numeric-content__scale-arrow[class*=sap-icon],.fd-numeric-content__scale--critical .fd-numeric-content__scale-text{color:var(--sapCriticalTextColor)}.fd-numeric-content__scale--negative .fd-numeric-content__scale-arrow [class*=sap-icon],.fd-numeric-content__scale--negative .fd-numeric-content__scale-arrow[class*=sap-icon],.fd-numeric-content__scale--negative .fd-numeric-content__scale-text{color:var(--sapNegativeTextColor)}.fd-numeric-content__scale--informative .fd-numeric-content__scale-arrow [class*=sap-icon],.fd-numeric-content__scale--informative .fd-numeric-content__scale-arrow[class*=sap-icon],.fd-numeric-content__scale--informative .fd-numeric-content__scale-text{color:var(--sapInformativeTextColor)}.fd-numeric-content--m{height:2.5rem}.fd-numeric-content--m .fd-numeric-content__kpi-container,.fd-numeric-content--m .fd-numeric-content__launch-icon-container{-webkit-padding-before:0;padding-block-start:0;-webkit-margin-end:.5rem;margin-inline-end:.5rem}.fd-numeric-content--m .fd-numeric-content__launch-icon-container{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-numeric-content--m .fd-numeric-content__scale-container{padding-block:.375rem .188rem}.fd-numeric-content--m .fd-numeric-content__kpi{font-size:2rem}.fd-numeric-content--s{height:2.25rem}.fd-numeric-content--s .fd-numeric-content__kpi-container,.fd-numeric-content--s .fd-numeric-content__launch-icon-container{-webkit-padding-before:0;padding-block-start:0;-webkit-margin-end:.5rem;margin-inline-end:.5rem}.fd-numeric-content--s .fd-numeric-content__scale-container{padding-block:0 .313rem}.fd-numeric-content--s .fd-numeric-content__kpi{font-size:1.75rem}.fd-numeric-content--small-tile{height:2.375rem}.fd-numeric-content--small-tile .fd-numeric-content__kpi-container,.fd-numeric-content--small-tile .fd-numeric-content__launch-icon-container{-webkit-padding-before:.5rem;padding-block-start:.5rem;-webkit-margin-end:.375rem;margin-inline-end:.375rem}.fd-numeric-content--small-tile .fd-numeric-content__launch-icon-container{max-width:1.5rem;min-width:1.5rem;width:1.5rem}.fd-numeric-content--small-tile .fd-numeric-content__scale-container{padding-block:.25rem}.fd-numeric-content--small-tile .fd-numeric-content__kpi,.fd-numeric-content--small-tile .fd-numeric-content__launch-icon [class*=sap-icon],.fd-numeric-content--small-tile .fd-numeric-content__launch-icon[class*=sap-icon]{font-size:1.5rem}.fd-numeric-content--small-tile .fd-numeric-content__kpi[dir=rtl],[dir=rtl] .fd-numeric-content--small-tile .fd-numeric-content__kpi{direction:ltr;text-align:right}.fd-numeric-content--small-tile.fd-numeric-content--m{height:2.375rem}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__kpi-container,.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__launch-icon-container{-webkit-padding-before:.5rem;padding-block-start:.5rem;-webkit-margin-end:.375rem;margin-inline-end:.375rem}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__launch-icon-container{max-width:1.5rem;min-width:1.5rem;width:1.5rem}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__scale-container{padding-block:.25rem}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__kpi,.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__launch-icon [class*=sap-icon],.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__launch-icon[class*=sap-icon]{font-size:1.5rem}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__kpi[dir=rtl],[dir=rtl] .fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__kpi{direction:ltr;text-align:right}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__launch-icon-container{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-numeric-content--small-tile.fd-numeric-content--s{height:2.375rem}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__kpi-container,.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__launch-icon-container{-webkit-padding-before:.5rem;padding-block-start:.5rem;-webkit-margin-end:.375rem;margin-inline-end:.375rem}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__launch-icon-container{max-width:1.5rem;min-width:1.5rem;width:1.5rem}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__scale-container{padding-block:.25rem}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__kpi,.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__launch-icon [class*=sap-icon],.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__launch-icon[class*=sap-icon]{font-size:1.5rem}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__kpi[dir=rtl],[dir=rtl] .fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__kpi{direction:ltr;text-align:right}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__scale-container{-webkit-padding-before:0;padding-block-start:0}.fd-card{--fdCard_Header_Text_Spacing:.25rem;--fdCard_Box_Shadow:var(--fdCard_Box_Shadow_Regular);--fdCard_Header_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Main_Header_Border_Radius:inherit;--fdCard_Footer_Border_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius);--fdCard_Content_Border_Radius:0;--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Offset:.0625rem;--fdCard_Media_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Main_Header_Border_Bottom:var(--fdCard_Header_Border_Bottom);--fdCard_Main_Header_Border_Top:none;--fdCard_Main_Header_Padding_Block_Start:1rem;--fdCard_Main_Header_Padding_Block_End:var(--fdCard_Main_Header_Padding_Bottom);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-flex:1;background:var(--fdCard_Background,var(--sapTile_Background));border:var(--fdCard_Border);border-radius:var(--fdCard_Border_Radius,var(--fdCard_Border_Corner_Radius));-webkit-box-shadow:var(--fdCard_Box_Shadow);box-shadow:var(--fdCard_Box_Shadow);-ms-flex:1;flex:1;min-height:100%;position:relative;width:100%}.fd-card:after,.fd-card:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card--interactive{cursor:pointer}.fd-card--interactive.is-focus,.fd-card--interactive:focus{outline:none;z-index:5}.fd-card--interactive.is-focus:before,.fd-card--interactive:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);border-radius:var(--fdCard_Focus_Outline_Radius);content:\"\";display:block;inset:var(--fdCard_Focus_Outline_Offset);position:absolute;z-index:3}.fd-card--interactive.is-hover,.fd-card--interactive:hover{--fdCard_Background:var(--sapTile_Hover_Background);--fdCard_Box_Shadow:var(--fdCard_Box_Shadow_Hover);--fdCard_Footer_Background:var(--sapTile_Hover_Background);--fdCard_Main_Header_Background:var(--sapTile_Hover_Background)}.fd-card--interactive.is-active,.fd-card--interactive:active{--fdCard_Box_Shadow:none;--fdCard_Background:var(--sapTile_Active_Background);--fdCard_Footer_Background:var(--sapTile_Active_Background);--fdCard_Main_Header_Background:var(--sapTile_Active_Background);--fdCard_Border:.0625rem solid var(--sapTile_Interactive_BorderColor)}.fd-card--interactive.is-selected:before,.fd-card--interactive[aria-selected=true]:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);border-radius:var(--fdCard_Focus_Outline_Radius);content:\"\";display:block;inset:var(--fdCard_Focus_Outline_Offset);position:absolute;z-index:3}.fd-card--interactive[role=button] .fd-card__header-main-container.is-focus,.fd-card--interactive[role=button] .fd-card__header-main-container:focus{outline:none;z-index:5}.fd-card--interactive[role=button] .fd-card__header-main-container.is-focus:before,.fd-card--interactive[role=button] .fd-card__header-main-container:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);border-radius:var(--fdCard_Focus_Outline_Radius);content:\"\";display:block;inset:var(--fdCard_Focus_Outline_Offset);position:absolute;z-index:3}.fd-card--interactive[role=listitem] .fd-card__header-main-container{pointer-events:none}.fd-card__header{border:0;border-radius:var(--fdCard_Header_Border_Radius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0}.fd-card__header:after,.fd-card__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header:is(:first-child){--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__header:is(:last-child){--fdCard_Main_Header_Border_Bottom:none;--fdCard_Main_Header_Padding_Block_End:1rem;--fdCard_Main_Header_Padding_Block_Start:1rem;--fdCard_Main_Header_Border_Top:var(--fdCard_Header_Border_Bottom);--fdCard_Header_Border_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius)}.fd-card__header:is(:last-child) .fd-card__header-main:not(:only-child){--fdCard_Focus_Outline_Radius:0}.fd-card__header:only-child{--fdCard_Header_Border_Radius:var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius)}.fd-card__header:only-child .fd-card__header-main:not(:only-child){--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__header:only-child .fd-card__header-main{--fdCard_Main_Header_Padding_Block_Start:1rem;--fdCard_Main_Header_Padding_Block_End:1rem;--fdCard_Main_Header_Border_Bottom:none;--fdCard_Main_Header_Border_Top:none}.fd-card__header--interactive .fd-card__header-main{cursor:pointer}.fd-card__header--interactive .fd-card__header-main.is-hover,.fd-card__header--interactive .fd-card__header-main:hover{--fdCard_Main_Header_Background:var(--sapTile_Hover_Background)}.fd-card__header--interactive .fd-card__header-main:has(.fd-card__header-main-container.is-active){--fdCard_Main_Header_Background:var(--sapTile_Active_Background)}.fd-card__header--interactive .fd-card__header-main:has(.fd-card__header-main-container:active){--fdCard_Main_Header_Background:var(--sapTile_Active_Background)}.fd-card__header--interactive .fd-card__header-main-container.is-focus,.fd-card__header--interactive .fd-card__header-main-container:focus{outline:none;z-index:5}.fd-card__header--interactive .fd-card__header-main-container.is-focus:before,.fd-card__header--interactive .fd-card__header-main-container:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);border-radius:var(--fdCard_Focus_Outline_Radius);content:\"\";display:block;inset:var(--fdCard_Focus_Outline_Offset);position:absolute;z-index:3}.fd-card__header-main{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;background:var(--fdCard_Main_Header_Background,var(--sapTile_Background));border-bottom:var(--fdCard_Main_Header_Border_Bottom);border-radius:var(--fdCard_Main_Header_Border_Radius);border-top:var(--fdCard_Main_Header_Border_Top);-ms-flex-direction:row;flex-direction:row;gap:.5rem;padding-block:var(--fdCard_Main_Header_Padding_Block_Start) var(--fdCard_Main_Header_Padding_Block_End);padding-inline:1rem;position:relative;text-decoration:none}.fd-card__header-main:after,.fd-card__header-main:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-main-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-box-flex:1;-ms-flex:1;flex:1;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start;height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;width:100%}.fd-card__header-main-container:after,.fd-card__header-main-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-main-actions{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:.25rem;-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end;z-index:5}.fd-card__header-main-actions:after,.fd-card__header-main-actions:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-extended{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-box-align:center;-ms-flex-align:center;align-items:center;padding-block:.5rem;padding-inline:1rem}.fd-card__header-extended:after,.fd-card__header-extended:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-extended--top-aligned{-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-card__header-extended--bottom-aligned{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-card__header-column{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-flex:1;-ms-flex:1;flex:1;gap:.25rem;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-card__header-column:after,.fd-card__header-column:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-column--right-aligned{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-card__header-row{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem}.fd-card__header-row:after,.fd-card__header-row:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-numeric{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:.25rem;padding-block:.25rem;padding-inline:1rem}.fd-card__header-numeric:after,.fd-card__header-numeric:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__indicator{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:.125rem;-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-card__indicator:after,.fd-card__indicator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__numeric-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-flex:1;-ms-flex:1;flex:1}.fd-card__numeric-container:after,.fd-card__numeric-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__indicator-title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapTile_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontSmallSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-card__indicator-title:after,.fd-card__indicator-title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__indicator-value{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapTile_TitleTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontSmallSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-align:right}.fd-card__indicator-value:after,.fd-card__indicator-value:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__footer{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdCard_Footer_Background,var(--sapTile_Background));border-radius:var(--fdCard_Footer_Border_Radius);border-top:var(--fdCard_Footer_Border_Top);padding-block:var(--fdCard_Footer_Padding) 1rem;padding-inline:1rem}.fd-card__footer:after,.fd-card__footer:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__footer-actions{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;width:100%}.fd-card__footer-actions:after,.fd-card__footer-actions:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__footer .fd-card__footer-link{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;-webkit-margin-end:var(--fdCard_Footer_Actions_Item_Spacing);margin-inline-end:var(--fdCard_Footer_Actions_Item_Spacing);text-overflow:clip}.fd-card__footer:is(:first-child){--fdCard_Footer_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__header-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-ms-flex-item-align:center;align-self:center;gap:var(--fdCard_Header_Text_Spacing);height:100%;width:100%}.fd-card__header-text:after,.fd-card__header-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__title-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start;width:100%}.fd-card__title-area:after,.fd-card__title-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-line-clamp:3;-webkit-box-orient:vertical;color:var(--sapTile_TitleTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--fdCard_Title_Font_Size);font-weight:var(--fdCard_Title_Font_Weight);overflow:hidden;text-overflow:ellipsis;white-space:normal;word-wrap:break-word;max-height:4.2rem;max-width:100%}.fd-card__title:after,.fd-card__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__subtitle-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-card__subtitle-area:after,.fd-card__subtitle-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__subtitle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-line-clamp:2;-webkit-box-orient:vertical;color:var(--sapTile_TextColor);overflow:hidden;text-overflow:ellipsis;white-space:normal;word-wrap:break-word;max-height:2.5rem;max-width:100%}.fd-card__subtitle:after,.fd-card__subtitle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__counter.fd-object-status{white-space:nowrap;-webkit-margin-start:1rem;font-size:var(--sapFontSmallSize);margin-inline-start:1rem;-webkit-margin-before:var(--fdCard_Counter_Margin);margin-block-start:var(--fdCard_Counter_Margin)}.fd-card__badge-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;right:.5rem;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.25rem;max-width:calc(100% - 1rem);min-width:1.375rem;position:absolute;top:-.5rem;z-index:10}.fd-card__badge-container:after,.fd-card__badge-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__badge-container[dir=rtl],[dir=rtl] .fd-card__badge-container{left:.5rem;right:auto}.fd-card__badge-container+.fd-card__header{--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Main_Header_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__badge-container+.fd-card__header:is(:last-child){--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius)}.fd-card__badge-container+.fd-card__content{overflow:hidden;--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__badge-container+.fd-card__content:is(:last-child){--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius)}.fd-card__badge.fd-object-status{--fdObjectStatus_Inverted_Border_Radius:.5rem;--fdObjectStatus_Inverted_Padding_Block:0;--fdObjectStatus_Inverted_Padding_Inline:.25rem;--fdObjectStatus_Inverted_Line_Height:.875rem}.fd-card__badge.fd-object-status span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-card__currency{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;color:var(--sapTile_TextColor);-ms-flex-direction:row;flex-direction:row;text-overflow:ellipsis;-webkit-margin-start:.25rem;margin-inline-start:.25rem;white-space:nowrap}.fd-card__currency:after,.fd-card__currency:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__currency:before{content:\"|\\a0\"}.fd-card__analytics-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;margin-top:.5rem;overflow:hidden}.fd-card__analytics-area:after,.fd-card__analytics-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__analytics-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;overflow-x:hidden;white-space:nowrap;width:100%;-webkit-margin-start:2rem;margin-inline-start:2rem}.fd-card__analytics-container:after,.fd-card__analytics-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__analytics{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end;-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;-webkit-padding-after:.25rem;padding-block-end:.25rem;-webkit-margin-start:1rem;font-size:var(--sapFontSmallSize);margin-inline-start:1rem;max-width:calc(50% - 1rem);overflow:hidden}.fd-card__analytics:after,.fd-card__analytics:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__analytics-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-after:.25rem;color:var(--sapTile_TextColor);padding-block-end:.25rem}.fd-card__analytics-text:after,.fd-card__analytics-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__analytics-content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapTile_TitleTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-card__analytics-content:after,.fd-card__analytics-content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__analytics-content[dir=rtl],[dir=rtl] .fd-card__analytics-content{direction:ltr;text-align:right}.fd-card__second-subtitle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapTile_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontSmallSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:.25rem;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:100%}.fd-card__second-subtitle:after,.fd-card__second-subtitle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__numeric-content.fd-numeric-content{-ms-flex-negative:0;flex-shrink:0;width:auto}.fd-card__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;--fdCard_Focus_Outline_Radius:0;-webkit-box-flex:1;border-radius:var(--fdCard_Content_Border_Radius);-ms-flex:1 0 auto;flex:1 0 auto;position:relative}.fd-card__content:after,.fd-card__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__content.is-focus,.fd-card__content:focus{outline:none;z-index:5}.fd-card__content.is-focus:before,.fd-card__content:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);border-radius:var(--fdCard_Focus_Outline_Radius);content:\"\";display:block;inset:var(--fdCard_Focus_Outline_Offset);position:absolute;z-index:3}.fd-card__content:is(:first-child){overflow:hidden;--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__content:is(:last-child){overflow:hidden;--fdCard_Content_Border_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius)}.fd-card__content:is(:only-child){overflow:hidden;--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius)}.fd-card__content--with-spacing{padding-block:1rem;padding-inline:1rem}.fd-card__content-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:1.75rem}.fd-card__content-container:after,.fd-card__content-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__content-container--horizontal{gap:2rem;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row}.fd-card__content-section{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:1rem;max-width:24rem;min-width:12rem;width:100%}.fd-card__content-section:after,.fd-card__content-section:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__content-title-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-after:.5rem;padding-block-end:.5rem}.fd-card__content-title-container:after,.fd-card__content-title-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__content-group{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-card__content-group:after,.fd-card__content-group:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__content-group-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:.25rem}.fd-card__content-group-text:after,.fd-card__content-group-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card--analytical .fd-card__subtitle-area{margin-top:.5rem}.fd-card--analytical .fd-card__title{display:-webkit-box;-webkit-line-clamp:2;-webkit-box-orient:vertical;max-height:2.8rem;overflow:hidden;text-overflow:ellipsis;white-space:normal}.fd-card--table[class*=-compact] .fd-card__content,.fd-card--table[class*=-condensed] .fd-card__content,[class*=-compact] .fd-card--table:not([class*=-cozy]) .fd-card__content,[class*=-condensed] .fd-card--table:not([class*=-cozy]) .fd-card__content{-webkit-padding-after:.5rem;padding-block-end:.5rem}.fd-card--object .fd-card__content{padding-block:1rem;padding-inline:1rem}.fd-card__loader{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;min-height:5rem}.fd-card__loader:after,.fd-card__loader:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__media{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;background-color:var(--fdCard_Media_Background,var(--sapTile_Background));border-radius:var(--fdCard_Media_Border_Radius);-ms-flex-direction:row;flex-direction:row;flex-direction:var(--fdCard_Media_Flex_Direction,row);height:100%;overflow:hidden;padding-block:var(--fdCard_Media_Padding_Block_Start,0) var(--fdCard_Media_Padding_Block_End,0);padding-inline:var(--fdCard_Media_Padding_Inline_Start,0) var(--fdCard_Media_Padding_Inline_End,0);position:relative}.fd-card__media:after,.fd-card__media:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__media.fd-card__media--with-padding{--fdCard_Media_Image_Radius:.5rem;--fdCard_Media_Padding_Inline_Start:1rem;--fdCard_Media_Padding_Inline_End:1rem;--fdCard_Media_Padding_Block_Start:1rem}.fd-card__media.fd-card__media--bg-shell-1{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_1_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_1_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_1_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_1_TextColor)}.fd-card__media.fd-card__media--bg-shell-2{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_2_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_2_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_2_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_2_TextColor)}.fd-card__media.fd-card__media--bg-shell-3{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_3_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_3_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_3_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_3_TextColor)}.fd-card__media.fd-card__media--bg-shell-4{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_4_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_4_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_4_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_4_TextColor)}.fd-card__media.fd-card__media--bg-shell-5{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_5_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_5_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_5_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_5_TextColor)}.fd-card__media.fd-card__media--bg-shell-6{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_6_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_6_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_6_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_6_TextColor)}.fd-card__media.fd-card__media--bg-shell-7{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_7_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_7_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_7_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_7_TextColor)}.fd-card__media.fd-card__media--bg-shell-8{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_8_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_8_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_8_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_8_TextColor)}.fd-card__media.fd-card__media--bg-shell-9{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_9_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_9_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_9_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_9_TextColor)}.fd-card__media.fd-card__media--bg-shell-10{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_10_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_10_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_10_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_10_TextColor)}.fd-card__media.fd-card__media--bg-shell-11{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_11_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_11_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_11_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_11_TextColor)}.fd-card__media.fd-card__media--bg-shell-12{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_12_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_12_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_12_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_12_TextColor)}.fd-card__media.fd-card__media--bg-shell-13{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_13_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_13_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_13_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_13_TextColor)}.fd-card__media.fd-card__media--bg-shell-14{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_14_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_14_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_14_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_14_TextColor)}.fd-card__media.fd-card__media--bg-shell-15{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_15_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_15_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_15_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_15_TextColor)}.fd-card__media.fd-card__media--bg-shell-16{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_16_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_16_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_16_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_16_TextColor)}.fd-card__media.fd-card__media--bg-legend-1{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor1);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-2{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor2);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-3{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor3);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-4{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor4);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-5{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor5);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-6{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor6);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-7{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor7);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-8{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor8);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-9{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor9);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-10{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor10);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-11{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor11);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-12{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor12);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-13{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor13);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-14{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor14);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-15{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor15);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-16{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor16);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-17{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor17);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-18{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor18);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-19{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor19);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-20{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor20);--fdCard_Media_Heading_Shadow:none}.fd-card__media+.fd-card__header{--fdCard_Header_Border_Radius:0;--fdCard_Focus_Outline_Radius:0}.fd-card__media+.fd-card__header:is(:last-child){--fdCard_Header_Border_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius)}.fd-card__media:only-child{--fdCard_Media_Border_Radius:var(--sapTile_BorderCornerRadius)}.fd-card__media-content-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:1rem;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start;-webkit-box-pack:center;-ms-flex-pack:center;background:var(--fdCard_Media_Content_Container_Background,var(--sapTile_Background));height:var(--fdCard_Media_Content_Container_Height,100%);inset:var(--fdCard_Media_Content_Container_Top,0) var(--fdCard_Media_Content_Container_Right,0) var(--fdCard_Media_Content_Container_Right,0) var(--fdCard_Media_Content_Container_Left,0);justify-content:center;max-height:100%;padding-block:var(--fdCard_Media_Content_Container_Padding_Block,1rem);padding-inline:var(--fdCard_Media_Content_Container_Padding_Inline,1rem);position:var(--fdCard_Media_Content_Container_Position,relative);-webkit-transform:var(--fdCard_Media_Content_Container_Transform,none);transform:var(--fdCard_Media_Content_Container_Transform,none);width:var(--fdCard_Media_Content_Container_Width,100%);z-index:3}.fd-card__media-content-container:after,.fd-card__media-content-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-1{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_1_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_1_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_1_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_1_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-2{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_2_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_2_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_2_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_2_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-3{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_3_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_3_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_3_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_3_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-4{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_4_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_4_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_4_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_4_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-5{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_5_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_5_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_5_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_5_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-6{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_6_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_6_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_6_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_6_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-7{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_7_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_7_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_7_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_7_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-8{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_8_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_8_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_8_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_8_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-9{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_9_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_9_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_9_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_9_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-10{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_10_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_10_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_10_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_10_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-11{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_11_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_11_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_11_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_11_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-12{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_12_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_12_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_12_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_12_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-13{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_13_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_13_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_13_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_13_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-14{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_14_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_14_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_14_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_14_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-15{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_15_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_15_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_15_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_15_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-16{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_16_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_16_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_16_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_16_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-1{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor1);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-2{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor2);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-3{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor3);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-4{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor4);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-5{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor5);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-6{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor6);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-7{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor7);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-8{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor8);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-9{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor9);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-10{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor10);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-11{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor11);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-12{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor12);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-13{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor13);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-14{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor14);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-15{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor15);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-16{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor16);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-17{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor17);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-18{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor18);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-19{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor19);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-20{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor20);--fdCard_Media_Heading_Shadow:none}.fd-card__media-image-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;height:var(--fdCard_Media_Image_Container_Height,100%);width:var(--fdCard_Media_Image_Container_Width,100%)}.fd-card__media-image-container:after,.fd-card__media-image-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__media-image{-webkit-box-flex:1;border-radius:var(--fdCard_Media_Image_Radius,0);-ms-flex:1;flex:1;height:var(--fdCard_Media_Image_Height,100%);width:var(--fdCard_Media_Image_Width,100%)}.fd-card__media-heading{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdCard_Media_Heading_Color,var(--sapTile_TitleTextColor));font-family:var(--sapFontFamily);font-family:var(--sapFontHeaderFamily);font-size:var(--sapFontSize);font-size:var(--sapFontHeader3Size);font-weight:400;font-weight:700;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-shadow:var(--fdCard_Media_Heading_Shadow,none)}.fd-card__media-heading:after,.fd-card__media-heading:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__media-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdCard_Media_Text_Color,var(--sapTile_TextColor));font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-card__media-text:after,.fd-card__media-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card--banner{--fdCard_Media_Content_Container_Width:80%;--fdCard_Media_Content_Container_Padding_Inline:3rem;--fdCard_Media_Content_Container_Padding_Block:3rem;border:.0625rem solid var(--sapTile_BorderColor);border-radius:var(--sapTile_BorderCornerRadius);-webkit-box-shadow:var(--sapContent_Shadow0);box-shadow:var(--sapContent_Shadow0);height:100%}@media (width >= 600px) and (width <= 1023px){.fd-card--banner{--fdCard_Media_Image_Container_Width:80%}}@media (width <= 599px){.fd-card--banner{--fdCard_Media_Image_Container_Width:100%}}.fd-card--banner:has(.fd-card__media-image-container){--fdCard_Media_Content_Container_Width:50%;--fdCard_Media_Image_Container_Width:50%}@media (width >= 600px) and (width <= 1023px){.fd-card--banner:has(.fd-card__media-image-container){--fdCard_Media_Content_Container_Width:80%;--fdCard_Media_Image_Container_Width:20%}}@media (width <= 599px){.fd-card--banner:has(.fd-card__media-image-container){--fdCard_Media_Flex_Direction:column-reverse;--fdCard_Media_Content_Container_Width:100%;--fdCard_Media_Image_Container_Width:100%}}.fd-card--banner:has(.fd-card__media-image-container):has(.fd-card__media-content-container--overlay){--fdCard_Media_Content_Container_Width: calc(50% - 3rem) ;--fdCard_Media_Image_Container_Width:100%;--fdCard_Media_Content_Container_Top:50%;--fdCard_Media_Content_Container_Left:3rem;--fdCard_Media_Content_Container_Height:fit-content;--fdCard_Media_Content_Container_Position:absolute;--fdCard_Media_Content_Container_Transform:translateY(-50%)}@media (width >= 600px) and (width <= 1023px){.fd-card--banner:has(.fd-card__media-image-container):has(.fd-card__media-content-container--overlay){--fdCard_Media_Content_Container_Width: calc(80% - 3rem) ;--fdCard_Media_Image_Container_Width:100%}}@media (width <= 599px){.fd-card--banner:has(.fd-card__media-image-container):has(.fd-card__media-content-container--overlay){--fdCard_Media_Content_Container_Width: calc(100% - 3rem) %;--fdCard_Media_Image_Container_Width:100%;--fdCard_Media_Content_Container_Right:3rem;--fdCard_Media_Content_Container_Padding_Inline:1rem;--fdCard_Media_Content_Container_Padding_Block:1rem}}.fd-card[class*=-compact],.fd-card[class*=-condensed],[class*=-compact] .fd-card:not([class*=-cozy]),[class*=-condensed] .fd-card:not([class*=-cozy]){--fdCard_Header_Text_Spacing:.5rem}@media (width <= 599px){.fd-card{--fdCard_Media_Content_Container_Width:100%}}.fd-badge{background:var(--sapHighlightColor);border:0;border:.0625rem solid var(--fdBadge_Border_Color);border-radius:.5rem;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_ContrastTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontSmallSize);font-weight:400;font-weight:700;forced-color-adjust:none;height:1rem;line-height:normal;margin-block:0;margin-inline:0;max-width:calc(100% - 1rem);overflow:hidden;padding-block:0;padding-inline:0;padding-inline:.5rem;position:absolute;right:.5rem;text-overflow:ellipsis;top:-.55rem;white-space:nowrap;z-index:10}.fd-badge:after,.fd-badge:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-badge[dir=rtl],[dir=rtl] .fd-badge{left:.5rem;right:auto}.fd-badge--static{position:static}\n/*! Bundled license information:\n\nfundamental-styles/dist/badge.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "component", type: ObjectStatusComponent, selector: "[fd-object-status]", inputs: ["class", "status", "glyph", "glyphFont", "label", "glyphAriaLabel", "indicationColor", "clickable", "inverted", "large", "secondaryIndication", "textTemplate"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-card', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        contentDensityObserverProviders(),
                        {
                            provide: FD_CARD,
                            useExisting: forwardRef(() => CardComponent)
                        },
                        {
                            provide: CardFocusItem,
                            useExisting: forwardRef(() => CardComponent)
                        }
                    ], imports: [ObjectStatusComponent], host: {
                        '[attr.id]': 'id()',
                        '[attr.role]': 'role()',
                        '[attr.aria-description]': 'role() === "listitem" ? ariaDescription() : null',
                        '[attr.aria-roledescription]': 'ariaRoledescription()',
                        '[attr.aria-labelledby]': 'cardTitle()?.id() || cardMediaHeading()?.id()',
                        '[attr.aria-label]': 'ariaLabel()',
                        '[attr.aria-selected]': 'selected()',
                        '[class.fd-card--interactive]': 'interactive()',
                        '[tabindex]': 'role() === "listitem" ? 0 : -1',
                        '[attr.aria-posinset]': 'role() === "listitem" ? ariaPosinset() : null',
                        '[attr.aria-setsize]': 'role() === "listitem" ? ariaSetsize() : null'
                    }, template: "@if (!isLoading()) {\n    <!-- Badge -->\n\n    @if (badge() || badgeIcon() || secondBadge() || secondBadgeIcon()) {\n        <div class=\"fd-card__badge-container\">\n            @if (badge() || badgeIcon()) {\n                <span\n                    fd-object-status\n                    [inverted]=\"true\"\n                    class=\"fd-card__badge\"\n                    [glyph]=\"badgeIcon()\"\n                    [status]=\"badgeStatus()\"\n                    [indicationColor]=\"badgeColor()\"\n                    [secondaryIndication]=\"badgeColorSecondary()\"\n                    [label]=\"badge()\"\n                    [attr.aria-label]=\"badgeAriaLabel()\"\n                >\n                </span>\n            }\n\n            @if (secondBadge() || secondBadgeIcon()) {\n                <span\n                    fd-object-status\n                    [inverted]=\"true\"\n                    class=\"fd-card__badge\"\n                    [glyph]=\"secondBadgeIcon()\"\n                    [status]=\"secondBadgeStatus()\"\n                    [indicationColor]=\"secondBadgeColor()\"\n                    [secondaryIndication]=\"secondBadgeColorSecondary()\"\n                    [label]=\"secondBadge()\"\n                    [attr.aria-label]=\"secondBadgeAriaLabel()\"\n                >\n                </span>\n            }\n        </div>\n    }\n\n    <!-- Header and Content -->\n    <ng-content></ng-content>\n    <!-- Footer -->\n    <ng-content select=\"fd-card-footer\"></ng-content>\n} @else {\n    <ng-content select=\"fd-card-loader\"></ng-content>\n}\n<!-- Loader -->\n", styles: ["@charset \"UTF-8\";.fd-numeric-content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:3rem;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%}.fd-numeric-content:after,.fd-numeric-content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__kpi-container,.fd-numeric-content__launch-icon-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:100%;overflow:hidden;-webkit-padding-before:.125rem;padding-block-start:.125rem;-webkit-margin-end:.375rem;margin-inline-end:.375rem}.fd-numeric-content__kpi-container:after,.fd-numeric-content__kpi-container:before,.fd-numeric-content__launch-icon-container:after,.fd-numeric-content__launch-icon-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__kpi-container:first-child:last-child,.fd-numeric-content__launch-icon-container:first-child:last-child{margin-block:0;margin-inline:0}.fd-numeric-content__launch-icon-container{max-width:1.75rem;min-width:1.75rem;width:1.75rem}.fd-numeric-content__scale-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:100%;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-block:.5rem .375rem;padding-inline:0}.fd-numeric-content__scale-container:after,.fd-numeric-content__scale-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__scale-container:first-child:last-child{margin-block:0;margin-inline:0}.fd-numeric-content__launch-icon [class*=sap-icon],.fd-numeric-content__launch-icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;color:var(--sapTile_IconColor);font-size:inherit;font-size:1.75rem;line-height:1;line-height:normal}.fd-numeric-content__kpi{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapNeutralTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:2.25rem;font-weight:400;font-weight:lighter;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-numeric-content__kpi:after,.fd-numeric-content__kpi:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__kpi--positive{color:var(--sapPositiveTextColor)}.fd-numeric-content__kpi--critical{color:var(--sapCriticalTextColor)}.fd-numeric-content__kpi--negative{color:var(--sapNegativeTextColor)}.fd-numeric-content__kpi--informative{color:var(--sapInformativeTextColor)}.fd-numeric-content__scale{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-numeric-content__scale:after,.fd-numeric-content__scale:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__scale-arrow [class*=sap-icon],.fd-numeric-content__scale-arrow[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;color:var(--sapNeutralTextColor);font-size:inherit;font-size:.875rem;line-height:1;line-height:normal}.fd-numeric-content__scale-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapNeutralTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:.875rem;font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-numeric-content__scale-text:after,.fd-numeric-content__scale-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-numeric-content__scale--positive .fd-numeric-content__scale-arrow [class*=sap-icon],.fd-numeric-content__scale--positive .fd-numeric-content__scale-arrow[class*=sap-icon],.fd-numeric-content__scale--positive .fd-numeric-content__scale-text{color:var(--sapPositiveTextColor)}.fd-numeric-content__scale--critical .fd-numeric-content__scale-arrow [class*=sap-icon],.fd-numeric-content__scale--critical .fd-numeric-content__scale-arrow[class*=sap-icon],.fd-numeric-content__scale--critical .fd-numeric-content__scale-text{color:var(--sapCriticalTextColor)}.fd-numeric-content__scale--negative .fd-numeric-content__scale-arrow [class*=sap-icon],.fd-numeric-content__scale--negative .fd-numeric-content__scale-arrow[class*=sap-icon],.fd-numeric-content__scale--negative .fd-numeric-content__scale-text{color:var(--sapNegativeTextColor)}.fd-numeric-content__scale--informative .fd-numeric-content__scale-arrow [class*=sap-icon],.fd-numeric-content__scale--informative .fd-numeric-content__scale-arrow[class*=sap-icon],.fd-numeric-content__scale--informative .fd-numeric-content__scale-text{color:var(--sapInformativeTextColor)}.fd-numeric-content--m{height:2.5rem}.fd-numeric-content--m .fd-numeric-content__kpi-container,.fd-numeric-content--m .fd-numeric-content__launch-icon-container{-webkit-padding-before:0;padding-block-start:0;-webkit-margin-end:.5rem;margin-inline-end:.5rem}.fd-numeric-content--m .fd-numeric-content__launch-icon-container{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-numeric-content--m .fd-numeric-content__scale-container{padding-block:.375rem .188rem}.fd-numeric-content--m .fd-numeric-content__kpi{font-size:2rem}.fd-numeric-content--s{height:2.25rem}.fd-numeric-content--s .fd-numeric-content__kpi-container,.fd-numeric-content--s .fd-numeric-content__launch-icon-container{-webkit-padding-before:0;padding-block-start:0;-webkit-margin-end:.5rem;margin-inline-end:.5rem}.fd-numeric-content--s .fd-numeric-content__scale-container{padding-block:0 .313rem}.fd-numeric-content--s .fd-numeric-content__kpi{font-size:1.75rem}.fd-numeric-content--small-tile{height:2.375rem}.fd-numeric-content--small-tile .fd-numeric-content__kpi-container,.fd-numeric-content--small-tile .fd-numeric-content__launch-icon-container{-webkit-padding-before:.5rem;padding-block-start:.5rem;-webkit-margin-end:.375rem;margin-inline-end:.375rem}.fd-numeric-content--small-tile .fd-numeric-content__launch-icon-container{max-width:1.5rem;min-width:1.5rem;width:1.5rem}.fd-numeric-content--small-tile .fd-numeric-content__scale-container{padding-block:.25rem}.fd-numeric-content--small-tile .fd-numeric-content__kpi,.fd-numeric-content--small-tile .fd-numeric-content__launch-icon [class*=sap-icon],.fd-numeric-content--small-tile .fd-numeric-content__launch-icon[class*=sap-icon]{font-size:1.5rem}.fd-numeric-content--small-tile .fd-numeric-content__kpi[dir=rtl],[dir=rtl] .fd-numeric-content--small-tile .fd-numeric-content__kpi{direction:ltr;text-align:right}.fd-numeric-content--small-tile.fd-numeric-content--m{height:2.375rem}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__kpi-container,.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__launch-icon-container{-webkit-padding-before:.5rem;padding-block-start:.5rem;-webkit-margin-end:.375rem;margin-inline-end:.375rem}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__launch-icon-container{max-width:1.5rem;min-width:1.5rem;width:1.5rem}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__scale-container{padding-block:.25rem}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__kpi,.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__launch-icon [class*=sap-icon],.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__launch-icon[class*=sap-icon]{font-size:1.5rem}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__kpi[dir=rtl],[dir=rtl] .fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__kpi{direction:ltr;text-align:right}.fd-numeric-content--small-tile.fd-numeric-content--m .fd-numeric-content__launch-icon-container{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-numeric-content--small-tile.fd-numeric-content--s{height:2.375rem}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__kpi-container,.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__launch-icon-container{-webkit-padding-before:.5rem;padding-block-start:.5rem;-webkit-margin-end:.375rem;margin-inline-end:.375rem}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__launch-icon-container{max-width:1.5rem;min-width:1.5rem;width:1.5rem}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__scale-container{padding-block:.25rem}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__kpi,.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__launch-icon [class*=sap-icon],.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__launch-icon[class*=sap-icon]{font-size:1.5rem}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__kpi[dir=rtl],[dir=rtl] .fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__kpi{direction:ltr;text-align:right}.fd-numeric-content--small-tile.fd-numeric-content--s .fd-numeric-content__scale-container{-webkit-padding-before:0;padding-block-start:0}.fd-card{--fdCard_Header_Text_Spacing:.25rem;--fdCard_Box_Shadow:var(--fdCard_Box_Shadow_Regular);--fdCard_Header_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Main_Header_Border_Radius:inherit;--fdCard_Footer_Border_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius);--fdCard_Content_Border_Radius:0;--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Offset:.0625rem;--fdCard_Media_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Main_Header_Border_Bottom:var(--fdCard_Header_Border_Bottom);--fdCard_Main_Header_Border_Top:none;--fdCard_Main_Header_Padding_Block_Start:1rem;--fdCard_Main_Header_Padding_Block_End:var(--fdCard_Main_Header_Padding_Bottom);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-flex:1;background:var(--fdCard_Background,var(--sapTile_Background));border:var(--fdCard_Border);border-radius:var(--fdCard_Border_Radius,var(--fdCard_Border_Corner_Radius));-webkit-box-shadow:var(--fdCard_Box_Shadow);box-shadow:var(--fdCard_Box_Shadow);-ms-flex:1;flex:1;min-height:100%;position:relative;width:100%}.fd-card:after,.fd-card:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card--interactive{cursor:pointer}.fd-card--interactive.is-focus,.fd-card--interactive:focus{outline:none;z-index:5}.fd-card--interactive.is-focus:before,.fd-card--interactive:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);border-radius:var(--fdCard_Focus_Outline_Radius);content:\"\";display:block;inset:var(--fdCard_Focus_Outline_Offset);position:absolute;z-index:3}.fd-card--interactive.is-hover,.fd-card--interactive:hover{--fdCard_Background:var(--sapTile_Hover_Background);--fdCard_Box_Shadow:var(--fdCard_Box_Shadow_Hover);--fdCard_Footer_Background:var(--sapTile_Hover_Background);--fdCard_Main_Header_Background:var(--sapTile_Hover_Background)}.fd-card--interactive.is-active,.fd-card--interactive:active{--fdCard_Box_Shadow:none;--fdCard_Background:var(--sapTile_Active_Background);--fdCard_Footer_Background:var(--sapTile_Active_Background);--fdCard_Main_Header_Background:var(--sapTile_Active_Background);--fdCard_Border:.0625rem solid var(--sapTile_Interactive_BorderColor)}.fd-card--interactive.is-selected:before,.fd-card--interactive[aria-selected=true]:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);border-radius:var(--fdCard_Focus_Outline_Radius);content:\"\";display:block;inset:var(--fdCard_Focus_Outline_Offset);position:absolute;z-index:3}.fd-card--interactive[role=button] .fd-card__header-main-container.is-focus,.fd-card--interactive[role=button] .fd-card__header-main-container:focus{outline:none;z-index:5}.fd-card--interactive[role=button] .fd-card__header-main-container.is-focus:before,.fd-card--interactive[role=button] .fd-card__header-main-container:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);border-radius:var(--fdCard_Focus_Outline_Radius);content:\"\";display:block;inset:var(--fdCard_Focus_Outline_Offset);position:absolute;z-index:3}.fd-card--interactive[role=listitem] .fd-card__header-main-container{pointer-events:none}.fd-card__header{border:0;border-radius:var(--fdCard_Header_Border_Radius);-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0}.fd-card__header:after,.fd-card__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header:is(:first-child){--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__header:is(:last-child){--fdCard_Main_Header_Border_Bottom:none;--fdCard_Main_Header_Padding_Block_End:1rem;--fdCard_Main_Header_Padding_Block_Start:1rem;--fdCard_Main_Header_Border_Top:var(--fdCard_Header_Border_Bottom);--fdCard_Header_Border_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius)}.fd-card__header:is(:last-child) .fd-card__header-main:not(:only-child){--fdCard_Focus_Outline_Radius:0}.fd-card__header:only-child{--fdCard_Header_Border_Radius:var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius)}.fd-card__header:only-child .fd-card__header-main:not(:only-child){--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__header:only-child .fd-card__header-main{--fdCard_Main_Header_Padding_Block_Start:1rem;--fdCard_Main_Header_Padding_Block_End:1rem;--fdCard_Main_Header_Border_Bottom:none;--fdCard_Main_Header_Border_Top:none}.fd-card__header--interactive .fd-card__header-main{cursor:pointer}.fd-card__header--interactive .fd-card__header-main.is-hover,.fd-card__header--interactive .fd-card__header-main:hover{--fdCard_Main_Header_Background:var(--sapTile_Hover_Background)}.fd-card__header--interactive .fd-card__header-main:has(.fd-card__header-main-container.is-active){--fdCard_Main_Header_Background:var(--sapTile_Active_Background)}.fd-card__header--interactive .fd-card__header-main:has(.fd-card__header-main-container:active){--fdCard_Main_Header_Background:var(--sapTile_Active_Background)}.fd-card__header--interactive .fd-card__header-main-container.is-focus,.fd-card__header--interactive .fd-card__header-main-container:focus{outline:none;z-index:5}.fd-card__header--interactive .fd-card__header-main-container.is-focus:before,.fd-card__header--interactive .fd-card__header-main-container:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);border-radius:var(--fdCard_Focus_Outline_Radius);content:\"\";display:block;inset:var(--fdCard_Focus_Outline_Offset);position:absolute;z-index:3}.fd-card__header-main{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;background:var(--fdCard_Main_Header_Background,var(--sapTile_Background));border-bottom:var(--fdCard_Main_Header_Border_Bottom);border-radius:var(--fdCard_Main_Header_Border_Radius);border-top:var(--fdCard_Main_Header_Border_Top);-ms-flex-direction:row;flex-direction:row;gap:.5rem;padding-block:var(--fdCard_Main_Header_Padding_Block_Start) var(--fdCard_Main_Header_Padding_Block_End);padding-inline:1rem;position:relative;text-decoration:none}.fd-card__header-main:after,.fd-card__header-main:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-main-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-box-flex:1;-ms-flex:1;flex:1;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start;height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;width:100%}.fd-card__header-main-container:after,.fd-card__header-main-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-main-actions{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:.25rem;-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end;z-index:5}.fd-card__header-main-actions:after,.fd-card__header-main-actions:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-extended{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-box-align:center;-ms-flex-align:center;align-items:center;padding-block:.5rem;padding-inline:1rem}.fd-card__header-extended:after,.fd-card__header-extended:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-extended--top-aligned{-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-card__header-extended--bottom-aligned{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-card__header-column{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-flex:1;-ms-flex:1;flex:1;gap:.25rem;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-card__header-column:after,.fd-card__header-column:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-column--right-aligned{-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-card__header-row{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem}.fd-card__header-row:after,.fd-card__header-row:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__header-numeric{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:.25rem;padding-block:.25rem;padding-inline:1rem}.fd-card__header-numeric:after,.fd-card__header-numeric:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__indicator{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:.125rem;-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-card__indicator:after,.fd-card__indicator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__numeric-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-flex:1;-ms-flex:1;flex:1}.fd-card__numeric-container:after,.fd-card__numeric-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__indicator-title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapTile_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontSmallSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-card__indicator-title:after,.fd-card__indicator-title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__indicator-value{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapTile_TitleTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontSmallSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-align:right}.fd-card__indicator-value:after,.fd-card__indicator-value:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__footer{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdCard_Footer_Background,var(--sapTile_Background));border-radius:var(--fdCard_Footer_Border_Radius);border-top:var(--fdCard_Footer_Border_Top);padding-block:var(--fdCard_Footer_Padding) 1rem;padding-inline:1rem}.fd-card__footer:after,.fd-card__footer:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__footer-actions{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;width:100%}.fd-card__footer-actions:after,.fd-card__footer-actions:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__footer .fd-card__footer-link{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;-webkit-margin-end:var(--fdCard_Footer_Actions_Item_Spacing);margin-inline-end:var(--fdCard_Footer_Actions_Item_Spacing);text-overflow:clip}.fd-card__footer:is(:first-child){--fdCard_Footer_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__header-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-ms-flex-item-align:center;align-self:center;gap:var(--fdCard_Header_Text_Spacing);height:100%;width:100%}.fd-card__header-text:after,.fd-card__header-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__title-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start;width:100%}.fd-card__title-area:after,.fd-card__title-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-line-clamp:3;-webkit-box-orient:vertical;color:var(--sapTile_TitleTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--fdCard_Title_Font_Size);font-weight:var(--fdCard_Title_Font_Weight);overflow:hidden;text-overflow:ellipsis;white-space:normal;word-wrap:break-word;max-height:4.2rem;max-width:100%}.fd-card__title:after,.fd-card__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__subtitle-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-card__subtitle-area:after,.fd-card__subtitle-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__subtitle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-line-clamp:2;-webkit-box-orient:vertical;color:var(--sapTile_TextColor);overflow:hidden;text-overflow:ellipsis;white-space:normal;word-wrap:break-word;max-height:2.5rem;max-width:100%}.fd-card__subtitle:after,.fd-card__subtitle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__counter.fd-object-status{white-space:nowrap;-webkit-margin-start:1rem;font-size:var(--sapFontSmallSize);margin-inline-start:1rem;-webkit-margin-before:var(--fdCard_Counter_Margin);margin-block-start:var(--fdCard_Counter_Margin)}.fd-card__badge-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;right:.5rem;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.25rem;max-width:calc(100% - 1rem);min-width:1.375rem;position:absolute;top:-.5rem;z-index:10}.fd-card__badge-container:after,.fd-card__badge-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__badge-container[dir=rtl],[dir=rtl] .fd-card__badge-container{left:.5rem;right:auto}.fd-card__badge-container+.fd-card__header{--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Main_Header_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__badge-container+.fd-card__header:is(:last-child){--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius)}.fd-card__badge-container+.fd-card__content{overflow:hidden;--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__badge-container+.fd-card__content:is(:last-child){--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius)}.fd-card__badge.fd-object-status{--fdObjectStatus_Inverted_Border_Radius:.5rem;--fdObjectStatus_Inverted_Padding_Block:0;--fdObjectStatus_Inverted_Padding_Inline:.25rem;--fdObjectStatus_Inverted_Line_Height:.875rem}.fd-card__badge.fd-object-status span{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-card__currency{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;color:var(--sapTile_TextColor);-ms-flex-direction:row;flex-direction:row;text-overflow:ellipsis;-webkit-margin-start:.25rem;margin-inline-start:.25rem;white-space:nowrap}.fd-card__currency:after,.fd-card__currency:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__currency:before{content:\"|\\a0\"}.fd-card__analytics-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;margin-top:.5rem;overflow:hidden}.fd-card__analytics-area:after,.fd-card__analytics-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__analytics-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;overflow-x:hidden;white-space:nowrap;width:100%;-webkit-margin-start:2rem;margin-inline-start:2rem}.fd-card__analytics-container:after,.fd-card__analytics-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__analytics{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end;-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;-webkit-padding-after:.25rem;padding-block-end:.25rem;-webkit-margin-start:1rem;font-size:var(--sapFontSmallSize);margin-inline-start:1rem;max-width:calc(50% - 1rem);overflow:hidden}.fd-card__analytics:after,.fd-card__analytics:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__analytics-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-after:.25rem;color:var(--sapTile_TextColor);padding-block-end:.25rem}.fd-card__analytics-text:after,.fd-card__analytics-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__analytics-content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapTile_TitleTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-card__analytics-content:after,.fd-card__analytics-content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__analytics-content[dir=rtl],[dir=rtl] .fd-card__analytics-content{direction:ltr;text-align:right}.fd-card__second-subtitle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapTile_TextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontSmallSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:.25rem;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:100%}.fd-card__second-subtitle:after,.fd-card__second-subtitle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__numeric-content.fd-numeric-content{-ms-flex-negative:0;flex-shrink:0;width:auto}.fd-card__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;--fdCard_Focus_Outline_Radius:0;-webkit-box-flex:1;border-radius:var(--fdCard_Content_Border_Radius);-ms-flex:1 0 auto;flex:1 0 auto;position:relative}.fd-card__content:after,.fd-card__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__content.is-focus,.fd-card__content:focus{outline:none;z-index:5}.fd-card__content.is-focus:before,.fd-card__content:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);border-radius:var(--fdCard_Focus_Outline_Radius);content:\"\";display:block;inset:var(--fdCard_Focus_Outline_Offset);position:absolute;z-index:3}.fd-card__content:is(:first-child){overflow:hidden;--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0;--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius) 0 0}.fd-card__content:is(:last-child){overflow:hidden;--fdCard_Content_Border_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius)}.fd-card__content:is(:only-child){overflow:hidden;--fdCard_Content_Border_Radius:var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:var(--fdCard_Border_Corner_Radius)}.fd-card__content--with-spacing{padding-block:1rem;padding-inline:1rem}.fd-card__content-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:1.75rem}.fd-card__content-container:after,.fd-card__content-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__content-container--horizontal{gap:2rem;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row}.fd-card__content-section{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:1rem;max-width:24rem;min-width:12rem;width:100%}.fd-card__content-section:after,.fd-card__content-section:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__content-title-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-after:.5rem;padding-block-end:.5rem}.fd-card__content-title-container:after,.fd-card__content-title-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__content-group{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-card__content-group:after,.fd-card__content-group:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__content-group-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:.25rem}.fd-card__content-group-text:after,.fd-card__content-group-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card--analytical .fd-card__subtitle-area{margin-top:.5rem}.fd-card--analytical .fd-card__title{display:-webkit-box;-webkit-line-clamp:2;-webkit-box-orient:vertical;max-height:2.8rem;overflow:hidden;text-overflow:ellipsis;white-space:normal}.fd-card--table[class*=-compact] .fd-card__content,.fd-card--table[class*=-condensed] .fd-card__content,[class*=-compact] .fd-card--table:not([class*=-cozy]) .fd-card__content,[class*=-condensed] .fd-card--table:not([class*=-cozy]) .fd-card__content{-webkit-padding-after:.5rem;padding-block-end:.5rem}.fd-card--object .fd-card__content{padding-block:1rem;padding-inline:1rem}.fd-card__loader{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;min-height:5rem}.fd-card__loader:after,.fd-card__loader:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__media{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;background-color:var(--fdCard_Media_Background,var(--sapTile_Background));border-radius:var(--fdCard_Media_Border_Radius);-ms-flex-direction:row;flex-direction:row;flex-direction:var(--fdCard_Media_Flex_Direction,row);height:100%;overflow:hidden;padding-block:var(--fdCard_Media_Padding_Block_Start,0) var(--fdCard_Media_Padding_Block_End,0);padding-inline:var(--fdCard_Media_Padding_Inline_Start,0) var(--fdCard_Media_Padding_Inline_End,0);position:relative}.fd-card__media:after,.fd-card__media:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__media.fd-card__media--with-padding{--fdCard_Media_Image_Radius:.5rem;--fdCard_Media_Padding_Inline_Start:1rem;--fdCard_Media_Padding_Inline_End:1rem;--fdCard_Media_Padding_Block_Start:1rem}.fd-card__media.fd-card__media--bg-shell-1{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_1_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_1_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_1_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_1_TextColor)}.fd-card__media.fd-card__media--bg-shell-2{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_2_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_2_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_2_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_2_TextColor)}.fd-card__media.fd-card__media--bg-shell-3{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_3_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_3_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_3_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_3_TextColor)}.fd-card__media.fd-card__media--bg-shell-4{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_4_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_4_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_4_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_4_TextColor)}.fd-card__media.fd-card__media--bg-shell-5{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_5_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_5_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_5_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_5_TextColor)}.fd-card__media.fd-card__media--bg-shell-6{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_6_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_6_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_6_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_6_TextColor)}.fd-card__media.fd-card__media--bg-shell-7{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_7_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_7_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_7_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_7_TextColor)}.fd-card__media.fd-card__media--bg-shell-8{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_8_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_8_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_8_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_8_TextColor)}.fd-card__media.fd-card__media--bg-shell-9{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_9_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_9_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_9_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_9_TextColor)}.fd-card__media.fd-card__media--bg-shell-10{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_10_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_10_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_10_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_10_TextColor)}.fd-card__media.fd-card__media--bg-shell-11{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_11_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_11_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_11_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_11_TextColor)}.fd-card__media.fd-card__media--bg-shell-12{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_12_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_12_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_12_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_12_TextColor)}.fd-card__media.fd-card__media--bg-shell-13{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_13_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_13_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_13_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_13_TextColor)}.fd-card__media.fd-card__media--bg-shell-14{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_14_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_14_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_14_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_14_TextColor)}.fd-card__media.fd-card__media--bg-shell-15{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_15_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_15_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_15_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_15_TextColor)}.fd-card__media.fd-card__media--bg-shell-16{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Background:var(--sapShell_Category_16_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_16_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_16_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_16_TextColor)}.fd-card__media.fd-card__media--bg-legend-1{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor1);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-2{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor2);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-3{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor3);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-4{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor4);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-5{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor5);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-6{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor6);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-7{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor7);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-8{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor8);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-9{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor9);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-10{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor10);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-11{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor11);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-12{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor12);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-13{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor13);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-14{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor14);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-15{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor15);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-16{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor16);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-17{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor17);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-18{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor18);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-19{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor19);--fdCard_Media_Heading_Shadow:none}.fd-card__media.fd-card__media--bg-legend-20{--fdCard_Media_Content_Container_Background:transparent;--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Background:var(--sapLegendBackgroundColor20);--fdCard_Media_Heading_Shadow:none}.fd-card__media+.fd-card__header{--fdCard_Header_Border_Radius:0;--fdCard_Focus_Outline_Radius:0}.fd-card__media+.fd-card__header:is(:last-child){--fdCard_Header_Border_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius);--fdCard_Focus_Outline_Radius:0 0 var(--fdCard_Border_Corner_Radius) var(--fdCard_Border_Corner_Radius)}.fd-card__media:only-child{--fdCard_Media_Border_Radius:var(--sapTile_BorderCornerRadius)}.fd-card__media-content-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:1rem;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start;-webkit-box-pack:center;-ms-flex-pack:center;background:var(--fdCard_Media_Content_Container_Background,var(--sapTile_Background));height:var(--fdCard_Media_Content_Container_Height,100%);inset:var(--fdCard_Media_Content_Container_Top,0) var(--fdCard_Media_Content_Container_Right,0) var(--fdCard_Media_Content_Container_Right,0) var(--fdCard_Media_Content_Container_Left,0);justify-content:center;max-height:100%;padding-block:var(--fdCard_Media_Content_Container_Padding_Block,1rem);padding-inline:var(--fdCard_Media_Content_Container_Padding_Inline,1rem);position:var(--fdCard_Media_Content_Container_Position,relative);-webkit-transform:var(--fdCard_Media_Content_Container_Transform,none);transform:var(--fdCard_Media_Content_Container_Transform,none);width:var(--fdCard_Media_Content_Container_Width,100%);z-index:3}.fd-card__media-content-container:after,.fd-card__media-content-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-1{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_1_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_1_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_1_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_1_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-2{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_2_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_2_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_2_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_2_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-3{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_3_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_3_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_3_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_3_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-4{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_4_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_4_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_4_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_4_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-5{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_5_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_5_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_5_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_5_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-6{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_6_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_6_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_6_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_6_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-7{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_7_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_7_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_7_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_7_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-8{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_8_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_8_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_8_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_8_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-9{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_9_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_9_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_9_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_9_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-10{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_10_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_10_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_10_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_10_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-11{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_11_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_11_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_11_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_11_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-12{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_12_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_12_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_12_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_12_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-13{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_13_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_13_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_13_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_13_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-14{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_14_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_14_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_14_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_14_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-15{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_15_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_15_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_15_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_15_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-shell-16{--fdCard_Media_Content_Container_Background:var(--sapShell_Category_16_Background);--fdCard_Media_Heading_Color:var(--sapShell_Category_16_TextColor);--fdCard_Media_Heading_Shadow:var(--sapShell_Category_16_TextShadow);--fdCard_Media_Text_Color:var(--sapShell_Category_16_TextColor)}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-1{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor1);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-2{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor2);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-3{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor3);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-4{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor4);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-5{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor5);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-6{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor6);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-7{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor7);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-8{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor8);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-9{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor9);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-10{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor10);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-11{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor11);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-12{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor12);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-13{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor13);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-14{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor14);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-15{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor15);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-16{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor16);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-17{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor17);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-18{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor18);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-19{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor19);--fdCard_Media_Heading_Shadow:none}.fd-card__media-content-container.fd-card__media-content-container--bg-legend-20{--fdCard_Media_Heading_Color:var(--sapTextColor);--fdCard_Media_Text_Color:var(--sapTextColor);--fdCard_Media_Content_Container_Background:var(--sapLegendBackgroundColor20);--fdCard_Media_Heading_Shadow:none}.fd-card__media-image-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;height:var(--fdCard_Media_Image_Container_Height,100%);width:var(--fdCard_Media_Image_Container_Width,100%)}.fd-card__media-image-container:after,.fd-card__media-image-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__media-image{-webkit-box-flex:1;border-radius:var(--fdCard_Media_Image_Radius,0);-ms-flex:1;flex:1;height:var(--fdCard_Media_Image_Height,100%);width:var(--fdCard_Media_Image_Width,100%)}.fd-card__media-heading{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdCard_Media_Heading_Color,var(--sapTile_TitleTextColor));font-family:var(--sapFontFamily);font-family:var(--sapFontHeaderFamily);font-size:var(--sapFontSize);font-size:var(--sapFontHeader3Size);font-weight:400;font-weight:700;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-shadow:var(--fdCard_Media_Heading_Shadow,none)}.fd-card__media-heading:after,.fd-card__media-heading:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card__media-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdCard_Media_Text_Color,var(--sapTile_TextColor));font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-card__media-text:after,.fd-card__media-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-card--banner{--fdCard_Media_Content_Container_Width:80%;--fdCard_Media_Content_Container_Padding_Inline:3rem;--fdCard_Media_Content_Container_Padding_Block:3rem;border:.0625rem solid var(--sapTile_BorderColor);border-radius:var(--sapTile_BorderCornerRadius);-webkit-box-shadow:var(--sapContent_Shadow0);box-shadow:var(--sapContent_Shadow0);height:100%}@media (width >= 600px) and (width <= 1023px){.fd-card--banner{--fdCard_Media_Image_Container_Width:80%}}@media (width <= 599px){.fd-card--banner{--fdCard_Media_Image_Container_Width:100%}}.fd-card--banner:has(.fd-card__media-image-container){--fdCard_Media_Content_Container_Width:50%;--fdCard_Media_Image_Container_Width:50%}@media (width >= 600px) and (width <= 1023px){.fd-card--banner:has(.fd-card__media-image-container){--fdCard_Media_Content_Container_Width:80%;--fdCard_Media_Image_Container_Width:20%}}@media (width <= 599px){.fd-card--banner:has(.fd-card__media-image-container){--fdCard_Media_Flex_Direction:column-reverse;--fdCard_Media_Content_Container_Width:100%;--fdCard_Media_Image_Container_Width:100%}}.fd-card--banner:has(.fd-card__media-image-container):has(.fd-card__media-content-container--overlay){--fdCard_Media_Content_Container_Width: calc(50% - 3rem) ;--fdCard_Media_Image_Container_Width:100%;--fdCard_Media_Content_Container_Top:50%;--fdCard_Media_Content_Container_Left:3rem;--fdCard_Media_Content_Container_Height:fit-content;--fdCard_Media_Content_Container_Position:absolute;--fdCard_Media_Content_Container_Transform:translateY(-50%)}@media (width >= 600px) and (width <= 1023px){.fd-card--banner:has(.fd-card__media-image-container):has(.fd-card__media-content-container--overlay){--fdCard_Media_Content_Container_Width: calc(80% - 3rem) ;--fdCard_Media_Image_Container_Width:100%}}@media (width <= 599px){.fd-card--banner:has(.fd-card__media-image-container):has(.fd-card__media-content-container--overlay){--fdCard_Media_Content_Container_Width: calc(100% - 3rem) %;--fdCard_Media_Image_Container_Width:100%;--fdCard_Media_Content_Container_Right:3rem;--fdCard_Media_Content_Container_Padding_Inline:1rem;--fdCard_Media_Content_Container_Padding_Block:1rem}}.fd-card[class*=-compact],.fd-card[class*=-condensed],[class*=-compact] .fd-card:not([class*=-cozy]),[class*=-condensed] .fd-card:not([class*=-cozy]){--fdCard_Header_Text_Spacing:.5rem}@media (width <= 599px){.fd-card{--fdCard_Media_Content_Container_Width:100%}}.fd-badge{background:var(--sapHighlightColor);border:0;border:.0625rem solid var(--fdBadge_Border_Color);border-radius:.5rem;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_ContrastTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontSmallSize);font-weight:400;font-weight:700;forced-color-adjust:none;height:1rem;line-height:normal;margin-block:0;margin-inline:0;max-width:calc(100% - 1rem);overflow:hidden;padding-block:0;padding-inline:0;padding-inline:.5rem;position:absolute;right:.5rem;text-overflow:ellipsis;top:-.55rem;white-space:nowrap;z-index:10}.fd-badge:after,.fd-badge:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-badge[dir=rtl],[dir=rtl] .fd-badge{left:.5rem;right:auto}.fd-badge--static{position:static}\n/*! Bundled license information:\n\nfundamental-styles/dist/badge.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i1$1.ContentDensityObserver }], propDecorators: { keydownHandler: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }], buildComponentCssClass: [] } });

class CardContentComponent {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardContent];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardContentComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: CardContentComponent, isStandalone: true, selector: "fd-card-content", ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardContentComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardContentComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-card-content',
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardFooterActionItemDirective {
    /** @hidden */
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardFooterActionItemDirective, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardFooterActionItemDirective, isStandalone: true, selector: "[fdCardFooterActionItem]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardFooterActionItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdCardFooterActionItem]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef }] });

class CardFooterComponent {
    /** @hidden */
    constructor(_changeDetectorRef) {
        this._changeDetectorRef = _changeDetectorRef;
        /** @hidden */
        this._destroyed$ = inject(DestroyRef);
    }
    /** @hidden */
    ngAfterViewInit() {
        this.cardActionItems.changes
            .pipe(startWith(this.cardActionItems), map(() => this.cardActionItems.toArray()), tap((items) => (this.actionItems = items)), tap(() => this._changeDetectorRef.detectChanges()), takeUntilDestroyed(this._destroyed$))
            .subscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardFooterComponent, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CardFooterComponent, isStandalone: true, selector: "fd-card-footer", host: { classAttribute: "fd-card__footer" }, queries: [{ propertyName: "cardActionItems", predicate: CardFooterActionItemDirective }], ngImport: i0, template: "<ng-content></ng-content>\n@if (actionItems && actionItems.length > 0) {\n    <div class=\"fd-card__footer-actions\">\n        @for (actionItem of actionItems; track actionItem) {\n            <ng-template [ngTemplateOutlet]=\"actionItem.templateRef\"></ng-template>\n        }\n    </div>\n}\n", dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardFooterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-card-footer', host: {
                        class: 'fd-card__footer'
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, imports: [NgTemplateOutlet], template: "<ng-content></ng-content>\n@if (actionItems && actionItems.length > 0) {\n    <div class=\"fd-card__footer-actions\">\n        @for (actionItem of actionItems; track actionItem) {\n            <ng-template [ngTemplateOutlet]=\"actionItem.templateRef\"></ng-template>\n        }\n    </div>\n}\n" }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }], propDecorators: { cardActionItems: [{
                type: ContentChildren,
                args: [CardFooterActionItemDirective]
            }] } });

class CardCounterDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /**
         * the status represented by the Object Status.
         * can be one of the following: 'negative' | 'critical' | 'positive' | 'informative' | 'neutral'
         */
        this.statusInput = input('neutral');
    }
    /** @hidden */
    buildComponentCssClass() {
        this.status = this.statusInput();
        const objectStatusClasses = buildObjectStatusCssClasses(this);
        return [CLASS_NAME.cardCounter, ...objectStatusClasses];
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardCounterDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.2", type: CardCounterDirective, isStandalone: true, selector: "[fd-card-counter]", inputs: { statusInput: { classPropertyName: "statusInput", publicName: "statusInput", isSignal: true, isRequired: false, transformFunction: null } }, providers: [
            {
                provide: FD_CARD_COUNTER,
                useExisting: CardCounterDirective
            }
        ], usesOnChanges: true, ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardCounterDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardCounterDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-counter]',
                    standalone: true,
                    providers: [
                        {
                            provide: FD_CARD_COUNTER,
                            useExisting: CardCounterDirective
                        }
                    ]
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardSecondSubtitleDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardSecondSubtitle];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardSecondSubtitleDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardSecondSubtitleDirective, isStandalone: true, selector: "[fd-card-second-subtitle]", providers: [
            {
                provide: FD_CARD_SECOND_SUBTITLE,
                useExisting: CardSecondSubtitleDirective
            }
        ], ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardSecondSubtitleDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardSecondSubtitleDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-second-subtitle]',
                    standalone: true,
                    providers: [
                        {
                            provide: FD_CARD_SECOND_SUBTITLE,
                            useExisting: CardSecondSubtitleDirective
                        }
                    ]
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardSubtitleDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardSubtitle];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardSubtitleDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardSubtitleDirective, isStandalone: true, selector: "[fd-card-subtitle]", providers: [
            {
                provide: FD_CARD_SUBTITLE,
                useExisting: CardSubtitleDirective
            }
        ], ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardSubtitleDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardSubtitleDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-subtitle]',
                    standalone: true,
                    providers: [
                        {
                            provide: FD_CARD_SUBTITLE,
                            useExisting: CardSubtitleDirective
                        }
                    ]
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

let cardTitleId = 0;
class CardTitleDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /** Card title id, it has some default value if not set,  */
        this.id = input('fd-card-title-id-' + cardTitleId++);
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardTitle];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardTitleDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.2", type: CardTitleDirective, isStandalone: true, selector: "[fd-card-title]", inputs: { id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "attr.id": "id()" } }, providers: [
            {
                provide: FD_CARD_TITLE,
                useExisting: CardTitleDirective
            }
        ], ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardTitleDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-title]',
                    standalone: true,
                    providers: [
                        {
                            provide: FD_CARD_TITLE,
                            useExisting: CardTitleDirective
                        }
                    ],
                    host: {
                        '[attr.id]': 'id()'
                    }
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardHeaderComponent {
    constructor() {
        /**
         * aria-roledescription for the container
         * default: 'Card Header'
         */
        this.ariaRoleDescription = input('Card Header');
        /** @hidden */
        this._cardMainHeader = contentChild(FD_CARD_MAIN_HEADER);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardHeaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.2.0", version: "20.0.2", type: CardHeaderComponent, isStandalone: true, selector: "fd-card-header", inputs: { ariaRoleDescription: { classPropertyName: "ariaRoleDescription", publicName: "ariaRoleDescription", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "role": "group" }, properties: { "class.fd-card__header--interactive": "_cardMainHeader()?.interactive()", "attr.aria-roledescription": "ariaRoleDescription()" }, classAttribute: "fd-card__header" }, queries: [{ propertyName: "_cardMainHeader", first: true, predicate: FD_CARD_MAIN_HEADER, descendants: true, isSignal: true }], ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardHeaderComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-card-header',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    imports: [],
                    host: {
                        role: 'group',
                        class: 'fd-card__header',
                        '[class.fd-card__header--interactive]': '_cardMainHeader()?.interactive()',
                        '[attr.aria-roledescription]': 'ariaRoleDescription()'
                    }
                }]
        }] });

class CardIndicatorTitleDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardIndicatorTitleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardIndicatorTitleDirective, isStandalone: true, selector: "[fd-card-indicator-title]", host: { classAttribute: "fd-card__indicator-title" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardIndicatorTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-indicator-title]',
                    standalone: true,
                    host: {
                        class: 'fd-card__indicator-title'
                    }
                }]
        }] });

class CardIndicatorValueDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardIndicatorValueDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardIndicatorValueDirective, isStandalone: true, selector: "[fd-card-indicator-value]", host: { classAttribute: "fd-card__indicator-value" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardIndicatorValueDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-indicator-value]',
                    standalone: true,
                    host: {
                        class: 'fd-card__indicator-value'
                    }
                }]
        }] });

class CardIndicatorComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardIndicatorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: CardIndicatorComponent, isStandalone: true, selector: "fd-card-indicator", host: { classAttribute: "fd-card__indicator" }, ngImport: i0, template: `<ng-content select="[fd-card-indicator-title]"></ng-content>
        <ng-content select="[fd-card-indicator-value]"></ng-content>`, isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardIndicatorComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-card-indicator',
                    template: `<ng-content select="[fd-card-indicator-title]"></ng-content>
        <ng-content select="[fd-card-indicator-value]"></ng-content>`,
                    standalone: true,
                    host: {
                        class: 'fd-card__indicator'
                    }
                }]
        }] });

class CardNumericContainerComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardNumericContainerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: CardNumericContainerComponent, isStandalone: true, selector: "fd-card-numeric-container", host: { classAttribute: "fd-card__numeric-container" }, ngImport: i0, template: "<div class=\"fd-numeric-content fd-card__numeric-content\">\n    <div class=\"fd-numeric-content__kpi-container\">\n        <ng-content select=\"[fd-card-kpi-value]\"></ng-content>\n    </div>\n    <div class=\"fd-numeric-content__scale-container\">\n        <div class=\"fd-numeric-content__scale\">\n            <ng-content select=\"[fd-card-kpi-scale-icon]\"></ng-content>\n            <ng-content select=\"[fd-card-kpi-scale-text]\"></ng-content>\n        </div>\n    </div>\n</div>\n" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardNumericContainerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-card-numeric-container', standalone: true, host: {
                        class: 'fd-card__numeric-container'
                    }, template: "<div class=\"fd-numeric-content fd-card__numeric-content\">\n    <div class=\"fd-numeric-content__kpi-container\">\n        <ng-content select=\"[fd-card-kpi-value]\"></ng-content>\n    </div>\n    <div class=\"fd-numeric-content__scale-container\">\n        <div class=\"fd-numeric-content__scale\">\n            <ng-content select=\"[fd-card-kpi-scale-icon]\"></ng-content>\n            <ng-content select=\"[fd-card-kpi-scale-text]\"></ng-content>\n        </div>\n    </div>\n</div>\n" }]
        }] });

class CardHeaderActionDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardHeaderActionDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardHeaderActionDirective, isStandalone: true, selector: "[fd-card-header-action]", providers: [
            {
                provide: FD_CARD_HEADER_ACTION,
                useExisting: CardHeaderActionDirective
            }
        ], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardHeaderActionDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-header-action]',
                    standalone: true,
                    providers: [
                        {
                            provide: FD_CARD_HEADER_ACTION,
                            useExisting: CardHeaderActionDirective
                        }
                    ]
                }]
        }] });

class CardHeaderColumnDirective {
    constructor() {
        /**
         * horizontal alignment of the elements inside the column
         * possible options: 'left' | 'right'
         * default: 'left'
         */
        this.align = input('left');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardHeaderColumnDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.2", type: CardHeaderColumnDirective, isStandalone: true, selector: "[fd-card-header-column]", inputs: { align: { classPropertyName: "align", publicName: "align", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "class.fd-card__header-column--right-aligned": "align() === \"right\"" }, classAttribute: "fd-card__header-column" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardHeaderColumnDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-header-column]',
                    standalone: true,
                    host: {
                        class: 'fd-card__header-column',
                        '[class.fd-card__header-column--right-aligned]': 'align() === "right"'
                    }
                }]
        }] });

class CardExtendedHeaderComponent {
    constructor() {
        /**
         * aria-roledescription for the container
         * default: 'Extended content'
         */
        this.ariaRoleDescription = input('Extended content');
        /**
         * vertical alignment of the elements inside the header columns
         * possible options: 'top' | 'bottom' | null
         * default: null (middle)
         */
        this.align = input(null);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardExtendedHeaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "20.0.2", type: CardExtendedHeaderComponent, isStandalone: true, selector: "fd-card-extended-header", inputs: { ariaRoleDescription: { classPropertyName: "ariaRoleDescription", publicName: "ariaRoleDescription", isSignal: true, isRequired: false, transformFunction: null }, align: { classPropertyName: "align", publicName: "align", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "role": "group" }, properties: { "class.fd-card__header-extended--top-aligned": "align() === \"top\"", "class.fd-card__header-extended--bottom-aligned": "align() === \"bottom\"", "attr.aria-roledescription": "ariaRoleDescription()" }, classAttribute: "fd-card__header-extended" }, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardExtendedHeaderComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-card-extended-header',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true,
                    host: {
                        role: 'group',
                        class: 'fd-card__header-extended',
                        '[class.fd-card__header-extended--top-aligned]': 'align() === "top"',
                        '[class.fd-card__header-extended--bottom-aligned]': 'align() === "bottom"',
                        '[attr.aria-roledescription]': 'ariaRoleDescription()'
                    }
                }]
        }] });

class CardMainHeaderComponent {
    constructor() {
        /**
         * whether the main header is interactive
         * default: false
         */
        this.interactive = input(false);
        /**
         * Text for the title, aria-label and aria-description
         * of the main container with role button
         * when the card main header is interactive
         * default: "Activate for action/navigation"
         */
        this.title = input('Activate for action/navigation');
        /** @hidden */
        this._cardTitle = contentChild(FD_CARD_TITLE);
        /** @hidden */
        this._cardSubtitle = contentChild(FD_CARD_SUBTITLE);
        /** @hidden */
        this._cardCounter = contentChild(FD_CARD_COUNTER);
        /** @hidden */
        this._cardHeaderAction = contentChild(FD_CARD_HEADER_ACTION);
        /** @hidden */
        this._cardKpiHeader = contentChild(FD_CARD_KPI_HEADER);
        /** @hidden */
        this._cardSecondSubtitle = contentChild(FD_CARD_SECOND_SUBTITLE);
        /** @hidden */
        this._cardAvatar = contentChild(FD_AVATAR_COMPONENT);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMainHeaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: CardMainHeaderComponent, isStandalone: true, selector: "fd-card-main-header", inputs: { interactive: { classPropertyName: "interactive", publicName: "interactive", isSignal: true, isRequired: false, transformFunction: null }, title: { classPropertyName: "title", publicName: "title", isSignal: true, isRequired: false, transformFunction: null } }, providers: [
            {
                provide: FD_CARD_MAIN_HEADER,
                useExisting: CardMainHeaderComponent
            }
        ], queries: [{ propertyName: "_cardTitle", first: true, predicate: FD_CARD_TITLE, descendants: true, isSignal: true }, { propertyName: "_cardSubtitle", first: true, predicate: FD_CARD_SUBTITLE, descendants: true, isSignal: true }, { propertyName: "_cardCounter", first: true, predicate: FD_CARD_COUNTER, descendants: true, isSignal: true }, { propertyName: "_cardHeaderAction", first: true, predicate: FD_CARD_HEADER_ACTION, descendants: true, isSignal: true }, { propertyName: "_cardKpiHeader", first: true, predicate: FD_CARD_KPI_HEADER, descendants: true, isSignal: true }, { propertyName: "_cardSecondSubtitle", first: true, predicate: FD_CARD_SECOND_SUBTITLE, descendants: true, isSignal: true }, { propertyName: "_cardAvatar", first: true, predicate: FD_AVATAR_COMPONENT, descendants: true, isSignal: true }], ngImport: i0, template: "<div class=\"fd-card__header-main\">\n    @if (_cardAvatar() || _cardTitle() || _cardSubtitle() || _cardKpiHeader() || _cardSecondSubtitle()) {\n        <div\n            class=\"fd-card__header-main-container\"\n            [attr.role]=\"interactive() ? 'button' : null\"\n            [tabindex]=\"interactive() ? '0' : '-1'\"\n            [attr.aria-description]=\"interactive() ? title() : null\"\n            [attr.aria-label]=\"interactive() ? title() : null\"\n            [attr.title]=\"interactive() ? title() : null\"\n        >\n            <ng-content select=\"fd-avatar\"></ng-content>\n\n            <div class=\"fd-card__header-text\">\n                @if (_cardTitle()) {\n                    <div class=\"fd-card__title-area\">\n                        <ng-content select=\"[fd-card-title]\"></ng-content>\n                    </div>\n                }\n\n                @if (_cardSubtitle()) {\n                    <div class=\"fd-card__subtitle-area\">\n                        <ng-content select=\"[fd-card-subtitle]\"></ng-content>\n                    </div>\n                }\n                <ng-content select=\"fd-card-kpi-header\"></ng-content>\n                <ng-content select=\"[fd-card-second-subtitle]\"></ng-content>\n            </div>\n        </div>\n    }\n\n    @if (_cardCounter() || _cardHeaderAction()) {\n        <div class=\"fd-card__header-main-actions\">\n            <ng-content select=\"[fd-card-header-action]\"></ng-content>\n            <ng-content select=\"[fd-card-counter]\"></ng-content>\n        </div>\n    }\n\n    <ng-content></ng-content>\n</div>\n", changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMainHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-card-main-header', changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: FD_CARD_MAIN_HEADER,
                            useExisting: CardMainHeaderComponent
                        }
                    ], imports: [], template: "<div class=\"fd-card__header-main\">\n    @if (_cardAvatar() || _cardTitle() || _cardSubtitle() || _cardKpiHeader() || _cardSecondSubtitle()) {\n        <div\n            class=\"fd-card__header-main-container\"\n            [attr.role]=\"interactive() ? 'button' : null\"\n            [tabindex]=\"interactive() ? '0' : '-1'\"\n            [attr.aria-description]=\"interactive() ? title() : null\"\n            [attr.aria-label]=\"interactive() ? title() : null\"\n            [attr.title]=\"interactive() ? title() : null\"\n        >\n            <ng-content select=\"fd-avatar\"></ng-content>\n\n            <div class=\"fd-card__header-text\">\n                @if (_cardTitle()) {\n                    <div class=\"fd-card__title-area\">\n                        <ng-content select=\"[fd-card-title]\"></ng-content>\n                    </div>\n                }\n\n                @if (_cardSubtitle()) {\n                    <div class=\"fd-card__subtitle-area\">\n                        <ng-content select=\"[fd-card-subtitle]\"></ng-content>\n                    </div>\n                }\n                <ng-content select=\"fd-card-kpi-header\"></ng-content>\n                <ng-content select=\"[fd-card-second-subtitle]\"></ng-content>\n            </div>\n        </div>\n    }\n\n    @if (_cardCounter() || _cardHeaderAction()) {\n        <div class=\"fd-card__header-main-actions\">\n            <ng-content select=\"[fd-card-header-action]\"></ng-content>\n            <ng-content select=\"[fd-card-counter]\"></ng-content>\n        </div>\n    }\n\n    <ng-content></ng-content>\n</div>\n" }]
        }] });

class CardNumericHeaderComponent {
    constructor() {
        /**
         * aria-roledescription for the container
         * default: 'Numeric content'
         */
        this.ariaRoleDescription = input('Numeric content');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardNumericHeaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "20.0.2", type: CardNumericHeaderComponent, isStandalone: true, selector: "fd-card-numeric-header", inputs: { ariaRoleDescription: { classPropertyName: "ariaRoleDescription", publicName: "ariaRoleDescription", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "role": "group" }, properties: { "attr.aria-roledescription": "ariaRoleDescription()" }, classAttribute: "fd-card__header-numeric" }, ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardNumericHeaderComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-card-numeric-header',
                    template: `<ng-content></ng-content>`,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    imports: [],
                    host: {
                        role: 'group',
                        class: 'fd-card__header-numeric',
                        '[attr.aria-roledescription]': 'ariaRoleDescription()'
                    }
                }]
        }] });

class CardHeaderRowDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardHeaderRowDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardHeaderRowDirective, isStandalone: true, selector: "[fd-card-header-row]", host: { classAttribute: "fd-card__header-row" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardHeaderRowDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-header-row]',
                    standalone: true,
                    host: {
                        class: 'fd-card__header-row'
                    }
                }]
        }] });

class CardKpiAnalyticsContentDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardAnalyticsContent];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiAnalyticsContentDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardKpiAnalyticsContentDirective, isStandalone: true, selector: "[fd-card-kpi-analytics-content]", ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardKpiAnalyticsContentDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiAnalyticsContentDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-kpi-analytics-content]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardKpiAnalyticsLabelDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardAnalyticsText];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiAnalyticsLabelDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardKpiAnalyticsLabelDirective, isStandalone: true, selector: "[fd-card-kpi-analytics-label]", ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardKpiAnalyticsLabelDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiAnalyticsLabelDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-kpi-analytics-label]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardKpiAnalyticsDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardAnalytics];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiAnalyticsDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardKpiAnalyticsDirective, isStandalone: true, selector: "[fd-card-kpi-analytics]", ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardKpiAnalyticsDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiAnalyticsDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-kpi-analytics]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardKpiHeaderComponent {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardAnalyticalArea];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiHeaderComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: CardKpiHeaderComponent, isStandalone: true, selector: "fd-card-kpi-header", providers: [
            {
                provide: FD_CARD_KPI_HEADER,
                useExisting: CardKpiHeaderComponent
            }
        ], ngImport: i0, template: "<div class=\"fd-numeric-content fd-card__numeric-content\">\n    <div class=\"fd-numeric-content__kpi-container\">\n        <ng-content select=\"[fd-card-kpi-value]\"></ng-content>\n    </div>\n    <div class=\"fd-numeric-content__scale-container\">\n        <div class=\"fd-numeric-content__scale\">\n            <ng-content select=\"[fd-card-kpi-scale-icon]\"></ng-content>\n            <ng-content select=\"[fd-card-kpi-scale-text]\"></ng-content>\n        </div>\n    </div>\n</div>\n\n<div class=\"fd-card__analytics-container\">\n    <ng-content select=\"[fd-card-kpi-analytics]\"></ng-content>\n</div>\n", changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardKpiHeaderComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-card-kpi-header', changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, providers: [
                        {
                            provide: FD_CARD_KPI_HEADER,
                            useExisting: CardKpiHeaderComponent
                        }
                    ], template: "<div class=\"fd-numeric-content fd-card__numeric-content\">\n    <div class=\"fd-numeric-content__kpi-container\">\n        <ng-content select=\"[fd-card-kpi-value]\"></ng-content>\n    </div>\n    <div class=\"fd-numeric-content__scale-container\">\n        <div class=\"fd-numeric-content__scale\">\n            <ng-content select=\"[fd-card-kpi-scale-icon]\"></ng-content>\n            <ng-content select=\"[fd-card-kpi-scale-text]\"></ng-content>\n        </div>\n    </div>\n</div>\n\n<div class=\"fd-card__analytics-container\">\n    <ng-content select=\"[fd-card-kpi-analytics]\"></ng-content>\n</div>\n" }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardKpiScaleIconDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardAnalyticsScaleIcon];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiScaleIconDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardKpiScaleIconDirective, isStandalone: true, selector: "[fd-card-kpi-scale-icon]", ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardKpiScaleIconDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiScaleIconDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-kpi-scale-icon]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardKpiScaleTextDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardAnalyticsScaleText];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiScaleTextDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardKpiScaleTextDirective, isStandalone: true, selector: "[fd-card-kpi-scale-text]", ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardKpiScaleTextDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiScaleTextDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-kpi-scale-text]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardKpiValueDirective {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [
            CLASS_NAME.cardAnalyticsKpiValue,
            this.status ? `${CLASS_NAME.cardAnalyticsKpiValue}--${this.status}` : ''
        ];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiValueDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardKpiValueDirective, isStandalone: true, selector: "[fd-card-kpi-value]", inputs: { status: "status" }, ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardKpiValueDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardKpiValueDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-kpi-value]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { status: [{
                type: Input
            }], buildComponentCssClass: [] } });

class CardLoaderComponent {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    /** @hidden */
    buildComponentCssClass() {
        return [CLASS_NAME.cardLoader];
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardLoaderComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: CardLoaderComponent, isStandalone: true, selector: "fd-card-loader", ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], CardLoaderComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardLoaderComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-card-loader',
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { buildComponentCssClass: [] } });

class CardMediaContentContainerDirective {
    constructor() {
        /**
         * Whether the media content container is an overlay
         * Default value: false
         */
        this.isOverlay = input(false, {
            transform: booleanAttribute
        });
        /**
         * Shell Category Colors
         * Available values: number from 1 to 16
         */
        this.shellColor = input();
        /**
         * Legend Background Colors
         * Available values: number from 1 to 20
         */
        this.legendColor = input();
    }
    /** @hidden */
    get cssClass() {
        return [
            this.shellColor() && `fd-card__media-content-container--bg-shell-${this.shellColor()}`,
            this.legendColor() && `fd-card__media-content-container--bg-legend-${this.legendColor()}`
        ].filter(isTruthy);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaContentContainerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.2", type: CardMediaContentContainerDirective, isStandalone: true, selector: "[fd-card-media-content-container]", inputs: { isOverlay: { classPropertyName: "isOverlay", publicName: "isOverlay", isSignal: true, isRequired: false, transformFunction: null }, shellColor: { classPropertyName: "shellColor", publicName: "shellColor", isSignal: true, isRequired: false, transformFunction: null }, legendColor: { classPropertyName: "legendColor", publicName: "legendColor", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "class.fd-card__media-content-container--overlay": "isOverlay()", "class": "this.cssClass" }, classAttribute: "fd-card__media-content-container" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaContentContainerDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-media-content-container]',
                    standalone: true,
                    host: {
                        class: 'fd-card__media-content-container',
                        '[class.fd-card__media-content-container--overlay]': 'isOverlay()'
                    }
                }]
        }], propDecorators: { cssClass: [{
                type: HostBinding,
                args: ['class']
            }] } });

let cardMediaHeadingId = 0;
class CardMediaHeadingDirective {
    constructor() {
        /** Card title id, it has some default value if not set,  */
        this.id = input('fd-card-media-heading-' + cardMediaHeadingId++);
        /**
         * Heading level
         * Available values: number from 1 to 6
         */
        this.level = input();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaHeadingDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "20.0.2", type: CardMediaHeadingDirective, isStandalone: true, selector: "[fd-card-media-heading]", inputs: { id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null }, level: { classPropertyName: "level", publicName: "level", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "role": "group" }, properties: { "attr.aria-level": "level()", "attr.id": "id()" }, classAttribute: "fd-card__media-heading" }, providers: [
            {
                provide: FD_CARD_MEDIA_HEADING,
                useExisting: CardMediaHeadingDirective
            }
        ], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaHeadingDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-media-heading]',
                    standalone: true,
                    providers: [
                        {
                            provide: FD_CARD_MEDIA_HEADING,
                            useExisting: CardMediaHeadingDirective
                        }
                    ],
                    host: {
                        role: 'group',
                        class: 'fd-card__media-heading',
                        '[attr.aria-level]': 'level()',
                        '[attr.id]': 'id()'
                    }
                }]
        }] });

class CardMediaImageContainerDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaImageContainerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardMediaImageContainerDirective, isStandalone: true, selector: "[fd-card-media-image-container]", host: { classAttribute: "fd-card__media-image-container" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaImageContainerDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-media-image-container]',
                    standalone: true,
                    host: {
                        class: 'fd-card__media-image-container'
                    }
                }]
        }] });

class CardMediaImageDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaImageDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardMediaImageDirective, isStandalone: true, selector: "[fd-card-media-image]", host: { attributes: { "role": "presentation" }, classAttribute: "fd-card__media-image" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaImageDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-media-image]',
                    standalone: true,
                    host: {
                        role: 'presentation',
                        class: 'fd-card__media-image'
                    }
                }]
        }] });

class CardMediaTextDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaTextDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: CardMediaTextDirective, isStandalone: true, selector: "[fd-card-media-text]", host: { classAttribute: "fd-card__media-text" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaTextDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-card-media-text]',
                    standalone: true,
                    host: {
                        class: 'fd-card__media-text'
                    }
                }]
        }] });

class CardMediaComponent {
    constructor() {
        /**
         * aria-roledescription for the container
         * default: 'Card Media Block'
         */
        this.ariaRoleDescription = input('Card Media Block');
        /**
         * Whether the media container comes with a 1rem padding
         * Default value: false
         */
        this.hasPadding = input(false, {
            transform: booleanAttribute
        });
        /**
         * Shell Category Colors
         * Available values: number from 1 to 16
         */
        this.shellColor = input();
        /**
         * Legend Background Colors
         * Available values: number from 1 to 20
         */
        this.legendColor = input();
    }
    /** @hidden */
    get cssClass() {
        return [
            this.shellColor() && `fd-card__media--bg-shell-${this.shellColor()}`,
            this.legendColor() && `fd-card__media--bg-legend-${this.legendColor()}`
        ].filter(isTruthy);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "20.0.2", type: CardMediaComponent, isStandalone: true, selector: "fd-card-media", inputs: { ariaRoleDescription: { classPropertyName: "ariaRoleDescription", publicName: "ariaRoleDescription", isSignal: true, isRequired: false, transformFunction: null }, hasPadding: { classPropertyName: "hasPadding", publicName: "hasPadding", isSignal: true, isRequired: false, transformFunction: null }, shellColor: { classPropertyName: "shellColor", publicName: "shellColor", isSignal: true, isRequired: false, transformFunction: null }, legendColor: { classPropertyName: "legendColor", publicName: "legendColor", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "role": "group" }, properties: { "class.fd-card__media--with-padding": "hasPadding()", "attr.aria-roledescription": "ariaRoleDescription()", "class": "this.cssClass" }, classAttribute: "fd-card__media" }, ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardMediaComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fd-card-media',
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true,
                    host: {
                        role: 'group',
                        class: 'fd-card__media',
                        '[class.fd-card__media--with-padding]': 'hasPadding()',
                        '[attr.aria-roledescription]': 'ariaRoleDescription()'
                    }
                }]
        }], propDecorators: { cssClass: [{
                type: HostBinding,
                args: ['class']
            }] } });

const components = [
    CardComponent,
    CardListDirective,
    CardHeaderComponent,
    CardMainHeaderComponent,
    CardHeaderActionDirective,
    CardExtendedHeaderComponent,
    CardNumericHeaderComponent,
    CardHeaderRowDirective,
    CardHeaderColumnDirective,
    CardNumericContainerComponent,
    CardIndicatorComponent,
    CardIndicatorTitleDirective,
    CardIndicatorValueDirective,
    CardContentComponent,
    CardTitleDirective,
    CardSubtitleDirective,
    CardSecondSubtitleDirective,
    CardCounterDirective,
    CardLoaderComponent,
    CardKpiHeaderComponent,
    CardKpiValueDirective,
    CardKpiScaleIconDirective,
    CardKpiScaleTextDirective,
    CardKpiAnalyticsDirective,
    CardKpiAnalyticsLabelDirective,
    CardKpiAnalyticsContentDirective,
    CardFooterComponent,
    CardFooterActionItemDirective,
    CardMediaComponent,
    CardMediaImageDirective,
    CardMediaImageContainerDirective,
    CardMediaContentContainerDirective,
    CardMediaHeadingDirective,
    CardMediaTextDirective
];
class CardModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: CardModule, imports: [CardComponent,
            CardListDirective,
            CardHeaderComponent,
            CardMainHeaderComponent,
            CardHeaderActionDirective,
            CardExtendedHeaderComponent,
            CardNumericHeaderComponent,
            CardHeaderRowDirective,
            CardHeaderColumnDirective,
            CardNumericContainerComponent,
            CardIndicatorComponent,
            CardIndicatorTitleDirective,
            CardIndicatorValueDirective,
            CardContentComponent,
            CardTitleDirective,
            CardSubtitleDirective,
            CardSecondSubtitleDirective,
            CardCounterDirective,
            CardLoaderComponent,
            CardKpiHeaderComponent,
            CardKpiValueDirective,
            CardKpiScaleIconDirective,
            CardKpiScaleTextDirective,
            CardKpiAnalyticsDirective,
            CardKpiAnalyticsLabelDirective,
            CardKpiAnalyticsContentDirective,
            CardFooterComponent,
            CardFooterActionItemDirective,
            CardMediaComponent,
            CardMediaImageDirective,
            CardMediaImageContainerDirective,
            CardMediaContentContainerDirective,
            CardMediaHeadingDirective,
            CardMediaTextDirective, ContentDensityModule], exports: [CardComponent,
            CardListDirective,
            CardHeaderComponent,
            CardMainHeaderComponent,
            CardHeaderActionDirective,
            CardExtendedHeaderComponent,
            CardNumericHeaderComponent,
            CardHeaderRowDirective,
            CardHeaderColumnDirective,
            CardNumericContainerComponent,
            CardIndicatorComponent,
            CardIndicatorTitleDirective,
            CardIndicatorValueDirective,
            CardContentComponent,
            CardTitleDirective,
            CardSubtitleDirective,
            CardSecondSubtitleDirective,
            CardCounterDirective,
            CardLoaderComponent,
            CardKpiHeaderComponent,
            CardKpiValueDirective,
            CardKpiScaleIconDirective,
            CardKpiScaleTextDirective,
            CardKpiAnalyticsDirective,
            CardKpiAnalyticsLabelDirective,
            CardKpiAnalyticsContentDirective,
            CardFooterComponent,
            CardFooterActionItemDirective,
            CardMediaComponent,
            CardMediaImageDirective,
            CardMediaImageContainerDirective,
            CardMediaContentContainerDirective,
            CardMediaHeadingDirective,
            CardMediaTextDirective, ContentDensityModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardModule, imports: [CardComponent, ContentDensityModule, ContentDensityModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: CardModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...components, ContentDensityModule],
                    exports: [...components, ContentDensityModule]
                }]
        }] });

// Tokens

/**
 * Generated bundle index. Do not edit.
 */

export { CardComponent, CardContentComponent, CardCounterDirective, CardExtendedHeaderComponent, CardFooterActionItemDirective, CardFooterComponent, CardHeaderActionDirective, CardHeaderColumnDirective, CardHeaderComponent, CardHeaderRowDirective, CardIndicatorComponent, CardIndicatorTitleDirective, CardIndicatorValueDirective, CardKpiAnalyticsContentDirective, CardKpiAnalyticsDirective, CardKpiAnalyticsLabelDirective, CardKpiHeaderComponent, CardKpiScaleIconDirective, CardKpiScaleTextDirective, CardKpiValueDirective, CardListDirective, CardLoaderComponent, CardMainHeaderComponent, CardMediaComponent, CardMediaContentContainerDirective, CardMediaHeadingDirective, CardMediaImageContainerDirective, CardMediaImageDirective, CardMediaTextDirective, CardModule, CardNumericContainerComponent, CardNumericHeaderComponent, CardSecondSubtitleDirective, CardSubtitleDirective, CardTitleDirective, FD_CARD, FD_CARD_COUNTER, FD_CARD_HEADER_ACTION, FD_CARD_KPI_HEADER, FD_CARD_MAIN_HEADER, FD_CARD_MEDIA_HEADING, FD_CARD_SECOND_SUBTITLE, FD_CARD_SUBTITLE, FD_CARD_TITLE };
//# sourceMappingURL=fundamental-ngx-core-card.mjs.map
