import { __decorate, __metadata } from 'tslib';
import { NgTemplateOutlet } from '@angular/common';
import * as i0 from '@angular/core';
import { InjectionToken, booleanAttribute, Input, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import { applyCssClass } from '@fundamental-ngx/cdk/utils';
import { FD_DEFAULT_ICON_FONT_FAMILY, IconComponent } from '@fundamental-ngx/core/icon';

const FD_OBJECT_STATUS_COMPONENT = new InjectionToken('FdObjectStatusComponent');

class ObjectStatusComponent {
    /** Whether the Object status is icon-only. */
    get iconOnly() {
        return !this.label && !this.textTemplate;
    }
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
        /** Glyph font family */
        this.glyphFont = FD_DEFAULT_ICON_FONT_FAMILY;
        /** Whether the Object Status is clickable. */
        this.clickable = false;
        /** Whether the Object Status is inverted. */
        this.inverted = false;
        /** Whether the Object Status is in Large Design. */
        this.large = false;
        /** Whether to use secondary set of indication colors. */
        this.secondaryIndication = false;
    }
    /** @hidden
     * CssClassBuilder interface implementation
     * function must return single string
     * function is responsible for order which css classes are applied
     */
    buildComponentCssClass() {
        return buildObjectStatusCssClasses(this);
    }
    /** @hidden */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ObjectStatusComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: ObjectStatusComponent, isStandalone: true, selector: "[fd-object-status]", inputs: { class: "class", status: "status", glyph: "glyph", glyphFont: "glyphFont", label: "label", glyphAriaLabel: "glyphAriaLabel", indicationColor: "indicationColor", clickable: "clickable", inverted: ["inverted", "inverted", booleanAttribute], large: "large", secondaryIndication: "secondaryIndication", textTemplate: "textTemplate" }, host: { properties: { "attr.tabindex": "clickable ? 0 : null" } }, providers: [
            {
                provide: FD_OBJECT_STATUS_COMPONENT,
                useExisting: ObjectStatusComponent
            }
        ], usesOnChanges: true, ngImport: i0, template: `
        @if (glyph) {
            <fd-icon
                class="fd-object-status__icon"
                [glyph]="glyph"
                [font]="glyphFont"
                [attr.role]="glyphAriaLabel ? 'presentation' : ''"
                [ariaLabel]="glyphAriaLabel"
            >
            </fd-icon>
        }
        @if (textTemplate) {
            <span class="fd-object-status__text" [class]="_textClass">
                <ng-template [ngTemplateOutlet]="textTemplate"></ng-template>
            </span>
        }
        @if (label) {
            <span class="fd-object-status__text" [class]="_textClass">{{ label }}</span>
        }
    `, isInline: true, styles: [".fd-object-status{--fdObjectStatus_Decoration:none;--fdObjectStatus_Underline:transparent;--fdObjectStatus_Text_Decoration:var(--fdObjectStatus_TextDecoration_Regular);--fdObjectStatus_Icon_Font_Size:1rem;--fdObjectStatus_Icon_Color:var(--sapNeutralElementColor);--fdObjectStatus_Text_Font_Family:var(--sapFontFamily);--fdObjectStatus_Text_Font_Size:var(--sapFontSize);--fdObjectStatus_Text_Color:var(--sapNeutralTextColor);--fdObjectStatus_Height:1rem;--fdObjectStatus_Text_Shadow:var(--sapContent_TextShadow);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--fdObjectStatus_Text_Color);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-family:var(--fdObjectStatus_Text_Font_Family);font-size:var(--fdObjectStatus_Text_Font_Size);gap:.25rem;height:var(--fdObjectStatus_Height);line-height:var(--fdObjectStatus_Height);max-height:var(--fdObjectStatus_Height);max-width:100%;position:relative;text-shadow:var(--fdObjectStatus_Text_Shadow);word-break:break-word}.fd-object-status:after,.fd-object-status:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-status__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-family:inherit;font-size:var(--sapFontSize);font-size:inherit;font-weight:400;font-weight:inherit;forced-color-adjust:none;line-height:normal;line-height:var(--fdObjectStatus_Height);margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;word-break:inherit}.fd-object-status__text:after,.fd-object-status__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-status__icon [class*=sap-icon],.fd-object-status__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--fdObjectStatus_Icon_Color);font-size:var(--fdObjectStatus_Icon_Font_Size);line-height:var(--fdObjectStatus_Height)}.fd-object-status.fd-object-status--positive{--fdObjectStatus_Text_Color:var(--fdElementTextColor,var(--sapPositiveTextColor));--fdObjectStatus_Icon_Color:var(--fdElementIconColor,var(--sapPositiveElementColor))}.fd-object-status.fd-object-status--positive:visited{--fdObjectStatus_Text_Color: ;--fdObjectStatus_Icon_Color: }.fd-object-status.fd-object-status--positive.is-focus,.fd-object-status.fd-object-status--positive:focus{z-index:5}.fd-object-status.fd-object-status--positive.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--positive:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Positive_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Positive_IconColor_Focus)}.fd-object-status.fd-object-status--critical{--fdObjectStatus_Text_Color:var(--fdElementTextColor,var(--sapCriticalTextColor));--fdObjectStatus_Icon_Color:var(--fdElementIconColor,var(--sapCriticalElementColor))}.fd-object-status.fd-object-status--critical:visited{--fdObjectStatus_Text_Color: ;--fdObjectStatus_Icon_Color: }.fd-object-status.fd-object-status--critical.is-focus,.fd-object-status.fd-object-status--critical:focus{z-index:5}.fd-object-status.fd-object-status--critical.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--critical:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Critical_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Critical_IconColor_Focus)}.fd-object-status.fd-object-status--negative{--fdObjectStatus_Text_Color:var(--fdElementTextColor,var(--sapNegativeTextColor));--fdObjectStatus_Icon_Color:var(--fdElementIconColor,var(--sapNegativeElementColor))}.fd-object-status.fd-object-status--negative:visited{--fdObjectStatus_Text_Color: ;--fdObjectStatus_Icon_Color: }.fd-object-status.fd-object-status--negative.is-focus,.fd-object-status.fd-object-status--negative:focus{z-index:5}.fd-object-status.fd-object-status--negative.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--negative:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Negative_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Negative_IconColor_Focus)}.fd-object-status.fd-object-status--informative{--fdObjectStatus_Text_Color:var(--fdElementTextColor,var(--sapInformativeTextColor));--fdObjectStatus_Icon_Color:var(--fdElementIconColor,var(--sapInformativeElementColor))}.fd-object-status.fd-object-status--informative:visited{--fdObjectStatus_Text_Color: ;--fdObjectStatus_Icon_Color: }.fd-object-status.fd-object-status--informative.is-focus,.fd-object-status.fd-object-status--informative:focus{z-index:5}.fd-object-status.fd-object-status--informative.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--informative:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Informative_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Informative_IconColor_Focus)}.fd-object-status.fd-object-status--neutral{--fdObjectStatus_Text_Color:var(--fdElementTextColor,var(--sapNeutralTextColor));--fdObjectStatus_Icon_Color:var(--fdElementIconColor,var(--sapNeutralElementColor))}.fd-object-status.fd-object-status--neutral:visited{--fdObjectStatus_Text_Color: ;--fdObjectStatus_Icon_Color: }.fd-object-status.fd-object-status--neutral.is-focus,.fd-object-status.fd-object-status--neutral:focus{z-index:5}.fd-object-status.fd-object-status--neutral.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--neutral:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Neutral_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Neutral_IconColor_Focus)}.fd-object-status.fd-object-status--indication-1,.fd-object-status.fd-object-status--indication-1:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1)}.fd-object-status.fd-object-status--indication-1.is-focus,.fd-object-status.fd-object-status--indication-1:focus{z-index:5}.fd-object-status.fd-object-status--indication-1.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-1:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_1_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_1_Focus)}.fd-object-status.fd-object-status--indication-2,.fd-object-status.fd-object-status--indication-2:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2)}.fd-object-status.fd-object-status--indication-2.is-focus,.fd-object-status.fd-object-status--indication-2:focus{z-index:5}.fd-object-status.fd-object-status--indication-2.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-2:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_2_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_2_Focus)}.fd-object-status.fd-object-status--indication-3,.fd-object-status.fd-object-status--indication-3:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3)}.fd-object-status.fd-object-status--indication-3.is-focus,.fd-object-status.fd-object-status--indication-3:focus{z-index:5}.fd-object-status.fd-object-status--indication-3.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-3:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_3_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_3_Focus)}.fd-object-status.fd-object-status--indication-4,.fd-object-status.fd-object-status--indication-4:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4)}.fd-object-status.fd-object-status--indication-4.is-focus,.fd-object-status.fd-object-status--indication-4:focus{z-index:5}.fd-object-status.fd-object-status--indication-4.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-4:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_4_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_4_Focus)}.fd-object-status.fd-object-status--indication-5,.fd-object-status.fd-object-status--indication-5:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5)}.fd-object-status.fd-object-status--indication-5.is-focus,.fd-object-status.fd-object-status--indication-5:focus{z-index:5}.fd-object-status.fd-object-status--indication-5.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-5:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_5_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_5_Focus)}.fd-object-status.fd-object-status--indication-6,.fd-object-status.fd-object-status--indication-6:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6)}.fd-object-status.fd-object-status--indication-6.is-focus,.fd-object-status.fd-object-status--indication-6:focus{z-index:5}.fd-object-status.fd-object-status--indication-6.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-6:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_6_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_6_Focus)}.fd-object-status.fd-object-status--indication-7,.fd-object-status.fd-object-status--indication-7:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7)}.fd-object-status.fd-object-status--indication-7.is-focus,.fd-object-status.fd-object-status--indication-7:focus{z-index:5}.fd-object-status.fd-object-status--indication-7.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-7:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_7_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_7_Focus)}.fd-object-status.fd-object-status--indication-8,.fd-object-status.fd-object-status--indication-8:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8)}.fd-object-status.fd-object-status--indication-8.is-focus,.fd-object-status.fd-object-status--indication-8:focus{z-index:5}.fd-object-status.fd-object-status--indication-8.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-8:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_8_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_8_Focus)}.fd-object-status--link{cursor:pointer;-webkit-text-decoration:var(--fdObjectStatus_Decoration);text-decoration:var(--fdObjectStatus_Decoration)}.fd-object-status--link .fd-object-status__text{-webkit-text-decoration:var(--fdObjectStatus_Text_Decoration);text-decoration:var(--fdObjectStatus_Text_Decoration)}.fd-object-status--link.is-visited,.fd-object-status--link:visited{--fdObjectStatus_Text_Decoration:var(--fdObjectStatus_TextDecoration_Visited)}.fd-object-status--link.is-hover,.fd-object-status--link:hover{--fdObjectStatus_Text_Decoration:var(--fdObjectStatus_TextDecoration_Hover)}.fd-object-status--link.is-active,.fd-object-status--link:active{--fdObjectStatus_Text_Decoration:var(--fdObjectStatus_TextDecoration_Down)}.fd-object-status--link.is-focus,.fd-object-status--link:focus{z-index:5}.fd-object-status--link.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status--link:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Neutral_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Neutral_IconColor_Focus);--fdObjectStatus_Text_Decoration:var(--fdObjectStatus_TextDecoration_Focus);background:var(--fdObjectStatus_Focus_Background);border-radius:var(--fdObjectStatus_Focus_Border_Radius);outline:var(--fdObjectStatus_Focus_Outline);text-shadow:none}.fd-object-status--large{--fdObjectStatus_Text_Font_Size:1.5rem;--fdObjectStatus_Height:1.5rem;--fdObjectStatus_Icon_Font_Size:1.5rem;--fdObjectStatus_Text_Font_Family:var(--sapFontLightFamily)}.fd-object-status--inverted{--fdObjectStatus_Text_Shadow:none;--fdObjectStatus_Icon_Font_Size:.75rem;--fdObjectStatus_Text_Font_Size:var(--sapFontSmallSize);--fdObjectStatus_Text_Font_Family:var(--sapFontBoldFamily);background-color:var(--fdObjectStatus_Background_Color,transparent);border-color:var(--fdObjectStatus_Border_Color,initial);border-radius:var(--fdObjectStatus_Inverted_Border_Radius);border-style:solid;border-width:var(--fdObjectStatus_Inverted_Border_Width);max-height:none;min-height:var(--fdObjectStatus_Inverted_Line_Height);min-width:var(--fdObjectStatus_Inverted_Min_Width);overflow:hidden;padding-block:var(--fdObjectStatus_Inverted_Padding_Block);padding-inline:var(--fdObjectStatus_Inverted_Padding_Inline);position:relative;--fdObjectStatus_Text_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Inverted_Neutral_Background_Regular);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Inverted_Neutral_Border_Color_Regular)}.fd-object-status--inverted .fd-object-status__icon,.fd-object-status--inverted .fd-object-status__text{line-height:1rem}.fd-object-status--inverted:before{background:var(--fdObjectStatus_Underline);bottom:0;content:\"\";height:var(--fdObjectStatus_Inverted_Underline_Width);position:absolute;width:100%;z-index:1}.fd-object-status--inverted:active,.fd-object-status--inverted:hover,.fd-object-status--inverted:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Inverted_Neutral_Background_Regular)}.fd-object-status--inverted.fd-object-status--positive{--fdObjectStatus_Text_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Background);--fdObjectStatus_Border_Color:var(--sapButton_Success_BorderColor)}.fd-object-status--inverted.fd-object-status--positive:active,.fd-object-status--inverted.fd-object-status--positive:hover,.fd-object-status--inverted.fd-object-status--positive:visited{--fdObjectStatus_Text_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Background)}.fd-object-status--inverted.fd-object-status--critical{--fdObjectStatus_Text_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Critical_Background);--fdObjectStatus_Border_Color:var(--sapButton_Critical_BorderColor)}.fd-object-status--inverted.fd-object-status--critical:active,.fd-object-status--inverted.fd-object-status--critical:hover,.fd-object-status--inverted.fd-object-status--critical:visited{--fdObjectStatus_Text_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Critical_Background)}.fd-object-status--inverted.fd-object-status--negative{--fdObjectStatus_Text_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Negative_Background);--fdObjectStatus_Border_Color:var(--sapButton_Negative_BorderColor)}.fd-object-status--inverted.fd-object-status--negative:active,.fd-object-status--inverted.fd-object-status--negative:hover,.fd-object-status--inverted.fd-object-status--negative:visited{--fdObjectStatus_Text_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Negative_Background)}.fd-object-status--inverted.fd-object-status--informative{--fdObjectStatus_Text_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Information_Background);--fdObjectStatus_Border_Color:var(--sapButton_Information_BorderColor)}.fd-object-status--inverted.fd-object-status--informative:active,.fd-object-status--inverted.fd-object-status--informative:hover,.fd-object-status--inverted.fd-object-status--informative:visited{--fdObjectStatus_Text_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Information_Background)}.fd-object-status--inverted.fd-object-status--indication-1{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-1:active,.fd-object-status--inverted.fd-object-status--indication-1:hover,.fd-object-status--inverted.fd-object-status--indication-1:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Background)}.fd-object-status--inverted.fd-object-status--indication-2{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-2:active,.fd-object-status--inverted.fd-object-status--indication-2:hover,.fd-object-status--inverted.fd-object-status--indication-2:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Background)}.fd-object-status--inverted.fd-object-status--indication-3{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-3:active,.fd-object-status--inverted.fd-object-status--indication-3:hover,.fd-object-status--inverted.fd-object-status--indication-3:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Background)}.fd-object-status--inverted.fd-object-status--indication-4{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-4:active,.fd-object-status--inverted.fd-object-status--indication-4:hover,.fd-object-status--inverted.fd-object-status--indication-4:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Background)}.fd-object-status--inverted.fd-object-status--indication-5{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-5:active,.fd-object-status--inverted.fd-object-status--indication-5:hover,.fd-object-status--inverted.fd-object-status--indication-5:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Background)}.fd-object-status--inverted.fd-object-status--indication-6{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-6:active,.fd-object-status--inverted.fd-object-status--indication-6:hover,.fd-object-status--inverted.fd-object-status--indication-6:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Background)}.fd-object-status--inverted.fd-object-status--indication-7{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-7:active,.fd-object-status--inverted.fd-object-status--indication-7:hover,.fd-object-status--inverted.fd-object-status--indication-7:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Background)}.fd-object-status--inverted.fd-object-status--indication-8{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-8:active,.fd-object-status--inverted.fd-object-status--indication-8:hover,.fd-object-status--inverted.fd-object-status--indication-8:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Background)}.fd-object-status--inverted.fd-object-status--indication-9{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-9:active,.fd-object-status--inverted.fd-object-status--indication-9:hover,.fd-object-status--inverted.fd-object-status--indication-9:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Background)}.fd-object-status--inverted.fd-object-status--indication-10{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-10:active,.fd-object-status--inverted.fd-object-status--indication-10:hover,.fd-object-status--inverted.fd-object-status--indication-10:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Background)}.fd-object-status--inverted.fd-object-status--indication-1b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_1b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_1b)}.fd-object-status--inverted.fd-object-status--indication-1b:active,.fd-object-status--inverted.fd-object-status--indication-1b:hover,.fd-object-status--inverted.fd-object-status--indication-1b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_1b)}.fd-object-status--inverted.fd-object-status--indication-1b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-1b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-2b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_2b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_2b)}.fd-object-status--inverted.fd-object-status--indication-2b:active,.fd-object-status--inverted.fd-object-status--indication-2b:hover,.fd-object-status--inverted.fd-object-status--indication-2b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_2b)}.fd-object-status--inverted.fd-object-status--indication-2b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-2b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-3b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_3b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_3b)}.fd-object-status--inverted.fd-object-status--indication-3b:active,.fd-object-status--inverted.fd-object-status--indication-3b:hover,.fd-object-status--inverted.fd-object-status--indication-3b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_3b)}.fd-object-status--inverted.fd-object-status--indication-3b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-3b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-4b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_4b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_4b)}.fd-object-status--inverted.fd-object-status--indication-4b:active,.fd-object-status--inverted.fd-object-status--indication-4b:hover,.fd-object-status--inverted.fd-object-status--indication-4b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_4b)}.fd-object-status--inverted.fd-object-status--indication-4b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-4b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-5b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_5b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_5b)}.fd-object-status--inverted.fd-object-status--indication-5b:active,.fd-object-status--inverted.fd-object-status--indication-5b:hover,.fd-object-status--inverted.fd-object-status--indication-5b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_5b)}.fd-object-status--inverted.fd-object-status--indication-5b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-5b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-6b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_6b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_6b)}.fd-object-status--inverted.fd-object-status--indication-6b:active,.fd-object-status--inverted.fd-object-status--indication-6b:hover,.fd-object-status--inverted.fd-object-status--indication-6b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_6b)}.fd-object-status--inverted.fd-object-status--indication-6b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-6b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-7b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_7b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_7b)}.fd-object-status--inverted.fd-object-status--indication-7b:active,.fd-object-status--inverted.fd-object-status--indication-7b:hover,.fd-object-status--inverted.fd-object-status--indication-7b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_7b)}.fd-object-status--inverted.fd-object-status--indication-7b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-7b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-8b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_8b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_8b)}.fd-object-status--inverted.fd-object-status--indication-8b:active,.fd-object-status--inverted.fd-object-status--indication-8b:hover,.fd-object-status--inverted.fd-object-status--indication-8b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_8b)}.fd-object-status--inverted.fd-object-status--indication-8b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-8b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-9b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_9b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_9b)}.fd-object-status--inverted.fd-object-status--indication-9b:active,.fd-object-status--inverted.fd-object-status--indication-9b:hover,.fd-object-status--inverted.fd-object-status--indication-9b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_9b)}.fd-object-status--inverted.fd-object-status--indication-9b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-9b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-10b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_10b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_10b)}.fd-object-status--inverted.fd-object-status--indication-10b:active,.fd-object-status--inverted.fd-object-status--indication-10b:hover,.fd-object-status--inverted.fd-object-status--indication-10b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_10b)}.fd-object-status--inverted.fd-object-status--indication-10b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-10b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--large{--fdObjectStatus_Text_Font_Size:1.25rem;--fdObjectStatus_Icon_Font_Size:1.5rem;--fdObjectStatus_Height:1.5rem;--fdObjectStatus_Text_Font_Family:var(--fdObjectStatus_Inverted_Large_Font_Family);height:auto;max-height:none;min-width:1.75rem;-ms-flex-item-align:center;align-self:center;padding-block:.0625rem;padding-inline:.25rem}.fd-object-status--inverted.fd-object-status--large .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--large .fd-object-status__text{line-height:var(--fdObjectStatus_Height)}.fd-object-status--inverted.fd-object-status--link{cursor:pointer;--fdObjectStatus_Text_Decoration:none;--fdObjectStatus_Text_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Inverted_Neutral_Background_Regular);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Inverted_Neutral_Border_Color_Regular)}.fd-object-status--inverted.fd-object-status--link:active .fd-object-status__text,.fd-object-status--inverted.fd-object-status--link:hover .fd-object-status__text,.fd-object-status--inverted.fd-object-status--link:visited .fd-object-status__text{--fdObjectStatus_Text_Decoration:none}.fd-object-status--inverted.fd-object-status--link:visited{--fdObjectStatus_Text_Color:var(--sapTextColor);--fdObjectStatus_Icon_Color:var(--sapTextColor);--fdObjectStatus_Background_Color:var(--sapNeutralBackground);--fdObjectStatus_Border_Color:var(--sapNeutralBorderColor)}.fd-object-status--inverted.fd-object-status--link.is-focus,.fd-object-status--inverted.fd-object-status--link:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.is-hover,.fd-object-status--inverted.fd-object-status--link:hover{--fdObjectStatus_Text_Color:var(--sapButton_Neutral_Hover_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Neutral_Hover_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Neutral_Hover_Background);--fdObjectStatus_Border_Color:var(--sapButton_Neutral_Hover_BorderColor)}.fd-object-status--inverted.fd-object-status--link.is-active,.fd-object-status--inverted.fd-object-status--link:active{--fdObjectStatus_Text_Color:var(--sapButton_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Neutral_Active_Background);--fdObjectStatus_Border_Color:var(--sapButton_Neutral_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive{--fdObjectStatus_Text_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Background);--fdObjectStatus_Border_Color:var(--sapButton_Success_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive:visited{--fdObjectStatus_Text_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Background);--fdObjectStatus_Border_Color:var(--sapButton_Success_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive:hover{--fdObjectStatus_Text_Color:var(--sapButton_Success_Hover_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Success_Hover_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Hover_Background);--fdObjectStatus_Border_Color:var(--sapButton_Success_Hover_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive:active{--fdObjectStatus_Text_Color:var(--sapButton_Accept_Selected_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Accept_Selected_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Active_Background);--fdObjectStatus_Border_Color:var(--sapButton_Success_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical,.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical:visited{--fdObjectStatus_Text_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Critical_Background);--fdObjectStatus_Border_Color:var(--sapButton_Critical_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical:hover{--fdObjectStatus_Text_Color:var(--sapButton_Critical_Hover_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Critical_Hover_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Critical_Hover_Background);--fdObjectStatus_Border_Color:var(--sapButton_Critical_Hover_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical:active{--fdObjectStatus_Text_Color:var(--sapButton_Attention_Selected_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Attention_Selected_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Critical_Active_Background);--fdObjectStatus_Border_Color:var(--sapButton_Critical_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative{--fdObjectStatus_Text_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Negative_Background);--fdObjectStatus_Border_Color:var(--sapButton_Negative_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative:visited{--fdObjectStatus_Text_Color:var(--sapButton_Negative_Background);--fdObjectStatus_Icon_Color:var(--sapButton_Negative_Background);--fdObjectStatus_Background_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Border_Color: }.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative:hover{--fdObjectStatus_Text_Color:var(--sapButton_Negative_Hover_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Negative_Hover_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Negative_Hover_Background);--fdObjectStatus_Border_Color:var(--sapButton_Negative_Hover_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative:active{--fdObjectStatus_Text_Color:var(--sapButton_Reject_Selected_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Reject_Selected_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Negative_Active_Background);--fdObjectStatus_Border_Color:var(--sapButton_Negative_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative,.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative:visited{--fdObjectStatus_Text_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Information_Background);--fdObjectStatus_Border_Color:var(--sapButton_Information_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative:hover{--fdObjectStatus_Text_Color:var(--sapButton_Information_Hover_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Information_Hover_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Information_Hover_Background);--fdObjectStatus_Border_Color:var(--sapButton_Information_Hover_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative:active{--fdObjectStatus_Text_Color:var(--sapButton_Selected_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Selected_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Information_Active_Background);--fdObjectStatus_Border_Color:var(--sapButton_Information_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_1);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_2);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_3);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_4);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_5);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_6);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_7);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_8);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_9);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_10);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_1b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_1b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_1b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_1b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_2b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_2b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_2b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_2b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_3b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_3b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_3b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_3b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_4b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_4b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_4b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_4b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_5b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_5b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_5b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_5b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_6b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_6b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_6b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_6b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_7b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_7b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_7b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_7b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_8b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_8b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_8b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_8b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_9b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_9b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_9b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_9b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_10b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_10b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_10b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_10b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_Active_BorderColor)}.fd-object-status--truncate .fd-object-status__text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}\n/*! Bundled license information:\n\nfundamental-styles/dist/object-status.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], ObjectStatusComponent.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ObjectStatusComponent, decorators: [{
            type: Component,
            args: [{ selector: '[fd-object-status]', template: `
        @if (glyph) {
            <fd-icon
                class="fd-object-status__icon"
                [glyph]="glyph"
                [font]="glyphFont"
                [attr.role]="glyphAriaLabel ? 'presentation' : ''"
                [ariaLabel]="glyphAriaLabel"
            >
            </fd-icon>
        }
        @if (textTemplate) {
            <span class="fd-object-status__text" [class]="_textClass">
                <ng-template [ngTemplateOutlet]="textTemplate"></ng-template>
            </span>
        }
        @if (label) {
            <span class="fd-object-status__text" [class]="_textClass">{{ label }}</span>
        }
    `, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: FD_OBJECT_STATUS_COMPONENT,
                            useExisting: ObjectStatusComponent
                        }
                    ], host: {
                        '[attr.tabindex]': 'clickable ? 0 : null'
                    }, imports: [IconComponent, NgTemplateOutlet], styles: [".fd-object-status{--fdObjectStatus_Decoration:none;--fdObjectStatus_Underline:transparent;--fdObjectStatus_Text_Decoration:var(--fdObjectStatus_TextDecoration_Regular);--fdObjectStatus_Icon_Font_Size:1rem;--fdObjectStatus_Icon_Color:var(--sapNeutralElementColor);--fdObjectStatus_Text_Font_Family:var(--sapFontFamily);--fdObjectStatus_Text_Font_Size:var(--sapFontSize);--fdObjectStatus_Text_Color:var(--sapNeutralTextColor);--fdObjectStatus_Height:1rem;--fdObjectStatus_Text_Shadow:var(--sapContent_TextShadow);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--fdObjectStatus_Text_Color);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-family:var(--fdObjectStatus_Text_Font_Family);font-size:var(--fdObjectStatus_Text_Font_Size);gap:.25rem;height:var(--fdObjectStatus_Height);line-height:var(--fdObjectStatus_Height);max-height:var(--fdObjectStatus_Height);max-width:100%;position:relative;text-shadow:var(--fdObjectStatus_Text_Shadow);word-break:break-word}.fd-object-status:after,.fd-object-status:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-status__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-family:inherit;font-size:var(--sapFontSize);font-size:inherit;font-weight:400;font-weight:inherit;forced-color-adjust:none;line-height:normal;line-height:var(--fdObjectStatus_Height);margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;word-break:inherit}.fd-object-status__text:after,.fd-object-status__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-status__icon [class*=sap-icon],.fd-object-status__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--fdObjectStatus_Icon_Color);font-size:var(--fdObjectStatus_Icon_Font_Size);line-height:var(--fdObjectStatus_Height)}.fd-object-status.fd-object-status--positive{--fdObjectStatus_Text_Color:var(--fdElementTextColor,var(--sapPositiveTextColor));--fdObjectStatus_Icon_Color:var(--fdElementIconColor,var(--sapPositiveElementColor))}.fd-object-status.fd-object-status--positive:visited{--fdObjectStatus_Text_Color: ;--fdObjectStatus_Icon_Color: }.fd-object-status.fd-object-status--positive.is-focus,.fd-object-status.fd-object-status--positive:focus{z-index:5}.fd-object-status.fd-object-status--positive.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--positive:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Positive_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Positive_IconColor_Focus)}.fd-object-status.fd-object-status--critical{--fdObjectStatus_Text_Color:var(--fdElementTextColor,var(--sapCriticalTextColor));--fdObjectStatus_Icon_Color:var(--fdElementIconColor,var(--sapCriticalElementColor))}.fd-object-status.fd-object-status--critical:visited{--fdObjectStatus_Text_Color: ;--fdObjectStatus_Icon_Color: }.fd-object-status.fd-object-status--critical.is-focus,.fd-object-status.fd-object-status--critical:focus{z-index:5}.fd-object-status.fd-object-status--critical.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--critical:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Critical_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Critical_IconColor_Focus)}.fd-object-status.fd-object-status--negative{--fdObjectStatus_Text_Color:var(--fdElementTextColor,var(--sapNegativeTextColor));--fdObjectStatus_Icon_Color:var(--fdElementIconColor,var(--sapNegativeElementColor))}.fd-object-status.fd-object-status--negative:visited{--fdObjectStatus_Text_Color: ;--fdObjectStatus_Icon_Color: }.fd-object-status.fd-object-status--negative.is-focus,.fd-object-status.fd-object-status--negative:focus{z-index:5}.fd-object-status.fd-object-status--negative.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--negative:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Negative_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Negative_IconColor_Focus)}.fd-object-status.fd-object-status--informative{--fdObjectStatus_Text_Color:var(--fdElementTextColor,var(--sapInformativeTextColor));--fdObjectStatus_Icon_Color:var(--fdElementIconColor,var(--sapInformativeElementColor))}.fd-object-status.fd-object-status--informative:visited{--fdObjectStatus_Text_Color: ;--fdObjectStatus_Icon_Color: }.fd-object-status.fd-object-status--informative.is-focus,.fd-object-status.fd-object-status--informative:focus{z-index:5}.fd-object-status.fd-object-status--informative.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--informative:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Informative_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Informative_IconColor_Focus)}.fd-object-status.fd-object-status--neutral{--fdObjectStatus_Text_Color:var(--fdElementTextColor,var(--sapNeutralTextColor));--fdObjectStatus_Icon_Color:var(--fdElementIconColor,var(--sapNeutralElementColor))}.fd-object-status.fd-object-status--neutral:visited{--fdObjectStatus_Text_Color: ;--fdObjectStatus_Icon_Color: }.fd-object-status.fd-object-status--neutral.is-focus,.fd-object-status.fd-object-status--neutral:focus{z-index:5}.fd-object-status.fd-object-status--neutral.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--neutral:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Neutral_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Neutral_IconColor_Focus)}.fd-object-status.fd-object-status--indication-1,.fd-object-status.fd-object-status--indication-1:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1)}.fd-object-status.fd-object-status--indication-1.is-focus,.fd-object-status.fd-object-status--indication-1:focus{z-index:5}.fd-object-status.fd-object-status--indication-1.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-1:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_1_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_1_Focus)}.fd-object-status.fd-object-status--indication-2,.fd-object-status.fd-object-status--indication-2:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2)}.fd-object-status.fd-object-status--indication-2.is-focus,.fd-object-status.fd-object-status--indication-2:focus{z-index:5}.fd-object-status.fd-object-status--indication-2.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-2:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_2_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_2_Focus)}.fd-object-status.fd-object-status--indication-3,.fd-object-status.fd-object-status--indication-3:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3)}.fd-object-status.fd-object-status--indication-3.is-focus,.fd-object-status.fd-object-status--indication-3:focus{z-index:5}.fd-object-status.fd-object-status--indication-3.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-3:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_3_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_3_Focus)}.fd-object-status.fd-object-status--indication-4,.fd-object-status.fd-object-status--indication-4:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4)}.fd-object-status.fd-object-status--indication-4.is-focus,.fd-object-status.fd-object-status--indication-4:focus{z-index:5}.fd-object-status.fd-object-status--indication-4.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-4:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_4_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_4_Focus)}.fd-object-status.fd-object-status--indication-5,.fd-object-status.fd-object-status--indication-5:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5)}.fd-object-status.fd-object-status--indication-5.is-focus,.fd-object-status.fd-object-status--indication-5:focus{z-index:5}.fd-object-status.fd-object-status--indication-5.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-5:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_5_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_5_Focus)}.fd-object-status.fd-object-status--indication-6,.fd-object-status.fd-object-status--indication-6:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6)}.fd-object-status.fd-object-status--indication-6.is-focus,.fd-object-status.fd-object-status--indication-6:focus{z-index:5}.fd-object-status.fd-object-status--indication-6.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-6:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_6_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_6_Focus)}.fd-object-status.fd-object-status--indication-7,.fd-object-status.fd-object-status--indication-7:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7)}.fd-object-status.fd-object-status--indication-7.is-focus,.fd-object-status.fd-object-status--indication-7:focus{z-index:5}.fd-object-status.fd-object-status--indication-7.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-7:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_7_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_7_Focus)}.fd-object-status.fd-object-status--indication-8,.fd-object-status.fd-object-status--indication-8:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8)}.fd-object-status.fd-object-status--indication-8.is-focus,.fd-object-status.fd-object-status--indication-8:focus{z-index:5}.fd-object-status.fd-object-status--indication-8.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status.fd-object-status--indication-8:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Accent_Color_8_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Accent_Color_8_Focus)}.fd-object-status--link{cursor:pointer;-webkit-text-decoration:var(--fdObjectStatus_Decoration);text-decoration:var(--fdObjectStatus_Decoration)}.fd-object-status--link .fd-object-status__text{-webkit-text-decoration:var(--fdObjectStatus_Text_Decoration);text-decoration:var(--fdObjectStatus_Text_Decoration)}.fd-object-status--link.is-visited,.fd-object-status--link:visited{--fdObjectStatus_Text_Decoration:var(--fdObjectStatus_TextDecoration_Visited)}.fd-object-status--link.is-hover,.fd-object-status--link:hover{--fdObjectStatus_Text_Decoration:var(--fdObjectStatus_TextDecoration_Hover)}.fd-object-status--link.is-active,.fd-object-status--link:active{--fdObjectStatus_Text_Decoration:var(--fdObjectStatus_TextDecoration_Down)}.fd-object-status--link.is-focus,.fd-object-status--link:focus{z-index:5}.fd-object-status--link.is-focus:not(:active):not(.fd-object-status--inverted),.fd-object-status--link:focus:not(:active):not(.fd-object-status--inverted){--fdObjectStatus_Text_Color:var(--fdObjectStatus_Neutral_Color_Focus);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Neutral_IconColor_Focus);--fdObjectStatus_Text_Decoration:var(--fdObjectStatus_TextDecoration_Focus);background:var(--fdObjectStatus_Focus_Background);border-radius:var(--fdObjectStatus_Focus_Border_Radius);outline:var(--fdObjectStatus_Focus_Outline);text-shadow:none}.fd-object-status--large{--fdObjectStatus_Text_Font_Size:1.5rem;--fdObjectStatus_Height:1.5rem;--fdObjectStatus_Icon_Font_Size:1.5rem;--fdObjectStatus_Text_Font_Family:var(--sapFontLightFamily)}.fd-object-status--inverted{--fdObjectStatus_Text_Shadow:none;--fdObjectStatus_Icon_Font_Size:.75rem;--fdObjectStatus_Text_Font_Size:var(--sapFontSmallSize);--fdObjectStatus_Text_Font_Family:var(--sapFontBoldFamily);background-color:var(--fdObjectStatus_Background_Color,transparent);border-color:var(--fdObjectStatus_Border_Color,initial);border-radius:var(--fdObjectStatus_Inverted_Border_Radius);border-style:solid;border-width:var(--fdObjectStatus_Inverted_Border_Width);max-height:none;min-height:var(--fdObjectStatus_Inverted_Line_Height);min-width:var(--fdObjectStatus_Inverted_Min_Width);overflow:hidden;padding-block:var(--fdObjectStatus_Inverted_Padding_Block);padding-inline:var(--fdObjectStatus_Inverted_Padding_Inline);position:relative;--fdObjectStatus_Text_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Inverted_Neutral_Background_Regular);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Inverted_Neutral_Border_Color_Regular)}.fd-object-status--inverted .fd-object-status__icon,.fd-object-status--inverted .fd-object-status__text{line-height:1rem}.fd-object-status--inverted:before{background:var(--fdObjectStatus_Underline);bottom:0;content:\"\";height:var(--fdObjectStatus_Inverted_Underline_Width);position:absolute;width:100%;z-index:1}.fd-object-status--inverted:active,.fd-object-status--inverted:hover,.fd-object-status--inverted:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Inverted_Neutral_Background_Regular)}.fd-object-status--inverted.fd-object-status--positive{--fdObjectStatus_Text_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Background);--fdObjectStatus_Border_Color:var(--sapButton_Success_BorderColor)}.fd-object-status--inverted.fd-object-status--positive:active,.fd-object-status--inverted.fd-object-status--positive:hover,.fd-object-status--inverted.fd-object-status--positive:visited{--fdObjectStatus_Text_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Background)}.fd-object-status--inverted.fd-object-status--critical{--fdObjectStatus_Text_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Critical_Background);--fdObjectStatus_Border_Color:var(--sapButton_Critical_BorderColor)}.fd-object-status--inverted.fd-object-status--critical:active,.fd-object-status--inverted.fd-object-status--critical:hover,.fd-object-status--inverted.fd-object-status--critical:visited{--fdObjectStatus_Text_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Critical_Background)}.fd-object-status--inverted.fd-object-status--negative{--fdObjectStatus_Text_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Negative_Background);--fdObjectStatus_Border_Color:var(--sapButton_Negative_BorderColor)}.fd-object-status--inverted.fd-object-status--negative:active,.fd-object-status--inverted.fd-object-status--negative:hover,.fd-object-status--inverted.fd-object-status--negative:visited{--fdObjectStatus_Text_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Negative_Background)}.fd-object-status--inverted.fd-object-status--informative{--fdObjectStatus_Text_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Information_Background);--fdObjectStatus_Border_Color:var(--sapButton_Information_BorderColor)}.fd-object-status--inverted.fd-object-status--informative:active,.fd-object-status--inverted.fd-object-status--informative:hover,.fd-object-status--inverted.fd-object-status--informative:visited{--fdObjectStatus_Text_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Information_Background)}.fd-object-status--inverted.fd-object-status--indication-1{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-1:active,.fd-object-status--inverted.fd-object-status--indication-1:hover,.fd-object-status--inverted.fd-object-status--indication-1:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Background)}.fd-object-status--inverted.fd-object-status--indication-2{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-2:active,.fd-object-status--inverted.fd-object-status--indication-2:hover,.fd-object-status--inverted.fd-object-status--indication-2:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Background)}.fd-object-status--inverted.fd-object-status--indication-3{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-3:active,.fd-object-status--inverted.fd-object-status--indication-3:hover,.fd-object-status--inverted.fd-object-status--indication-3:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Background)}.fd-object-status--inverted.fd-object-status--indication-4{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-4:active,.fd-object-status--inverted.fd-object-status--indication-4:hover,.fd-object-status--inverted.fd-object-status--indication-4:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Background)}.fd-object-status--inverted.fd-object-status--indication-5{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-5:active,.fd-object-status--inverted.fd-object-status--indication-5:hover,.fd-object-status--inverted.fd-object-status--indication-5:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Background)}.fd-object-status--inverted.fd-object-status--indication-6{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-6:active,.fd-object-status--inverted.fd-object-status--indication-6:hover,.fd-object-status--inverted.fd-object-status--indication-6:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Background)}.fd-object-status--inverted.fd-object-status--indication-7{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-7:active,.fd-object-status--inverted.fd-object-status--indication-7:hover,.fd-object-status--inverted.fd-object-status--indication-7:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Background)}.fd-object-status--inverted.fd-object-status--indication-8{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-8:active,.fd-object-status--inverted.fd-object-status--indication-8:hover,.fd-object-status--inverted.fd-object-status--indication-8:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Background)}.fd-object-status--inverted.fd-object-status--indication-9{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-9:active,.fd-object-status--inverted.fd-object-status--indication-9:hover,.fd-object-status--inverted.fd-object-status--indication-9:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Background)}.fd-object-status--inverted.fd-object-status--indication-10{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_BorderColor)}.fd-object-status--inverted.fd-object-status--indication-10:active,.fd-object-status--inverted.fd-object-status--indication-10:hover,.fd-object-status--inverted.fd-object-status--indication-10:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Background)}.fd-object-status--inverted.fd-object-status--indication-1b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_1b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_1b)}.fd-object-status--inverted.fd-object-status--indication-1b:active,.fd-object-status--inverted.fd-object-status--indication-1b:hover,.fd-object-status--inverted.fd-object-status--indication-1b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_1b)}.fd-object-status--inverted.fd-object-status--indication-1b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-1b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-2b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_2b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_2b)}.fd-object-status--inverted.fd-object-status--indication-2b:active,.fd-object-status--inverted.fd-object-status--indication-2b:hover,.fd-object-status--inverted.fd-object-status--indication-2b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_2b)}.fd-object-status--inverted.fd-object-status--indication-2b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-2b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-3b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_3b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_3b)}.fd-object-status--inverted.fd-object-status--indication-3b:active,.fd-object-status--inverted.fd-object-status--indication-3b:hover,.fd-object-status--inverted.fd-object-status--indication-3b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_3b)}.fd-object-status--inverted.fd-object-status--indication-3b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-3b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-4b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_4b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_4b)}.fd-object-status--inverted.fd-object-status--indication-4b:active,.fd-object-status--inverted.fd-object-status--indication-4b:hover,.fd-object-status--inverted.fd-object-status--indication-4b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_4b)}.fd-object-status--inverted.fd-object-status--indication-4b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-4b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-5b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_5b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_5b)}.fd-object-status--inverted.fd-object-status--indication-5b:active,.fd-object-status--inverted.fd-object-status--indication-5b:hover,.fd-object-status--inverted.fd-object-status--indication-5b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_5b)}.fd-object-status--inverted.fd-object-status--indication-5b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-5b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-6b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_6b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_6b)}.fd-object-status--inverted.fd-object-status--indication-6b:active,.fd-object-status--inverted.fd-object-status--indication-6b:hover,.fd-object-status--inverted.fd-object-status--indication-6b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_6b)}.fd-object-status--inverted.fd-object-status--indication-6b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-6b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-7b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_7b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_7b)}.fd-object-status--inverted.fd-object-status--indication-7b:active,.fd-object-status--inverted.fd-object-status--indication-7b:hover,.fd-object-status--inverted.fd-object-status--indication-7b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_7b)}.fd-object-status--inverted.fd-object-status--indication-7b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-7b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-8b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_8b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_8b)}.fd-object-status--inverted.fd-object-status--indication-8b:active,.fd-object-status--inverted.fd-object-status--indication-8b:hover,.fd-object-status--inverted.fd-object-status--indication-8b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_8b)}.fd-object-status--inverted.fd-object-status--indication-8b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-8b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-9b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_9b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_9b)}.fd-object-status--inverted.fd-object-status--indication-9b:active,.fd-object-status--inverted.fd-object-status--indication-9b:hover,.fd-object-status--inverted.fd-object-status--indication-9b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_9b)}.fd-object-status--inverted.fd-object-status--indication-9b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-9b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--indication-10b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_10b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_10b)}.fd-object-status--inverted.fd-object-status--indication-10b:active,.fd-object-status--inverted.fd-object-status--indication-10b:hover,.fd-object-status--inverted.fd-object-status--indication-10b:visited{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_10b)}.fd-object-status--inverted.fd-object-status--indication-10b .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--indication-10b .fd-object-status__text{text-shadow:var(--fdObjectStatus_Text_Shadow_Indication_Color)}.fd-object-status--inverted.fd-object-status--large{--fdObjectStatus_Text_Font_Size:1.25rem;--fdObjectStatus_Icon_Font_Size:1.5rem;--fdObjectStatus_Height:1.5rem;--fdObjectStatus_Text_Font_Family:var(--fdObjectStatus_Inverted_Large_Font_Family);height:auto;max-height:none;min-width:1.75rem;-ms-flex-item-align:center;align-self:center;padding-block:.0625rem;padding-inline:.25rem}.fd-object-status--inverted.fd-object-status--large .fd-object-status__icon,.fd-object-status--inverted.fd-object-status--large .fd-object-status__text{line-height:var(--fdObjectStatus_Height)}.fd-object-status--inverted.fd-object-status--link{cursor:pointer;--fdObjectStatus_Text_Decoration:none;--fdObjectStatus_Text_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Inverted_Neutral_Color_Regular);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Inverted_Neutral_Background_Regular);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Inverted_Neutral_Border_Color_Regular)}.fd-object-status--inverted.fd-object-status--link:active .fd-object-status__text,.fd-object-status--inverted.fd-object-status--link:hover .fd-object-status__text,.fd-object-status--inverted.fd-object-status--link:visited .fd-object-status__text{--fdObjectStatus_Text_Decoration:none}.fd-object-status--inverted.fd-object-status--link:visited{--fdObjectStatus_Text_Color:var(--sapTextColor);--fdObjectStatus_Icon_Color:var(--sapTextColor);--fdObjectStatus_Background_Color:var(--sapNeutralBackground);--fdObjectStatus_Border_Color:var(--sapNeutralBorderColor)}.fd-object-status--inverted.fd-object-status--link.is-focus,.fd-object-status--inverted.fd-object-status--link:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.is-hover,.fd-object-status--inverted.fd-object-status--link:hover{--fdObjectStatus_Text_Color:var(--sapButton_Neutral_Hover_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Neutral_Hover_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Neutral_Hover_Background);--fdObjectStatus_Border_Color:var(--sapButton_Neutral_Hover_BorderColor)}.fd-object-status--inverted.fd-object-status--link.is-active,.fd-object-status--inverted.fd-object-status--link:active{--fdObjectStatus_Text_Color:var(--sapButton_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Neutral_Active_Background);--fdObjectStatus_Border_Color:var(--sapButton_Neutral_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive{--fdObjectStatus_Text_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Success_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Background);--fdObjectStatus_Border_Color:var(--sapButton_Success_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive:visited{--fdObjectStatus_Text_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Background);--fdObjectStatus_Border_Color:var(--sapButton_Success_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive:hover{--fdObjectStatus_Text_Color:var(--sapButton_Success_Hover_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Success_Hover_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Hover_Background);--fdObjectStatus_Border_Color:var(--sapButton_Success_Hover_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--positive:active{--fdObjectStatus_Text_Color:var(--sapButton_Accept_Selected_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Accept_Selected_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Success_Active_Background);--fdObjectStatus_Border_Color:var(--sapButton_Success_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical,.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical:visited{--fdObjectStatus_Text_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Critical_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Critical_Background);--fdObjectStatus_Border_Color:var(--sapButton_Critical_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical:hover{--fdObjectStatus_Text_Color:var(--sapButton_Critical_Hover_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Critical_Hover_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Critical_Hover_Background);--fdObjectStatus_Border_Color:var(--sapButton_Critical_Hover_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--critical:active{--fdObjectStatus_Text_Color:var(--sapButton_Attention_Selected_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Attention_Selected_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Critical_Active_Background);--fdObjectStatus_Border_Color:var(--sapButton_Critical_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative{--fdObjectStatus_Text_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Negative_Background);--fdObjectStatus_Border_Color:var(--sapButton_Negative_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative:visited{--fdObjectStatus_Text_Color:var(--sapButton_Negative_Background);--fdObjectStatus_Icon_Color:var(--sapButton_Negative_Background);--fdObjectStatus_Background_Color:var(--sapButton_Negative_TextColor);--fdObjectStatus_Border_Color: }.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative:hover{--fdObjectStatus_Text_Color:var(--sapButton_Negative_Hover_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Negative_Hover_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Negative_Hover_Background);--fdObjectStatus_Border_Color:var(--sapButton_Negative_Hover_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--negative:active{--fdObjectStatus_Text_Color:var(--sapButton_Reject_Selected_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Reject_Selected_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Negative_Active_Background);--fdObjectStatus_Border_Color:var(--sapButton_Negative_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative,.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative:visited{--fdObjectStatus_Text_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Information_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Information_Background);--fdObjectStatus_Border_Color:var(--sapButton_Information_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative:hover{--fdObjectStatus_Text_Color:var(--sapButton_Information_Hover_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Information_Hover_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Information_Hover_Background);--fdObjectStatus_Border_Color:var(--sapButton_Information_Hover_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--informative:active{--fdObjectStatus_Text_Color:var(--sapButton_Selected_TextColor);--fdObjectStatus_Icon_Color:var(--sapButton_Selected_TextColor);--fdObjectStatus_Background_Color:var(--sapButton_Information_Active_Background);--fdObjectStatus_Border_Color:var(--sapButton_Information_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_1);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_2);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_3);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_4);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_5);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_6);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_7);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_8);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_9);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10:hover{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Hover_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10:active{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Active_Text_Indication_Color_10);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_1b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_1b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_1_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_1b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_1b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_1b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-1b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_1_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_1_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_1_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_2b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_2b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_2_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_2b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_2b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_2b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-2b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_2_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_2_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_2_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_3b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_3b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_3_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_3b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_3b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_3b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-3b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_3_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_3_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_3_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_4b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_4b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_4_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_4b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_4b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_4b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-4b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_4_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_4_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_4_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_5b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_5b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_5_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_5b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_5b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_5b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-5b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_5_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_5_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_5_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_6b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_6b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_6_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_6b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_6b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_6b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-6b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_6_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_6_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_6_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_7b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_7b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_7_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_7b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_7b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_7b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-7b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_7_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_7_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_7_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_8b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_8b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_8_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_8b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_8b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_8b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-8b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_8_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_8_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_8_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_9b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_9b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_9_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_9b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_9b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_9b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-9b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_9_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_9_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_9_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Indication_Color_10b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_10b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b:visited{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_Active_TextColor);--fdObjectStatus_Icon_Color:var(--sapIndicationColor_10_Active_TextColor);--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_Active_BorderColor)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b.is-focus,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b:focus{border-color:var(--sapContent_FocusColor);-webkit-box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);box-shadow:var(--fdObjectStatus_Inverted_Box_Shadow);outline:var(--fdObjectStatus_Inverted_Outline_Color) .0625rem var(--sapContent_FocusStyle);outline-offset:-.125rem;z-index:5}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b.is-hover,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b:hover{--fdObjectStatus_Text_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Icon_Color:var(--fdObjectStatus_Text_Indication_Color_10b);--fdObjectStatus_Background_Color:var(--fdObjectStatus_Background_Hover_Indication_Color_10b);--fdObjectStatus_Border_Color:var(--fdObjectStatus_Border_Indication_Color_10b)}.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b.is-active,.fd-object-status--inverted.fd-object-status--link.fd-object-status--indication-10b:active{--fdObjectStatus_Text_Color:var(--sapIndicationColor_10_Active_TextColor);--fdObjectStatus_Icon_Color: ;--fdObjectStatus_Background_Color:var(--sapIndicationColor_10_Active_Background);--fdObjectStatus_Border_Color:var(--sapIndicationColor_10_Active_BorderColor)}.fd-object-status--truncate .fd-object-status__text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}\n/*! Bundled license information:\n\nfundamental-styles/dist/object-status.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { class: [{
                type: Input
            }], status: [{
                type: Input
            }], glyph: [{
                type: Input
            }], glyphFont: [{
                type: Input
            }], label: [{
                type: Input
            }], glyphAriaLabel: [{
                type: Input
            }], indicationColor: [{
                type: Input
            }], clickable: [{
                type: Input
            }], inverted: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], large: [{
                type: Input
            }], secondaryIndication: [{
                type: Input
            }], textTemplate: [{
                type: Input
            }], buildComponentCssClass: [] } });
const buildObjectStatusCssClasses = (data) => [
    'fd-object-status',
    data.inverted ? 'fd-object-status--inverted' : '',
    data.large ? 'fd-object-status--large' : '',
    data.status ? `fd-object-status--${data.status}` : '',
    data.indicationColor
        ? `fd-object-status--indication-${data.indicationColor}${data.secondaryIndication ? 'b' : ''}`
        : '',
    data.clickable ? 'fd-object-status--link' : '',
    data.iconOnly ? 'fd-object-status--icon-only' : '',
    data.class || ''
];

/**
 * @deprecated
 * Use `ObjectStatusComponent` import instead.
 */
class ObjectStatusModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ObjectStatusModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: ObjectStatusModule, imports: [ObjectStatusComponent], exports: [ObjectStatusComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ObjectStatusModule, imports: [ObjectStatusComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ObjectStatusModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [ObjectStatusComponent],
                    exports: [ObjectStatusComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { FD_OBJECT_STATUS_COMPONENT, ObjectStatusComponent, ObjectStatusModule, buildObjectStatusCssClasses };
//# sourceMappingURL=fundamental-ngx-core-object-status.mjs.map
