import { NgTemplateOutlet } from '@angular/common';
import * as i0 from '@angular/core';
import { inject, DestroyRef, Input, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { resizeObservable } from '@fundamental-ngx/cdk/utils';
import { IconComponent } from '@fundamental-ngx/core/icon';
import { PopoverComponent, PopoverControlComponent, PopoverBodyComponent } from '@fundamental-ngx/core/popover';
import { debounceTime } from 'rxjs/operators';

class ProgressIndicatorComponent {
    /** @hidden */
    constructor(_elementRef, _cdRef) {
        this._elementRef = _elementRef;
        this._cdRef = _cdRef;
        /** Custom unit if you would like to override the default percentage. */
        this.unit = '%';
        /** The minimum value possible for the progress indicator. */
        this.valueMin = 0;
        /** The maximum value possible for the progress indicator. */
        this.valueMax = 100;
        /** The current value for the progress indicator. */
        this.valueNow = 0;
        /** Whether or not to animate changes to the progress bar's valueNow. */
        this.animate = false;
        /** @hidden */
        this.hasPopover = false;
        /** @hidden */
        this._progressBarWidth = 0;
        /** @hidden An RxJS Subject that will kill the data stream upon component’s destruction (for unsubscribing)  */
        this._destroyRef = inject(DestroyRef);
    }
    /** @hidden */
    ngOnChanges(changes) {
        if (changes.valueText) {
            this._handleTruncation();
        }
        if ('valueNow' in changes || 'valueMin' in changes || 'valueMax' in changes) {
            this._progressBarWidth = this.calculateProgressBarWidth();
        }
    }
    /** @hidden */
    ngOnInit() {
        resizeObservable(this._elementRef.nativeElement)
            .pipe(debounceTime(20), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => {
            this._handleTruncation();
        });
    }
    /** @hidden */
    ngAfterViewInit() {
        this._handleTruncation();
    }
    /** @hidden */
    calculateProgressBarWidth() {
        return ((this.valueNow - this.valueMin) / (this.valueMax - this.valueMin)) * 100;
    }
    /** @hidden */
    _handleTruncation() {
        const labelSpan = this._elementRef.nativeElement.querySelector('.fd-progress-indicator__label');
        this.hasPopover = labelSpan && labelSpan.offsetWidth < labelSpan.scrollWidth;
        this._cdRef.detectChanges();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ProgressIndicatorComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.0.2", type: ProgressIndicatorComponent, isStandalone: true, selector: "fd-progress-indicator", inputs: { valueText: "valueText", unit: "unit", valueMin: "valueMin", valueMax: "valueMax", valueNow: "valueNow", state: "state", animate: "animate" }, usesOnChanges: true, ngImport: i0, template: "<div\n    class=\"fd-progress-indicator\"\n    tabindex=\"-1\"\n    role=\"progressbar\"\n    [attr.aria-valuemin]=\"valueMin\"\n    [attr.aria-valuenow]=\"valueNow\"\n    [attr.aria-valuemax]=\"valueMax\"\n    [attr.aria-valuetext]=\"valueText\"\n    [attr.aria-label]=\"valueText\"\n    [class]=\"state ? 'fd-progress-indicator--' + state : ''\"\n>\n    @if (!hasPopover) {\n        @if (_progressBarWidth >= 0) {\n            <div class=\"fd-progress-indicator__container\">\n                <ng-template [ngTemplateOutlet]=\"indicatorContainer\"></ng-template>\n            </div>\n        }\n    } @else {\n        <fd-popover\n            [style.width.%]=\"100\"\n            [noArrow]=\"false\"\n            placement=\"bottom\"\n            fillControlMode=\"equal\"\n            #popover\n            class=\"fd-progress-indicator__container\"\n        >\n            @if (_progressBarWidth >= 0) {\n                <fd-popover-control>\n                    <ng-template [ngTemplateOutlet]=\"indicatorContainer\"></ng-template>\n                </fd-popover-control>\n            }\n            <fd-popover-body>\n                <div class=\"fd-popover__wrapper\">\n                    <div class=\"fd-progress-indicator__overflow\">\n                        <span>{{ valueText }}</span>\n                        <span class=\"fd-progress-indicator__overflow-close\" (click)=\"popover.close()\">\n                            <fd-icon glyph=\"decline\"></fd-icon>\n                        </span>\n                    </div>\n                </div>\n            </fd-popover-body>\n        </fd-popover>\n    }\n</div>\n<ng-template #indicatorContainer>\n    @if (_progressBarWidth > 0) {\n        <div\n            class=\"fd-progress-indicator__progress-bar\"\n            [class.fd-progress-indicator__progress-bar--animated]=\"animate\"\n            [style.min-width.%]=\"_progressBarWidth\"\n            [style.width.%]=\"_progressBarWidth\"\n        >\n            @if (_progressBarWidth > 50) {\n                <ng-template [ngTemplateOutlet]=\"progressBarLabel\"></ng-template>\n            }\n        </div>\n    }\n    <div class=\"fd-progress-indicator__remaining\" [style.min-width]=\"0\">\n        @if (_progressBarWidth <= 50) {\n            <ng-template [ngTemplateOutlet]=\"progressBarLabel\"></ng-template>\n        }\n    </div>\n</ng-template>\n<ng-template #progressBarLabel>\n    @if (state) {\n        <span class=\"fd-progress-indicator__icon\"></span>\n    }\n    @if (!valueText) {\n        <span class=\"fd-progress-indicator__label\"> {{ valueNow }}% </span>\n    } @else {\n        <span class=\"fd-progress-indicator__label\">\n            {{ valueText }}\n        </span>\n    }\n</ng-template>\n", styles: [".fd-progress-indicator{--rootMarginBlock:.5rem;--progressBarBackground:var(--fdProgress_Indicator_Background_Color_Neutral);--progressBarBorderColor:var(--fdProgress_Indicator_Progress_Bar_Border_Color_Neutral,transparent);--progressBarBorderRightColor:var(--fdProgress_Indicator_Border_Right_Color,var(--progressBarBorderColor));--containerBackground:var(--fdProgress_Indicator_Container_Background_Neutral,var(--sapField_Background));--containerBorderColor:var(--fdProgress_Indicator_Container_Border_Neutral,var(--sapField_BorderColor));--iconDisplay:none;--iconContent:\"\";--labelMarginStart:var(--fdProgress_Indicator_Label_Margin_Start);--labelMarginEnd:var(--fdProgress_Indicator_Label_Margin_End);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdProgress_Indicator_Height);line-height:normal;margin-block:0;margin-block:var(--rootMarginBlock);margin-inline:0;padding-block:0;padding-block:var(--fdProgress_Indicator_Container_Margin_Block);padding-inline:0;padding-inline:var(--fdProgress_Indicator_Container_Margin_Inline);width:100%}.fd-progress-indicator:after,.fd-progress-indicator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator.fd-popover{cursor:pointer;margin-block:var(--rootMarginBlock);margin-inline:0}.fd-progress-indicator--mobile{--rootMarginBlock:.875rem}.fd-progress-indicator--display{--rootMarginBlock:0}.fd-progress-indicator--display.fd-popover{margin-block:0;margin-inline:0}.fd-progress-indicator--informative{--progressBarBackground:var(--fdProgress_Indicator_Background_Color_Informative);--progressBarBorderColor:var(--fdProgress_Indicator_Progress_Bar_Border_Color_Informative,transparent);--containerBackground:var(--fdProgress_Indicator_Container_Background_Informative,var(--sapField_Background));--containerBorderColor:var(--fdProgress_Indicator_Container_Border_Informative,var(--sapField_BorderColor));--iconContent:var(--fdProgress_Icon_Informative);--iconDisplay:inline;--iconColor:var(--fdProgress_Icon_Color_Informative,var(--fdProgress_Indicator_Label_Color));--labelMarginStart:0}.fd-progress-indicator--positive{--progressBarBackground:var(--fdProgress_Indicator_Background_Color_Positive);--progressBarBorderColor:var(--fdProgress_Indicator_Progress_Bar_Border_Color_Positive,transparent);--containerBackground:var(--fdProgress_Indicator_Container_Background_Positive,var(--sapField_Background));--containerBorderColor:var(--fdProgress_Indicator_Container_Border_Positive,var(--sapField_BorderColor));--iconContent:var(--fdProgress_Icon_Positive);--iconDisplay:inline;--iconColor:var(--fdProgress_Icon_Color_Positive,var(--fdProgress_Indicator_Label_Color));--labelMarginStart:0}.fd-progress-indicator--negative{--progressBarBackground:var(--fdProgress_Indicator_Background_Color_Negative);--progressBarBorderColor:var(--fdProgress_Indicator_Progress_Bar_Border_Color_Negative,transparent);--containerBackground:var(--fdProgress_Indicator_Container_Background_Negative,var(--sapField_Background));--containerBorderColor:var(--fdProgress_Indicator_Container_Border_Negative,var(--sapField_BorderColor));--iconContent:var(--fdProgress_Icon_Negative);--iconDisplay:inline;--iconColor:var(--fdProgress_Icon_Color_Negative,var(--fdProgress_Indicator_Label_Color));--labelMarginStart:0}.fd-progress-indicator--critical{--progressBarBackground:var(--fdProgress_Indicator_Background_Color_Critical);--progressBarBorderColor:var(--fdProgress_Indicator_Progress_Bar_Border_Color_Critical,transparent);--containerBackground:var(--fdProgress_Indicator_Container_Background_Critical,var(--sapField_Background));--containerBorderColor:var(--fdProgress_Indicator_Container_Border_Critical,var(--sapField_BorderColor));--iconContent:var(--fdProgress_Icon_Critical);--iconDisplay:inline;--iconColor:var(--fdProgress_Icon_Color_Critical,var(--fdProgress_Indicator_Label_Color));--labelMarginStart:0}.fd-progress-indicator .fd-progress-indicator__container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;background:var(--containerBackground);border:.0625rem solid var(--containerBorderColor);border-radius:.5rem;-ms-flex-direction:row;flex-direction:row;height:var(--fdProgress_Indicator_Container_Height);min-height:var(--fdProgress_Indicator_Container_Height);min-width:4rem;overflow:var(--fdProgress_Indicator_Container_Overflow);position:var(--fdProgress_Indicator_Container_Position,static);width:var(--fdProgress_Indicator_Container_Width)}.fd-progress-indicator .fd-progress-indicator__container:after,.fd-progress-indicator .fd-progress-indicator__container:before{background-color:var(--progressBarBackground);border-radius:50%;-webkit-box-sizing:inherit;box-sizing:inherit;content:\"\";display:var(--fdProgress_Indicator_Progress_Bar_Boundary_Display,none);font-size:inherit;height:.25rem;position:absolute;top:0;width:.25rem}.fd-progress-indicator .fd-progress-indicator__container:before{left:0}.fd-progress-indicator .fd-progress-indicator__container:after{right:0}.fd-progress-indicator[aria-valuenow=\"0\"] .fd-progress-indicator__progress-bar{border:none}.fd-progress-indicator[aria-valuenow=\"100\"] .fd-progress-indicator__progress-bar{right:var(--fdProgress_Indicator_Progress_Bar_Position_Left);width:auto!important}.fd-progress-indicator[aria-valuenow=\"100\"] .fd-progress-indicator__progress-bar[dir=rtl],.fd-progress-indicator__progress-bar,[dir=rtl] .fd-progress-indicator[aria-valuenow=\"100\"] .fd-progress-indicator__progress-bar{left:var(--fdProgress_Indicator_Progress_Bar_Position_Left)}.fd-progress-indicator__progress-bar{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:end;-ms-flex-pack:end;background:var(--progressBarBackground);border:var(--fdProgress_Indicator_Progress_Bar_Border) var(--progressBarBorderColor);border-radius:var(--fdProgress_Indicator_Progress_Bar_Border_Radius);border-right:var(--fdProgress_Indicator_Border_Right) var(--progressBarBorderRightColor);bottom:var(--fdProgress_Indicator_Progress_Bar_Position_Bottom);height:var(--fdProgress_Indicator_Progress_Bar_Height);justify-content:flex-end;margin-block:var(--fdProgress_Indicator_Progress_Bar_Margin_Block);margin-inline:0}.fd-progress-indicator__progress-bar:after,.fd-progress-indicator__progress-bar:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator__progress-bar .fd-progress-indicator__label{color:var(--fdProgress_Indicator_Label_Color_Contrast)}.fd-progress-indicator__progress-bar[dir=rtl],[dir=rtl] .fd-progress-indicator__progress-bar{border-right:none;border:var(--fdProgress_Indicator_Progress_Bar_Border) var(--progressBarBorderColor);border-left:var(--fdProgress_Indicator_Border_Right) var(--progressBarBorderRightColor);left:auto;right:var(--fdProgress_Indicator_Progress_Bar_Position_Left)}.fd-progress-indicator .fd-progress-indicator__remaining{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center;position:static}.fd-progress-indicator .fd-progress-indicator__remaining:after,.fd-progress-indicator .fd-progress-indicator__remaining:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator .fd-progress-indicator__remaining.fd-popover__control{-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;min-width:0}.fd-progress-indicator__icon{bottom:-.625rem;display:var(--iconDisplay);margin-inline:var(--fdProgress_Indicator_Label_Margin_Start) var(--fdProgress_Icon_Space_Before_Label);position:var(--fdProgress_Indicator_Icon_Position,static);right:-1.25rem}.fd-progress-indicator__icon[dir=rtl],[dir=rtl] .fd-progress-indicator__icon{left:-1.25rem;right:auto}.fd-progress-indicator__icon:before{color:var(--iconColor);content:var(--iconContent);font-family:SAP-icons;font-size:var(--fdProgress_Indicator_Icon_Font_Size);vertical-align:middle}.fd-progress-indicator__icon+.fd-progress-indicator__label{-webkit-margin-start:0;margin-inline-start:0}.fd-progress-indicator__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdProgress_Indicator_Label_Color);display:inline-block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdProgress_Indicator_Label_Font_Size);font-weight:400;forced-color-adjust:none;left:0;line-height:normal;margin-block:0;margin-inline:0;margin-inline:var(--labelMarginStart) var(--labelMarginEnd);max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;position:var(--fdProgress_Indicator_Label_Position,static);text-overflow:ellipsis;top:-1.25rem;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;white-space:nowrap}.fd-progress-indicator__label:after,.fd-progress-indicator__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator__label[dir=rtl],[dir=rtl] .fd-progress-indicator__label{left:auto;right:0}.fd-progress-indicator__overflow{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:.25rem;padding-inline:0;padding-inline:.5rem 0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.5rem;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;max-width:95vw;overflow:hidden;white-space:normal}.fd-progress-indicator__overflow:after,.fd-progress-indicator__overflow:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator__overflow-close{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:transparent;cursor:pointer;height:1.375rem;max-height:1.375rem;max-width:1.4375rem;min-height:1.375rem;min-width:1.4375rem;text-align:center;width:1.4375rem}.fd-progress-indicator__overflow-close:after,.fd-progress-indicator__overflow-close:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator__overflow-close.is-focus,.fd-progress-indicator__overflow-close:focus{outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);z-index:5}.fd-progress-indicator__overflow-close [class*=sap-icon]{color:var(--sapContent_IconColor);font-size:var(--sapFontSmallSize)}.fd-progress-indicator__progress-bar--animated{-webkit-transition:min-width .5s ease-in-out,width .5s ease-in-out;-moz-transition:min-width .5s ease-in-out,width .5s ease-in-out;-o-transition:min-width .5s ease-in-out,width .5s ease-in-out;transition:min-width .5s ease-in-out,width .5s ease-in-out}.fd-progress-indicator__container .fd-popover__control{width:100%}\n/*! Bundled license information:\n\nfundamental-styles/dist/progress-indicator.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: PopoverComponent, selector: "fd-popover", inputs: ["title", "trigger", "fixedPosition", "id", "mobile", "mobileConfig", "preventSpaceKeyScroll"] }, { kind: "component", type: PopoverControlComponent, selector: "fd-popover-control, [fdPopoverControl]" }, { kind: "component", type: PopoverBodyComponent, selector: "fd-popover-body", inputs: ["minWidth", "maxWidth", "minHeight", "maxHeight"] }, { kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ProgressIndicatorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-progress-indicator', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, imports: [NgTemplateOutlet, PopoverComponent, PopoverControlComponent, PopoverBodyComponent, IconComponent], template: "<div\n    class=\"fd-progress-indicator\"\n    tabindex=\"-1\"\n    role=\"progressbar\"\n    [attr.aria-valuemin]=\"valueMin\"\n    [attr.aria-valuenow]=\"valueNow\"\n    [attr.aria-valuemax]=\"valueMax\"\n    [attr.aria-valuetext]=\"valueText\"\n    [attr.aria-label]=\"valueText\"\n    [class]=\"state ? 'fd-progress-indicator--' + state : ''\"\n>\n    @if (!hasPopover) {\n        @if (_progressBarWidth >= 0) {\n            <div class=\"fd-progress-indicator__container\">\n                <ng-template [ngTemplateOutlet]=\"indicatorContainer\"></ng-template>\n            </div>\n        }\n    } @else {\n        <fd-popover\n            [style.width.%]=\"100\"\n            [noArrow]=\"false\"\n            placement=\"bottom\"\n            fillControlMode=\"equal\"\n            #popover\n            class=\"fd-progress-indicator__container\"\n        >\n            @if (_progressBarWidth >= 0) {\n                <fd-popover-control>\n                    <ng-template [ngTemplateOutlet]=\"indicatorContainer\"></ng-template>\n                </fd-popover-control>\n            }\n            <fd-popover-body>\n                <div class=\"fd-popover__wrapper\">\n                    <div class=\"fd-progress-indicator__overflow\">\n                        <span>{{ valueText }}</span>\n                        <span class=\"fd-progress-indicator__overflow-close\" (click)=\"popover.close()\">\n                            <fd-icon glyph=\"decline\"></fd-icon>\n                        </span>\n                    </div>\n                </div>\n            </fd-popover-body>\n        </fd-popover>\n    }\n</div>\n<ng-template #indicatorContainer>\n    @if (_progressBarWidth > 0) {\n        <div\n            class=\"fd-progress-indicator__progress-bar\"\n            [class.fd-progress-indicator__progress-bar--animated]=\"animate\"\n            [style.min-width.%]=\"_progressBarWidth\"\n            [style.width.%]=\"_progressBarWidth\"\n        >\n            @if (_progressBarWidth > 50) {\n                <ng-template [ngTemplateOutlet]=\"progressBarLabel\"></ng-template>\n            }\n        </div>\n    }\n    <div class=\"fd-progress-indicator__remaining\" [style.min-width]=\"0\">\n        @if (_progressBarWidth <= 50) {\n            <ng-template [ngTemplateOutlet]=\"progressBarLabel\"></ng-template>\n        }\n    </div>\n</ng-template>\n<ng-template #progressBarLabel>\n    @if (state) {\n        <span class=\"fd-progress-indicator__icon\"></span>\n    }\n    @if (!valueText) {\n        <span class=\"fd-progress-indicator__label\"> {{ valueNow }}% </span>\n    } @else {\n        <span class=\"fd-progress-indicator__label\">\n            {{ valueText }}\n        </span>\n    }\n</ng-template>\n", styles: [".fd-progress-indicator{--rootMarginBlock:.5rem;--progressBarBackground:var(--fdProgress_Indicator_Background_Color_Neutral);--progressBarBorderColor:var(--fdProgress_Indicator_Progress_Bar_Border_Color_Neutral,transparent);--progressBarBorderRightColor:var(--fdProgress_Indicator_Border_Right_Color,var(--progressBarBorderColor));--containerBackground:var(--fdProgress_Indicator_Container_Background_Neutral,var(--sapField_Background));--containerBorderColor:var(--fdProgress_Indicator_Container_Border_Neutral,var(--sapField_BorderColor));--iconDisplay:none;--iconContent:\"\";--labelMarginStart:var(--fdProgress_Indicator_Label_Margin_Start);--labelMarginEnd:var(--fdProgress_Indicator_Label_Margin_End);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:var(--fdProgress_Indicator_Height);line-height:normal;margin-block:0;margin-block:var(--rootMarginBlock);margin-inline:0;padding-block:0;padding-block:var(--fdProgress_Indicator_Container_Margin_Block);padding-inline:0;padding-inline:var(--fdProgress_Indicator_Container_Margin_Inline);width:100%}.fd-progress-indicator:after,.fd-progress-indicator:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator.fd-popover{cursor:pointer;margin-block:var(--rootMarginBlock);margin-inline:0}.fd-progress-indicator--mobile{--rootMarginBlock:.875rem}.fd-progress-indicator--display{--rootMarginBlock:0}.fd-progress-indicator--display.fd-popover{margin-block:0;margin-inline:0}.fd-progress-indicator--informative{--progressBarBackground:var(--fdProgress_Indicator_Background_Color_Informative);--progressBarBorderColor:var(--fdProgress_Indicator_Progress_Bar_Border_Color_Informative,transparent);--containerBackground:var(--fdProgress_Indicator_Container_Background_Informative,var(--sapField_Background));--containerBorderColor:var(--fdProgress_Indicator_Container_Border_Informative,var(--sapField_BorderColor));--iconContent:var(--fdProgress_Icon_Informative);--iconDisplay:inline;--iconColor:var(--fdProgress_Icon_Color_Informative,var(--fdProgress_Indicator_Label_Color));--labelMarginStart:0}.fd-progress-indicator--positive{--progressBarBackground:var(--fdProgress_Indicator_Background_Color_Positive);--progressBarBorderColor:var(--fdProgress_Indicator_Progress_Bar_Border_Color_Positive,transparent);--containerBackground:var(--fdProgress_Indicator_Container_Background_Positive,var(--sapField_Background));--containerBorderColor:var(--fdProgress_Indicator_Container_Border_Positive,var(--sapField_BorderColor));--iconContent:var(--fdProgress_Icon_Positive);--iconDisplay:inline;--iconColor:var(--fdProgress_Icon_Color_Positive,var(--fdProgress_Indicator_Label_Color));--labelMarginStart:0}.fd-progress-indicator--negative{--progressBarBackground:var(--fdProgress_Indicator_Background_Color_Negative);--progressBarBorderColor:var(--fdProgress_Indicator_Progress_Bar_Border_Color_Negative,transparent);--containerBackground:var(--fdProgress_Indicator_Container_Background_Negative,var(--sapField_Background));--containerBorderColor:var(--fdProgress_Indicator_Container_Border_Negative,var(--sapField_BorderColor));--iconContent:var(--fdProgress_Icon_Negative);--iconDisplay:inline;--iconColor:var(--fdProgress_Icon_Color_Negative,var(--fdProgress_Indicator_Label_Color));--labelMarginStart:0}.fd-progress-indicator--critical{--progressBarBackground:var(--fdProgress_Indicator_Background_Color_Critical);--progressBarBorderColor:var(--fdProgress_Indicator_Progress_Bar_Border_Color_Critical,transparent);--containerBackground:var(--fdProgress_Indicator_Container_Background_Critical,var(--sapField_Background));--containerBorderColor:var(--fdProgress_Indicator_Container_Border_Critical,var(--sapField_BorderColor));--iconContent:var(--fdProgress_Icon_Critical);--iconDisplay:inline;--iconColor:var(--fdProgress_Icon_Color_Critical,var(--fdProgress_Indicator_Label_Color));--labelMarginStart:0}.fd-progress-indicator .fd-progress-indicator__container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;background:var(--containerBackground);border:.0625rem solid var(--containerBorderColor);border-radius:.5rem;-ms-flex-direction:row;flex-direction:row;height:var(--fdProgress_Indicator_Container_Height);min-height:var(--fdProgress_Indicator_Container_Height);min-width:4rem;overflow:var(--fdProgress_Indicator_Container_Overflow);position:var(--fdProgress_Indicator_Container_Position,static);width:var(--fdProgress_Indicator_Container_Width)}.fd-progress-indicator .fd-progress-indicator__container:after,.fd-progress-indicator .fd-progress-indicator__container:before{background-color:var(--progressBarBackground);border-radius:50%;-webkit-box-sizing:inherit;box-sizing:inherit;content:\"\";display:var(--fdProgress_Indicator_Progress_Bar_Boundary_Display,none);font-size:inherit;height:.25rem;position:absolute;top:0;width:.25rem}.fd-progress-indicator .fd-progress-indicator__container:before{left:0}.fd-progress-indicator .fd-progress-indicator__container:after{right:0}.fd-progress-indicator[aria-valuenow=\"0\"] .fd-progress-indicator__progress-bar{border:none}.fd-progress-indicator[aria-valuenow=\"100\"] .fd-progress-indicator__progress-bar{right:var(--fdProgress_Indicator_Progress_Bar_Position_Left);width:auto!important}.fd-progress-indicator[aria-valuenow=\"100\"] .fd-progress-indicator__progress-bar[dir=rtl],.fd-progress-indicator__progress-bar,[dir=rtl] .fd-progress-indicator[aria-valuenow=\"100\"] .fd-progress-indicator__progress-bar{left:var(--fdProgress_Indicator_Progress_Bar_Position_Left)}.fd-progress-indicator__progress-bar{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:end;-ms-flex-pack:end;background:var(--progressBarBackground);border:var(--fdProgress_Indicator_Progress_Bar_Border) var(--progressBarBorderColor);border-radius:var(--fdProgress_Indicator_Progress_Bar_Border_Radius);border-right:var(--fdProgress_Indicator_Border_Right) var(--progressBarBorderRightColor);bottom:var(--fdProgress_Indicator_Progress_Bar_Position_Bottom);height:var(--fdProgress_Indicator_Progress_Bar_Height);justify-content:flex-end;margin-block:var(--fdProgress_Indicator_Progress_Bar_Margin_Block);margin-inline:0}.fd-progress-indicator__progress-bar:after,.fd-progress-indicator__progress-bar:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator__progress-bar .fd-progress-indicator__label{color:var(--fdProgress_Indicator_Label_Color_Contrast)}.fd-progress-indicator__progress-bar[dir=rtl],[dir=rtl] .fd-progress-indicator__progress-bar{border-right:none;border:var(--fdProgress_Indicator_Progress_Bar_Border) var(--progressBarBorderColor);border-left:var(--fdProgress_Indicator_Border_Right) var(--progressBarBorderRightColor);left:auto;right:var(--fdProgress_Indicator_Progress_Bar_Position_Left)}.fd-progress-indicator .fd-progress-indicator__remaining{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center;position:static}.fd-progress-indicator .fd-progress-indicator__remaining:after,.fd-progress-indicator .fd-progress-indicator__remaining:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator .fd-progress-indicator__remaining.fd-popover__control{-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;min-width:0}.fd-progress-indicator__icon{bottom:-.625rem;display:var(--iconDisplay);margin-inline:var(--fdProgress_Indicator_Label_Margin_Start) var(--fdProgress_Icon_Space_Before_Label);position:var(--fdProgress_Indicator_Icon_Position,static);right:-1.25rem}.fd-progress-indicator__icon[dir=rtl],[dir=rtl] .fd-progress-indicator__icon{left:-1.25rem;right:auto}.fd-progress-indicator__icon:before{color:var(--iconColor);content:var(--iconContent);font-family:SAP-icons;font-size:var(--fdProgress_Indicator_Icon_Font_Size);vertical-align:middle}.fd-progress-indicator__icon+.fd-progress-indicator__label{-webkit-margin-start:0;margin-inline-start:0}.fd-progress-indicator__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdProgress_Indicator_Label_Color);display:inline-block;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--fdProgress_Indicator_Label_Font_Size);font-weight:400;forced-color-adjust:none;left:0;line-height:normal;margin-block:0;margin-inline:0;margin-inline:var(--labelMarginStart) var(--labelMarginEnd);max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;position:var(--fdProgress_Indicator_Label_Position,static);text-overflow:ellipsis;top:-1.25rem;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;white-space:nowrap}.fd-progress-indicator__label:after,.fd-progress-indicator__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator__label[dir=rtl],[dir=rtl] .fd-progress-indicator__label{left:auto;right:0}.fd-progress-indicator__overflow{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:.25rem;padding-inline:0;padding-inline:.5rem 0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.5rem;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;max-width:95vw;overflow:hidden;white-space:normal}.fd-progress-indicator__overflow:after,.fd-progress-indicator__overflow:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator__overflow-close{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:transparent;cursor:pointer;height:1.375rem;max-height:1.375rem;max-width:1.4375rem;min-height:1.375rem;min-width:1.4375rem;text-align:center;width:1.4375rem}.fd-progress-indicator__overflow-close:after,.fd-progress-indicator__overflow-close:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-progress-indicator__overflow-close.is-focus,.fd-progress-indicator__overflow-close:focus{outline:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);z-index:5}.fd-progress-indicator__overflow-close [class*=sap-icon]{color:var(--sapContent_IconColor);font-size:var(--sapFontSmallSize)}.fd-progress-indicator__progress-bar--animated{-webkit-transition:min-width .5s ease-in-out,width .5s ease-in-out;-moz-transition:min-width .5s ease-in-out,width .5s ease-in-out;-o-transition:min-width .5s ease-in-out,width .5s ease-in-out;transition:min-width .5s ease-in-out,width .5s ease-in-out}.fd-progress-indicator__container .fd-popover__control{width:100%}\n/*! Bundled license information:\n\nfundamental-styles/dist/progress-indicator.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }], propDecorators: { valueText: [{
                type: Input
            }], unit: [{
                type: Input
            }], valueMin: [{
                type: Input
            }], valueMax: [{
                type: Input
            }], valueNow: [{
                type: Input
            }], state: [{
                type: Input
            }], animate: [{
                type: Input
            }] } });

/**
 * @deprecated
 * Use `ProgressIndicatorComponent` import instead.
 */
class ProgressIndicatorModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ProgressIndicatorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: ProgressIndicatorModule, imports: [ProgressIndicatorComponent], exports: [ProgressIndicatorComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ProgressIndicatorModule, imports: [ProgressIndicatorComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: ProgressIndicatorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [ProgressIndicatorComponent],
                    exports: [ProgressIndicatorComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ProgressIndicatorComponent, ProgressIndicatorModule };
//# sourceMappingURL=fundamental-ngx-core-progress-indicator.mjs.map
