import * as i0 from '@angular/core';
import { HostBinding, Input, Directive, booleanAttribute, HostListener, ContentChildren, inject, Renderer2, ElementRef, ContentChild, signal, ChangeDetectorRef, effect, ChangeDetectionStrategy, ViewEncapsulation, Component, NgModule } from '@angular/core';
import * as i3 from '@fundamental-ngx/cdk/utils';
import { FocusableItemDirective, FDK_FOCUSABLE_ITEM_DIRECTIVE, ResizeObserverService, applyCssClass, FocusableListDirective, FDK_FOCUSABLE_LIST_DIRECTIVE, FocusableGridDirective } from '@fundamental-ngx/cdk/utils';
import { FD_CHECKBOX_COMPONENT } from '@fundamental-ngx/core/checkbox';
import { FD_TOOLBAR } from '@fundamental-ngx/core/toolbar';
import { Subscription, startWith as startWith$1, first } from 'rxjs';
import { __decorate, __metadata } from 'tslib';
import { FD_DEFAULT_ICON_FONT_FAMILY, fdBuildIconClass } from '@fundamental-ngx/core/icon';
import { startWith } from 'rxjs/operators';
import * as i1 from '@fundamental-ngx/core/content-density';
import { contentDensityObserverProviders, ContentDensityMode } from '@fundamental-ngx/core/content-density';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';

class TableBodyDirective {
    constructor() {
        /** @hidden */
        this.fdTableBodyClass = true;
        /**  Whether to show the table body's horizontal borders */
        this.noBorderX = false;
        /**  Whether to show the table body's vertical borders */
        this.noBorderY = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableBodyDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TableBodyDirective, isStandalone: true, selector: "[fdTableBody], [fd-table-body]", inputs: { noBorderX: "noBorderX", noBorderY: "noBorderY" }, host: { properties: { "class.fd-table__body": "this.fdTableBodyClass", "class.fd-table__body--no-horizontal-borders": "this.noBorderX", "class.fd-table__body--no-vertical-borders": "this.noBorderY" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableBodyDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableBody], [fd-table-body]',
                    standalone: true
                }]
        }], propDecorators: { fdTableBodyClass: [{
                type: HostBinding,
                args: ['class.fd-table__body']
            }], noBorderX: [{
                type: HostBinding,
                args: ['class.fd-table__body--no-horizontal-borders']
            }, {
                type: Input
            }], noBorderY: [{
                type: HostBinding,
                args: ['class.fd-table__body--no-vertical-borders']
            }, {
                type: Input
            }] } });

class TableCellDirective extends FocusableItemDirective {
    /** @hidden */
    set focusable(value) {
        this.fdkFocusableItem = value;
    }
    get focusable() {
        return this.fdkFocusableItem;
    }
    /** @hidden */
    constructor() {
        super();
        /** Whether to show the table cell's horizontal borders */
        this.noBorderX = false;
        /** Whether to show the table cell's vertical borders */
        this.noBorderY = false;
        /** Whether the table cell is activable */
        this.activable = false;
        /** Whether the table cell is hoverable */
        this.hoverable = false;
        /** Whether the table cell's width should fit to content  */
        this.fitContent = false;
        /** Whether the table cell shouldn't have padding on sides */
        this.noPadding = false;
        /** Whether the table cell indicates that there is no data */
        this.noData = false;
        /** Whether the table cell inside table header should be non-interactive */
        this.nonInteractive = false;
        /** @hidden */
        this._fdTableCellClass = true;
        this.fdkFocusableItem = false;
    }
    /** @hidden */
    _focusIn() {
        const parentEl = this.elementRef.nativeElement.parentElement;
        this._parentPreviousTabIndex = parentEl?.tabIndex;
        parentEl?.removeAttribute('tabindex');
    }
    /** @hidden */
    _focusOut() {
        const parentEl = this.elementRef.nativeElement.parentElement;
        if (this._parentPreviousTabIndex) {
            parentEl?.setAttribute('tabindex', this._parentPreviousTabIndex.toString());
        }
    }
    /** @hidden */
    ngAfterContentInit() {
        const cell = this.elementRef.nativeElement;
        if (this._checkboxes && this._checkboxes.length) {
            cell.classList.add('fd-table__cell--checkbox');
        }
        if (this.noData) {
            cell.setAttribute('colspan', '100%');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableCellDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "20.0.2", type: TableCellDirective, isStandalone: true, selector: "[fdTableCell], [fd-table-cell]", inputs: { noBorderX: "noBorderX", noBorderY: "noBorderY", activable: "activable", focusable: ["focusable", "focusable", booleanAttribute], hoverable: "hoverable", fitContent: "fitContent", noPadding: "noPadding", noData: "noData", nonInteractive: "nonInteractive", key: "key" }, host: { listeners: { "focusin": "_focusIn()", "focusout": "_focusOut()" }, properties: { "class.fd-table__cell--no-horizontal-border": "this.noBorderX", "class.fd-table__cell--no-vertical-border": "this.noBorderY", "class.fd-table__cell--activable": "this.activable", "class.fd-table__cell--focusable": "this.focusable", "class.fd-table__cell--hoverable": "this.hoverable", "class.fd-table__cell--fit-content": "this.fitContent", "class.fd-table__cell--no-padding": "this.noPadding", "class.fd-table__cell--no-data": "this.noData", "class.fd-table__cell--non-interactive": "this.nonInteractive", "class.fd-table__cell": "this._fdTableCellClass" } }, providers: [
            {
                provide: FDK_FOCUSABLE_ITEM_DIRECTIVE,
                useExisting: TableCellDirective
            }
        ], queries: [{ propertyName: "_checkboxes", predicate: FD_CHECKBOX_COMPONENT }], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableCellDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableCell], [fd-table-cell]',
                    providers: [
                        {
                            provide: FDK_FOCUSABLE_ITEM_DIRECTIVE,
                            useExisting: TableCellDirective
                        }
                    ],
                    standalone: true
                }]
        }], ctorParameters: () => [], propDecorators: { noBorderX: [{
                type: HostBinding,
                args: ['class.fd-table__cell--no-horizontal-border']
            }, {
                type: Input
            }], noBorderY: [{
                type: HostBinding,
                args: ['class.fd-table__cell--no-vertical-border']
            }, {
                type: Input
            }], activable: [{
                type: HostBinding,
                args: ['class.fd-table__cell--activable']
            }, {
                type: Input
            }], focusable: [{
                type: HostBinding,
                args: ['class.fd-table__cell--focusable']
            }, {
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hoverable: [{
                type: HostBinding,
                args: ['class.fd-table__cell--hoverable']
            }, {
                type: Input
            }], fitContent: [{
                type: HostBinding,
                args: ['class.fd-table__cell--fit-content']
            }, {
                type: Input
            }], noPadding: [{
                type: HostBinding,
                args: ['class.fd-table__cell--no-padding']
            }, {
                type: Input
            }], noData: [{
                type: HostBinding,
                args: ['class.fd-table__cell--no-data']
            }, {
                type: Input
            }], nonInteractive: [{
                type: HostBinding,
                args: ['class.fd-table__cell--non-interactive']
            }, {
                type: Input
            }], key: [{
                type: Input
            }], _checkboxes: [{
                type: ContentChildren,
                args: [FD_CHECKBOX_COMPONENT]
            }], _fdTableCellClass: [{
                type: HostBinding,
                args: ['class.fd-table__cell']
            }], _focusIn: [{
                type: HostListener,
                args: ['focusin']
            }], _focusOut: [{
                type: HostListener,
                args: ['focusout']
            }] } });

class TableHeaderDirective {
    constructor() {
        /** @hidden */
        this.fdTableHeaderClass = true;
        /** Whether or not to show the table header's horizontal borders */
        this.noBorderX = false;
        /** Whether or not to show the table header's vertical borders */
        this.noBorderY = false;
        /**
         * Whether or not the header cells should be interactive
         * (have hover and active states)
         * default: false
         */
        this.nonInteractive = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableHeaderDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TableHeaderDirective, isStandalone: true, selector: "[fdTableHeader], [fd-table-header]", inputs: { noBorderX: "noBorderX", noBorderY: "noBorderY", nonInteractive: "nonInteractive" }, host: { properties: { "class.fd-table__header": "this.fdTableHeaderClass", "class.fd-table__header--no-horizontal-borders": "this.noBorderX", "class.fd-table__header--no-vertical-borders": "this.noBorderY", "class.fd-table__header--non-interactive": "this.nonInteractive" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableHeaderDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableHeader], [fd-table-header]',
                    standalone: true
                }]
        }], propDecorators: { fdTableHeaderClass: [{
                type: HostBinding,
                args: ['class.fd-table__header']
            }], noBorderX: [{
                type: HostBinding,
                args: ['class.fd-table__header--no-horizontal-borders']
            }, {
                type: Input
            }], noBorderY: [{
                type: HostBinding,
                args: ['class.fd-table__header--no-vertical-borders']
            }, {
                type: Input
            }], nonInteractive: [{
                type: HostBinding,
                args: ['class.fd-table__header--non-interactive']
            }, {
                type: Input
            }] } });

class TableContainerDirective {
    constructor() {
        /** Whether the scroll is applied on the page and not on the table */
        this.outerScroll = false;
        /** @hidden */
        this.resizeObserverService = inject(ResizeObserverService);
        /** @hidden */
        this._renderer = inject(Renderer2);
        /** @hidden */
        this._resizeSubscription = new Subscription();
    }
    /** @hidden */
    set toolbar(toolbarElRef) {
        if (this.outerScroll && toolbarElRef) {
            const toolbarEl = toolbarElRef.nativeElement;
            if (this._resizeSubscription) {
                this._resizeSubscription.unsubscribe();
            }
            this._resizeSubscription = this.resizeObserverService.observe(toolbarEl).subscribe(() => {
                this._renderer.setStyle(toolbarEl, 'position', 'sticky');
                this._renderer.setStyle(toolbarEl, 'top', '0');
                this._renderer.setStyle(this._tableHeaderEl, 'position', 'sticky');
                this._renderer.setStyle(this._tableHeaderEl, 'top', `${toolbarEl.offsetHeight}px`);
            });
        }
    }
    /** @hidden */
    set tableHeader(tableHeaderEl) {
        if (this.outerScroll) {
            this._tableHeaderEl = tableHeaderEl.nativeElement;
            this._renderer.setStyle(this._tableHeaderEl, 'position', 'sticky');
            this._renderer.setStyle(this._tableHeaderEl, 'top', '0');
        }
    }
    /** @hidden */
    ngOnDestroy() {
        if (this._resizeSubscription) {
            this._resizeSubscription.unsubscribe();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableContainerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "20.0.2", type: TableContainerDirective, isStandalone: true, selector: "[fdTableContainer], [fd-table-container]", inputs: { outerScroll: ["outerScroll", "outerScroll", booleanAttribute] }, queries: [{ propertyName: "toolbar", first: true, predicate: FD_TOOLBAR, descendants: true, read: ElementRef }, { propertyName: "tableHeader", first: true, predicate: TableHeaderDirective, descendants: true, read: ElementRef }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableContainerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableContainer], [fd-table-container]',
                    standalone: true
                }]
        }], propDecorators: { outerScroll: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], toolbar: [{
                type: ContentChild,
                args: [FD_TOOLBAR, { read: ElementRef }]
            }], tableHeader: [{
                type: ContentChild,
                args: [TableHeaderDirective, { read: ElementRef }]
            }] } });

class TableFixedDirective {
    constructor() {
        /** @hidden */
        this.fdTableFixedClass = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableFixedDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TableFixedDirective, isStandalone: true, selector: "[fdTableFixed], [fd-table-fixed]", host: { properties: { "class.fd-table--fixed": "this.fdTableFixedClass" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableFixedDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableFixed], [fd-table-fixed]',
                    standalone: true
                }]
        }], propDecorators: { fdTableFixedClass: [{
                type: HostBinding,
                args: ['class.fd-table--fixed']
            }] } });

class TableFooterDirective {
    constructor() {
        /** @hidden */
        this.fdTableFooterClass = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableFooterDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TableFooterDirective, isStandalone: true, selector: "[fdTableFooter], [fd-table-footer]", host: { properties: { "class.fd-table__footer": "this.fdTableFooterClass" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableFooterDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableFooter], [fd-table-footer]',
                    standalone: true
                }]
        }], propDecorators: { fdTableFooterClass: [{
                type: HostBinding,
                args: ['class.fd-table__footer']
            }] } });

class TableIconDirective {
    constructor() {
        /** @hidden */
        this.fdTableIconClass = true;
        /** The property allows user to pass additional css classes
         */
        this.class = '';
        /** The icon to include in the button. See the icon page for the list of icons.
         * Setter is used to control when css class have to be rebuilded.
         * Default value is set to ''.
         */
        this.glyph = '';
        /** Glyph font family */
        this.glyphFont = FD_DEFAULT_ICON_FONT_FAMILY;
        /** Whether or no icon is used as navigation  */
        this.navigation = false;
        /** @hidden */
        this.elementRef = inject(ElementRef);
    }
    /**
     * @hidden
     * CssClassBuilder interface implementation
     * function must return single string
     * function is responsible for order which css classes are applied
     */
    buildComponentCssClass() {
        return [
            'fd-table__icon',
            this.glyph ? fdBuildIconClass(this.glyphFont, this.glyph) : '',
            this.navigation ? 'fd-table__icon--navigation' : '',
            this.class
        ];
    }
    /** Function runs when component is initialized
     * function should build component css class
     * function should build css style
     */
    ngOnChanges() {
        this.buildComponentCssClass();
    }
    /** @hidden */
    ngOnInit() {
        this.buildComponentCssClass();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableIconDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TableIconDirective, isStandalone: true, selector: "[fdTableIcon], [fd-table-icon]", inputs: { class: "class", glyph: "glyph", glyphFont: "glyphFont", navigation: "navigation" }, host: { properties: { "class.fd-table__icon": "this.fdTableIconClass" } }, usesOnChanges: true, ngImport: i0 }); }
}
__decorate([
    applyCssClass,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], TableIconDirective.prototype, "buildComponentCssClass", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableIconDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableIcon], [fd-table-icon]',
                    standalone: true
                }]
        }], propDecorators: { fdTableIconClass: [{
                type: HostBinding,
                args: ['class.fd-table__icon']
            }], class: [{
                type: Input
            }], glyph: [{
                type: Input
            }], glyphFont: [{
                type: Input
            }], navigation: [{
                type: Input
            }], buildComponentCssClass: [] } });

class TableInnerDirective {
    constructor() {
        /** @hidden */
        this.fdTableInnerClass = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableInnerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TableInnerDirective, isStandalone: true, selector: "[fdTableInner], [fd-table-inner]", host: { properties: { "class.fd-table__inner": "this.fdTableInnerClass" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableInnerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableInner], [fd-table-inner]',
                    standalone: true
                }]
        }], propDecorators: { fdTableInnerClass: [{
                type: HostBinding,
                args: ['class.fd-table__inner']
            }] } });

class TablePopoverDirective {
    constructor() {
        /** @hidden */
        this.fdTablePopoverClass = 'fd-table__popover fd-table__popover--custom';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TablePopoverDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TablePopoverDirective, isStandalone: true, selector: "[fdTablePopover], [fd-table-popover]", host: { properties: { "class": "this.fdTablePopoverClass" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TablePopoverDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTablePopover], [fd-table-popover]',
                    standalone: true
                }]
        }], propDecorators: { fdTablePopoverClass: [{
                type: HostBinding,
                args: ['class']
            }] } });

/**
 * The directive that represents a table.
 * A table is a set of tabular data. Line items can support data, images and actions.
 * ```html
 *     <div fd-table-responsive-wrapper>
 *         <table fd-table>
 *         </table>
 *     </div>
 * ```
 */
class TableResponsiveWrapperDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableResponsiveWrapperDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TableResponsiveWrapperDirective, isStandalone: true, selector: "[fd-table-responsive-wrapper]", host: { properties: { "style.overflow-x": "\"auto\"" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableResponsiveWrapperDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fd-table-responsive-wrapper]',
                    host: {
                        '[style.overflow-x]': '"auto"'
                    },
                    standalone: true
                }]
        }] });

class TableService {
    constructor() {
        /** @hidden */
        this.propagateKeys$ = signal([]);
    }
    /** @hidden */
    changeKeys(keys) {
        if (keys && keys.length > 0) {
            this.propagateKeys$.set([...keys]);
        }
    }
}

const HIDDEN_CLASS_NAME = 'fd-table--hidden';
class TableRowDirective extends FocusableListDirective {
    /** Whether the table row is focusable */
    set focusable(value) {
        this._focusable = value;
        this.setTabbable(this._focusable);
    }
    get focusable() {
        return this._focusable;
    }
    /** @hidden */
    constructor() {
        super();
        /** @hidden */
        this.fdTableRowClass = true;
        /** Whether the table row is activable */
        this.activable = false;
        /** Whether the table row is hoverable */
        /** Whether to highlight active row when clicked. */
        this.highlightActive = false;
        /**  Whether the table row is hoverable */
        this.hoverable = false;
        /** Whether the table row is main row, it's concerned only on pop in mode */
        this.main = false;
        /** Whether the table row is secondary row, it's concerned only on pop in mode */
        this.secondary = false;
        /** Whether the table row is active. */
        this.active = false;
        /** @hidden */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this._changeDetRef = inject(ChangeDetectorRef);
        /** @hidden */
        this._tableService = inject(TableService);
        effect(() => {
            this._resetCells(this._tableService.propagateKeys$());
        });
    }
    /** @hidden */
    ngOnInit() {
        this.navigationDirection = 'grid';
        this._updateNavigationDirection();
    }
    /** @hidden */
    ngAfterViewInit() {
        super.ngAfterViewInit();
        this._resetCells(this._tableService.propagateKeys$());
        this._setupCellsSubscription();
    }
    /** @hidden */
    _resetCells(keys) {
        if (this.cells && keys && keys.length > 0) {
            this._changeVisibility(keys);
            const sortedCells = this.cells.toArray().sort((a, b) => this._sortMethod(a, b, keys));
            this.cells.reset(sortedCells);
            this._sortNativeElements();
            this._changeDetRef.detectChanges();
        }
    }
    /** @hidden */
    _sortMethod(a, b, keys) {
        if (keys.findIndex((_key) => _key === a.key) < keys.findIndex((_key) => _key === b.key)) {
            return -1;
        }
        else {
            return 1;
        }
    }
    /** @hidden */
    _sortNativeElements() {
        this.cells.forEach((cell) => cell.elementRef.nativeElement.parentNode?.appendChild(cell.elementRef.nativeElement));
    }
    /** @hidden */
    _changeVisibility(keys) {
        this.cells.forEach((cell) => cell.elementRef.nativeElement.classList.remove(HIDDEN_CLASS_NAME));
        const notFoundElements = this.cells.filter((cell) => !keys.find((key) => key === cell.key));
        notFoundElements.forEach(this._hideElement);
    }
    /** @hidden */
    _hideElement(element) {
        element.elementRef.nativeElement.classList.add(HIDDEN_CLASS_NAME);
    }
    /** @hidden */
    _setupCellsSubscription() {
        this.cells.changes.pipe(startWith(null)).subscribe(() => {
            this.cells.forEach((cell, index) => {
                cell.elementRef.nativeElement.ariaColIndex = index.toString();
            });
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableRowDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "20.0.2", type: TableRowDirective, isStandalone: true, selector: "[fdTableRow], [fd-table-row]", inputs: { activable: "activable", highlightActive: "highlightActive", hoverable: "hoverable", focusable: ["focusable", "focusable", booleanAttribute], main: "main", secondary: "secondary", active: "active" }, host: { attributes: { "role": "row" }, properties: { "class.fd-table__row": "this.fdTableRowClass", "class.fd-table__row--activable": "this.activable", "class.fd-table__row--hoverable": "this.hoverable", "class.fd-table__row--focusable": "this.focusable", "class.fd-table__row--main": "this.main", "class.fd-table__row--secondary": "this.secondary", "class.is-selected": "this.active" } }, providers: [
            {
                provide: FDK_FOCUSABLE_LIST_DIRECTIVE,
                useExisting: TableRowDirective
            }
        ], queries: [{ propertyName: "cells", predicate: TableCellDirective }], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableRowDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableRow], [fd-table-row]',
                    providers: [
                        {
                            provide: FDK_FOCUSABLE_LIST_DIRECTIVE,
                            useExisting: TableRowDirective
                        }
                    ],
                    host: {
                        role: 'row'
                    },
                    standalone: true
                }]
        }], ctorParameters: () => [], propDecorators: { cells: [{
                type: ContentChildren,
                args: [TableCellDirective]
            }], fdTableRowClass: [{
                type: HostBinding,
                args: ['class.fd-table__row']
            }], activable: [{
                type: HostBinding,
                args: ['class.fd-table__row--activable']
            }, {
                type: Input
            }], highlightActive: [{
                type: Input
            }], hoverable: [{
                type: HostBinding,
                args: ['class.fd-table__row--hoverable']
            }, {
                type: Input
            }], focusable: [{
                type: HostBinding,
                args: ['class.fd-table__row--focusable']
            }, {
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], main: [{
                type: HostBinding,
                args: ['class.fd-table__row--main']
            }, {
                type: Input
            }], secondary: [{
                type: HostBinding,
                args: ['class.fd-table__row--secondary']
            }, {
                type: Input
            }], active: [{
                type: HostBinding,
                args: ['class.is-selected']
            }, {
                type: Input
            }] } });

class TableStatusIndicatorDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableStatusIndicatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TableStatusIndicatorDirective, isStandalone: true, selector: "[fdTableStatusIndicator], [fd-table-status-indicator]", inputs: { status: "status" }, host: { properties: { "class.fd-table__cell--status-indicator--valid": "status === \"valid\"", "class.fd-table__cell--status-indicator--warning": "status === \"warning\"", "class.fd-table__cell--status-indicator--information": "status === \"information\"", "class.fd-table__cell--status-indicator--error": "status === \"error\"" }, classAttribute: "fd-table__cell--status-indicator" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableStatusIndicatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableStatusIndicator], [fd-table-status-indicator]',
                    host: {
                        class: 'fd-table__cell--status-indicator',
                        '[class.fd-table__cell--status-indicator--valid]': 'status === "valid"',
                        '[class.fd-table__cell--status-indicator--warning]': 'status === "warning"',
                        '[class.fd-table__cell--status-indicator--information]': 'status === "information"',
                        '[class.fd-table__cell--status-indicator--error]': 'status === "error"'
                    },
                    standalone: true
                }]
        }], propDecorators: { status: [{
                type: Input
            }] } });

class TableTextDirective {
    constructor() {
        /** Whether the text should have shadow (halo) & overflow should be hidden. */
        this.fdTableTextClass = true;
        /** Whether the text should wrap when the text is too long for 1 line */
        this.noWrap = false;
        /** Whether the text should be bolded and marked as a title */
        this.title = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableTextDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "20.0.2", type: TableTextDirective, isStandalone: true, selector: "[fdTableText], [fd-table-text]", inputs: { fdTableTextClass: "fdTableTextClass", noWrap: "noWrap", title: "title", maxWidth: "maxWidth" }, host: { properties: { "class.fd-table__text": "this.fdTableTextClass", "class.fd-table__text--no-wrap": "this.noWrap", "class.fd-table__text--title": "this.title", "style.max-width": "this.maxWidth" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableTextDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdTableText], [fd-table-text]',
                    standalone: true
                }]
        }], propDecorators: { fdTableTextClass: [{
                type: HostBinding,
                args: ['class.fd-table__text']
            }, {
                type: Input
            }], noWrap: [{
                type: HostBinding,
                args: ['class.fd-table__text--no-wrap']
            }, {
                type: Input
            }], title: [{
                type: HostBinding,
                args: ['class.fd-table__text--title']
            }, {
                type: Input
            }], maxWidth: [{
                type: HostBinding,
                args: ['style.max-width']
            }, {
                type: Input
            }] } });

/**
 * The component that represents a table wrapper, it will add fd-table class to its first child.
 * A table is a set of tabular data. Line items can support data, images and actions.
 * ```html
 * <table-wrapper>
 * <table></table>
 * </table-wrapper>
 * ```
 */
class TableWrapperComponent {
    /** @hidden */
    constructor(elementRef, _contentDensityObserver) {
        this.elementRef = elementRef;
        this._contentDensityObserver = _contentDensityObserver;
    }
    /** @hidden */
    ngAfterContentInit() {
        if (this.elementRef.nativeElement && this.elementRef.nativeElement.firstChild) {
            const tableElement = this.elementRef.nativeElement.firstChild;
            tableElement.classList.add('fd-table');
            const tableElementRef = new ElementRef(tableElement);
            this._contentDensitySettings = {
                elementRef: tableElementRef
            };
            this._contentDensityObserver.consume(this._contentDensitySettings);
            if (tableElement.children) {
                for (let i = 0; i < tableElement.children.length; i++) {
                    if (tableElement.children[i].tagName === 'THEAD') {
                        tableElement.children[i].classList.add('fd-table__header');
                    }
                    else if (tableElement.children[i].tagName === 'TBODY') {
                        tableElement.children[i].classList.add('fd-table__body');
                    }
                    else if (tableElement.children[i].tagName === 'TFOOT') {
                        tableElement.children[i].classList.add('fd-table__footer');
                    }
                }
            }
        }
    }
    /** @hidden */
    ngOnDestroy() {
        if (!this._contentDensitySettings) {
            return;
        }
        this._contentDensityObserver.removeConsumer(this._contentDensitySettings);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableWrapperComponent, deps: [{ token: i0.ElementRef }, { token: i1.ContentDensityObserver }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "20.0.2", type: TableWrapperComponent, isStandalone: true, selector: "fd-table-wrapper", providers: [contentDensityObserverProviders()], ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, styles: [".fd-table{--fdTable_Header_Cell_Height:2.75rem;--fdTable_Cell_Height:2.75rem;border-bottom-left-radius:var(--fdTable_Border_Radius);border-bottom-right-radius:var(--fdTable_Border_Radius);border-collapse:separate;border-spacing:0;max-width:100%;width:100%}.fd-table,.fd-table__body,.fd-table__cell,.fd-table__footer,.fd-table__header,.fd-table__row,.fd-table__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-table:after,.fd-table:before,.fd-table__body:after,.fd-table__body:before,.fd-table__cell:after,.fd-table__cell:before,.fd-table__footer:after,.fd-table__footer:before,.fd-table__header:after,.fd-table__header:before,.fd-table__row:after,.fd-table__row:before,.fd-table__text:after,.fd-table__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-table__icon [class*=sap-icon],.fd-table__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);font-size:var(--sapFontSmallSize)}.fd-table__icon--navigation [class*=sap-icon],.fd-table__icon--navigation[class*=sap-icon]{font-size:var(--sapFontSmallSize);height:100%;min-width:2rem;width:2rem}.fd-table__icon--navigation [class*=sap-icon][dir=rtl],.fd-table__icon--navigation[class*=sap-icon][dir=rtl],[dir=rtl] .fd-table__icon--navigation [class*=sap-icon],[dir=rtl] .fd-table__icon--navigation[class*=sap-icon]{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.fd-table__header .fd-table__cell{background-color:var(--sapList_HeaderBackground);border-bottom:var(--fdTable_Header_Horizontal_Border);border-top:var(--fdTable_Header_Horizontal_Border);color:var(--sapList_HeaderTextColor);font-weight:var(--fdTable_Header_Cell_Font_Weight);height:var(--fdTable_Header_Cell_Height)}.fd-table__header .fd-table__cell.is-hover,.fd-table__header .fd-table__cell:hover{background-color:var(--fdTable_Header_Cell_Hover_Background);color:var(--fdTable_Header_Cell_Hover_Active_Color)}.fd-table__header .fd-table__cell.is-active,.fd-table__header .fd-table__cell:active{background-color:var(--fdTable_Header_Cell_Active_Background);color:var(--fdTable_Header_Cell_Hover_Active_Color)}.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:hover{background-color:var(--sapList_HeaderBackground);color:var(--sapList_HeaderTextColor)}.fd-table__header--non-interactive .fd-table__cell.is-active,.fd-table__header--non-interactive .fd-table__cell.is-hover,.fd-table__header--non-interactive .fd-table__cell:active,.fd-table__header--non-interactive .fd-table__cell:hover{background-color:var(--sapList_HeaderBackground)}.fd-table__text{overflow:hidden;text-overflow:ellipsis;text-shadow:var(--sapContent_TextShadow);white-space:nowrap;white-space:normal;word-break:break-word}.fd-table__text--no-wrap{white-space:nowrap}.fd-table__cell{border-bottom:var(--sapList_BorderWidth) var(--fdTable_Cell_Horizontal_Border_Style,solid) var(--sapList_BorderColor);border-left:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor);color:inherit;height:var(--fdTable_Cell_Height);outline:none;padding-block:0;padding-inline:.5rem;text-align:left}.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{border-left-style:none}.fd-table__cell.is-last-child,.fd-table__cell:last-child,.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{border-right:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor)}.fd-table__cell.is-last-child[dir=rtl],.fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table__cell.is-last-child,[dir=rtl] .fd-table__cell:last-child{border-left:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor);border-right-style:none}.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{text-align:right}.fd-table__cell--no-data{text-align:center}.fd-table__cell--mock{padding-block:0;padding-inline:0;width:auto}.fd-table__cell--checkbox{padding-block:0;padding-inline:0;vertical-align:baseline;width:var(--fdTable_Header_Cell_Height)}.fd-table__cell--fit-content{white-space:nowrap;width:.5rem;word-break:keep-all}.fd-table__cell--no-padding{padding-block:0;padding-inline:0}.fd-table__cell--status-indicator{padding-block:0;padding-inline:0;width:.375rem}.fd-table__cell--navigated{-webkit-box-shadow:inset -.1875rem 0 var(--sapSelectedColor);box-shadow:inset -.1875rem 0 var(--sapSelectedColor)}.fd-table__cell--navigated[dir=rtl],[dir=rtl] .fd-table__cell--navigated{-webkit-box-shadow:inset .1875rem 0 var(--sapSelectedColor);box-shadow:inset .1875rem 0 var(--sapSelectedColor)}.fd-table__cell:first-child:not(.fd-table__cell--checkbox,.fd-table__cell.fd-table__cell--status-indicator){-webkit-padding-start:1rem;padding-inline-start:1rem}.fd-table__row{background-color:var(--sapList_Background)}.fd-table__row.is-selected,.fd-table__row[aria-selected=true]{background-color:var(--sapList_SelectionBackgroundColor)}.fd-table__row.is-selected .fd-table__cell,.fd-table__row[aria-selected=true] .fd-table__cell{border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table__cell--hoverable.is-hover,.fd-table__cell--hoverable:hover,.fd-table__row--hoverable.is-hover,.fd-table__row--hoverable:hover{background-color:var(--sapList_Hover_Background);color:var(--fdTable_Hover_Down_Color)}.fd-table__cell--hoverable.is-selected.is-hover,.fd-table__cell--hoverable.is-selected:hover,.fd-table__cell--hoverable[aria-selected=true].is-hover,.fd-table__cell--hoverable[aria-selected=true]:hover,.fd-table__row--hoverable.is-selected.is-hover,.fd-table__row--hoverable.is-selected:hover,.fd-table__row--hoverable[aria-selected=true].is-hover,.fd-table__row--hoverable[aria-selected=true]:hover{background-color:var(--sapList_Hover_SelectionBackground)}.fd-table__cell--activable,.fd-table__cell--focusable,.fd-table__row--activable,.fd-table__row--focusable{position:relative}.fd-table__cell--activable.is-focus:after,.fd-table__cell--activable:focus:after,.fd-table__cell--focusable.is-focus:after,.fd-table__cell--focusable:focus:after,.fd-table__row--activable.is-focus:after,.fd-table__row--activable:focus:after,.fd-table__row--focusable.is-focus:after,.fd-table__row--focusable:focus:after{border-color:var(--sapContent_FocusColor);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:.0625rem;pointer-events:none;position:absolute}.fd-table__cell--activable:after,.fd-table__cell--focusable:after,.fd-table__row--activable:after,.fd-table__row--focusable:after{z-index:4}.fd-table__cell--activable,.fd-table__row--activable{cursor:pointer}.fd-table__cell--activable.is-active,.fd-table__cell--activable:active,.fd-table__row--activable.is-active,.fd-table__row--activable:active{background-color:var(--sapList_Active_Background);color:var(--sapList_Active_TextColor)}.fd-table__cell--activable.is-active *,.fd-table__cell--activable:active *,.fd-table__row--activable.is-active *,.fd-table__row--activable:active *{color:var(--sapList_Active_TextColor)!important}.fd-table__cell--activable.is-active .fd-table__cell.is-hover,.fd-table__cell--activable.is-active .fd-table__cell:hover,.fd-table__cell--activable:active .fd-table__cell.is-hover,.fd-table__cell--activable:active .fd-table__cell:hover,.fd-table__row--activable.is-active .fd-table__cell.is-hover,.fd-table__row--activable.is-active .fd-table__cell:hover,.fd-table__row--activable:active .fd-table__cell.is-hover,.fd-table__row--activable:active .fd-table__cell:hover{background-color:var(--sapList_Active_Background)}.fd-table__cell--activable.is-active .fd-table__text,.fd-table__cell--activable:active .fd-table__text,.fd-table__row--activable.is-active .fd-table__text,.fd-table__row--activable:active .fd-table__text{text-shadow:none}.fd-table__cell--activable.is-active .fd-table__icon [class*=sap-icon],.fd-table__cell--activable.is-active .fd-table__icon[class*=sap-icon],.fd-table__cell--activable:active .fd-table__icon [class*=sap-icon],.fd-table__cell--activable:active .fd-table__icon[class*=sap-icon],.fd-table__row--activable.is-active .fd-table__icon [class*=sap-icon],.fd-table__row--activable.is-active .fd-table__icon[class*=sap-icon],.fd-table__row--activable:active .fd-table__icon [class*=sap-icon],.fd-table__row--activable:active .fd-table__icon[class*=sap-icon]{color:var(--sapContent_ContrastIconColor)}.fd-table__cell--activable.is-active .fd-form-label,.fd-table__cell--activable.is-active .fd-link,.fd-table__cell--activable.is-active .fd-object-status,.fd-table__cell--activable:active .fd-form-label,.fd-table__cell--activable:active .fd-link,.fd-table__cell--activable:active .fd-object-status,.fd-table__row--activable.is-active .fd-form-label,.fd-table__row--activable.is-active .fd-link,.fd-table__row--activable.is-active .fd-object-status,.fd-table__row--activable:active .fd-form-label,.fd-table__row--activable:active .fd-link,.fd-table__row--activable:active .fd-object-status{color:inherit}.fd-table__cell--activable.is-selected.is-active,.fd-table__cell--activable.is-selected:active,.fd-table__cell--activable[aria-selected=true].is-active,.fd-table__cell--activable[aria-selected=true]:active,.fd-table__row--activable.is-selected.is-active,.fd-table__row--activable.is-selected:active,.fd-table__row--activable[aria-selected=true].is-active,.fd-table__row--activable[aria-selected=true]:active{background-color:var(--sapList_Active_Background)}.fd-table__cell--activable.is-selected.is-active .fd-table__cell,.fd-table__cell--activable.is-selected:active .fd-table__cell,.fd-table__cell--activable[aria-selected=true].is-active .fd-table__cell,.fd-table__cell--activable[aria-selected=true]:active .fd-table__cell,.fd-table__row--activable.is-selected.is-active .fd-table__cell,.fd-table__row--activable.is-selected:active .fd-table__cell,.fd-table__row--activable[aria-selected=true].is-active .fd-table__cell,.fd-table__row--activable[aria-selected=true]:active .fd-table__cell{border-bottom-color:var(--sapList_Active_Background)}.fd-table__body:not(:last-child) .fd-table__row:last-child .fd-table__cell{border-bottom-color:transparent}.fd-table__footer .fd-table__row{background-color:var(--sapList_Background);vertical-align:middle}.fd-table__footer .fd-table__cell{border-bottom-color:transparent;border-left-color:transparent;border-right-color:transparent;border-top:.125rem solid var(--sapList_TableFooterBorder);font-weight:700}.fd-table__inner{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-table__inner:after,.fd-table__inner:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-table__column-header-icons{display:-webkit-box;display:-ms-flexbox;display:flex}.fd-table__column-header-icons .fd-table__icon:not(:last-child){-webkit-margin-end:.25rem;margin-inline-end:.25rem}.fd-table__caption{position:absolute;clip:rect(0 0 0 0);border:0;height:1px;margin-block:-1px;margin-inline:-1px;overflow:hidden;padding-block:0;padding-inline:0;white-space:nowrap;width:1px}.fd-table__item--clickable{cursor:pointer}.fd-table__popover.fd-popover{color:inherit;display:block;height:100%}.fd-table__popover.fd-popover .fd-popover__control{color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;height:100%;width:100%;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-table[class*=-compact],[class*=-compact] .fd-table:not([class*=-cozy],[class*=-condensed]){--fdTable_Cell_Height:2rem}.fd-table[class*=-condensed],[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]){--fdTable_Cell_Height:1.5rem}.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--checkbox .fd-table__checkbox-label,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--checkbox .fd-table__checkbox-label,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--checkbox .fd-table__checkbox-label,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--checkbox .fd-table__checkbox-label{margin-top:-.25rem;position:absolute}.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--activable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--focusable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__row--activable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__row--focusable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--activable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--focusable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__row--activable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__row--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__row--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__row--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__row--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__row--focusable:after{inset:var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset)}.fd-table[class*=-compact],.fd-table[class*=-condensed],[class*=-compact] .fd-table:not([class*=-cozy]),[class*=-condensed] .fd-table:not([class*=-cozy]){--fdTable_Header_Cell_Height:2rem}.fd-table--hidden{display:none}.fd-table--fixed{overflow:auto;scrollbar-color:var(--fdScrollbar_Thumb_Color) var(--fdScrollbar_Track_Color)}.fd-table--fixed.is-focus,.fd-table--fixed:focus{outline:none;z-index:5}.fd-table--fixed::-webkit-scrollbar{height:var(--fdScrollbar_Dimension);width:var(--fdScrollbar_Dimension)}.fd-table--fixed::-webkit-scrollbar-corner,.fd-table--fixed::-webkit-scrollbar-track{background-color:var(--fdScrollbar_Track_Color)}.fd-table--fixed::-webkit-scrollbar-thumb{background-color:transparent;border:var(--fdScrollbar_Thumb_Offset) solid transparent;border-radius:calc(var(--fdScrollbar_Thumb_Border_Radius) - var(--fdScrollbar_Thumb_Offset));-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color)}.fd-table--fixed::-webkit-scrollbar-thumb:active,.fd-table--fixed::-webkit-scrollbar-thumb:hover{-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color)}.fd-table--fixed .fd-table__cell--fixed{left:0}.fd-table--fixed .fd-table__cell--fixed[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed{left:auto;right:0}.fd-table--fixed .fd-table__cell--fixed,.fd-table--fixed .fd-table__cell--fixed-end{background-color:inherit;display:table-cell;position:sticky;z-index:1}.fd-table--fixed .fd-table__cell--fixed-last{border-right:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__cell--fixed-last+.fd-table__cell{border-left:none}.fd-table--fixed .fd-table__cell--fixed-last[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-last{border-left:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor);border-right:var(--sapList_BorderWidth) solid var(--sapList_BorderColor)}.fd-table--fixed .fd-table__cell--fixed-last[dir=rtl]+.fd-table__cell,[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-last+.fd-table__cell{border-right:none}.fd-table--fixed .fd-table__cell--fixed-end{right:0}.fd-table--fixed .fd-table__cell--fixed-end[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-end{left:0;right:auto}.fd-table--fixed .fd-table__cell--fixed-end-last{border-left:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__cell--fixed-end-last[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-end-last{border-right:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__header .fd-table__cell{position:sticky;top:0;z-index:2}.fd-table--fixed .fd-table__header .fd-table__cell--fixed,.fd-table--fixed .fd-table__header .fd-table__cell--fixed-end{z-index:3}.fd-table--fixed .fd-table__footer .fd-table__cell{background-color:inherit;bottom:0;position:sticky;z-index:2}.fd-table .fd-table__cell--valid{color:var(--sapSuccessColor)}.fd-table .fd-table__cell--status-indicator--valid{background-color:var(--sapSuccessBorderColor)}.fd-table .fd-table__cell--warning{color:var(--sapWarningColor)}.fd-table .fd-table__cell--status-indicator--warning{background-color:var(--sapWarningBorderColor)}.fd-table .fd-table__cell--error{color:var(--sapErrorColor)}.fd-table .fd-table__cell--status-indicator--error{background-color:var(--sapErrorBorderColor)}.fd-table .fd-table__cell--information{color:var(--sapInformationColor)}.fd-table .fd-table__cell--status-indicator--information{background-color:var(--sapInformationBorderColor)}.fd-table--pop-in .fd-table__text{color:inherit;-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-table--pop-in .fd-table__text--title{font-weight:700}.fd-table--pop-in .fd-table__text.is-last-child,.fd-table--pop-in .fd-table__text:last-child{-webkit-margin-after:0;margin-block-end:0}.fd-table--pop-in .fd-table__cell--checkbox+.fd-table__cell{-webkit-padding-start:0;padding-inline-start:0}.fd-table--pop-in .fd-table__body .fd-table__cell{height:auto}.fd-table--pop-in .fd-table__row--main,.fd-table--pop-in .fd-table__row--secondary{border-left-color:transparent;border-right-color:transparent}.fd-table--pop-in .fd-table__row--main .fd-table__cell{border-bottom-color:transparent;padding-block:.25rem}.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable:hover+.fd-table__row--secondary{background-color:var(--sapList_Hover_Background)}.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-selected.is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-selected:hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable[aria-selected=true].is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable[aria-selected=true]:hover+.fd-table__row--secondary{background-color:var(--sapList_Hover_SelectionBackground)}.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-active .fd-table__cell,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable:active .fd-table__cell{border-bottom-color:transparent}.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-selected.is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-selected:active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable:active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable[aria-selected=true].is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable[aria-selected=true]:active+.fd-table__row--secondary{background-color:var(--sapList_Active_Background);border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table--pop-in .fd-table__row--main.is-selected .fd-table__cell,.fd-table--pop-in .fd-table__row--main[aria-selected=true] .fd-table__cell{border-bottom-color:transparent}.fd-table--pop-in .fd-table__row--main.is-selected+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main[aria-selected=true]+.fd-table__row--secondary{background-color:var(--sapList_SelectionBackgroundColor);border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table--pop-in .fd-table__row--secondary .fd-table__cell{padding-block:.5rem}.fd-table--pop-in .fd-table__row--secondary.is-active,.fd-table--pop-in .fd-table__row--secondary.is-hover,.fd-table--pop-in .fd-table__row--secondary:active,.fd-table--pop-in .fd-table__row--secondary:hover{background-color:var(--sapList_Background)}.fd-table--no-vertical-borders .fd-table__cell,.fd-table__body--no-vertical-borders .fd-table__cell,.fd-table__header--no-vertical-borders .fd-table__cell{--fdTable_Cell_Vertical_Border_Style:none}.fd-table--no-vertical-borders .fd-table__cell[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell{border-left-color:var(--sapList_BorderColor)}.fd-table--no-vertical-borders .fd-table__cell.is-first-child,.fd-table--no-vertical-borders .fd-table__cell:first-child,.fd-table__body--no-vertical-borders .fd-table__cell.is-first-child,.fd-table__body--no-vertical-borders .fd-table__cell:first-child,.fd-table__header--no-vertical-borders .fd-table__cell.is-first-child,.fd-table__header--no-vertical-borders .fd-table__cell:first-child{border-left-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table--no-vertical-borders .fd-table__cell:first-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell:first-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell:first-child[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell:first-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell:first-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell:first-child{border-left-style:none;border-right-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--no-vertical-borders .fd-table__cell:last-child,.fd-table__body--no-vertical-borders .fd-table__cell.is-last-child,.fd-table__body--no-vertical-borders .fd-table__cell:last-child,.fd-table__header--no-vertical-borders .fd-table__cell.is-last-child,.fd-table__header--no-vertical-borders .fd-table__cell:last-child{border-right-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-vertical-borders .fd-table__cell:last-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell:last-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell:last-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell:last-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell:last-child{border-left-style:solid;border-right-style:none}.fd-table--no-horizontal-borders .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__cell{border-bottom-color:transparent}.fd-table--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table--no-horizontal-borders .fd-table__row:last-child .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__row:last-child .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__row:last-child .fd-table__cell{border-bottom-color:var(--sapList_BorderColor)}.fd-table .fd-table__cell--no-vertical-border+.fd-table__cell{border-left-style:none}.fd-table .fd-table__cell--no-vertical-border[dir=rtl],[dir=rtl] .fd-table .fd-table__cell--no-vertical-border{border-right-style:none}.fd-table .fd-table__cell--no-horizontal-border{border-bottom-color:transparent}.fd-table--no-outer-border:not(.fd-table--top-border) .fd-table__header .fd-table__cell,.fd-table--responsive:not(.fd-table--top-border) .fd-table__header .fd-table__cell{border-top-color:transparent}.fd-table--no-outer-border .fd-table__body .fd-table__row.is-last-child .fd-table__cell,.fd-table--no-outer-border .fd-table__body .fd-table__row:last-child .fd-table__cell,.fd-table--responsive .fd-table__body .fd-table__row.is-last-child .fd-table__cell,.fd-table--responsive .fd-table__body .fd-table__row:last-child .fd-table__cell{border-bottom-color:transparent}.fd-table--no-outer-border .fd-table__cell.is-first-child,.fd-table--no-outer-border .fd-table__cell.is-last-child,.fd-table--no-outer-border .fd-table__cell:first-child,.fd-table--no-outer-border .fd-table__cell:last-child,.fd-table--responsive .fd-table__cell.is-first-child,.fd-table--responsive .fd-table__cell.is-last-child,.fd-table--responsive .fd-table__cell:first-child,.fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:solid}.fd-table--no-outer-border .fd-table__cell.is-first-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:first-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:last-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-first-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-last-child[dir=rtl],.fd-table--responsive .fd-table__cell:first-child[dir=rtl],.fd-table--responsive .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-first-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:first-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:last-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-first-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-last-child,[dir=rtl] .fd-table--responsive .fd-table__cell:first-child,[dir=rtl] .fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:none}.fd-table--no-outer-border .fd-table__cell.is-last-child,.fd-table--no-outer-border .fd-table__cell:last-child,.fd-table--responsive .fd-table__cell.is-last-child,.fd-table--responsive .fd-table__cell:last-child{border-left-style:solid;border-right-style:none}.fd-table--no-outer-border .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:last-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-last-child[dir=rtl],.fd-table--responsive .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:last-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-last-child,[dir=rtl] .fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:solid}.fd-table--no-outer-border.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--no-outer-border.fd-table--no-vertical-borders .fd-table__cell:last-child,.fd-table--responsive.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--responsive.fd-table--no-vertical-borders .fd-table__cell:last-child{border-left-style:none;border-right-style:none}.fd-table--group .fd-table__cell--group{background-color:var(--fdTable_Group_Header_Background);border-bottom-color:var(--sapList_TableGroupHeaderBorderColor);font-weight:var(--fdTable_Header_Cell_Font_Weight)}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"]{-webkit-padding-start:5rem;padding-inline-start:5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"]{-webkit-padding-start:5.5rem;padding-inline-start:5.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"]{-webkit-padding-start:6rem;padding-inline-start:6rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"]{-webkit-padding-start:6.5rem;padding-inline-start:6.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"]{-webkit-padding-start:7rem;padding-inline-start:7rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"]{-webkit-padding-start:7.5rem;padding-inline-start:7.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"]{-webkit-padding-start:8rem;padding-inline-start:8rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"]{-webkit-padding-start:8.5rem;padding-inline-start:8.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"]{-webkit-padding-start:9rem;padding-inline-start:9rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"]{-webkit-padding-start:9.5rem;padding-inline-start:9.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"]{-webkit-padding-start:10rem;padding-inline-start:10rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"]{-webkit-padding-start:10.5rem;padding-inline-start:10.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"]{-webkit-padding-start:11rem;padding-inline-start:11rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"]{-webkit-padding-start:11.5rem;padding-inline-start:11.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"]{-webkit-padding-start:12rem;padding-inline-start:12rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"]{-webkit-padding-start:12.5rem;padding-inline-start:12.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"]{-webkit-padding-start:13rem;padding-inline-start:13rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"]{-webkit-padding-start:13.5rem;padding-inline-start:13.5rem}.fd-table--group .fd-table__body .fd-table__cell--expand,.fd-table--tree .fd-table__body .fd-table__cell--expand{cursor:pointer;white-space:nowrap}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"]{-webkit-padding-start:0;padding-inline-start:0}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"]{-webkit-padding-start:1.5rem;padding-inline-start:1.5rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"]{-webkit-padding-start:2.25rem;padding-inline-start:2.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"]{-webkit-padding-start:3.25rem;padding-inline-start:3.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"]{-webkit-padding-start:3.75rem;padding-inline-start:3.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand{color:var(--sapContent_IconColor);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-size:var(--sapFontSmallSize);height:var(--fdTable_Cell_Height);min-width:var(--fdTable_Header_Cell_Height);-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand:before{content:\"\\e066\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl]:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl]:before,[dir=rtl] .fd-table--group .fd-table__body .fd-table__cell .fd-table__expand:before,[dir=rtl] .fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand:before{content:\"\\e067\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl].fd-table__expand--open:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl].fd-table__expand--open:before,[dir=rtl] .fd-table--group .fd-table__body .fd-table__cell .fd-table__expand.fd-table__expand--open:before,[dir=rtl] .fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand.fd-table__expand--open:before{content:\"\\e1e2\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand--open:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand--open:before{content:\"\\e1e2\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"]{-webkit-padding-start:2rem;padding-inline-start:2rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"]{-webkit-padding-start:3.5rem;padding-inline-start:3.5rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"]{-webkit-padding-start:11.25rem;padding-inline-start:11.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"]{-webkit-padding-start:11.75rem;padding-inline-start:11.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"]{-webkit-padding-start:12.25rem;padding-inline-start:12.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"]{-webkit-padding-start:12.75rem;padding-inline-start:12.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"]{-webkit-padding-start:0;padding-inline-start:0}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"]{-webkit-padding-start:1.5rem;padding-inline-start:1.5rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"]{-webkit-padding-start:2.25rem;padding-inline-start:2.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"]{-webkit-padding-start:3.25rem;padding-inline-start:3.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"]{-webkit-padding-start:3.75rem;padding-inline-start:3.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.cdk-visually-hidden{border:0;clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;width:1px;white-space:nowrap;outline:0;-webkit-appearance:none;-moz-appearance:none;left:0}[dir=rtl] .cdk-visually-hidden{left:auto;right:0}.fd-table__popover--custom{width:100%}.fd-table__cell--checkbox .fd-checkbox__label{margin:0}.fd-table__cell--focusable[aria-selected=true]:after{border-color:var(--sapContent_FocusColor)!important}.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-active{background-color:var(--sapList_HeaderBackground);color:var(--sapList_HeaderTextColor)}\n/*! Bundled license information:\n\nfundamental-styles/dist/table.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableWrapperComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fd-table-wrapper', template: `<ng-content></ng-content>`, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [contentDensityObserverProviders()], standalone: true, styles: [".fd-table{--fdTable_Header_Cell_Height:2.75rem;--fdTable_Cell_Height:2.75rem;border-bottom-left-radius:var(--fdTable_Border_Radius);border-bottom-right-radius:var(--fdTable_Border_Radius);border-collapse:separate;border-spacing:0;max-width:100%;width:100%}.fd-table,.fd-table__body,.fd-table__cell,.fd-table__footer,.fd-table__header,.fd-table__row,.fd-table__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-table:after,.fd-table:before,.fd-table__body:after,.fd-table__body:before,.fd-table__cell:after,.fd-table__cell:before,.fd-table__footer:after,.fd-table__footer:before,.fd-table__header:after,.fd-table__header:before,.fd-table__row:after,.fd-table__row:before,.fd-table__text:after,.fd-table__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-table__icon [class*=sap-icon],.fd-table__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);font-size:var(--sapFontSmallSize)}.fd-table__icon--navigation [class*=sap-icon],.fd-table__icon--navigation[class*=sap-icon]{font-size:var(--sapFontSmallSize);height:100%;min-width:2rem;width:2rem}.fd-table__icon--navigation [class*=sap-icon][dir=rtl],.fd-table__icon--navigation[class*=sap-icon][dir=rtl],[dir=rtl] .fd-table__icon--navigation [class*=sap-icon],[dir=rtl] .fd-table__icon--navigation[class*=sap-icon]{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.fd-table__header .fd-table__cell{background-color:var(--sapList_HeaderBackground);border-bottom:var(--fdTable_Header_Horizontal_Border);border-top:var(--fdTable_Header_Horizontal_Border);color:var(--sapList_HeaderTextColor);font-weight:var(--fdTable_Header_Cell_Font_Weight);height:var(--fdTable_Header_Cell_Height)}.fd-table__header .fd-table__cell.is-hover,.fd-table__header .fd-table__cell:hover{background-color:var(--fdTable_Header_Cell_Hover_Background);color:var(--fdTable_Header_Cell_Hover_Active_Color)}.fd-table__header .fd-table__cell.is-active,.fd-table__header .fd-table__cell:active{background-color:var(--fdTable_Header_Cell_Active_Background);color:var(--fdTable_Header_Cell_Hover_Active_Color)}.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:hover{background-color:var(--sapList_HeaderBackground);color:var(--sapList_HeaderTextColor)}.fd-table__header--non-interactive .fd-table__cell.is-active,.fd-table__header--non-interactive .fd-table__cell.is-hover,.fd-table__header--non-interactive .fd-table__cell:active,.fd-table__header--non-interactive .fd-table__cell:hover{background-color:var(--sapList_HeaderBackground)}.fd-table__text{overflow:hidden;text-overflow:ellipsis;text-shadow:var(--sapContent_TextShadow);white-space:nowrap;white-space:normal;word-break:break-word}.fd-table__text--no-wrap{white-space:nowrap}.fd-table__cell{border-bottom:var(--sapList_BorderWidth) var(--fdTable_Cell_Horizontal_Border_Style,solid) var(--sapList_BorderColor);border-left:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor);color:inherit;height:var(--fdTable_Cell_Height);outline:none;padding-block:0;padding-inline:.5rem;text-align:left}.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{border-left-style:none}.fd-table__cell.is-last-child,.fd-table__cell:last-child,.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{border-right:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor)}.fd-table__cell.is-last-child[dir=rtl],.fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table__cell.is-last-child,[dir=rtl] .fd-table__cell:last-child{border-left:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor);border-right-style:none}.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{text-align:right}.fd-table__cell--no-data{text-align:center}.fd-table__cell--mock{padding-block:0;padding-inline:0;width:auto}.fd-table__cell--checkbox{padding-block:0;padding-inline:0;vertical-align:baseline;width:var(--fdTable_Header_Cell_Height)}.fd-table__cell--fit-content{white-space:nowrap;width:.5rem;word-break:keep-all}.fd-table__cell--no-padding{padding-block:0;padding-inline:0}.fd-table__cell--status-indicator{padding-block:0;padding-inline:0;width:.375rem}.fd-table__cell--navigated{-webkit-box-shadow:inset -.1875rem 0 var(--sapSelectedColor);box-shadow:inset -.1875rem 0 var(--sapSelectedColor)}.fd-table__cell--navigated[dir=rtl],[dir=rtl] .fd-table__cell--navigated{-webkit-box-shadow:inset .1875rem 0 var(--sapSelectedColor);box-shadow:inset .1875rem 0 var(--sapSelectedColor)}.fd-table__cell:first-child:not(.fd-table__cell--checkbox,.fd-table__cell.fd-table__cell--status-indicator){-webkit-padding-start:1rem;padding-inline-start:1rem}.fd-table__row{background-color:var(--sapList_Background)}.fd-table__row.is-selected,.fd-table__row[aria-selected=true]{background-color:var(--sapList_SelectionBackgroundColor)}.fd-table__row.is-selected .fd-table__cell,.fd-table__row[aria-selected=true] .fd-table__cell{border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table__cell--hoverable.is-hover,.fd-table__cell--hoverable:hover,.fd-table__row--hoverable.is-hover,.fd-table__row--hoverable:hover{background-color:var(--sapList_Hover_Background);color:var(--fdTable_Hover_Down_Color)}.fd-table__cell--hoverable.is-selected.is-hover,.fd-table__cell--hoverable.is-selected:hover,.fd-table__cell--hoverable[aria-selected=true].is-hover,.fd-table__cell--hoverable[aria-selected=true]:hover,.fd-table__row--hoverable.is-selected.is-hover,.fd-table__row--hoverable.is-selected:hover,.fd-table__row--hoverable[aria-selected=true].is-hover,.fd-table__row--hoverable[aria-selected=true]:hover{background-color:var(--sapList_Hover_SelectionBackground)}.fd-table__cell--activable,.fd-table__cell--focusable,.fd-table__row--activable,.fd-table__row--focusable{position:relative}.fd-table__cell--activable.is-focus:after,.fd-table__cell--activable:focus:after,.fd-table__cell--focusable.is-focus:after,.fd-table__cell--focusable:focus:after,.fd-table__row--activable.is-focus:after,.fd-table__row--activable:focus:after,.fd-table__row--focusable.is-focus:after,.fd-table__row--focusable:focus:after{border-color:var(--sapContent_FocusColor);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:.0625rem;pointer-events:none;position:absolute}.fd-table__cell--activable:after,.fd-table__cell--focusable:after,.fd-table__row--activable:after,.fd-table__row--focusable:after{z-index:4}.fd-table__cell--activable,.fd-table__row--activable{cursor:pointer}.fd-table__cell--activable.is-active,.fd-table__cell--activable:active,.fd-table__row--activable.is-active,.fd-table__row--activable:active{background-color:var(--sapList_Active_Background);color:var(--sapList_Active_TextColor)}.fd-table__cell--activable.is-active *,.fd-table__cell--activable:active *,.fd-table__row--activable.is-active *,.fd-table__row--activable:active *{color:var(--sapList_Active_TextColor)!important}.fd-table__cell--activable.is-active .fd-table__cell.is-hover,.fd-table__cell--activable.is-active .fd-table__cell:hover,.fd-table__cell--activable:active .fd-table__cell.is-hover,.fd-table__cell--activable:active .fd-table__cell:hover,.fd-table__row--activable.is-active .fd-table__cell.is-hover,.fd-table__row--activable.is-active .fd-table__cell:hover,.fd-table__row--activable:active .fd-table__cell.is-hover,.fd-table__row--activable:active .fd-table__cell:hover{background-color:var(--sapList_Active_Background)}.fd-table__cell--activable.is-active .fd-table__text,.fd-table__cell--activable:active .fd-table__text,.fd-table__row--activable.is-active .fd-table__text,.fd-table__row--activable:active .fd-table__text{text-shadow:none}.fd-table__cell--activable.is-active .fd-table__icon [class*=sap-icon],.fd-table__cell--activable.is-active .fd-table__icon[class*=sap-icon],.fd-table__cell--activable:active .fd-table__icon [class*=sap-icon],.fd-table__cell--activable:active .fd-table__icon[class*=sap-icon],.fd-table__row--activable.is-active .fd-table__icon [class*=sap-icon],.fd-table__row--activable.is-active .fd-table__icon[class*=sap-icon],.fd-table__row--activable:active .fd-table__icon [class*=sap-icon],.fd-table__row--activable:active .fd-table__icon[class*=sap-icon]{color:var(--sapContent_ContrastIconColor)}.fd-table__cell--activable.is-active .fd-form-label,.fd-table__cell--activable.is-active .fd-link,.fd-table__cell--activable.is-active .fd-object-status,.fd-table__cell--activable:active .fd-form-label,.fd-table__cell--activable:active .fd-link,.fd-table__cell--activable:active .fd-object-status,.fd-table__row--activable.is-active .fd-form-label,.fd-table__row--activable.is-active .fd-link,.fd-table__row--activable.is-active .fd-object-status,.fd-table__row--activable:active .fd-form-label,.fd-table__row--activable:active .fd-link,.fd-table__row--activable:active .fd-object-status{color:inherit}.fd-table__cell--activable.is-selected.is-active,.fd-table__cell--activable.is-selected:active,.fd-table__cell--activable[aria-selected=true].is-active,.fd-table__cell--activable[aria-selected=true]:active,.fd-table__row--activable.is-selected.is-active,.fd-table__row--activable.is-selected:active,.fd-table__row--activable[aria-selected=true].is-active,.fd-table__row--activable[aria-selected=true]:active{background-color:var(--sapList_Active_Background)}.fd-table__cell--activable.is-selected.is-active .fd-table__cell,.fd-table__cell--activable.is-selected:active .fd-table__cell,.fd-table__cell--activable[aria-selected=true].is-active .fd-table__cell,.fd-table__cell--activable[aria-selected=true]:active .fd-table__cell,.fd-table__row--activable.is-selected.is-active .fd-table__cell,.fd-table__row--activable.is-selected:active .fd-table__cell,.fd-table__row--activable[aria-selected=true].is-active .fd-table__cell,.fd-table__row--activable[aria-selected=true]:active .fd-table__cell{border-bottom-color:var(--sapList_Active_Background)}.fd-table__body:not(:last-child) .fd-table__row:last-child .fd-table__cell{border-bottom-color:transparent}.fd-table__footer .fd-table__row{background-color:var(--sapList_Background);vertical-align:middle}.fd-table__footer .fd-table__cell{border-bottom-color:transparent;border-left-color:transparent;border-right-color:transparent;border-top:.125rem solid var(--sapList_TableFooterBorder);font-weight:700}.fd-table__inner{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-table__inner:after,.fd-table__inner:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-table__column-header-icons{display:-webkit-box;display:-ms-flexbox;display:flex}.fd-table__column-header-icons .fd-table__icon:not(:last-child){-webkit-margin-end:.25rem;margin-inline-end:.25rem}.fd-table__caption{position:absolute;clip:rect(0 0 0 0);border:0;height:1px;margin-block:-1px;margin-inline:-1px;overflow:hidden;padding-block:0;padding-inline:0;white-space:nowrap;width:1px}.fd-table__item--clickable{cursor:pointer}.fd-table__popover.fd-popover{color:inherit;display:block;height:100%}.fd-table__popover.fd-popover .fd-popover__control{color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;height:100%;width:100%;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-table[class*=-compact],[class*=-compact] .fd-table:not([class*=-cozy],[class*=-condensed]){--fdTable_Cell_Height:2rem}.fd-table[class*=-condensed],[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]){--fdTable_Cell_Height:1.5rem}.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--checkbox .fd-table__checkbox-label,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--checkbox .fd-table__checkbox-label,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--checkbox .fd-table__checkbox-label,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--checkbox .fd-table__checkbox-label{margin-top:-.25rem;position:absolute}.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--activable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--focusable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__row--activable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__row--focusable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--activable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--focusable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__row--activable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__row--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__row--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__row--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__row--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__row--focusable:after{inset:var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset)}.fd-table[class*=-compact],.fd-table[class*=-condensed],[class*=-compact] .fd-table:not([class*=-cozy]),[class*=-condensed] .fd-table:not([class*=-cozy]){--fdTable_Header_Cell_Height:2rem}.fd-table--hidden{display:none}.fd-table--fixed{overflow:auto;scrollbar-color:var(--fdScrollbar_Thumb_Color) var(--fdScrollbar_Track_Color)}.fd-table--fixed.is-focus,.fd-table--fixed:focus{outline:none;z-index:5}.fd-table--fixed::-webkit-scrollbar{height:var(--fdScrollbar_Dimension);width:var(--fdScrollbar_Dimension)}.fd-table--fixed::-webkit-scrollbar-corner,.fd-table--fixed::-webkit-scrollbar-track{background-color:var(--fdScrollbar_Track_Color)}.fd-table--fixed::-webkit-scrollbar-thumb{background-color:transparent;border:var(--fdScrollbar_Thumb_Offset) solid transparent;border-radius:calc(var(--fdScrollbar_Thumb_Border_Radius) - var(--fdScrollbar_Thumb_Offset));-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color)}.fd-table--fixed::-webkit-scrollbar-thumb:active,.fd-table--fixed::-webkit-scrollbar-thumb:hover{-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color)}.fd-table--fixed .fd-table__cell--fixed{left:0}.fd-table--fixed .fd-table__cell--fixed[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed{left:auto;right:0}.fd-table--fixed .fd-table__cell--fixed,.fd-table--fixed .fd-table__cell--fixed-end{background-color:inherit;display:table-cell;position:sticky;z-index:1}.fd-table--fixed .fd-table__cell--fixed-last{border-right:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__cell--fixed-last+.fd-table__cell{border-left:none}.fd-table--fixed .fd-table__cell--fixed-last[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-last{border-left:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor);border-right:var(--sapList_BorderWidth) solid var(--sapList_BorderColor)}.fd-table--fixed .fd-table__cell--fixed-last[dir=rtl]+.fd-table__cell,[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-last+.fd-table__cell{border-right:none}.fd-table--fixed .fd-table__cell--fixed-end{right:0}.fd-table--fixed .fd-table__cell--fixed-end[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-end{left:0;right:auto}.fd-table--fixed .fd-table__cell--fixed-end-last{border-left:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__cell--fixed-end-last[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-end-last{border-right:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__header .fd-table__cell{position:sticky;top:0;z-index:2}.fd-table--fixed .fd-table__header .fd-table__cell--fixed,.fd-table--fixed .fd-table__header .fd-table__cell--fixed-end{z-index:3}.fd-table--fixed .fd-table__footer .fd-table__cell{background-color:inherit;bottom:0;position:sticky;z-index:2}.fd-table .fd-table__cell--valid{color:var(--sapSuccessColor)}.fd-table .fd-table__cell--status-indicator--valid{background-color:var(--sapSuccessBorderColor)}.fd-table .fd-table__cell--warning{color:var(--sapWarningColor)}.fd-table .fd-table__cell--status-indicator--warning{background-color:var(--sapWarningBorderColor)}.fd-table .fd-table__cell--error{color:var(--sapErrorColor)}.fd-table .fd-table__cell--status-indicator--error{background-color:var(--sapErrorBorderColor)}.fd-table .fd-table__cell--information{color:var(--sapInformationColor)}.fd-table .fd-table__cell--status-indicator--information{background-color:var(--sapInformationBorderColor)}.fd-table--pop-in .fd-table__text{color:inherit;-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-table--pop-in .fd-table__text--title{font-weight:700}.fd-table--pop-in .fd-table__text.is-last-child,.fd-table--pop-in .fd-table__text:last-child{-webkit-margin-after:0;margin-block-end:0}.fd-table--pop-in .fd-table__cell--checkbox+.fd-table__cell{-webkit-padding-start:0;padding-inline-start:0}.fd-table--pop-in .fd-table__body .fd-table__cell{height:auto}.fd-table--pop-in .fd-table__row--main,.fd-table--pop-in .fd-table__row--secondary{border-left-color:transparent;border-right-color:transparent}.fd-table--pop-in .fd-table__row--main .fd-table__cell{border-bottom-color:transparent;padding-block:.25rem}.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable:hover+.fd-table__row--secondary{background-color:var(--sapList_Hover_Background)}.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-selected.is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-selected:hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable[aria-selected=true].is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable[aria-selected=true]:hover+.fd-table__row--secondary{background-color:var(--sapList_Hover_SelectionBackground)}.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-active .fd-table__cell,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable:active .fd-table__cell{border-bottom-color:transparent}.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-selected.is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-selected:active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable:active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable[aria-selected=true].is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable[aria-selected=true]:active+.fd-table__row--secondary{background-color:var(--sapList_Active_Background);border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table--pop-in .fd-table__row--main.is-selected .fd-table__cell,.fd-table--pop-in .fd-table__row--main[aria-selected=true] .fd-table__cell{border-bottom-color:transparent}.fd-table--pop-in .fd-table__row--main.is-selected+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main[aria-selected=true]+.fd-table__row--secondary{background-color:var(--sapList_SelectionBackgroundColor);border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table--pop-in .fd-table__row--secondary .fd-table__cell{padding-block:.5rem}.fd-table--pop-in .fd-table__row--secondary.is-active,.fd-table--pop-in .fd-table__row--secondary.is-hover,.fd-table--pop-in .fd-table__row--secondary:active,.fd-table--pop-in .fd-table__row--secondary:hover{background-color:var(--sapList_Background)}.fd-table--no-vertical-borders .fd-table__cell,.fd-table__body--no-vertical-borders .fd-table__cell,.fd-table__header--no-vertical-borders .fd-table__cell{--fdTable_Cell_Vertical_Border_Style:none}.fd-table--no-vertical-borders .fd-table__cell[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell{border-left-color:var(--sapList_BorderColor)}.fd-table--no-vertical-borders .fd-table__cell.is-first-child,.fd-table--no-vertical-borders .fd-table__cell:first-child,.fd-table__body--no-vertical-borders .fd-table__cell.is-first-child,.fd-table__body--no-vertical-borders .fd-table__cell:first-child,.fd-table__header--no-vertical-borders .fd-table__cell.is-first-child,.fd-table__header--no-vertical-borders .fd-table__cell:first-child{border-left-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table--no-vertical-borders .fd-table__cell:first-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell:first-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell:first-child[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell:first-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell:first-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell:first-child{border-left-style:none;border-right-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--no-vertical-borders .fd-table__cell:last-child,.fd-table__body--no-vertical-borders .fd-table__cell.is-last-child,.fd-table__body--no-vertical-borders .fd-table__cell:last-child,.fd-table__header--no-vertical-borders .fd-table__cell.is-last-child,.fd-table__header--no-vertical-borders .fd-table__cell:last-child{border-right-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-vertical-borders .fd-table__cell:last-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell:last-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell:last-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell:last-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell:last-child{border-left-style:solid;border-right-style:none}.fd-table--no-horizontal-borders .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__cell{border-bottom-color:transparent}.fd-table--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table--no-horizontal-borders .fd-table__row:last-child .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__row:last-child .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__row:last-child .fd-table__cell{border-bottom-color:var(--sapList_BorderColor)}.fd-table .fd-table__cell--no-vertical-border+.fd-table__cell{border-left-style:none}.fd-table .fd-table__cell--no-vertical-border[dir=rtl],[dir=rtl] .fd-table .fd-table__cell--no-vertical-border{border-right-style:none}.fd-table .fd-table__cell--no-horizontal-border{border-bottom-color:transparent}.fd-table--no-outer-border:not(.fd-table--top-border) .fd-table__header .fd-table__cell,.fd-table--responsive:not(.fd-table--top-border) .fd-table__header .fd-table__cell{border-top-color:transparent}.fd-table--no-outer-border .fd-table__body .fd-table__row.is-last-child .fd-table__cell,.fd-table--no-outer-border .fd-table__body .fd-table__row:last-child .fd-table__cell,.fd-table--responsive .fd-table__body .fd-table__row.is-last-child .fd-table__cell,.fd-table--responsive .fd-table__body .fd-table__row:last-child .fd-table__cell{border-bottom-color:transparent}.fd-table--no-outer-border .fd-table__cell.is-first-child,.fd-table--no-outer-border .fd-table__cell.is-last-child,.fd-table--no-outer-border .fd-table__cell:first-child,.fd-table--no-outer-border .fd-table__cell:last-child,.fd-table--responsive .fd-table__cell.is-first-child,.fd-table--responsive .fd-table__cell.is-last-child,.fd-table--responsive .fd-table__cell:first-child,.fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:solid}.fd-table--no-outer-border .fd-table__cell.is-first-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:first-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:last-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-first-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-last-child[dir=rtl],.fd-table--responsive .fd-table__cell:first-child[dir=rtl],.fd-table--responsive .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-first-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:first-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:last-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-first-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-last-child,[dir=rtl] .fd-table--responsive .fd-table__cell:first-child,[dir=rtl] .fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:none}.fd-table--no-outer-border .fd-table__cell.is-last-child,.fd-table--no-outer-border .fd-table__cell:last-child,.fd-table--responsive .fd-table__cell.is-last-child,.fd-table--responsive .fd-table__cell:last-child{border-left-style:solid;border-right-style:none}.fd-table--no-outer-border .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:last-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-last-child[dir=rtl],.fd-table--responsive .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:last-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-last-child,[dir=rtl] .fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:solid}.fd-table--no-outer-border.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--no-outer-border.fd-table--no-vertical-borders .fd-table__cell:last-child,.fd-table--responsive.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--responsive.fd-table--no-vertical-borders .fd-table__cell:last-child{border-left-style:none;border-right-style:none}.fd-table--group .fd-table__cell--group{background-color:var(--fdTable_Group_Header_Background);border-bottom-color:var(--sapList_TableGroupHeaderBorderColor);font-weight:var(--fdTable_Header_Cell_Font_Weight)}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"]{-webkit-padding-start:5rem;padding-inline-start:5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"]{-webkit-padding-start:5.5rem;padding-inline-start:5.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"]{-webkit-padding-start:6rem;padding-inline-start:6rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"]{-webkit-padding-start:6.5rem;padding-inline-start:6.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"]{-webkit-padding-start:7rem;padding-inline-start:7rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"]{-webkit-padding-start:7.5rem;padding-inline-start:7.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"]{-webkit-padding-start:8rem;padding-inline-start:8rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"]{-webkit-padding-start:8.5rem;padding-inline-start:8.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"]{-webkit-padding-start:9rem;padding-inline-start:9rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"]{-webkit-padding-start:9.5rem;padding-inline-start:9.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"]{-webkit-padding-start:10rem;padding-inline-start:10rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"]{-webkit-padding-start:10.5rem;padding-inline-start:10.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"]{-webkit-padding-start:11rem;padding-inline-start:11rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"]{-webkit-padding-start:11.5rem;padding-inline-start:11.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"]{-webkit-padding-start:12rem;padding-inline-start:12rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"]{-webkit-padding-start:12.5rem;padding-inline-start:12.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"]{-webkit-padding-start:13rem;padding-inline-start:13rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"]{-webkit-padding-start:13.5rem;padding-inline-start:13.5rem}.fd-table--group .fd-table__body .fd-table__cell--expand,.fd-table--tree .fd-table__body .fd-table__cell--expand{cursor:pointer;white-space:nowrap}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"]{-webkit-padding-start:0;padding-inline-start:0}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"]{-webkit-padding-start:1.5rem;padding-inline-start:1.5rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"]{-webkit-padding-start:2.25rem;padding-inline-start:2.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"]{-webkit-padding-start:3.25rem;padding-inline-start:3.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"]{-webkit-padding-start:3.75rem;padding-inline-start:3.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand{color:var(--sapContent_IconColor);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-size:var(--sapFontSmallSize);height:var(--fdTable_Cell_Height);min-width:var(--fdTable_Header_Cell_Height);-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand:before{content:\"\\e066\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl]:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl]:before,[dir=rtl] .fd-table--group .fd-table__body .fd-table__cell .fd-table__expand:before,[dir=rtl] .fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand:before{content:\"\\e067\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl].fd-table__expand--open:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl].fd-table__expand--open:before,[dir=rtl] .fd-table--group .fd-table__body .fd-table__cell .fd-table__expand.fd-table__expand--open:before,[dir=rtl] .fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand.fd-table__expand--open:before{content:\"\\e1e2\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand--open:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand--open:before{content:\"\\e1e2\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"]{-webkit-padding-start:2rem;padding-inline-start:2rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"]{-webkit-padding-start:3.5rem;padding-inline-start:3.5rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"]{-webkit-padding-start:11.25rem;padding-inline-start:11.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"]{-webkit-padding-start:11.75rem;padding-inline-start:11.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"]{-webkit-padding-start:12.25rem;padding-inline-start:12.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"]{-webkit-padding-start:12.75rem;padding-inline-start:12.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"]{-webkit-padding-start:0;padding-inline-start:0}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"]{-webkit-padding-start:1.5rem;padding-inline-start:1.5rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"]{-webkit-padding-start:2.25rem;padding-inline-start:2.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"]{-webkit-padding-start:3.25rem;padding-inline-start:3.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"]{-webkit-padding-start:3.75rem;padding-inline-start:3.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.cdk-visually-hidden{border:0;clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;width:1px;white-space:nowrap;outline:0;-webkit-appearance:none;-moz-appearance:none;left:0}[dir=rtl] .cdk-visually-hidden{left:auto;right:0}.fd-table__popover--custom{width:100%}.fd-table__cell--checkbox .fd-checkbox__label{margin:0}.fd-table__cell--focusable[aria-selected=true]:after{border-color:var(--sapContent_FocusColor)!important}.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-active{background-color:var(--sapList_HeaderBackground);color:var(--sapList_HeaderTextColor)}\n/*! Bundled license information:\n\nfundamental-styles/dist/table.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i1.ContentDensityObserver }] });

const FdTableContentDensityProviderParams = {
    supportedContentDensity: [ContentDensityMode.COMPACT, ContentDensityMode.CONDENSED, ContentDensityMode.COZY]
};
/**
 * The component that represents a table.
 * A table is a set of tabular data. Line items can support data, images and actions.
 * ```html
 * <table fd-table></table>
 * ```
 */
class TableComponent {
    /** Applies `focusable` to all cells within this table */
    set allCellsFocusable(value) {
        this._allCellsFocusable = value;
        this._updateCells();
    }
    get allCellsFocusable() {
        return this._allCellsFocusable;
    }
    /** @hidden */
    constructor(_tableService, _contentDensityObserver, _destroyRef, _ngZone) {
        this._tableService = _tableService;
        this._contentDensityObserver = _contentDensityObserver;
        this._destroyRef = _destroyRef;
        this._ngZone = _ngZone;
        /** @hidden */
        this.fdTableClass = true;
        /** Whether or not to show the table's horizontal borders */
        this.noBorderX = false;
        /** Whether or not to show the table's vertical borders */
        this.noBorderY = false;
        /** Whether or not to show the table's outer border */
        this.noOuterBorder = false;
        /** Whether or not to show the table's top border */
        this.topBorder = false;
        /** Whether or not to display the table in pop in mode, it also require change of markup */
        this.popIn = false;
        /** Whether or not to display the table in responsive mode. */
        this.responsive = false;
        /** @hidden */
        this._allCellsFocusable = false;
        this._contentDensityObserver.subscribe();
    }
    /** @hidden */
    ngAfterContentInit() {
        this._cells.changes
            .pipe(startWith$1(this._cells), takeUntilDestroyed(this._destroyRef))
            .subscribe(() => this._updateCells());
    }
    /** @hidden */
    ngAfterViewInit() {
        this._propagateKeys(this.keys);
    }
    /** Method that sorts and changes visible state of particular cells  */
    reset(keys) {
        this._propagateKeys(keys);
    }
    /** @hidden */
    _propagateKeys(keys) {
        if (keys) {
            this._tableService.changeKeys([...keys]);
        }
    }
    /** @hidden */
    _updateCells() {
        this._ngZone.onStable.pipe(first()).subscribe(() => {
            this._cells?.forEach((cell) => (cell.focusable = cell.focusable || this.allCellsFocusable));
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableComponent, deps: [{ token: TableService }, { token: i1.ContentDensityObserver }, { token: i0.DestroyRef }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "16.1.0", version: "20.0.2", type: TableComponent, isStandalone: true, selector: "table[fd-table]", inputs: { noBorderX: "noBorderX", noBorderY: "noBorderY", noOuterBorder: "noOuterBorder", topBorder: "topBorder", popIn: "popIn", responsive: "responsive", keys: "keys", allCellsFocusable: ["allCellsFocusable", "allCellsFocusable", booleanAttribute] }, host: { properties: { "class.fd-table": "this.fdTableClass", "class.fd-table--no-horizontal-borders": "this.noBorderX", "class.fd-table--no-vertical-borders": "this.noBorderY", "class.fd-table--no-outer-border": "this.noOuterBorder", "class.fd-table--top-border": "this.topBorder", "class.fd-table--pop-in": "this.popIn", "class.fd-table--responsive": "this.responsive" } }, providers: [TableService, contentDensityObserverProviders(FdTableContentDensityProviderParams)], queries: [{ propertyName: "_cells", predicate: TableCellDirective, descendants: true }], exportAs: ["fd-table"], hostDirectives: [{ directive: i3.FocusableGridDirective }], ngImport: i0, template: `<ng-content></ng-content>`, isInline: true, styles: [".fd-table{--fdTable_Header_Cell_Height:2.75rem;--fdTable_Cell_Height:2.75rem;border-bottom-left-radius:var(--fdTable_Border_Radius);border-bottom-right-radius:var(--fdTable_Border_Radius);border-collapse:separate;border-spacing:0;max-width:100%;width:100%}.fd-table,.fd-table__body,.fd-table__cell,.fd-table__footer,.fd-table__header,.fd-table__row,.fd-table__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-table:after,.fd-table:before,.fd-table__body:after,.fd-table__body:before,.fd-table__cell:after,.fd-table__cell:before,.fd-table__footer:after,.fd-table__footer:before,.fd-table__header:after,.fd-table__header:before,.fd-table__row:after,.fd-table__row:before,.fd-table__text:after,.fd-table__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-table__icon [class*=sap-icon],.fd-table__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);font-size:var(--sapFontSmallSize)}.fd-table__icon--navigation [class*=sap-icon],.fd-table__icon--navigation[class*=sap-icon]{font-size:var(--sapFontSmallSize);height:100%;min-width:2rem;width:2rem}.fd-table__icon--navigation [class*=sap-icon][dir=rtl],.fd-table__icon--navigation[class*=sap-icon][dir=rtl],[dir=rtl] .fd-table__icon--navigation [class*=sap-icon],[dir=rtl] .fd-table__icon--navigation[class*=sap-icon]{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.fd-table__header .fd-table__cell{background-color:var(--sapList_HeaderBackground);border-bottom:var(--fdTable_Header_Horizontal_Border);border-top:var(--fdTable_Header_Horizontal_Border);color:var(--sapList_HeaderTextColor);font-weight:var(--fdTable_Header_Cell_Font_Weight);height:var(--fdTable_Header_Cell_Height)}.fd-table__header .fd-table__cell.is-hover,.fd-table__header .fd-table__cell:hover{background-color:var(--fdTable_Header_Cell_Hover_Background);color:var(--fdTable_Header_Cell_Hover_Active_Color)}.fd-table__header .fd-table__cell.is-active,.fd-table__header .fd-table__cell:active{background-color:var(--fdTable_Header_Cell_Active_Background);color:var(--fdTable_Header_Cell_Hover_Active_Color)}.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:hover{background-color:var(--sapList_HeaderBackground);color:var(--sapList_HeaderTextColor)}.fd-table__header--non-interactive .fd-table__cell.is-active,.fd-table__header--non-interactive .fd-table__cell.is-hover,.fd-table__header--non-interactive .fd-table__cell:active,.fd-table__header--non-interactive .fd-table__cell:hover{background-color:var(--sapList_HeaderBackground)}.fd-table__text{overflow:hidden;text-overflow:ellipsis;text-shadow:var(--sapContent_TextShadow);white-space:nowrap;white-space:normal;word-break:break-word}.fd-table__text--no-wrap{white-space:nowrap}.fd-table__cell{border-bottom:var(--sapList_BorderWidth) var(--fdTable_Cell_Horizontal_Border_Style,solid) var(--sapList_BorderColor);border-left:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor);color:inherit;height:var(--fdTable_Cell_Height);outline:none;padding-block:0;padding-inline:.5rem;text-align:left}.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{border-left-style:none}.fd-table__cell.is-last-child,.fd-table__cell:last-child,.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{border-right:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor)}.fd-table__cell.is-last-child[dir=rtl],.fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table__cell.is-last-child,[dir=rtl] .fd-table__cell:last-child{border-left:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor);border-right-style:none}.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{text-align:right}.fd-table__cell--no-data{text-align:center}.fd-table__cell--mock{padding-block:0;padding-inline:0;width:auto}.fd-table__cell--checkbox{padding-block:0;padding-inline:0;vertical-align:baseline;width:var(--fdTable_Header_Cell_Height)}.fd-table__cell--fit-content{white-space:nowrap;width:.5rem;word-break:keep-all}.fd-table__cell--no-padding{padding-block:0;padding-inline:0}.fd-table__cell--status-indicator{padding-block:0;padding-inline:0;width:.375rem}.fd-table__cell--navigated{-webkit-box-shadow:inset -.1875rem 0 var(--sapSelectedColor);box-shadow:inset -.1875rem 0 var(--sapSelectedColor)}.fd-table__cell--navigated[dir=rtl],[dir=rtl] .fd-table__cell--navigated{-webkit-box-shadow:inset .1875rem 0 var(--sapSelectedColor);box-shadow:inset .1875rem 0 var(--sapSelectedColor)}.fd-table__cell:first-child:not(.fd-table__cell--checkbox,.fd-table__cell.fd-table__cell--status-indicator){-webkit-padding-start:1rem;padding-inline-start:1rem}.fd-table__row{background-color:var(--sapList_Background)}.fd-table__row.is-selected,.fd-table__row[aria-selected=true]{background-color:var(--sapList_SelectionBackgroundColor)}.fd-table__row.is-selected .fd-table__cell,.fd-table__row[aria-selected=true] .fd-table__cell{border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table__cell--hoverable.is-hover,.fd-table__cell--hoverable:hover,.fd-table__row--hoverable.is-hover,.fd-table__row--hoverable:hover{background-color:var(--sapList_Hover_Background);color:var(--fdTable_Hover_Down_Color)}.fd-table__cell--hoverable.is-selected.is-hover,.fd-table__cell--hoverable.is-selected:hover,.fd-table__cell--hoverable[aria-selected=true].is-hover,.fd-table__cell--hoverable[aria-selected=true]:hover,.fd-table__row--hoverable.is-selected.is-hover,.fd-table__row--hoverable.is-selected:hover,.fd-table__row--hoverable[aria-selected=true].is-hover,.fd-table__row--hoverable[aria-selected=true]:hover{background-color:var(--sapList_Hover_SelectionBackground)}.fd-table__cell--activable,.fd-table__cell--focusable,.fd-table__row--activable,.fd-table__row--focusable{position:relative}.fd-table__cell--activable.is-focus:after,.fd-table__cell--activable:focus:after,.fd-table__cell--focusable.is-focus:after,.fd-table__cell--focusable:focus:after,.fd-table__row--activable.is-focus:after,.fd-table__row--activable:focus:after,.fd-table__row--focusable.is-focus:after,.fd-table__row--focusable:focus:after{border-color:var(--sapContent_FocusColor);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:.0625rem;pointer-events:none;position:absolute}.fd-table__cell--activable:after,.fd-table__cell--focusable:after,.fd-table__row--activable:after,.fd-table__row--focusable:after{z-index:4}.fd-table__cell--activable,.fd-table__row--activable{cursor:pointer}.fd-table__cell--activable.is-active,.fd-table__cell--activable:active,.fd-table__row--activable.is-active,.fd-table__row--activable:active{background-color:var(--sapList_Active_Background);color:var(--sapList_Active_TextColor)}.fd-table__cell--activable.is-active *,.fd-table__cell--activable:active *,.fd-table__row--activable.is-active *,.fd-table__row--activable:active *{color:var(--sapList_Active_TextColor)!important}.fd-table__cell--activable.is-active .fd-table__cell.is-hover,.fd-table__cell--activable.is-active .fd-table__cell:hover,.fd-table__cell--activable:active .fd-table__cell.is-hover,.fd-table__cell--activable:active .fd-table__cell:hover,.fd-table__row--activable.is-active .fd-table__cell.is-hover,.fd-table__row--activable.is-active .fd-table__cell:hover,.fd-table__row--activable:active .fd-table__cell.is-hover,.fd-table__row--activable:active .fd-table__cell:hover{background-color:var(--sapList_Active_Background)}.fd-table__cell--activable.is-active .fd-table__text,.fd-table__cell--activable:active .fd-table__text,.fd-table__row--activable.is-active .fd-table__text,.fd-table__row--activable:active .fd-table__text{text-shadow:none}.fd-table__cell--activable.is-active .fd-table__icon [class*=sap-icon],.fd-table__cell--activable.is-active .fd-table__icon[class*=sap-icon],.fd-table__cell--activable:active .fd-table__icon [class*=sap-icon],.fd-table__cell--activable:active .fd-table__icon[class*=sap-icon],.fd-table__row--activable.is-active .fd-table__icon [class*=sap-icon],.fd-table__row--activable.is-active .fd-table__icon[class*=sap-icon],.fd-table__row--activable:active .fd-table__icon [class*=sap-icon],.fd-table__row--activable:active .fd-table__icon[class*=sap-icon]{color:var(--sapContent_ContrastIconColor)}.fd-table__cell--activable.is-active .fd-form-label,.fd-table__cell--activable.is-active .fd-link,.fd-table__cell--activable.is-active .fd-object-status,.fd-table__cell--activable:active .fd-form-label,.fd-table__cell--activable:active .fd-link,.fd-table__cell--activable:active .fd-object-status,.fd-table__row--activable.is-active .fd-form-label,.fd-table__row--activable.is-active .fd-link,.fd-table__row--activable.is-active .fd-object-status,.fd-table__row--activable:active .fd-form-label,.fd-table__row--activable:active .fd-link,.fd-table__row--activable:active .fd-object-status{color:inherit}.fd-table__cell--activable.is-selected.is-active,.fd-table__cell--activable.is-selected:active,.fd-table__cell--activable[aria-selected=true].is-active,.fd-table__cell--activable[aria-selected=true]:active,.fd-table__row--activable.is-selected.is-active,.fd-table__row--activable.is-selected:active,.fd-table__row--activable[aria-selected=true].is-active,.fd-table__row--activable[aria-selected=true]:active{background-color:var(--sapList_Active_Background)}.fd-table__cell--activable.is-selected.is-active .fd-table__cell,.fd-table__cell--activable.is-selected:active .fd-table__cell,.fd-table__cell--activable[aria-selected=true].is-active .fd-table__cell,.fd-table__cell--activable[aria-selected=true]:active .fd-table__cell,.fd-table__row--activable.is-selected.is-active .fd-table__cell,.fd-table__row--activable.is-selected:active .fd-table__cell,.fd-table__row--activable[aria-selected=true].is-active .fd-table__cell,.fd-table__row--activable[aria-selected=true]:active .fd-table__cell{border-bottom-color:var(--sapList_Active_Background)}.fd-table__body:not(:last-child) .fd-table__row:last-child .fd-table__cell{border-bottom-color:transparent}.fd-table__footer .fd-table__row{background-color:var(--sapList_Background);vertical-align:middle}.fd-table__footer .fd-table__cell{border-bottom-color:transparent;border-left-color:transparent;border-right-color:transparent;border-top:.125rem solid var(--sapList_TableFooterBorder);font-weight:700}.fd-table__inner{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-table__inner:after,.fd-table__inner:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-table__column-header-icons{display:-webkit-box;display:-ms-flexbox;display:flex}.fd-table__column-header-icons .fd-table__icon:not(:last-child){-webkit-margin-end:.25rem;margin-inline-end:.25rem}.fd-table__caption{position:absolute;clip:rect(0 0 0 0);border:0;height:1px;margin-block:-1px;margin-inline:-1px;overflow:hidden;padding-block:0;padding-inline:0;white-space:nowrap;width:1px}.fd-table__item--clickable{cursor:pointer}.fd-table__popover.fd-popover{color:inherit;display:block;height:100%}.fd-table__popover.fd-popover .fd-popover__control{color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;height:100%;width:100%;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-table[class*=-compact],[class*=-compact] .fd-table:not([class*=-cozy],[class*=-condensed]){--fdTable_Cell_Height:2rem}.fd-table[class*=-condensed],[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]){--fdTable_Cell_Height:1.5rem}.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--checkbox .fd-table__checkbox-label,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--checkbox .fd-table__checkbox-label,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--checkbox .fd-table__checkbox-label,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--checkbox .fd-table__checkbox-label{margin-top:-.25rem;position:absolute}.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--activable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--focusable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__row--activable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__row--focusable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--activable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--focusable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__row--activable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__row--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__row--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__row--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__row--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__row--focusable:after{inset:var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset)}.fd-table[class*=-compact],.fd-table[class*=-condensed],[class*=-compact] .fd-table:not([class*=-cozy]),[class*=-condensed] .fd-table:not([class*=-cozy]){--fdTable_Header_Cell_Height:2rem}.fd-table--hidden{display:none}.fd-table--fixed{overflow:auto;scrollbar-color:var(--fdScrollbar_Thumb_Color) var(--fdScrollbar_Track_Color)}.fd-table--fixed.is-focus,.fd-table--fixed:focus{outline:none;z-index:5}.fd-table--fixed::-webkit-scrollbar{height:var(--fdScrollbar_Dimension);width:var(--fdScrollbar_Dimension)}.fd-table--fixed::-webkit-scrollbar-corner,.fd-table--fixed::-webkit-scrollbar-track{background-color:var(--fdScrollbar_Track_Color)}.fd-table--fixed::-webkit-scrollbar-thumb{background-color:transparent;border:var(--fdScrollbar_Thumb_Offset) solid transparent;border-radius:calc(var(--fdScrollbar_Thumb_Border_Radius) - var(--fdScrollbar_Thumb_Offset));-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color)}.fd-table--fixed::-webkit-scrollbar-thumb:active,.fd-table--fixed::-webkit-scrollbar-thumb:hover{-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color)}.fd-table--fixed .fd-table__cell--fixed{left:0}.fd-table--fixed .fd-table__cell--fixed[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed{left:auto;right:0}.fd-table--fixed .fd-table__cell--fixed,.fd-table--fixed .fd-table__cell--fixed-end{background-color:inherit;display:table-cell;position:sticky;z-index:1}.fd-table--fixed .fd-table__cell--fixed-last{border-right:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__cell--fixed-last+.fd-table__cell{border-left:none}.fd-table--fixed .fd-table__cell--fixed-last[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-last{border-left:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor);border-right:var(--sapList_BorderWidth) solid var(--sapList_BorderColor)}.fd-table--fixed .fd-table__cell--fixed-last[dir=rtl]+.fd-table__cell,[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-last+.fd-table__cell{border-right:none}.fd-table--fixed .fd-table__cell--fixed-end{right:0}.fd-table--fixed .fd-table__cell--fixed-end[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-end{left:0;right:auto}.fd-table--fixed .fd-table__cell--fixed-end-last{border-left:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__cell--fixed-end-last[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-end-last{border-right:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__header .fd-table__cell{position:sticky;top:0;z-index:2}.fd-table--fixed .fd-table__header .fd-table__cell--fixed,.fd-table--fixed .fd-table__header .fd-table__cell--fixed-end{z-index:3}.fd-table--fixed .fd-table__footer .fd-table__cell{background-color:inherit;bottom:0;position:sticky;z-index:2}.fd-table .fd-table__cell--valid{color:var(--sapSuccessColor)}.fd-table .fd-table__cell--status-indicator--valid{background-color:var(--sapSuccessBorderColor)}.fd-table .fd-table__cell--warning{color:var(--sapWarningColor)}.fd-table .fd-table__cell--status-indicator--warning{background-color:var(--sapWarningBorderColor)}.fd-table .fd-table__cell--error{color:var(--sapErrorColor)}.fd-table .fd-table__cell--status-indicator--error{background-color:var(--sapErrorBorderColor)}.fd-table .fd-table__cell--information{color:var(--sapInformationColor)}.fd-table .fd-table__cell--status-indicator--information{background-color:var(--sapInformationBorderColor)}.fd-table--pop-in .fd-table__text{color:inherit;-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-table--pop-in .fd-table__text--title{font-weight:700}.fd-table--pop-in .fd-table__text.is-last-child,.fd-table--pop-in .fd-table__text:last-child{-webkit-margin-after:0;margin-block-end:0}.fd-table--pop-in .fd-table__cell--checkbox+.fd-table__cell{-webkit-padding-start:0;padding-inline-start:0}.fd-table--pop-in .fd-table__body .fd-table__cell{height:auto}.fd-table--pop-in .fd-table__row--main,.fd-table--pop-in .fd-table__row--secondary{border-left-color:transparent;border-right-color:transparent}.fd-table--pop-in .fd-table__row--main .fd-table__cell{border-bottom-color:transparent;padding-block:.25rem}.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable:hover+.fd-table__row--secondary{background-color:var(--sapList_Hover_Background)}.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-selected.is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-selected:hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable[aria-selected=true].is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable[aria-selected=true]:hover+.fd-table__row--secondary{background-color:var(--sapList_Hover_SelectionBackground)}.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-active .fd-table__cell,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable:active .fd-table__cell{border-bottom-color:transparent}.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-selected.is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-selected:active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable:active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable[aria-selected=true].is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable[aria-selected=true]:active+.fd-table__row--secondary{background-color:var(--sapList_Active_Background);border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table--pop-in .fd-table__row--main.is-selected .fd-table__cell,.fd-table--pop-in .fd-table__row--main[aria-selected=true] .fd-table__cell{border-bottom-color:transparent}.fd-table--pop-in .fd-table__row--main.is-selected+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main[aria-selected=true]+.fd-table__row--secondary{background-color:var(--sapList_SelectionBackgroundColor);border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table--pop-in .fd-table__row--secondary .fd-table__cell{padding-block:.5rem}.fd-table--pop-in .fd-table__row--secondary.is-active,.fd-table--pop-in .fd-table__row--secondary.is-hover,.fd-table--pop-in .fd-table__row--secondary:active,.fd-table--pop-in .fd-table__row--secondary:hover{background-color:var(--sapList_Background)}.fd-table--no-vertical-borders .fd-table__cell,.fd-table__body--no-vertical-borders .fd-table__cell,.fd-table__header--no-vertical-borders .fd-table__cell{--fdTable_Cell_Vertical_Border_Style:none}.fd-table--no-vertical-borders .fd-table__cell[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell{border-left-color:var(--sapList_BorderColor)}.fd-table--no-vertical-borders .fd-table__cell.is-first-child,.fd-table--no-vertical-borders .fd-table__cell:first-child,.fd-table__body--no-vertical-borders .fd-table__cell.is-first-child,.fd-table__body--no-vertical-borders .fd-table__cell:first-child,.fd-table__header--no-vertical-borders .fd-table__cell.is-first-child,.fd-table__header--no-vertical-borders .fd-table__cell:first-child{border-left-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table--no-vertical-borders .fd-table__cell:first-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell:first-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell:first-child[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell:first-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell:first-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell:first-child{border-left-style:none;border-right-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--no-vertical-borders .fd-table__cell:last-child,.fd-table__body--no-vertical-borders .fd-table__cell.is-last-child,.fd-table__body--no-vertical-borders .fd-table__cell:last-child,.fd-table__header--no-vertical-borders .fd-table__cell.is-last-child,.fd-table__header--no-vertical-borders .fd-table__cell:last-child{border-right-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-vertical-borders .fd-table__cell:last-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell:last-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell:last-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell:last-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell:last-child{border-left-style:solid;border-right-style:none}.fd-table--no-horizontal-borders .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__cell{border-bottom-color:transparent}.fd-table--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table--no-horizontal-borders .fd-table__row:last-child .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__row:last-child .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__row:last-child .fd-table__cell{border-bottom-color:var(--sapList_BorderColor)}.fd-table .fd-table__cell--no-vertical-border+.fd-table__cell{border-left-style:none}.fd-table .fd-table__cell--no-vertical-border[dir=rtl],[dir=rtl] .fd-table .fd-table__cell--no-vertical-border{border-right-style:none}.fd-table .fd-table__cell--no-horizontal-border{border-bottom-color:transparent}.fd-table--no-outer-border:not(.fd-table--top-border) .fd-table__header .fd-table__cell,.fd-table--responsive:not(.fd-table--top-border) .fd-table__header .fd-table__cell{border-top-color:transparent}.fd-table--no-outer-border .fd-table__body .fd-table__row.is-last-child .fd-table__cell,.fd-table--no-outer-border .fd-table__body .fd-table__row:last-child .fd-table__cell,.fd-table--responsive .fd-table__body .fd-table__row.is-last-child .fd-table__cell,.fd-table--responsive .fd-table__body .fd-table__row:last-child .fd-table__cell{border-bottom-color:transparent}.fd-table--no-outer-border .fd-table__cell.is-first-child,.fd-table--no-outer-border .fd-table__cell.is-last-child,.fd-table--no-outer-border .fd-table__cell:first-child,.fd-table--no-outer-border .fd-table__cell:last-child,.fd-table--responsive .fd-table__cell.is-first-child,.fd-table--responsive .fd-table__cell.is-last-child,.fd-table--responsive .fd-table__cell:first-child,.fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:solid}.fd-table--no-outer-border .fd-table__cell.is-first-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:first-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:last-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-first-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-last-child[dir=rtl],.fd-table--responsive .fd-table__cell:first-child[dir=rtl],.fd-table--responsive .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-first-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:first-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:last-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-first-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-last-child,[dir=rtl] .fd-table--responsive .fd-table__cell:first-child,[dir=rtl] .fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:none}.fd-table--no-outer-border .fd-table__cell.is-last-child,.fd-table--no-outer-border .fd-table__cell:last-child,.fd-table--responsive .fd-table__cell.is-last-child,.fd-table--responsive .fd-table__cell:last-child{border-left-style:solid;border-right-style:none}.fd-table--no-outer-border .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:last-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-last-child[dir=rtl],.fd-table--responsive .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:last-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-last-child,[dir=rtl] .fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:solid}.fd-table--no-outer-border.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--no-outer-border.fd-table--no-vertical-borders .fd-table__cell:last-child,.fd-table--responsive.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--responsive.fd-table--no-vertical-borders .fd-table__cell:last-child{border-left-style:none;border-right-style:none}.fd-table--group .fd-table__cell--group{background-color:var(--fdTable_Group_Header_Background);border-bottom-color:var(--sapList_TableGroupHeaderBorderColor);font-weight:var(--fdTable_Header_Cell_Font_Weight)}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"]{-webkit-padding-start:5rem;padding-inline-start:5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"]{-webkit-padding-start:5.5rem;padding-inline-start:5.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"]{-webkit-padding-start:6rem;padding-inline-start:6rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"]{-webkit-padding-start:6.5rem;padding-inline-start:6.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"]{-webkit-padding-start:7rem;padding-inline-start:7rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"]{-webkit-padding-start:7.5rem;padding-inline-start:7.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"]{-webkit-padding-start:8rem;padding-inline-start:8rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"]{-webkit-padding-start:8.5rem;padding-inline-start:8.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"]{-webkit-padding-start:9rem;padding-inline-start:9rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"]{-webkit-padding-start:9.5rem;padding-inline-start:9.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"]{-webkit-padding-start:10rem;padding-inline-start:10rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"]{-webkit-padding-start:10.5rem;padding-inline-start:10.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"]{-webkit-padding-start:11rem;padding-inline-start:11rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"]{-webkit-padding-start:11.5rem;padding-inline-start:11.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"]{-webkit-padding-start:12rem;padding-inline-start:12rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"]{-webkit-padding-start:12.5rem;padding-inline-start:12.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"]{-webkit-padding-start:13rem;padding-inline-start:13rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"]{-webkit-padding-start:13.5rem;padding-inline-start:13.5rem}.fd-table--group .fd-table__body .fd-table__cell--expand,.fd-table--tree .fd-table__body .fd-table__cell--expand{cursor:pointer;white-space:nowrap}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"]{-webkit-padding-start:0;padding-inline-start:0}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"]{-webkit-padding-start:1.5rem;padding-inline-start:1.5rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"]{-webkit-padding-start:2.25rem;padding-inline-start:2.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"]{-webkit-padding-start:3.25rem;padding-inline-start:3.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"]{-webkit-padding-start:3.75rem;padding-inline-start:3.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand{color:var(--sapContent_IconColor);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-size:var(--sapFontSmallSize);height:var(--fdTable_Cell_Height);min-width:var(--fdTable_Header_Cell_Height);-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand:before{content:\"\\e066\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl]:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl]:before,[dir=rtl] .fd-table--group .fd-table__body .fd-table__cell .fd-table__expand:before,[dir=rtl] .fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand:before{content:\"\\e067\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl].fd-table__expand--open:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl].fd-table__expand--open:before,[dir=rtl] .fd-table--group .fd-table__body .fd-table__cell .fd-table__expand.fd-table__expand--open:before,[dir=rtl] .fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand.fd-table__expand--open:before{content:\"\\e1e2\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand--open:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand--open:before{content:\"\\e1e2\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"]{-webkit-padding-start:2rem;padding-inline-start:2rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"]{-webkit-padding-start:3.5rem;padding-inline-start:3.5rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"]{-webkit-padding-start:11.25rem;padding-inline-start:11.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"]{-webkit-padding-start:11.75rem;padding-inline-start:11.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"]{-webkit-padding-start:12.25rem;padding-inline-start:12.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"]{-webkit-padding-start:12.75rem;padding-inline-start:12.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"]{-webkit-padding-start:0;padding-inline-start:0}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"]{-webkit-padding-start:1.5rem;padding-inline-start:1.5rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"]{-webkit-padding-start:2.25rem;padding-inline-start:2.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"]{-webkit-padding-start:3.25rem;padding-inline-start:3.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"]{-webkit-padding-start:3.75rem;padding-inline-start:3.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.cdk-visually-hidden{border:0;clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;width:1px;white-space:nowrap;outline:0;-webkit-appearance:none;-moz-appearance:none;left:0}[dir=rtl] .cdk-visually-hidden{left:auto;right:0}.fd-table__popover--custom{width:100%}.fd-table__cell--checkbox .fd-checkbox__label{margin:0}.fd-table__cell--focusable[aria-selected=true]:after{border-color:var(--sapContent_FocusColor)!important}.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-active{background-color:var(--sapList_HeaderBackground);color:var(--sapList_HeaderTextColor)}\n/*! Bundled license information:\n\nfundamental-styles/dist/table.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'table[fd-table]', exportAs: 'fd-table', template: `<ng-content></ng-content>`, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [TableService, contentDensityObserverProviders(FdTableContentDensityProviderParams)], hostDirectives: [FocusableGridDirective], standalone: true, styles: [".fd-table{--fdTable_Header_Cell_Height:2.75rem;--fdTable_Cell_Height:2.75rem;border-bottom-left-radius:var(--fdTable_Border_Radius);border-bottom-right-radius:var(--fdTable_Border_Radius);border-collapse:separate;border-spacing:0;max-width:100%;width:100%}.fd-table,.fd-table__body,.fd-table__cell,.fd-table__footer,.fd-table__header,.fd-table__row,.fd-table__text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-table:after,.fd-table:before,.fd-table__body:after,.fd-table__body:before,.fd-table__cell:after,.fd-table__cell:before,.fd-table__footer:after,.fd-table__footer:before,.fd-table__header:after,.fd-table__header:before,.fd-table__row:after,.fd-table__row:before,.fd-table__text:after,.fd-table__text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-table__icon [class*=sap-icon],.fd-table__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);font-size:var(--sapFontSmallSize)}.fd-table__icon--navigation [class*=sap-icon],.fd-table__icon--navigation[class*=sap-icon]{font-size:var(--sapFontSmallSize);height:100%;min-width:2rem;width:2rem}.fd-table__icon--navigation [class*=sap-icon][dir=rtl],.fd-table__icon--navigation[class*=sap-icon][dir=rtl],[dir=rtl] .fd-table__icon--navigation [class*=sap-icon],[dir=rtl] .fd-table__icon--navigation[class*=sap-icon]{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.fd-table__header .fd-table__cell{background-color:var(--sapList_HeaderBackground);border-bottom:var(--fdTable_Header_Horizontal_Border);border-top:var(--fdTable_Header_Horizontal_Border);color:var(--sapList_HeaderTextColor);font-weight:var(--fdTable_Header_Cell_Font_Weight);height:var(--fdTable_Header_Cell_Height)}.fd-table__header .fd-table__cell.is-hover,.fd-table__header .fd-table__cell:hover{background-color:var(--fdTable_Header_Cell_Hover_Background);color:var(--fdTable_Header_Cell_Hover_Active_Color)}.fd-table__header .fd-table__cell.is-active,.fd-table__header .fd-table__cell:active{background-color:var(--fdTable_Header_Cell_Active_Background);color:var(--fdTable_Header_Cell_Hover_Active_Color)}.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:hover{background-color:var(--sapList_HeaderBackground);color:var(--sapList_HeaderTextColor)}.fd-table__header--non-interactive .fd-table__cell.is-active,.fd-table__header--non-interactive .fd-table__cell.is-hover,.fd-table__header--non-interactive .fd-table__cell:active,.fd-table__header--non-interactive .fd-table__cell:hover{background-color:var(--sapList_HeaderBackground)}.fd-table__text{overflow:hidden;text-overflow:ellipsis;text-shadow:var(--sapContent_TextShadow);white-space:nowrap;white-space:normal;word-break:break-word}.fd-table__text--no-wrap{white-space:nowrap}.fd-table__cell{border-bottom:var(--sapList_BorderWidth) var(--fdTable_Cell_Horizontal_Border_Style,solid) var(--sapList_BorderColor);border-left:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor);color:inherit;height:var(--fdTable_Cell_Height);outline:none;padding-block:0;padding-inline:.5rem;text-align:left}.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{border-left-style:none}.fd-table__cell.is-last-child,.fd-table__cell:last-child,.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{border-right:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor)}.fd-table__cell.is-last-child[dir=rtl],.fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table__cell.is-last-child,[dir=rtl] .fd-table__cell:last-child{border-left:var(--sapList_BorderWidth) var(--fdTable_Cell_Vertical_Border_Style,solid) var(--sapList_BorderColor);border-right-style:none}.fd-table__cell[dir=rtl],[dir=rtl] .fd-table__cell{text-align:right}.fd-table__cell--no-data{text-align:center}.fd-table__cell--mock{padding-block:0;padding-inline:0;width:auto}.fd-table__cell--checkbox{padding-block:0;padding-inline:0;vertical-align:baseline;width:var(--fdTable_Header_Cell_Height)}.fd-table__cell--fit-content{white-space:nowrap;width:.5rem;word-break:keep-all}.fd-table__cell--no-padding{padding-block:0;padding-inline:0}.fd-table__cell--status-indicator{padding-block:0;padding-inline:0;width:.375rem}.fd-table__cell--navigated{-webkit-box-shadow:inset -.1875rem 0 var(--sapSelectedColor);box-shadow:inset -.1875rem 0 var(--sapSelectedColor)}.fd-table__cell--navigated[dir=rtl],[dir=rtl] .fd-table__cell--navigated{-webkit-box-shadow:inset .1875rem 0 var(--sapSelectedColor);box-shadow:inset .1875rem 0 var(--sapSelectedColor)}.fd-table__cell:first-child:not(.fd-table__cell--checkbox,.fd-table__cell.fd-table__cell--status-indicator){-webkit-padding-start:1rem;padding-inline-start:1rem}.fd-table__row{background-color:var(--sapList_Background)}.fd-table__row.is-selected,.fd-table__row[aria-selected=true]{background-color:var(--sapList_SelectionBackgroundColor)}.fd-table__row.is-selected .fd-table__cell,.fd-table__row[aria-selected=true] .fd-table__cell{border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table__cell--hoverable.is-hover,.fd-table__cell--hoverable:hover,.fd-table__row--hoverable.is-hover,.fd-table__row--hoverable:hover{background-color:var(--sapList_Hover_Background);color:var(--fdTable_Hover_Down_Color)}.fd-table__cell--hoverable.is-selected.is-hover,.fd-table__cell--hoverable.is-selected:hover,.fd-table__cell--hoverable[aria-selected=true].is-hover,.fd-table__cell--hoverable[aria-selected=true]:hover,.fd-table__row--hoverable.is-selected.is-hover,.fd-table__row--hoverable.is-selected:hover,.fd-table__row--hoverable[aria-selected=true].is-hover,.fd-table__row--hoverable[aria-selected=true]:hover{background-color:var(--sapList_Hover_SelectionBackground)}.fd-table__cell--activable,.fd-table__cell--focusable,.fd-table__row--activable,.fd-table__row--focusable{position:relative}.fd-table__cell--activable.is-focus:after,.fd-table__cell--activable:focus:after,.fd-table__cell--focusable.is-focus:after,.fd-table__cell--focusable:focus:after,.fd-table__row--activable.is-focus:after,.fd-table__row--activable:focus:after,.fd-table__row--focusable.is-focus:after,.fd-table__row--focusable:focus:after{border-color:var(--sapContent_FocusColor);border-style:var(--sapContent_FocusStyle);border-width:var(--sapContent_FocusWidth);content:\"\";inset:.0625rem;pointer-events:none;position:absolute}.fd-table__cell--activable:after,.fd-table__cell--focusable:after,.fd-table__row--activable:after,.fd-table__row--focusable:after{z-index:4}.fd-table__cell--activable,.fd-table__row--activable{cursor:pointer}.fd-table__cell--activable.is-active,.fd-table__cell--activable:active,.fd-table__row--activable.is-active,.fd-table__row--activable:active{background-color:var(--sapList_Active_Background);color:var(--sapList_Active_TextColor)}.fd-table__cell--activable.is-active *,.fd-table__cell--activable:active *,.fd-table__row--activable.is-active *,.fd-table__row--activable:active *{color:var(--sapList_Active_TextColor)!important}.fd-table__cell--activable.is-active .fd-table__cell.is-hover,.fd-table__cell--activable.is-active .fd-table__cell:hover,.fd-table__cell--activable:active .fd-table__cell.is-hover,.fd-table__cell--activable:active .fd-table__cell:hover,.fd-table__row--activable.is-active .fd-table__cell.is-hover,.fd-table__row--activable.is-active .fd-table__cell:hover,.fd-table__row--activable:active .fd-table__cell.is-hover,.fd-table__row--activable:active .fd-table__cell:hover{background-color:var(--sapList_Active_Background)}.fd-table__cell--activable.is-active .fd-table__text,.fd-table__cell--activable:active .fd-table__text,.fd-table__row--activable.is-active .fd-table__text,.fd-table__row--activable:active .fd-table__text{text-shadow:none}.fd-table__cell--activable.is-active .fd-table__icon [class*=sap-icon],.fd-table__cell--activable.is-active .fd-table__icon[class*=sap-icon],.fd-table__cell--activable:active .fd-table__icon [class*=sap-icon],.fd-table__cell--activable:active .fd-table__icon[class*=sap-icon],.fd-table__row--activable.is-active .fd-table__icon [class*=sap-icon],.fd-table__row--activable.is-active .fd-table__icon[class*=sap-icon],.fd-table__row--activable:active .fd-table__icon [class*=sap-icon],.fd-table__row--activable:active .fd-table__icon[class*=sap-icon]{color:var(--sapContent_ContrastIconColor)}.fd-table__cell--activable.is-active .fd-form-label,.fd-table__cell--activable.is-active .fd-link,.fd-table__cell--activable.is-active .fd-object-status,.fd-table__cell--activable:active .fd-form-label,.fd-table__cell--activable:active .fd-link,.fd-table__cell--activable:active .fd-object-status,.fd-table__row--activable.is-active .fd-form-label,.fd-table__row--activable.is-active .fd-link,.fd-table__row--activable.is-active .fd-object-status,.fd-table__row--activable:active .fd-form-label,.fd-table__row--activable:active .fd-link,.fd-table__row--activable:active .fd-object-status{color:inherit}.fd-table__cell--activable.is-selected.is-active,.fd-table__cell--activable.is-selected:active,.fd-table__cell--activable[aria-selected=true].is-active,.fd-table__cell--activable[aria-selected=true]:active,.fd-table__row--activable.is-selected.is-active,.fd-table__row--activable.is-selected:active,.fd-table__row--activable[aria-selected=true].is-active,.fd-table__row--activable[aria-selected=true]:active{background-color:var(--sapList_Active_Background)}.fd-table__cell--activable.is-selected.is-active .fd-table__cell,.fd-table__cell--activable.is-selected:active .fd-table__cell,.fd-table__cell--activable[aria-selected=true].is-active .fd-table__cell,.fd-table__cell--activable[aria-selected=true]:active .fd-table__cell,.fd-table__row--activable.is-selected.is-active .fd-table__cell,.fd-table__row--activable.is-selected:active .fd-table__cell,.fd-table__row--activable[aria-selected=true].is-active .fd-table__cell,.fd-table__row--activable[aria-selected=true]:active .fd-table__cell{border-bottom-color:var(--sapList_Active_Background)}.fd-table__body:not(:last-child) .fd-table__row:last-child .fd-table__cell{border-bottom-color:transparent}.fd-table__footer .fd-table__row{background-color:var(--sapList_Background);vertical-align:middle}.fd-table__footer .fd-table__cell{border-bottom-color:transparent;border-left-color:transparent;border-right-color:transparent;border-top:.125rem solid var(--sapList_TableFooterBorder);font-weight:700}.fd-table__inner{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;width:100%;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-table__inner:after,.fd-table__inner:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-table__column-header-icons{display:-webkit-box;display:-ms-flexbox;display:flex}.fd-table__column-header-icons .fd-table__icon:not(:last-child){-webkit-margin-end:.25rem;margin-inline-end:.25rem}.fd-table__caption{position:absolute;clip:rect(0 0 0 0);border:0;height:1px;margin-block:-1px;margin-inline:-1px;overflow:hidden;padding-block:0;padding-inline:0;white-space:nowrap;width:1px}.fd-table__item--clickable{cursor:pointer}.fd-table__popover.fd-popover{color:inherit;display:block;height:100%}.fd-table__popover.fd-popover .fd-popover__control{color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;height:100%;width:100%;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-table[class*=-compact],[class*=-compact] .fd-table:not([class*=-cozy],[class*=-condensed]){--fdTable_Cell_Height:2rem}.fd-table[class*=-condensed],[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]){--fdTable_Cell_Height:1.5rem}.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--checkbox .fd-table__checkbox-label,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--checkbox .fd-table__checkbox-label,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--checkbox .fd-table__checkbox-label,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--checkbox .fd-table__checkbox-label{margin-top:-.25rem;position:absolute}.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--activable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__cell--focusable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__row--activable:after,.fd-table[class*=-condensed] .fd-table__body .fd-table__row--focusable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--activable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__cell--focusable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__row--activable:after,.fd-table[class*=-condensed] .fd-table__footer .fd-table__row--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__cell--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__row--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__body .fd-table__row--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__cell--focusable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__row--activable:after,[class*=-condensed] .fd-table:not([class*=-cozy],[class*=-compact]) .fd-table__footer .fd-table__row--focusable:after{inset:var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset) var(--fdTable_Condensed_Focus_Outline_Offset)}.fd-table[class*=-compact],.fd-table[class*=-condensed],[class*=-compact] .fd-table:not([class*=-cozy]),[class*=-condensed] .fd-table:not([class*=-cozy]){--fdTable_Header_Cell_Height:2rem}.fd-table--hidden{display:none}.fd-table--fixed{overflow:auto;scrollbar-color:var(--fdScrollbar_Thumb_Color) var(--fdScrollbar_Track_Color)}.fd-table--fixed.is-focus,.fd-table--fixed:focus{outline:none;z-index:5}.fd-table--fixed::-webkit-scrollbar{height:var(--fdScrollbar_Dimension);width:var(--fdScrollbar_Dimension)}.fd-table--fixed::-webkit-scrollbar-corner,.fd-table--fixed::-webkit-scrollbar-track{background-color:var(--fdScrollbar_Track_Color)}.fd-table--fixed::-webkit-scrollbar-thumb{background-color:transparent;border:var(--fdScrollbar_Thumb_Offset) solid transparent;border-radius:calc(var(--fdScrollbar_Thumb_Border_Radius) - var(--fdScrollbar_Thumb_Offset));-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Color)}.fd-table--fixed::-webkit-scrollbar-thumb:active,.fd-table--fixed::-webkit-scrollbar-thumb:hover{-webkit-box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color);box-shadow:inset 0 0 0 var(--fdScrollbar_Dimension) var(--fdScrollbar_Thumb_Hover_Color)}.fd-table--fixed .fd-table__cell--fixed{left:0}.fd-table--fixed .fd-table__cell--fixed[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed{left:auto;right:0}.fd-table--fixed .fd-table__cell--fixed,.fd-table--fixed .fd-table__cell--fixed-end{background-color:inherit;display:table-cell;position:sticky;z-index:1}.fd-table--fixed .fd-table__cell--fixed-last{border-right:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__cell--fixed-last+.fd-table__cell{border-left:none}.fd-table--fixed .fd-table__cell--fixed-last[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-last{border-left:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor);border-right:var(--sapList_BorderWidth) solid var(--sapList_BorderColor)}.fd-table--fixed .fd-table__cell--fixed-last[dir=rtl]+.fd-table__cell,[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-last+.fd-table__cell{border-right:none}.fd-table--fixed .fd-table__cell--fixed-end{right:0}.fd-table--fixed .fd-table__cell--fixed-end[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-end{left:0;right:auto}.fd-table--fixed .fd-table__cell--fixed-end-last{border-left:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__cell--fixed-end-last[dir=rtl],[dir=rtl] .fd-table--fixed .fd-table__cell--fixed-end-last{border-right:var(--sapList_BorderWidth) solid var(--sapList_TableFixedBorderColor)}.fd-table--fixed .fd-table__header .fd-table__cell{position:sticky;top:0;z-index:2}.fd-table--fixed .fd-table__header .fd-table__cell--fixed,.fd-table--fixed .fd-table__header .fd-table__cell--fixed-end{z-index:3}.fd-table--fixed .fd-table__footer .fd-table__cell{background-color:inherit;bottom:0;position:sticky;z-index:2}.fd-table .fd-table__cell--valid{color:var(--sapSuccessColor)}.fd-table .fd-table__cell--status-indicator--valid{background-color:var(--sapSuccessBorderColor)}.fd-table .fd-table__cell--warning{color:var(--sapWarningColor)}.fd-table .fd-table__cell--status-indicator--warning{background-color:var(--sapWarningBorderColor)}.fd-table .fd-table__cell--error{color:var(--sapErrorColor)}.fd-table .fd-table__cell--status-indicator--error{background-color:var(--sapErrorBorderColor)}.fd-table .fd-table__cell--information{color:var(--sapInformationColor)}.fd-table .fd-table__cell--status-indicator--information{background-color:var(--sapInformationBorderColor)}.fd-table--pop-in .fd-table__text{color:inherit;-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-table--pop-in .fd-table__text--title{font-weight:700}.fd-table--pop-in .fd-table__text.is-last-child,.fd-table--pop-in .fd-table__text:last-child{-webkit-margin-after:0;margin-block-end:0}.fd-table--pop-in .fd-table__cell--checkbox+.fd-table__cell{-webkit-padding-start:0;padding-inline-start:0}.fd-table--pop-in .fd-table__body .fd-table__cell{height:auto}.fd-table--pop-in .fd-table__row--main,.fd-table--pop-in .fd-table__row--secondary{border-left-color:transparent;border-right-color:transparent}.fd-table--pop-in .fd-table__row--main .fd-table__cell{border-bottom-color:transparent;padding-block:.25rem}.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable:hover+.fd-table__row--secondary{background-color:var(--sapList_Hover_Background)}.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-selected.is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable.is-selected:hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable[aria-selected=true].is-hover+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--hoverable[aria-selected=true]:hover+.fd-table__row--secondary{background-color:var(--sapList_Hover_SelectionBackground)}.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-active .fd-table__cell,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable:active .fd-table__cell{border-bottom-color:transparent}.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-selected.is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable.is-selected:active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable:active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable[aria-selected=true].is-active+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main.fd-table__row--activable[aria-selected=true]:active+.fd-table__row--secondary{background-color:var(--sapList_Active_Background);border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table--pop-in .fd-table__row--main.is-selected .fd-table__cell,.fd-table--pop-in .fd-table__row--main[aria-selected=true] .fd-table__cell{border-bottom-color:transparent}.fd-table--pop-in .fd-table__row--main.is-selected+.fd-table__row--secondary,.fd-table--pop-in .fd-table__row--main[aria-selected=true]+.fd-table__row--secondary{background-color:var(--sapList_SelectionBackgroundColor);border-bottom-color:var(--sapList_SelectionBorderColor)}.fd-table--pop-in .fd-table__row--secondary .fd-table__cell{padding-block:.5rem}.fd-table--pop-in .fd-table__row--secondary.is-active,.fd-table--pop-in .fd-table__row--secondary.is-hover,.fd-table--pop-in .fd-table__row--secondary:active,.fd-table--pop-in .fd-table__row--secondary:hover{background-color:var(--sapList_Background)}.fd-table--no-vertical-borders .fd-table__cell,.fd-table__body--no-vertical-borders .fd-table__cell,.fd-table__header--no-vertical-borders .fd-table__cell{--fdTable_Cell_Vertical_Border_Style:none}.fd-table--no-vertical-borders .fd-table__cell[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell{border-left-color:var(--sapList_BorderColor)}.fd-table--no-vertical-borders .fd-table__cell.is-first-child,.fd-table--no-vertical-borders .fd-table__cell:first-child,.fd-table__body--no-vertical-borders .fd-table__cell.is-first-child,.fd-table__body--no-vertical-borders .fd-table__cell:first-child,.fd-table__header--no-vertical-borders .fd-table__cell.is-first-child,.fd-table__header--no-vertical-borders .fd-table__cell:first-child{border-left-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table--no-vertical-borders .fd-table__cell:first-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell:first-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell.is-first-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell:first-child[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell:first-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell:first-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell.is-first-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell:first-child{border-left-style:none;border-right-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--no-vertical-borders .fd-table__cell:last-child,.fd-table__body--no-vertical-borders .fd-table__cell.is-last-child,.fd-table__body--no-vertical-borders .fd-table__cell:last-child,.fd-table__header--no-vertical-borders .fd-table__cell.is-last-child,.fd-table__header--no-vertical-borders .fd-table__cell:last-child{border-right-style:solid}.fd-table--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-vertical-borders .fd-table__cell:last-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table__body--no-vertical-borders .fd-table__cell:last-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell.is-last-child[dir=rtl],.fd-table__header--no-vertical-borders .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-vertical-borders .fd-table__cell:last-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table__body--no-vertical-borders .fd-table__cell:last-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell.is-last-child,[dir=rtl] .fd-table__header--no-vertical-borders .fd-table__cell:last-child{border-left-style:solid;border-right-style:none}.fd-table--no-horizontal-borders .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__cell{border-bottom-color:transparent}.fd-table--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table--no-horizontal-borders .fd-table__row:last-child .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table__body--no-horizontal-borders .fd-table__row:last-child .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__row.is-last-child .fd-table__cell,.fd-table__header--no-horizontal-borders .fd-table__row:last-child .fd-table__cell{border-bottom-color:var(--sapList_BorderColor)}.fd-table .fd-table__cell--no-vertical-border+.fd-table__cell{border-left-style:none}.fd-table .fd-table__cell--no-vertical-border[dir=rtl],[dir=rtl] .fd-table .fd-table__cell--no-vertical-border{border-right-style:none}.fd-table .fd-table__cell--no-horizontal-border{border-bottom-color:transparent}.fd-table--no-outer-border:not(.fd-table--top-border) .fd-table__header .fd-table__cell,.fd-table--responsive:not(.fd-table--top-border) .fd-table__header .fd-table__cell{border-top-color:transparent}.fd-table--no-outer-border .fd-table__body .fd-table__row.is-last-child .fd-table__cell,.fd-table--no-outer-border .fd-table__body .fd-table__row:last-child .fd-table__cell,.fd-table--responsive .fd-table__body .fd-table__row.is-last-child .fd-table__cell,.fd-table--responsive .fd-table__body .fd-table__row:last-child .fd-table__cell{border-bottom-color:transparent}.fd-table--no-outer-border .fd-table__cell.is-first-child,.fd-table--no-outer-border .fd-table__cell.is-last-child,.fd-table--no-outer-border .fd-table__cell:first-child,.fd-table--no-outer-border .fd-table__cell:last-child,.fd-table--responsive .fd-table__cell.is-first-child,.fd-table--responsive .fd-table__cell.is-last-child,.fd-table--responsive .fd-table__cell:first-child,.fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:solid}.fd-table--no-outer-border .fd-table__cell.is-first-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:first-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:last-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-first-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-last-child[dir=rtl],.fd-table--responsive .fd-table__cell:first-child[dir=rtl],.fd-table--responsive .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-first-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:first-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:last-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-first-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-last-child,[dir=rtl] .fd-table--responsive .fd-table__cell:first-child,[dir=rtl] .fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:none}.fd-table--no-outer-border .fd-table__cell.is-last-child,.fd-table--no-outer-border .fd-table__cell:last-child,.fd-table--responsive .fd-table__cell.is-last-child,.fd-table--responsive .fd-table__cell:last-child{border-left-style:solid;border-right-style:none}.fd-table--no-outer-border .fd-table__cell.is-last-child[dir=rtl],.fd-table--no-outer-border .fd-table__cell:last-child[dir=rtl],.fd-table--responsive .fd-table__cell.is-last-child[dir=rtl],.fd-table--responsive .fd-table__cell:last-child[dir=rtl],[dir=rtl] .fd-table--no-outer-border .fd-table__cell.is-last-child,[dir=rtl] .fd-table--no-outer-border .fd-table__cell:last-child,[dir=rtl] .fd-table--responsive .fd-table__cell.is-last-child,[dir=rtl] .fd-table--responsive .fd-table__cell:last-child{border-left-style:none;border-right-style:solid}.fd-table--no-outer-border.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--no-outer-border.fd-table--no-vertical-borders .fd-table__cell:last-child,.fd-table--responsive.fd-table--no-vertical-borders .fd-table__cell.is-last-child,.fd-table--responsive.fd-table--no-vertical-borders .fd-table__cell:last-child{border-left-style:none;border-right-style:none}.fd-table--group .fd-table__cell--group{background-color:var(--fdTable_Group_Header_Background);border-bottom-color:var(--sapList_TableGroupHeaderBorderColor);font-weight:var(--fdTable_Header_Cell_Font_Weight)}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"]{-webkit-padding-start:5rem;padding-inline-start:5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"]{-webkit-padding-start:5.5rem;padding-inline-start:5.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"]{-webkit-padding-start:6rem;padding-inline-start:6rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"]{-webkit-padding-start:6.5rem;padding-inline-start:6.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"]{-webkit-padding-start:7rem;padding-inline-start:7rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"]{-webkit-padding-start:7.5rem;padding-inline-start:7.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"]{-webkit-padding-start:8rem;padding-inline-start:8rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"]{-webkit-padding-start:8.5rem;padding-inline-start:8.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"]{-webkit-padding-start:9rem;padding-inline-start:9rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"]{-webkit-padding-start:9.5rem;padding-inline-start:9.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"]{-webkit-padding-start:10rem;padding-inline-start:10rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"]{-webkit-padding-start:10.5rem;padding-inline-start:10.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"]{-webkit-padding-start:11rem;padding-inline-start:11rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"]{-webkit-padding-start:11.5rem;padding-inline-start:11.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"]{-webkit-padding-start:12rem;padding-inline-start:12rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"]{-webkit-padding-start:12.5rem;padding-inline-start:12.5rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"]{-webkit-padding-start:13rem;padding-inline-start:13rem}.fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"]{-webkit-padding-start:13.5rem;padding-inline-start:13.5rem}.fd-table--group .fd-table__body .fd-table__cell--expand,.fd-table--tree .fd-table__body .fd-table__cell--expand{cursor:pointer;white-space:nowrap}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"]{-webkit-padding-start:0;padding-inline-start:0}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"]{-webkit-padding-start:1.5rem;padding-inline-start:1.5rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"]{-webkit-padding-start:2.25rem;padding-inline-start:2.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"]{-webkit-padding-start:3.25rem;padding-inline-start:3.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"]{-webkit-padding-start:3.75rem;padding-inline-start:3.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand{color:var(--sapContent_IconColor);display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;font-size:var(--sapFontSmallSize);height:var(--fdTable_Cell_Height);min-width:var(--fdTable_Header_Cell_Height);-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand:before{content:\"\\e066\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl]:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl]:before,[dir=rtl] .fd-table--group .fd-table__body .fd-table__cell .fd-table__expand:before,[dir=rtl] .fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand:before{content:\"\\e067\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl].fd-table__expand--open:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand[dir=rtl].fd-table__expand--open:before,[dir=rtl] .fd-table--group .fd-table__body .fd-table__cell .fd-table__expand.fd-table__expand--open:before,[dir=rtl] .fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand.fd-table__expand--open:before{content:\"\\e1e2\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table--group .fd-table__body .fd-table__cell .fd-table__expand--open:before,.fd-table--tree .fd-table__body .fd-table__cell .fd-table__expand--open:before{content:\"\\e1e2\";font-family:SAP-icons;text-align:center;text-decoration:inherit;text-rendering:optimizeLegibility;text-transform:none}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"1\"]{-webkit-padding-start:2rem;padding-inline-start:2rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"2\"]{-webkit-padding-start:3.5rem;padding-inline-start:3.5rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"3\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"4\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"5\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"6\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"7\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"8\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"9\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"10\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"11\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"12\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"13\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"14\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"15\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"16\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"17\"]{-webkit-padding-start:11.25rem;padding-inline-start:11.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"18\"]{-webkit-padding-start:11.75rem;padding-inline-start:11.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"19\"]{-webkit-padding-start:12.25rem;padding-inline-start:12.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell[data-nesting-level=\"20\"]{-webkit-padding-start:12.75rem;padding-inline-start:12.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"1\"]{-webkit-padding-start:0;padding-inline-start:0}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"2\"]{-webkit-padding-start:1.5rem;padding-inline-start:1.5rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"3\"]{-webkit-padding-start:2.25rem;padding-inline-start:2.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"4\"]{-webkit-padding-start:2.75rem;padding-inline-start:2.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"5\"]{-webkit-padding-start:3.25rem;padding-inline-start:3.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"6\"]{-webkit-padding-start:3.75rem;padding-inline-start:3.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"7\"]{-webkit-padding-start:4.25rem;padding-inline-start:4.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"8\"]{-webkit-padding-start:4.75rem;padding-inline-start:4.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"9\"]{-webkit-padding-start:5.25rem;padding-inline-start:5.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"10\"]{-webkit-padding-start:5.75rem;padding-inline-start:5.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"11\"]{-webkit-padding-start:6.25rem;padding-inline-start:6.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"12\"]{-webkit-padding-start:6.75rem;padding-inline-start:6.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"13\"]{-webkit-padding-start:7.25rem;padding-inline-start:7.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"14\"]{-webkit-padding-start:7.75rem;padding-inline-start:7.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"15\"]{-webkit-padding-start:8.25rem;padding-inline-start:8.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"16\"]{-webkit-padding-start:8.75rem;padding-inline-start:8.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"17\"]{-webkit-padding-start:9.25rem;padding-inline-start:9.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"18\"]{-webkit-padding-start:9.75rem;padding-inline-start:9.75rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"19\"]{-webkit-padding-start:10.25rem;padding-inline-start:10.25rem}.fd-table[class*=-compact].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-compact].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],.fd-table[class*=-condensed].fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-compact] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--group .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"],[class*=-condensed] .fd-table:not([class*=-cozy]).fd-table--tree .fd-table__body .fd-table__cell--expand[data-nesting-level=\"20\"]{-webkit-padding-start:10.75rem;padding-inline-start:10.75rem}.cdk-visually-hidden{border:0;clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;width:1px;white-space:nowrap;outline:0;-webkit-appearance:none;-moz-appearance:none;left:0}[dir=rtl] .cdk-visually-hidden{left:auto;right:0}.fd-table__popover--custom{width:100%}.fd-table__cell--checkbox .fd-checkbox__label{margin:0}.fd-table__cell--focusable[aria-selected=true]:after{border-color:var(--sapContent_FocusColor)!important}.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-hover,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive:active,.fd-table__header .fd-table__cell.fd-table__cell--non-interactive.is-active{background-color:var(--sapList_HeaderBackground);color:var(--sapList_HeaderTextColor)}\n/*! Bundled license information:\n\nfundamental-styles/dist/table.css:\n  (*!\n   * Fundamental Library Styles v0.40.1\n   * Copyright (c) 2025 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: TableService }, { type: i1.ContentDensityObserver }, { type: i0.DestroyRef }, { type: i0.NgZone }], propDecorators: { fdTableClass: [{
                type: HostBinding,
                args: ['class.fd-table']
            }], noBorderX: [{
                type: HostBinding,
                args: ['class.fd-table--no-horizontal-borders']
            }, {
                type: Input
            }], noBorderY: [{
                type: HostBinding,
                args: ['class.fd-table--no-vertical-borders']
            }, {
                type: Input
            }], noOuterBorder: [{
                type: HostBinding,
                args: ['class.fd-table--no-outer-border']
            }, {
                type: Input
            }], topBorder: [{
                type: HostBinding,
                args: ['class.fd-table--top-border']
            }, {
                type: Input
            }], popIn: [{
                type: HostBinding,
                args: ['class.fd-table--pop-in']
            }, {
                type: Input
            }], responsive: [{
                type: HostBinding,
                args: ['class.fd-table--responsive']
            }, {
                type: Input
            }], keys: [{
                type: Input
            }], allCellsFocusable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], _cells: [{
                type: ContentChildren,
                args: [TableCellDirective, { descendants: true }]
            }] } });

const components = [
    TableComponent,
    TableResponsiveWrapperDirective,
    TableWrapperComponent,
    TableHeaderDirective,
    TableFooterDirective,
    TableBodyDirective,
    TableRowDirective,
    TableCellDirective,
    TableStatusIndicatorDirective,
    TablePopoverDirective,
    TableInnerDirective,
    TableTextDirective,
    TableIconDirective,
    TableFixedDirective,
    TableContainerDirective
];
class TableModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "20.0.2", ngImport: i0, type: TableModule, imports: [TableComponent,
            TableResponsiveWrapperDirective,
            TableWrapperComponent,
            TableHeaderDirective,
            TableFooterDirective,
            TableBodyDirective,
            TableRowDirective,
            TableCellDirective,
            TableStatusIndicatorDirective,
            TablePopoverDirective,
            TableInnerDirective,
            TableTextDirective,
            TableIconDirective,
            TableFixedDirective,
            TableContainerDirective], exports: [TableComponent,
            TableResponsiveWrapperDirective,
            TableWrapperComponent,
            TableHeaderDirective,
            TableFooterDirective,
            TableBodyDirective,
            TableRowDirective,
            TableCellDirective,
            TableStatusIndicatorDirective,
            TablePopoverDirective,
            TableInnerDirective,
            TableTextDirective,
            TableIconDirective,
            TableFixedDirective,
            TableContainerDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableModule, providers: [TableService] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.0.2", ngImport: i0, type: TableModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...components],
                    exports: [...components],
                    providers: [TableService]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { FdTableContentDensityProviderParams, HIDDEN_CLASS_NAME, TableBodyDirective, TableCellDirective, TableComponent, TableContainerDirective, TableFixedDirective, TableFooterDirective, TableHeaderDirective, TableIconDirective, TableInnerDirective, TableModule, TablePopoverDirective, TableResponsiveWrapperDirective, TableRowDirective, TableService, TableStatusIndicatorDirective, TableTextDirective, TableWrapperComponent };
//# sourceMappingURL=fundamental-ngx-core-table.mjs.map
